# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'date'
require 'google/apis/core/base_service'
require 'google/apis/core/json_representation'
require 'google/apis/core/hashable'
require 'google/apis/errors'

module Google
  module Apis
    module ContentwarehouseV1
      
      # 
      class AbuseiamAbuseType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Optional client specific subtype of abuse that is too specific to belong in
        # the above enumeration. For example, some client may want to differentiate
        # nudity from graphic sex, but both are PORNOGRAPHY.
        # Corresponds to the JSON property `subtype`
        # @return [String]
        attr_accessor :subtype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @subtype = args[:subtype] if args.key?(:subtype)
        end
      end
      
      # 
      class AbuseiamAgeRestriction
        include Google::Apis::Core::Hashable
      
        # This restriction applies if the user is between [min_age_years, age_years)
        # years old.
        # Corresponds to the JSON property `ageYears`
        # @return [Fixnum]
        attr_accessor :age_years
      
        # 
        # Corresponds to the JSON property `minAgeYears`
        # @return [Fixnum]
        attr_accessor :min_age_years
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @age_years = args[:age_years] if args.key?(:age_years)
          @min_age_years = args[:min_age_years] if args.key?(:min_age_years)
        end
      end
      
      # 
      class AbuseiamAndRestriction
        include Google::Apis::Core::Hashable
      
        # This restriction applies if all of the children apply.
        # Corresponds to the JSON property `child`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction>]
        attr_accessor :child
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child = args[:child] if args.key?(:child)
        end
      end
      
      # A client is be a Google product, or subproduct that provides content for
      # AbuseIAm to classify.
      class AbuseiamClient
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The name of the subservice within a client. This subservice can be used to
        # affect the flow of decision script, or selection of backend classifiers. For
        # example, StreetView may want to specify a panel is insufficiently blurred (
        # maybe there is a lisense plate or public sex, etc), which requires manual
        # review then the subservice might be "blurring".
        # Corresponds to the JSON property `subservice`
        # @return [String]
        attr_accessor :subservice
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @subservice = args[:subservice] if args.key?(:subservice)
        end
      end
      
      # Extra information regarding evaluations received through cluster review.
      class AbuseiamClusterEvaluationContext
        include Google::Apis::Core::Hashable
      
        # The family of the cluster where the case received the evaluation.
        # Corresponds to the JSON property `clusterFamily`
        # @return [String]
        attr_accessor :cluster_family
      
        # The AbuseIAm rowkey of the cluster where the case received an evaluation.
        # Corresponds to the JSON property `clusterRowkey`
        # @return [String]
        attr_accessor :cluster_rowkey
      
        # The gaia id of a mail box that ops can send inquiries to for appeals. Used
        # only by user clusters to fill a required gatekeeper param. See
        # gaia_disableserver.DisableSpec.escalate_to field.
        # Corresponds to the JSON property `gaiaIdToEscalate`
        # @return [Fixnum]
        attr_accessor :gaia_id_to_escalate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_family = args[:cluster_family] if args.key?(:cluster_family)
          @cluster_rowkey = args[:cluster_rowkey] if args.key?(:cluster_rowkey)
          @gaia_id_to_escalate = args[:gaia_id_to_escalate] if args.key?(:gaia_id_to_escalate)
        end
      end
      
      # 
      class AbuseiamConstantRestriction
        include Google::Apis::Core::Hashable
      
        # A constant of type TRUE always applies, and of type FALSE never applies.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Pair of Verdicts used for ProjectR age/geo gating. See http://go/projectr for
      # more information.
      class AbuseiamContentRestriction
        include Google::Apis::Core::Hashable
      
        # Takedowns specified by admins via AbuseIAm
        # Corresponds to the JSON property `adminVerdict`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamVerdict>]
        attr_accessor :admin_verdict
      
        # User-specified takedowns
        # Corresponds to the JSON property `userVerdict`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamVerdict>]
        attr_accessor :user_verdict
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @admin_verdict = args[:admin_verdict] if args.key?(:admin_verdict)
          @user_verdict = args[:user_verdict] if args.key?(:user_verdict)
        end
      end
      
      # Backends return Evaluations to AbuseIAm. One of the things Evaluations are
      # used for is to explain Verdicts.
      class AbuseiamEvaluation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `abuseType`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamAbuseType]
        attr_accessor :abuse_type
      
        # Who creates this Evaluation. This field is required.
        # Corresponds to the JSON property `backend`
        # @return [String]
        attr_accessor :backend
      
        # Extra information regarding evaluations received through cluster review.
        # Corresponds to the JSON property `clusterEvaluationContext`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamClusterEvaluationContext]
        attr_accessor :cluster_evaluation_context
      
        # Backends can choose to put some debug info in addition to abuse_type, score,
        # and status.
        # Corresponds to the JSON property `comment`
        # @return [String]
        attr_accessor :comment
      
        # A set of repeated features to allow adapters to return semi structured data.
        # Please, prefer using feature instead of the old misc_data field since it
        # supports richer and more structured data to be passed back.
        # Corresponds to the JSON property `feature`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamFeature>]
        attr_accessor :feature
      
        # Relevant information for manual review evaluations.
        # Corresponds to the JSON property `manualReviewInfo`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamManualReviewEvaluationInfo]
        attr_accessor :manual_review_info
      
        # This field is used to store miscellaneous information that Backend might
        # provide. If you find youself here considering to use this field, please prefer
        # using the repeated feature field below instead. It supports a richer structure
        # for passing complex data back from the backend.
        # Corresponds to the JSON property `miscData`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamNameValuePair>]
        attr_accessor :misc_data
      
        # Time in milliseconds when the Backend processed this Evaluation.
        # Corresponds to the JSON property `processTimeMillisecs`
        # @return [Fixnum]
        attr_accessor :process_time_millisecs
      
        # When the evaluation was processed by the decision script.
        # Corresponds to the JSON property `processedMicros`
        # @return [Fixnum]
        attr_accessor :processed_micros
      
        # The list of regions where the evaluation applies.
        # Corresponds to the JSON property `region`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamRegion>]
        attr_accessor :region
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # 
        # Corresponds to the JSON property `target`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamTarget]
        attr_accessor :target
      
        # When the Evaluation was generated.
        # Corresponds to the JSON property `timestampMicros`
        # @return [Fixnum]
        attr_accessor :timestamp_micros
      
        # Describes restrictions on where the verdict applies. Please use `@code
        # TakedownManager` to evaluate this proto.
        # Corresponds to the JSON property `userRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction]
        attr_accessor :user_restriction
      
        # Version of Backend. For rules, this string is the only way to differentiate
        # between them.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        # Information about a video review.
        # Corresponds to the JSON property `videoReviewData`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamVideoReviewData]
        attr_accessor :video_review_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abuse_type = args[:abuse_type] if args.key?(:abuse_type)
          @backend = args[:backend] if args.key?(:backend)
          @cluster_evaluation_context = args[:cluster_evaluation_context] if args.key?(:cluster_evaluation_context)
          @comment = args[:comment] if args.key?(:comment)
          @feature = args[:feature] if args.key?(:feature)
          @manual_review_info = args[:manual_review_info] if args.key?(:manual_review_info)
          @misc_data = args[:misc_data] if args.key?(:misc_data)
          @process_time_millisecs = args[:process_time_millisecs] if args.key?(:process_time_millisecs)
          @processed_micros = args[:processed_micros] if args.key?(:processed_micros)
          @region = args[:region] if args.key?(:region)
          @score = args[:score] if args.key?(:score)
          @status = args[:status] if args.key?(:status)
          @target = args[:target] if args.key?(:target)
          @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros)
          @user_restriction = args[:user_restriction] if args.key?(:user_restriction)
          @version = args[:version] if args.key?(:version)
          @video_review_data = args[:video_review_data] if args.key?(:video_review_data)
        end
      end
      
      # 
      class AbuseiamFeature
        include Google::Apis::Core::Hashable
      
        # Exactly one of the following should be filled in.
        # Corresponds to the JSON property `booleanValue`
        # @return [Boolean]
        attr_accessor :boolean_value
        alias_method :boolean_value?, :boolean_value
      
        # 
        # Corresponds to the JSON property `doubleValue`
        # @return [Float]
        attr_accessor :double_value
      
        # Useful for applications that need to know how many times a specific feature
        # occurs
        # Corresponds to the JSON property `featureCount`
        # @return [Fixnum]
        attr_accessor :feature_count
      
        # Useful for timestamps, or for numerical features where it is helpful for
        # decision scripts to have exact values.
        # Corresponds to the JSON property `int64Value`
        # @return [Fixnum]
        attr_accessor :int64_value
      
        # integer value field is deprecated and shall only be used for passing the
        # following features hardcoded in spamiam::SpamIAmMessage: spamiam::
        # OrkutSenderId spamiam::OrkutPostnumReports spamiam::BloggerNumComments spamiam:
        # :BloggerNumCommentsByOthers Another hard-coded spamiam feature is spamiam::
        # BlogName, which can be specified via string value.
        # Corresponds to the JSON property `integerValue`
        # @return [Fixnum]
        attr_accessor :integer_value
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `stringValue`
        # @return [Array<String>]
        attr_accessor :string_value
      
        # This field should only be used to store a sequence of timestamps associated
        # with the feature.
        # Corresponds to the JSON property `timestampSequence`
        # @return [Array<Fixnum>]
        attr_accessor :timestamp_sequence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
          @double_value = args[:double_value] if args.key?(:double_value)
          @feature_count = args[:feature_count] if args.key?(:feature_count)
          @int64_value = args[:int64_value] if args.key?(:int64_value)
          @integer_value = args[:integer_value] if args.key?(:integer_value)
          @name = args[:name] if args.key?(:name)
          @string_value = args[:string_value] if args.key?(:string_value)
          @timestamp_sequence = args[:timestamp_sequence] if args.key?(:timestamp_sequence)
        end
      end
      
      # A node representing a table of regions and restrictions that apply to those
      # regions. This table understands region inclusion and knows to apply the most
      # specific rule, for example, a rule for France would override a rule for the EU
      # for a user in France.
      class AbuseiamGeoRestriction
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamGeoRestrictionLocale>]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # 
      class AbuseiamGeoRestrictionLocale
        include Google::Apis::Core::Hashable
      
        # The location where the restriction applies. Defaults to the "The world". See
        # go/iii.
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        # Describes restrictions on where the verdict applies. Please use `@code
        # TakedownManager` to evaluate this proto.
        # Corresponds to the JSON property `restriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction]
        attr_accessor :restriction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @location = args[:location] if args.key?(:location)
          @restriction = args[:restriction] if args.key?(:restriction)
        end
      end
      
      # Information about various hashes that can be computed on a message ex: simhash,
      # attachment hash, etc
      class AbuseiamHash
        include Google::Apis::Core::Hashable
      
        # 64 bit hash in the hex form.
        # Corresponds to the JSON property `hash`
        # @return [String]
        attr_accessor :hash_prop
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hash_prop = args[:hash_prop] if args.key?(:hash_prop)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Relevant information for manual review evaluations.
      class AbuseiamManualReviewEvaluationInfo
        include Google::Apis::Core::Hashable
      
        # Reviewer performing the manual review.
        # Corresponds to the JSON property `reviewer`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamManualReviewerInfo]
        attr_accessor :reviewer
      
        # Tool used to perform the manual review.
        # Corresponds to the JSON property `tool`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamManualReviewTool]
        attr_accessor :tool
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reviewer = args[:reviewer] if args.key?(:reviewer)
          @tool = args[:tool] if args.key?(:tool)
        end
      end
      
      # 
      class AbuseiamManualReviewTool
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `experimentId`
        # @return [String]
        attr_accessor :experiment_id
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experiment_id = args[:experiment_id] if args.key?(:experiment_id)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class AbuseiamManualReviewerInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `credential`
        # @return [Array<String>]
        attr_accessor :credential
      
        # 
        # Corresponds to the JSON property `username`
        # @return [String]
        attr_accessor :username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @credential = args[:credential] if args.key?(:credential)
          @username = args[:username] if args.key?(:username)
        end
      end
      
      # 
      class AbuseiamNameValuePair
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `nonUtf8Value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :non_utf8_value
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @non_utf8_value = args[:non_utf8_value] if args.key?(:non_utf8_value)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AbuseiamNotRestriction
        include Google::Apis::Core::Hashable
      
        # This restriction applies if the child does not apply. Only one is allowed. "
        # repeated" is used to avoid breaking Sawzall (See b/6758277).
        # Corresponds to the JSON property `child`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction>]
        attr_accessor :child
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child = args[:child] if args.key?(:child)
        end
      end
      
      # 
      class AbuseiamOrRestriction
        include Google::Apis::Core::Hashable
      
        # This restriction applies if any of the children apply.
        # Corresponds to the JSON property `child`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction>]
        attr_accessor :child
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child = args[:child] if args.key?(:child)
        end
      end
      
      # 
      class AbuseiamRegion
        include Google::Apis::Core::Hashable
      
        # This is a CLDR Region Code: http://wiki/Main/IIIHowTo#using_region It is used
        # to denote the region affected by a verdict.
        # Corresponds to the JSON property `region`
        # @return [String]
        attr_accessor :region
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @region = args[:region] if args.key?(:region)
        end
      end
      
      # A SpecialRestriction is a standardized UserRestriction which lives in a table
      # maintained via CDD.
      class AbuseiamSpecialRestriction
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AbuseiamTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A structure used to configure a notification to a user.
      class AbuseiamUserNotification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `channel`
        # @return [String]
        attr_accessor :channel
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel = args[:channel] if args.key?(:channel)
        end
      end
      
      # Describes restrictions on where the verdict applies. Please use `@code
      # TakedownManager` to evaluate this proto.
      class AbuseiamUserRestriction
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `ageRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamAgeRestriction]
        attr_accessor :age_restriction
      
        # Operators
        # Corresponds to the JSON property `andRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamAndRestriction]
        attr_accessor :and_restriction
      
        # Constant
        # Corresponds to the JSON property `constantRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamConstantRestriction]
        attr_accessor :constant_restriction
      
        # A node representing a table of regions and restrictions that apply to those
        # regions. This table understands region inclusion and knows to apply the most
        # specific rule, for example, a rule for France would override a rule for the EU
        # for a user in France.
        # Corresponds to the JSON property `geoRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamGeoRestriction]
        attr_accessor :geo_restriction
      
        # 
        # Corresponds to the JSON property `notRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamNotRestriction]
        attr_accessor :not_restriction
      
        # 
        # Corresponds to the JSON property `orRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamOrRestriction]
        attr_accessor :or_restriction
      
        # A SpecialRestriction is a standardized UserRestriction which lives in a table
        # maintained via CDD.
        # Corresponds to the JSON property `specialRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamSpecialRestriction]
        attr_accessor :special_restriction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @age_restriction = args[:age_restriction] if args.key?(:age_restriction)
          @and_restriction = args[:and_restriction] if args.key?(:and_restriction)
          @constant_restriction = args[:constant_restriction] if args.key?(:constant_restriction)
          @geo_restriction = args[:geo_restriction] if args.key?(:geo_restriction)
          @not_restriction = args[:not_restriction] if args.key?(:not_restriction)
          @or_restriction = args[:or_restriction] if args.key?(:or_restriction)
          @special_restriction = args[:special_restriction] if args.key?(:special_restriction)
        end
      end
      
      # Verdict against a target. AbuseIAm generates a verdict based on evaluations.
      # AbuseIAm can send such verdicts to clients for enforcement.
      class AbuseiamVerdict
        include Google::Apis::Core::Hashable
      
        # A client is be a Google product, or subproduct that provides content for
        # AbuseIAm to classify.
        # Corresponds to the JSON property `client`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamClient]
        attr_accessor :client
      
        # Additional info regarding the verdict.
        # Corresponds to the JSON property `comment`
        # @return [String]
        attr_accessor :comment
      
        # 
        # Corresponds to the JSON property `decision`
        # @return [String]
        attr_accessor :decision
      
        # Time duration (in minutes) of the verdict.
        # Corresponds to the JSON property `durationMins`
        # @return [Fixnum]
        attr_accessor :duration_mins
      
        # Evaluations relevant to this verdict. Every Verdict should contain at least
        # one Evaluation.
        # Corresponds to the JSON property `evaluation`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamEvaluation>]
        attr_accessor :evaluation
      
        # Details of all the hashes that can be computed on a message, such as simhash
        # and attachment hash
        # Corresponds to the JSON property `hashes`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamHash>]
        attr_accessor :hashes
      
        # Is this verdict issued by legal?
        # Corresponds to the JSON property `isLegalIssued`
        # @return [Boolean]
        attr_accessor :is_legal_issued
        alias_method :is_legal_issued?, :is_legal_issued
      
        # This field is used to pass relevant / necessary scores to our clients. For eg:
        # ASBE propogates these scores to moonshine.
        # Corresponds to the JSON property `miscScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamNameValuePair>]
        attr_accessor :misc_scores
      
        # A short description of the reason why the verdict decision is made.
        # Corresponds to the JSON property `reasonCode`
        # @return [String]
        attr_accessor :reason_code
      
        # The regions in which this verdict should be enforced. Absence of this field
        # indicates that the verdict is applicable everywhere.
        # Corresponds to the JSON property `region`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamRegion>]
        attr_accessor :region
      
        # Restrictions on where this verdict applies. If any restriction is met, the
        # verdict is applied there. If no restrictions are present, the verdict is
        # considered global.
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamVerdictRestriction>]
        attr_accessor :restriction
      
        # Category of the strike if this is a strike verdict.
        # Corresponds to the JSON property `strikeCategory`
        # @return [String]
        attr_accessor :strike_category
      
        # 
        # Corresponds to the JSON property `target`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamTarget]
        attr_accessor :target
      
        # The timestamp of the target. E.g., the time when the target was updated.
        # Corresponds to the JSON property `targetTimestampMicros`
        # @return [Fixnum]
        attr_accessor :target_timestamp_micros
      
        # When the verdict is generated
        # Corresponds to the JSON property `timestampMicros`
        # @return [Fixnum]
        attr_accessor :timestamp_micros
      
        # Extra notification(s) to be delivered to target user or message owner about
        # the verdict.
        # Corresponds to the JSON property `userNotification`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamUserNotification>]
        attr_accessor :user_notification
      
        # version of decision script
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client = args[:client] if args.key?(:client)
          @comment = args[:comment] if args.key?(:comment)
          @decision = args[:decision] if args.key?(:decision)
          @duration_mins = args[:duration_mins] if args.key?(:duration_mins)
          @evaluation = args[:evaluation] if args.key?(:evaluation)
          @hashes = args[:hashes] if args.key?(:hashes)
          @is_legal_issued = args[:is_legal_issued] if args.key?(:is_legal_issued)
          @misc_scores = args[:misc_scores] if args.key?(:misc_scores)
          @reason_code = args[:reason_code] if args.key?(:reason_code)
          @region = args[:region] if args.key?(:region)
          @restriction = args[:restriction] if args.key?(:restriction)
          @strike_category = args[:strike_category] if args.key?(:strike_category)
          @target = args[:target] if args.key?(:target)
          @target_timestamp_micros = args[:target_timestamp_micros] if args.key?(:target_timestamp_micros)
          @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros)
          @user_notification = args[:user_notification] if args.key?(:user_notification)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Describes restrictions on where the verdict applies.
      class AbuseiamVerdictRestriction
        include Google::Apis::Core::Hashable
      
        # For a restriction to apply, all contexts must be satisfied. For example, if
        # context[0] is COUNTRY/'GERMANY' and context[1] is DESTINATION_STREAM/'gplus:
        # SQUARE:knitting_discussion', then the verdict applies only when the 'knitting
        # discussion' square is viewed from inside Germany. Please note that this is
        # present for legacy reasons and users of this field would be migrated to use
        # the user_restriction field defined below.
        # Corresponds to the JSON property `context`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamVerdictRestrictionContext>]
        attr_accessor :context
      
        # Describes restrictions on where the verdict applies. Please use `@code
        # TakedownManager` to evaluate this proto.
        # Corresponds to the JSON property `userRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamUserRestriction]
        attr_accessor :user_restriction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @context = args[:context] if args.key?(:context)
          @user_restriction = args[:user_restriction] if args.key?(:user_restriction)
        end
      end
      
      # Describes a dimension of a context where a verdict applies.
      class AbuseiamVerdictRestrictionContext
        include Google::Apis::Core::Hashable
      
        # String identifying the context.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Information about a video review.
      class AbuseiamVideoReviewData
        include Google::Apis::Core::Hashable
      
        # Serialized repeated youtube_admin.adminmatch.csai.ReferenceFragment
        # Corresponds to the JSON property `referenceFragment`
        # @return [Array<String>]
        attr_accessor :reference_fragment
      
        # Information about video reviewers.
        # Corresponds to the JSON property `reviewer`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamVideoReviewer]
        attr_accessor :reviewer
      
        # The Viper id of the video.
        # Corresponds to the JSON property `videoId`
        # @return [String]
        attr_accessor :video_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reference_fragment = args[:reference_fragment] if args.key?(:reference_fragment)
          @reviewer = args[:reviewer] if args.key?(:reviewer)
          @video_id = args[:video_id] if args.key?(:video_id)
        end
      end
      
      # Information about video reviewers.
      class AbuseiamVideoReviewer
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The username of the person doing the video review.
        # Corresponds to the JSON property `username`
        # @return [String]
        attr_accessor :username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
          @username = args[:username] if args.key?(:username)
        end
      end
      
      # The serialized form of a SORI id. NOTE that this proto is stored in V4/O4
      # index and that new fields should not be added without getting an agreement
      # from the serving team as well.
      class AdsShoppingReportingOffersSerializedSoriId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `highId`
        # @return [Fixnum]
        attr_accessor :high_id
      
        # 
        # Corresponds to the JSON property `lowId1`
        # @return [Fixnum]
        attr_accessor :low_id1
      
        # 
        # Corresponds to the JSON property `lowId2`
        # @return [Fixnum]
        attr_accessor :low_id2
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @high_id = args[:high_id] if args.key?(:high_id)
          @low_id1 = args[:low_id1] if args.key?(:low_id1)
          @low_id2 = args[:low_id2] if args.key?(:low_id2)
        end
      end
      
      # 
      class Anchors
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchor`
        # @return [Array<Google::Apis::ContentwarehouseV1::AnchorsAnchor>]
        attr_accessor :anchor
      
        # The total # of local homepage anchors dropped in AnchorAccumulator.
        # Corresponds to the JSON property `homepageAnchorsDropped`
        # @return [Fixnum]
        attr_accessor :homepage_anchors_dropped
      
        # The index tier from which the anchors were extracted. Note that this is only
        # valid in the anchor record written by linkextractor. The value can be one of
        # the enum values defined in segindexer/types.h.
        # Corresponds to the JSON property `indexTier`
        # @return [Fixnum]
        attr_accessor :index_tier
      
        # The total # of local non-homepage anchors dropped in AnchorAccumulator.
        # Corresponds to the JSON property `localAnchorsDropped`
        # @return [Fixnum]
        attr_accessor :local_anchors_dropped
      
        # The total # of non-local anchors dropped in AnchorAccumulator.
        # Corresponds to the JSON property `nonlocalAnchorsDropped`
        # @return [Fixnum]
        attr_accessor :nonlocal_anchors_dropped
      
        # The *_anchors_dropped fields below are not populated by Alexandria, which uses
        # cdoc.anchor_stats instead. The total # of redundant anchors dropped in
        # linkextractor.
        # Corresponds to the JSON property `redundantAnchorsDropped`
        # @return [Fixnum]
        attr_accessor :redundant_anchors_dropped
      
        # 
        # Corresponds to the JSON property `redundantanchorinfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AnchorsRedundantAnchorInfo>]
        attr_accessor :redundantanchorinfo
      
        # The total # of supplemental anchors dropped in AnchorAccumulator. ##
        # DEPRECATED.
        # Corresponds to the JSON property `supplementalAnchorsDropped`
        # @return [Fixnum]
        attr_accessor :supplemental_anchors_dropped
      
        # may be implicit
        # Corresponds to the JSON property `targetDocid`
        # @return [Fixnum]
        attr_accessor :target_docid
      
        # HOST_LEVEL site chunking.
        # Corresponds to the JSON property `targetSite`
        # @return [String]
        attr_accessor :target_site
      
        # This is produced during link extraction but not written out in the linklogs in
        # order to save space.
        # Corresponds to the JSON property `targetUrl`
        # @return [String]
        attr_accessor :target_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor = args[:anchor] if args.key?(:anchor)
          @homepage_anchors_dropped = args[:homepage_anchors_dropped] if args.key?(:homepage_anchors_dropped)
          @index_tier = args[:index_tier] if args.key?(:index_tier)
          @local_anchors_dropped = args[:local_anchors_dropped] if args.key?(:local_anchors_dropped)
          @nonlocal_anchors_dropped = args[:nonlocal_anchors_dropped] if args.key?(:nonlocal_anchors_dropped)
          @redundant_anchors_dropped = args[:redundant_anchors_dropped] if args.key?(:redundant_anchors_dropped)
          @redundantanchorinfo = args[:redundantanchorinfo] if args.key?(:redundantanchorinfo)
          @supplemental_anchors_dropped = args[:supplemental_anchors_dropped] if args.key?(:supplemental_anchors_dropped)
          @target_docid = args[:target_docid] if args.key?(:target_docid)
          @target_site = args[:target_site] if args.key?(:target_site)
          @target_url = args[:target_url] if args.key?(:target_url)
        end
      end
      
      # 
      class AnchorsAnchor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `bucket`
        # @return [Fixnum]
        attr_accessor :bucket
      
        # CATfish tags attached to a link. These are similar to link tags, except the
        # values are created on the fly within Cookbook. See: http://sites/cookbook/
        # exporting/indexing
        # Corresponds to the JSON property `catfishTags`
        # @return [Array<Fixnum>]
        attr_accessor :catfish_tags
      
        # If the anchor contained images, these image urls are stored here in compressed
        # form.
        # Corresponds to the JSON property `compressedImageUrls`
        # @return [Array<String>]
        attr_accessor :compressed_image_urls
      
        # The anchor's original target url, compressed. Available only in Alexandria
        # docjoins when the anchor is forwarded.
        # Corresponds to the JSON property `compressedOriginalTargetUrl`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :compressed_original_target_url
      
        # 
        # Corresponds to the JSON property `context`
        # @return [Fixnum]
        attr_accessor :context
      
        # This is a hash of terms near the anchor. (This is a second-generation hash
        # replacing the value stored in the 'context' field.)
        # Corresponds to the JSON property `context2`
        # @return [Fixnum]
        attr_accessor :context2
      
        # used for history - the first and last time we have seen this anchor.
        # creation_date also used for Freshdocs Twitter indexing, a retweet is an anchor
        # of the original tweet. This field records the time when a retweet is created.
        # Corresponds to the JSON property `creationDate`
        # @return [Fixnum]
        attr_accessor :creation_date
      
        # 
        # Corresponds to the JSON property `deleted`
        # @return [Boolean]
        attr_accessor :deleted
        alias_method :deleted?, :deleted
      
        # 
        # Corresponds to the JSON property `deletionDate`
        # @return [Fixnum]
        attr_accessor :deletion_date
      
        # DEPRECATED
        # Corresponds to the JSON property `demotionreason`
        # @return [Fixnum]
        attr_accessor :demotionreason
      
        # Encoded data containing information about newsiness of anchor. Populated only
        # if anchor is classified as coming from a newsy, high quality site. Encoded
        # data for anchor sources are being stored in googledata/quality/freshness/
        # news_anchors/encoded_news_anchors_data.txt Scores are being computed with
        # quality/freshness/news_anchors/ routines.
        # Corresponds to the JSON property `encodedNewsAnchorData`
        # @return [Fixnum]
        attr_accessor :encoded_news_anchor_data
      
        # If true, the anchor is for experimental purposes and should not be used in
        # serving.
        # Corresponds to the JSON property `experimental`
        # @return [Boolean]
        attr_accessor :experimental
        alias_method :experimental?, :experimental
      
        # true iff exp domain
        # Corresponds to the JSON property `expired`
        # @return [Boolean]
        attr_accessor :expired
        alias_method :expired?, :expired
      
        # # days past Dec 31, 1994, 23:00:00 UTC (Unix time @788914800) that this link
        # was first seen. Should never occupy more than 15 bits. NOTE: this is NOT the
        # same as creation_date; firstseen_date is filled during link extraction
        # Corresponds to the JSON property `firstseenDate`
        # @return [Fixnum]
        attr_accessor :firstseen_date
      
        # true if we think 'firstseen_date' is an accurate estimate of when the link was
        # actually added to the source page. false if it may have existed for some time
        # before we saw it.
        # Corresponds to the JSON property `firstseenNearCreation`
        # @return [Boolean]
        attr_accessor :firstseen_near_creation
        alias_method :firstseen_near_creation?, :firstseen_near_creation
      
        # 
        # Corresponds to the JSON property `fontsize`
        # @return [Fixnum]
        attr_accessor :fontsize
      
        # How the anchor is forwarded to the canonical, available only for forwarded
        # anchors (i.e., the field is set). The forwarding types are defined in
        # URLForwardingUtil (segindexer/segment-indexer-util.h). Always use
        # URLForwardingUtil to access this field and use URLForwardingUtil::
        # GetAnchorForwardingReason to get the explanation how the anchor is forwarded
        # to the canonical. NOTE: Use with caution as it is only set for docjoins
        # generated using the urlmap from repository/updater.
        # Corresponds to the JSON property `forwardingTypes`
        # @return [Fixnum]
        attr_accessor :forwarding_types
      
        # The URL fragment for this anchor (the foo in http://www.google.com#foo)
        # Corresponds to the JSON property `fragment`
        # @return [String]
        attr_accessor :fragment
      
        # The full context. These are not written out in the linklogs.
        # Corresponds to the JSON property `fullLeftContext`
        # @return [Array<Fixnum>]
        attr_accessor :full_left_context
      
        # 
        # Corresponds to the JSON property `fullRightContext`
        # @return [Array<Fixnum>]
        attr_accessor :full_right_context
      
        # The bit ~roughly~ indicates whether an anchor's source and target pages are on
        # the same domain. Note: this plays no role in determining whether an anchor is
        # onsite, ondomain, or offdomain in mustang (i.e., the bit above).
        # Corresponds to the JSON property `isLocal`
        # @return [Boolean]
        attr_accessor :is_local
        alias_method :is_local?, :is_local
      
        # Used for history and freshness tracking - the timestamp this anchor is updated
        # in indexing.
        # Corresponds to the JSON property `lastUpdateTimestamp`
        # @return [Fixnum]
        attr_accessor :last_update_timestamp
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `linkAdditionalInfo`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :link_additional_info
      
        # Contains info on link type, source page, etc.
        # Corresponds to the JSON property `linkTags`
        # @return [Array<Fixnum>]
        attr_accessor :link_tags
      
        # For ranking purposes, the quality of an anchor is measured by its "locality"
        # and "bucket". See quality/anchors/definitions.h for more information.
        # Corresponds to the JSON property `locality`
        # @return [Fixnum]
        attr_accessor :locality
      
        # This is the offset for the first term in the anchor - it can be used as a
        # unique ID for the anchor within the document and compared against all per-tag
        # data. This is measured in bytes from the start of the document. We write this
        # out to the linklogs to recover the original order of links after source/target
        # forwarding. This is necessary for computing the global related data.
        # Corresponds to the JSON property `offset`
        # @return [Fixnum]
        attr_accessor :offset
      
        # Original text, including capitalization and punctuation. Runs of whitespace
        # are collapsed into a single space.
        # Corresponds to the JSON property `origText`
        # @return [String]
        attr_accessor :orig_text
      
        # The docid of the anchor's original target. This field is available if and only
        # if the anchor is forwarded.
        # Corresponds to the JSON property `originalTargetDocid`
        # @return [Fixnum]
        attr_accessor :original_target_docid
      
        # Weight to be stored in linkmaps for pageranker
        # Corresponds to the JSON property `pagerankWeight`
        # @return [Float]
        attr_accessor :pagerank_weight
      
        # The number of additional links from the same source page to the same target
        # domain. Not populated if is_local is true.
        # Corresponds to the JSON property `parallelLinks`
        # @return [Fixnum]
        attr_accessor :parallel_links
      
        # DEPRECATED. It used to be set if firstseen_date is not set. It's to indicate
        # that the anchor is possibly old, but we don't have enough information to tell
        # until the linkage map is updated. TODO(hxu) rename it to
        # possibly_old_firstseen_date_DEPRECATED after clean up other dependencies.
        # Corresponds to the JSON property `possiblyOldFirstseenDate`
        # @return [Boolean]
        attr_accessor :possibly_old_firstseen_date
        alias_method :possibly_old_firstseen_date?, :possibly_old_firstseen_date
      
        # TEMPORARY
        # Corresponds to the JSON property `setiPagerankWeight`
        # @return [Float]
        attr_accessor :seti_pagerank_weight
      
        # attributes of the source document for the link
        # Corresponds to the JSON property `source`
        # @return [Google::Apis::ContentwarehouseV1::AnchorsAnchorSource]
        attr_accessor :source
      
        # is to record the quality of the anchor's source page and is correlated with
        # but not identical to the index tier of the source page. In the docjoins built
        # by the indexing pipeline (Alexandria), - Anchors marked TYPE_HIGH_QUALITY are
        # from base documents. - Anchors marked TYPE_MEDIUM_QUALITY are from documents
        # of medium quality (roughly but not exactly supplemental tier documents). -
        # Anchors marked TYPE_LOW_QUALITY are from documents of low quality (roughly but
        # not exactly blackhole documents). Note that the source_type can also be used
        # as an importance indicator of an anchor (a lower source_type value indicates a
        # more important anchor), so it is important to enforce that TYPE_HIGH_QUALITY <
        # TYPE_MEDIUM_QUALITY < TYPE_LOW_QUALITY To add a new source type in future,
        # please maintain the proper relationship among the types as well.
        # TYPE_FRESHDOCS, only available in freshdocs indexing, is a special case and is
        # considered the same type as TYPE_HIGH_QUALITY for the purpose of anchor
        # importance in duplicate anchor removal.
        # Corresponds to the JSON property `sourceType`
        # @return [Fixnum]
        attr_accessor :source_type
      
        # A given target URL may be found in different encodings in different documents.
        # We store the URL encoding with each source anchor so that we can count them
        # later to find the encoding most likely to be expected by the Web site. Around
        # 0.7% of target URLs are expected to require a non-default value here. The
        # default value 0 is referenced in C++ as webutil::kDefaultUrlEncoding. See also
        # webutil/urlencoding.
        # Corresponds to the JSON property `targetUrlEncoding`
        # @return [Fixnum]
        attr_accessor :target_url_encoding
      
        # Space-delimited anchor words. Text that needs segmentation (like CJK or Thai)
        # is unsegmented, since we set FLAGS_segment_during_lexing to false in mr-
        # linkextractor.cc .
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # This field is DEPRECATED and no longer filled. For source page crawl timestamp,
        # use Source.crawl_timestamp. Next tag id should be 62.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # DEPRECATED: Now in link_tags
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        # weights are 0-127
        # Corresponds to the JSON property `weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bucket = args[:bucket] if args.key?(:bucket)
          @catfish_tags = args[:catfish_tags] if args.key?(:catfish_tags)
          @compressed_image_urls = args[:compressed_image_urls] if args.key?(:compressed_image_urls)
          @compressed_original_target_url = args[:compressed_original_target_url] if args.key?(:compressed_original_target_url)
          @context = args[:context] if args.key?(:context)
          @context2 = args[:context2] if args.key?(:context2)
          @creation_date = args[:creation_date] if args.key?(:creation_date)
          @deleted = args[:deleted] if args.key?(:deleted)
          @deletion_date = args[:deletion_date] if args.key?(:deletion_date)
          @demotionreason = args[:demotionreason] if args.key?(:demotionreason)
          @encoded_news_anchor_data = args[:encoded_news_anchor_data] if args.key?(:encoded_news_anchor_data)
          @experimental = args[:experimental] if args.key?(:experimental)
          @expired = args[:expired] if args.key?(:expired)
          @firstseen_date = args[:firstseen_date] if args.key?(:firstseen_date)
          @firstseen_near_creation = args[:firstseen_near_creation] if args.key?(:firstseen_near_creation)
          @fontsize = args[:fontsize] if args.key?(:fontsize)
          @forwarding_types = args[:forwarding_types] if args.key?(:forwarding_types)
          @fragment = args[:fragment] if args.key?(:fragment)
          @full_left_context = args[:full_left_context] if args.key?(:full_left_context)
          @full_right_context = args[:full_right_context] if args.key?(:full_right_context)
          @is_local = args[:is_local] if args.key?(:is_local)
          @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
          @link_additional_info = args[:link_additional_info] if args.key?(:link_additional_info)
          @link_tags = args[:link_tags] if args.key?(:link_tags)
          @locality = args[:locality] if args.key?(:locality)
          @offset = args[:offset] if args.key?(:offset)
          @orig_text = args[:orig_text] if args.key?(:orig_text)
          @original_target_docid = args[:original_target_docid] if args.key?(:original_target_docid)
          @pagerank_weight = args[:pagerank_weight] if args.key?(:pagerank_weight)
          @parallel_links = args[:parallel_links] if args.key?(:parallel_links)
          @possibly_old_firstseen_date = args[:possibly_old_firstseen_date] if args.key?(:possibly_old_firstseen_date)
          @seti_pagerank_weight = args[:seti_pagerank_weight] if args.key?(:seti_pagerank_weight)
          @source = args[:source] if args.key?(:source)
          @source_type = args[:source_type] if args.key?(:source_type)
          @target_url_encoding = args[:target_url_encoding] if args.key?(:target_url_encoding)
          @text = args[:text] if args.key?(:text)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @type = args[:type] if args.key?(:type)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # attributes of the source document for the link
      class AnchorsAnchorSource
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `additionalInfo`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :additional_info
      
        # anchor++ cluster id
        # Corresponds to the JSON property `cluster`
        # @return [Fixnum]
        attr_accessor :cluster
      
        # compressed source url
        # Corresponds to the JSON property `compressedUrl`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :compressed_url
      
        # Source page crawl timestamp.
        # Corresponds to the JSON property `crawlTimestamp`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp
      
        # The docid field used to be "required", but it is now "optional" because it is
        # not present when anchors are stored in webtable. When anchors are stored as
        # part of docjoin files in the segment indexer, however, docid should be
        # considered required.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # necessary for anything?
        # Corresponds to the JSON property `doclength`
        # @return [Fixnum]
        attr_accessor :doclength
      
        # Information about if the source page is a home page. It can be one of the enum
        # values defined in PerDocData::HomePageInfo (NOT_HOMEPAGE, NOT_TRUSTED,
        # PARTIALLY_TRUSTED, and FULLY_TRUSTED).
        # Corresponds to the JSON property `homePageInfo`
        # @return [Fixnum]
        attr_accessor :home_page_info
      
        # uint16 scale
        # Corresponds to the JSON property `indyrank`
        # @return [Fixnum]
        attr_accessor :indyrank
      
        # DEPRECATED, use packed_ipaddress
        # Corresponds to the JSON property `ipaddr`
        # @return [Fixnum]
        attr_accessor :ipaddr
      
        # default -> English
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # 0 -> no hash
        # Corresponds to the JSON property `linkhash`
        # @return [Fixnum]
        attr_accessor :linkhash
      
        # Countries to which the source page is local/most relevant; stored as III
        # identifiers for country/region codes (see http://go/iii).
        # Corresponds to the JSON property `localCountryCodes`
        # @return [Array<Fixnum>]
        attr_accessor :local_country_codes
      
        # This NSR value has range [0,1000] and is the original value [0.0,1.0]
        # multiplied by 1000 rounded to an integer.
        # Corresponds to the JSON property `nsr`
        # @return [Fixnum]
        attr_accessor :nsr
      
        # 
        # Corresponds to the JSON property `outdegree`
        # @return [Fixnum]
        attr_accessor :outdegree
      
        # approx num of pointed-to sites
        # Corresponds to the JSON property `outsites`
        # @return [Fixnum]
        attr_accessor :outsites
      
        # string in IPAddress::ToPackedString() format.
        # Corresponds to the JSON property `packedIpaddress`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :packed_ipaddress
      
        # Page tags are described by enum PageTag in PerDocData. Page tags are used in
        # anchors to identify properties of the linking page. These are DEPRECATED: in
        # the future, use link_tags instead. DEPRECATED
        # Corresponds to the JSON property `pageTags`
        # @return [Array<Fixnum>]
        attr_accessor :page_tags
      
        # uint16 scale
        # Corresponds to the JSON property `pagerank`
        # @return [Fixnum]
        attr_accessor :pagerank
      
        # unit16 scale
        # Corresponds to the JSON property `pagerankNs`
        # @return [Fixnum]
        attr_accessor :pagerank_ns
      
        # DEPRECATED
        # Corresponds to the JSON property `seglanguage`
        # @return [Fixnum]
        attr_accessor :seglanguage
      
        # 
        # Corresponds to the JSON property `site`
        # @return [String]
        attr_accessor :site
      
        # uint16 scale
        # Corresponds to the JSON property `spamrank`
        # @return [Fixnum]
        attr_accessor :spamrank
      
        # deprecated, to be removed after October 20. 0-127 scale
        # Corresponds to the JSON property `spamscore1`
        # @return [Fixnum]
        attr_accessor :spamscore1
      
        # 0-127 scale
        # Corresponds to the JSON property `spamscore2`
        # @return [Fixnum]
        attr_accessor :spamscore2
      
        # Webtable key of source
        # Corresponds to the JSON property `webtableKey`
        # @return [String]
        attr_accessor :webtable_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_info = args[:additional_info] if args.key?(:additional_info)
          @cluster = args[:cluster] if args.key?(:cluster)
          @compressed_url = args[:compressed_url] if args.key?(:compressed_url)
          @crawl_timestamp = args[:crawl_timestamp] if args.key?(:crawl_timestamp)
          @docid = args[:docid] if args.key?(:docid)
          @doclength = args[:doclength] if args.key?(:doclength)
          @home_page_info = args[:home_page_info] if args.key?(:home_page_info)
          @indyrank = args[:indyrank] if args.key?(:indyrank)
          @ipaddr = args[:ipaddr] if args.key?(:ipaddr)
          @language = args[:language] if args.key?(:language)
          @linkhash = args[:linkhash] if args.key?(:linkhash)
          @local_country_codes = args[:local_country_codes] if args.key?(:local_country_codes)
          @nsr = args[:nsr] if args.key?(:nsr)
          @outdegree = args[:outdegree] if args.key?(:outdegree)
          @outsites = args[:outsites] if args.key?(:outsites)
          @packed_ipaddress = args[:packed_ipaddress] if args.key?(:packed_ipaddress)
          @page_tags = args[:page_tags] if args.key?(:page_tags)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @pagerank_ns = args[:pagerank_ns] if args.key?(:pagerank_ns)
          @seglanguage = args[:seglanguage] if args.key?(:seglanguage)
          @site = args[:site] if args.key?(:site)
          @spamrank = args[:spamrank] if args.key?(:spamrank)
          @spamscore1 = args[:spamscore1] if args.key?(:spamscore1)
          @spamscore2 = args[:spamscore2] if args.key?(:spamscore2)
          @webtable_key = args[:webtable_key] if args.key?(:webtable_key)
        end
      end
      
      # NOTE: in docjoins, the following anchor sampling information is only ##
      # available in the first record of a document (under the same docid). The total
      # number of redundant anchors dropped per (domain, text) in linkextractor. If we
      # receive a large number of anchors from a particular domain, then we'll throw
      # out all but a sampling of them from that domain. The data is sorted by the (
      # domain,text) pairs. This field is not populated by Alexandria, which uses cdoc.
      # anchor_stats instead.
      class AnchorsRedundantAnchorInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchorsDropped`
        # @return [Fixnum]
        attr_accessor :anchors_dropped
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchors_dropped = args[:anchors_dropped] if args.key?(:anchors_dropped)
          @domain = args[:domain] if args.key?(:domain)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Represents a GSuite customer ID. Obfuscated with CustomerIdObfuscator.
      class AppsDynamiteCustomerId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `customerId`
        # @return [String]
        attr_accessor :customer_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @customer_id = args[:customer_id] if args.key?(:customer_id)
        end
      end
      
      # Contains info about the entity that something is, or is owned by.
      class AppsDynamiteSharedOrganizationInfo
        include Google::Apis::Core::Hashable
      
        # Intentionally empty. Used to disambiguate consumer and customer use cases in
        # oneof below.
        # Corresponds to the JSON property `consumerInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsDynamiteSharedOrganizationInfoConsumerInfo]
        attr_accessor :consumer_info
      
        # 
        # Corresponds to the JSON property `customerInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsDynamiteSharedOrganizationInfoCustomerInfo]
        attr_accessor :customer_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @consumer_info = args[:consumer_info] if args.key?(:consumer_info)
          @customer_info = args[:customer_info] if args.key?(:customer_info)
        end
      end
      
      # Intentionally empty. Used to disambiguate consumer and customer use cases in
      # oneof below.
      class AppsDynamiteSharedOrganizationInfoConsumerInfo
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AppsDynamiteSharedOrganizationInfoCustomerInfo
        include Google::Apis::Core::Hashable
      
        # Represents a GSuite customer ID. Obfuscated with CustomerIdObfuscator.
        # Corresponds to the JSON property `customerId`
        # @return [Google::Apis::ContentwarehouseV1::AppsDynamiteCustomerId]
        attr_accessor :customer_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @customer_id = args[:customer_id] if args.key?(:customer_id)
        end
      end
      
      # A DestinationStream is a /namespace/id[0]/id[1]/.../id[n] that represents a
      # collection of Activities. Example destinations: -The Profile Stream on http://
      # plus.google.com/+JohnDoe/posts -A Square Stream on http://plus.google.com/
      # squares/123 -A "comment Stream" (Fountain) on http://www.youtube.com/watch?id=
      # 123 It's possible for a single Activity to show in each of these destinations -
      # and it might behave/look slightly differently for each one. Destinations can
      # have their own business logic associated with them at both write-time and read-
      # time server-side (these are documented below). Each DestinationStream is
      # indexed and can be retrieved using the GetDestinationStreamRequest. For the
      # repeated ID space indexing happens at all levels, e.g. if you have: /square/
      # 123/abc /square/123/efd /square/456 You can fetch /square/123/abc directly or /
      # square/123 (which includes all Activities in both /square/123/abc and /square/
      # 123/efd), or even /square which retrieves all Activities in the Square
      # namespace (visible for that user). On the storage layer, we represent
      # DestinationStream as Channel (http://cs/#google3/social/common/channel/channel.
      # proto), since the storage does not have the concept of a Stream. Both terms
      # are used interchangeably within the service layer, but client of Social
      # Infrastructure should use the term DestinationStream. Next ID: 3
      class AppsPeopleActivityBackendDestinationStream
        include Google::Apis::Core::Hashable
      
        # The hierarchy of IDs. Each individual ID is "flat" and the repeated list
        # defines the hierarchy. Namespaces define the "validity" of this hierachy (
        # depth, naming convention, etc) and the server will reject invalid IDs.
        # Corresponds to the JSON property `id`
        # @return [Array<String>]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `namespace`
        # @return [String]
        attr_accessor :namespace
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @namespace = args[:namespace] if args.key?(:namespace)
        end
      end
      
      # Stores the number of different kind of user engagement actions. Abuse Report
      # is also consider an engagement. Currently we only have abuse report
      # engagements but in future we might add other types of engagements as well.
      class AppsPeopleActivityStreamqualityDistillerEngagements
        include Google::Apis::Core::Hashable
      
        # Corresponds on "This account might be compromised or hacked" reporting action.
        # Corresponds to the JSON property `reportCompromised`
        # @return [Fixnum]
        attr_accessor :report_compromised
      
        # Corresponds on "Harassment or bullying" reporting action.
        # Corresponds to the JSON property `reportHarassment`
        # @return [Fixnum]
        attr_accessor :report_harassment
      
        # Corresponds on "Hate speach or graphic violence" reporting action.
        # Corresponds to the JSON property `reportHate`
        # @return [Fixnum]
        attr_accessor :report_hate
      
        # Corresponds on "Pornography or sexually explicit material" reporting action.
        # Corresponds to the JSON property `reportPorn`
        # @return [Fixnum]
        attr_accessor :report_porn
      
        # Corresponds on "Unwanted commercial content or spam" reporting action.
        # Corresponds to the JSON property `reportSpam`
        # @return [Fixnum]
        attr_accessor :report_spam
      
        # Number of times this activity was served out of asbe/stanza.
        # Corresponds to the JSON property `serveCount`
        # @return [Fixnum]
        attr_accessor :serve_count
      
        # Timestamp in seconds for which time this record is valid.
        # Corresponds to the JSON property `timeSec`
        # @return [Fixnum]
        attr_accessor :time_sec
      
        # Corresponds on Distiller comment thumbs down action.
        # Corresponds to the JSON property `ytThumbsDown`
        # @return [Fixnum]
        attr_accessor :yt_thumbs_down
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @report_compromised = args[:report_compromised] if args.key?(:report_compromised)
          @report_harassment = args[:report_harassment] if args.key?(:report_harassment)
          @report_hate = args[:report_hate] if args.key?(:report_hate)
          @report_porn = args[:report_porn] if args.key?(:report_porn)
          @report_spam = args[:report_spam] if args.key?(:report_spam)
          @serve_count = args[:serve_count] if args.key?(:serve_count)
          @time_sec = args[:time_sec] if args.key?(:time_sec)
          @yt_thumbs_down = args[:yt_thumbs_down] if args.key?(:yt_thumbs_down)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiAbout
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # IMPORTANT: It is unsafe to accept this message from an untrusted source, since
        # it's trivial for an attacker to forge serialized messages that don't fulfill
        # the type's safety contract -- for example, it could contain attacker
        # controlled script. A system which receives a SafeHtmlProto implicitly trusts
        # the producer of the SafeHtmlProto. So, it's generally safe to return this
        # message in RPC responses, but generally unsafe to accept it in RPC requests.
        # Corresponds to the JSON property `safeHtmlValue`
        # @return [Google::Apis::ContentwarehouseV1::WebutilHtmlTypesSafeHtmlProto]
        attr_accessor :safe_html_value
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_type = args[:content_type] if args.key?(:content_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @safe_html_value = args[:safe_html_value] if args.key?(:safe_html_value)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Extension data for use in AboutMe.
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedData
        include Google::Apis::Core::Hashable
      
        # See NameDisplayOptions in //depot/google3/focus/backend/proto/backend.proto.
        # See also go/nickname-mess.
        # Corresponds to the JSON property `nameDisplayOptions`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataNameDisplayOptions]
        attr_accessor :name_display_options
      
        # 
        # Corresponds to the JSON property `photosCompareData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataPhotosCompareData]
        attr_accessor :photos_compare_data
      
        # See UserEditedLockedMask in //depot/google3/focus/backend/proto/backend.proto.
        # Corresponds to the JSON property `profileEditability`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataProfileEditability]
        attr_accessor :profile_editability
      
        # See ABUSE_NAME_LAST_MODIFIED in //depot/google3/focus/backend/proto/backend.
        # proto which maps to //depot/google3/focus/proto/profileattribute.proto
        # Corresponds to the JSON property `profileNameModificationHistory`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataProfileNameModificationHistory]
        attr_accessor :profile_name_modification_history
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name_display_options = args[:name_display_options] if args.key?(:name_display_options)
          @photos_compare_data = args[:photos_compare_data] if args.key?(:photos_compare_data)
          @profile_editability = args[:profile_editability] if args.key?(:profile_editability)
          @profile_name_modification_history = args[:profile_name_modification_history] if args.key?(:profile_name_modification_history)
        end
      end
      
      # See NameDisplayOptions in //depot/google3/focus/backend/proto/backend.proto.
      # See also go/nickname-mess.
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataNameDisplayOptions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `nicknameOption`
        # @return [String]
        attr_accessor :nickname_option
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @nickname_option = args[:nickname_option] if args.key?(:nickname_option)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataPhotosCompareData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `diffData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataPhotosCompareDataDiffData]
        attr_accessor :diff_data
      
        # 
        # Corresponds to the JSON property `highResUrl`
        # @return [String]
        attr_accessor :high_res_url
      
        # True if photo diff is greater than 0.01 on any color band, or if the user has
        # a low res photo but no high res photo. This field is primarily for use in
        # About Me and for other uses it's recommended to use the DiffData values
        # directly instead. The cutoff is based on a heuristic determined in go/
        # comparing-profile-photos
        # Corresponds to the JSON property `inconsistentPhoto`
        # @return [Boolean]
        attr_accessor :inconsistent_photo
        alias_method :inconsistent_photo?, :inconsistent_photo
      
        # Only present if the photo diff is greater than 0.01 on any color band.
        # Corresponds to the JSON property `lowResData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :low_res_data
      
        # 
        # Corresponds to the JSON property `lowResUrl`
        # @return [String]
        attr_accessor :low_res_url
      
        # 
        # Corresponds to the JSON property `monogramUrl`
        # @return [String]
        attr_accessor :monogram_url
      
        # True if the low-res photo has a private ACL set.
        # Corresponds to the JSON property `privateLowResAcl`
        # @return [Boolean]
        attr_accessor :private_low_res_acl
        alias_method :private_low_res_acl?, :private_low_res_acl
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @diff_data = args[:diff_data] if args.key?(:diff_data)
          @high_res_url = args[:high_res_url] if args.key?(:high_res_url)
          @inconsistent_photo = args[:inconsistent_photo] if args.key?(:inconsistent_photo)
          @low_res_data = args[:low_res_data] if args.key?(:low_res_data)
          @low_res_url = args[:low_res_url] if args.key?(:low_res_url)
          @monogram_url = args[:monogram_url] if args.key?(:monogram_url)
          @private_low_res_acl = args[:private_low_res_acl] if args.key?(:private_low_res_acl)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataPhotosCompareDataDiffData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `blueDiff`
        # @return [Float]
        attr_accessor :blue_diff
      
        # 
        # Corresponds to the JSON property `greenDiff`
        # @return [Float]
        attr_accessor :green_diff
      
        # 
        # Corresponds to the JSON property `redDiff`
        # @return [Float]
        attr_accessor :red_diff
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blue_diff = args[:blue_diff] if args.key?(:blue_diff)
          @green_diff = args[:green_diff] if args.key?(:green_diff)
          @red_diff = args[:red_diff] if args.key?(:red_diff)
        end
      end
      
      # See UserEditedLockedMask in //depot/google3/focus/backend/proto/backend.proto.
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataProfileEditability
        include Google::Apis::Core::Hashable
      
        # Read-only set of zero or more field paths that are locked for update on this
        # person, such as "person.name", "person.email", etc. The set of fields is only
        # populated for the requester's profile. Fields in the set cannot be edited,
        # added, or deleted from the profile. Attempting to update any of these fields
        # will result in an exception.
        # Corresponds to the JSON property `lockedField`
        # @return [Array<String>]
        attr_accessor :locked_field
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locked_field = args[:locked_field] if args.key?(:locked_field)
        end
      end
      
      # See ABUSE_NAME_LAST_MODIFIED in //depot/google3/focus/backend/proto/backend.
      # proto which maps to //depot/google3/focus/proto/profileattribute.proto
      class AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedDataProfileNameModificationHistory
        include Google::Apis::Core::Hashable
      
        # The number of name changes remaining at RPC request time. This can be more
        # than name_changes_remaining, if user hasn't changed name for some time and
        # accrued quota since last change.
        # Corresponds to the JSON property `computedNameChangesRemaining`
        # @return [Fixnum]
        attr_accessor :computed_name_changes_remaining
      
        # The number of nickname changes remaining at RPC request time. This can be more
        # than nickname_changes_remaining, if user hasn't changed nickname for some time
        # and accrued quota since last change.
        # Corresponds to the JSON property `computedNicknameChangesRemaining`
        # @return [Fixnum]
        attr_accessor :computed_nickname_changes_remaining
      
        # The number of name changes remaining at the time the name was last modified.
        # Corresponds to the JSON property `nameChangesRemaining`
        # @return [Fixnum]
        attr_accessor :name_changes_remaining
      
        # The last time the profile name was modified in milliseconds UTC.
        # Corresponds to the JSON property `nameLastModified`
        # @return [Fixnum]
        attr_accessor :name_last_modified
      
        # The number of nickname changes remaining at the time the nickname was last
        # modified.
        # Corresponds to the JSON property `nicknameChangesRemaining`
        # @return [Fixnum]
        attr_accessor :nickname_changes_remaining
      
        # The last time the profile nickname was modified in milliseconds UTC.
        # Corresponds to the JSON property `nicknameLastModified`
        # @return [Fixnum]
        attr_accessor :nickname_last_modified
      
        # 
        # Corresponds to the JSON property `quotaEnforcementStatus`
        # @return [String]
        attr_accessor :quota_enforcement_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @computed_name_changes_remaining = args[:computed_name_changes_remaining] if args.key?(:computed_name_changes_remaining)
          @computed_nickname_changes_remaining = args[:computed_nickname_changes_remaining] if args.key?(:computed_nickname_changes_remaining)
          @name_changes_remaining = args[:name_changes_remaining] if args.key?(:name_changes_remaining)
          @name_last_modified = args[:name_last_modified] if args.key?(:name_last_modified)
          @nickname_changes_remaining = args[:nickname_changes_remaining] if args.key?(:nickname_changes_remaining)
          @nickname_last_modified = args[:nickname_last_modified] if args.key?(:nickname_last_modified)
          @quota_enforcement_status = args[:quota_enforcement_status] if args.key?(:quota_enforcement_status)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiAccountEmail
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
        end
      end
      
      # Additional information about a container. TO BE DELETED: replaced by
      # DeviceContactInfo.
      class AppsPeopleOzExternalMergedpeopleapiAdditionalContainerInfo
        include Google::Apis::Core::Hashable
      
        # When the container is a DEVICE_CONTACT, this list provides account information
        # from the raw contact which is the source of this field.
        # Corresponds to the JSON property `rawDeviceContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRawDeviceContactInfo>]
        attr_accessor :raw_device_contact_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_device_contact_info = args[:raw_device_contact_info] if args.key?(:raw_device_contact_info)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiAddress
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # FeatureId associated with the address. The format is the same as that used for
        # ids in PLACE containers in SourceIdentity.
        # Corresponds to the JSON property `encodedPlaceId`
        # @return [String]
        attr_accessor :encoded_place_id
      
        # 
        # Corresponds to the JSON property `extendedAddress`
        # @return [String]
        attr_accessor :extended_address
      
        # 
        # Corresponds to the JSON property `formatted`
        # @return [String]
        attr_accessor :formatted
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # 
        # Corresponds to the JSON property `locality`
        # @return [String]
        attr_accessor :locality
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `poBox`
        # @return [String]
        attr_accessor :po_box
      
        # Map marker location for an address.
        # Corresponds to the JSON property `pointSpec`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPointSpec]
        attr_accessor :point_spec
      
        # 
        # Corresponds to the JSON property `postalCode`
        # @return [String]
        attr_accessor :postal_code
      
        # 
        # Corresponds to the JSON property `region`
        # @return [String]
        attr_accessor :region
      
        # 
        # Corresponds to the JSON property `streetAddress`
        # @return [String]
        attr_accessor :street_address
      
        # The type of the address. The type can be free form or one of these predefined
        # values: * `home` * `work` * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country = args[:country] if args.key?(:country)
          @country_code = args[:country_code] if args.key?(:country_code)
          @encoded_place_id = args[:encoded_place_id] if args.key?(:encoded_place_id)
          @extended_address = args[:extended_address] if args.key?(:extended_address)
          @formatted = args[:formatted] if args.key?(:formatted)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @locality = args[:locality] if args.key?(:locality)
          @metadata = args[:metadata] if args.key?(:metadata)
          @po_box = args[:po_box] if args.key?(:po_box)
          @point_spec = args[:point_spec] if args.key?(:point_spec)
          @postal_code = args[:postal_code] if args.key?(:postal_code)
          @region = args[:region] if args.key?(:region)
          @street_address = args[:street_address] if args.key?(:street_address)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Similar to social.graph.storage.Affinity, but pared down to what the clients
      # of the People API are interested in.
      class AppsPeopleOzExternalMergedpeopleapiAffinity
        include Google::Apis::Core::Hashable
      
        # Extra ranking info returned with affinity data. This info is returned by DAS
        # and passed to PAPI clients (Yenta), where it is used for ranking and filtering
        # device and server suggestions together.
        # Corresponds to the JSON property `affinityMetadata`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiAffinityMetadata]
        attr_accessor :affinity_metadata
      
        # 
        # Corresponds to the JSON property `affinityType`
        # @return [String]
        attr_accessor :affinity_type
      
        # The ID of the container
        # Corresponds to the JSON property `containerId`
        # @return [String]
        attr_accessor :container_id
      
        # The type of container to which this affinity applies
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # Used to log events for this affinity value, for disco diagnostic-purposes. See
        # go/disco-diagnostics.
        # Corresponds to the JSON property `loggingId`
        # @return [String]
        attr_accessor :logging_id
      
        # Affinity value. Frequently represented as an inverse ranking, sometimes with
        # additional data encoded. If data_formats.affinity_formats.score_format is set
        # to RAW_SCORE then the value will be the score returned by DAS.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @affinity_metadata = args[:affinity_metadata] if args.key?(:affinity_metadata)
          @affinity_type = args[:affinity_type] if args.key?(:affinity_type)
          @container_id = args[:container_id] if args.key?(:container_id)
          @container_type = args[:container_type] if args.key?(:container_type)
          @logging_id = args[:logging_id] if args.key?(:logging_id)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Please read go/people-api-howto:age on how to get age data. Message for the `
      # Person.age_range_repeated` field. Replaces the existing `Person.age_range`
      # field.
      class AppsPeopleOzExternalMergedpeopleapiAgeRangeType
        include Google::Apis::Core::Hashable
      
        # Please read go/people-api-howto:age on how to get age data. Age of the user.
        # The field is set based on profile storage fields such as account birthday. If
        # the source fields are not present, `age_in_years` will be left unset.
        # Corresponds to the JSON property `ageInYears`
        # @return [Fixnum]
        attr_accessor :age_in_years
      
        # Deprecated. Use go/supervised-accounts#capabilities-for-child-accounts instead.
        # Denotes whether the user is under the region based Age of Consent. The user's
        # region is based on ClientUserInfo.GlobalTos.AgreedLocation The age is inferred
        # from Birthday field or CertifiedBornBefore field. The region based AoC is
        # specified at go/aoc.
        # Corresponds to the JSON property `ageOfConsentStatus`
        # @return [String]
        attr_accessor :age_of_consent_status
      
        # Deprecated. Please read go/people-api-howto:age on how to get age data. Age
        # range is populated based on `account_birthday` and `certified_born_before`,
        # which may not be set for dasher users.
        # Corresponds to the JSON property `ageRange`
        # @return [String]
        attr_accessor :age_range
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @age_in_years = args[:age_in_years] if args.key?(:age_in_years)
          @age_of_consent_status = args[:age_of_consent_status] if args.key?(:age_of_consent_status)
          @age_range = args[:age_range] if args.key?(:age_range)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Store all app unique info that are needed for app action fulfillment.
      class AppsPeopleOzExternalMergedpeopleapiAppUniqueInfo
        include Google::Apis::Core::Hashable
      
        # Store the app unique id endpoint. This will be passed over to app to fulfill
        # the action. For example, app_unique_id for Whatsapp will be "11234567890@s.
        # whatsapp.net"
        # Corresponds to the JSON property `appUniqueId`
        # @return [String]
        attr_accessor :app_unique_id
      
        # Store third party endpoint that is displayed to users. For example,
        # display_app_unique_id for Whatsapp will be "Message +11234567890".
        # Corresponds to the JSON property `displayAppUniqueId`
        # @return [String]
        attr_accessor :display_app_unique_id
      
        # Store third party endpoint label. For example, "HOME", "WORK"
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # Store mimetype of this endpoint. We will use this as the differentiator for
        # Assistant to know whether to use the RawContact for messaging, call or video
        # call. For example, send message mimetype for whatsapp: "vnd.android.cursor.
        # item/vnd.com.whatsapp.profile" voice call mimetype for whatsapp: "vnd.android.
        # cursor.item/vnd.com.whatsapp.voip.call"
        # Corresponds to the JSON property `mimetype`
        # @return [String]
        attr_accessor :mimetype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_unique_id = args[:app_unique_id] if args.key?(:app_unique_id)
          @display_app_unique_id = args[:display_app_unique_id] if args.key?(:display_app_unique_id)
          @label = args[:label] if args.key?(:label)
          @mimetype = args[:mimetype] if args.key?(:mimetype)
        end
      end
      
      # The best suggested name to use for the Person from the available source fields,
      # which may include FileAs, Name, Org, Email, IM, Phone, ... Rough source
      # container priority order is Contact, then Profile, then Place.
      class AppsPeopleOzExternalMergedpeopleapiBestDisplayName
        include Google::Apis::Core::Hashable
      
        # The container the suggested name was sourced from
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # The display name. This name is intended to be the best name to display for
        # this Person. It may be built from a variety of fields, even if those fields
        # are not explicitly requested in the request mask. Generally, the display name
        # is formatted in 'first last' format. If the name appears to be a CJK name (as
        # determined by a heuristic), the 'last first' format will be used. There may be
        # other cases that the 'last first' format is used which are not documented here.
        # See the code at: http://google3/java/com/google/focus/backend/client/
        # DisplayNameFormatter.java?l=659&rcl=351360938
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # The display name, always in 'last first' format. This field does not depend on
        # the format of `display_name` and will always be in 'last first' format.
        # Corresponds to the JSON property `displayNameLastFirst`
        # @return [String]
        attr_accessor :display_name_last_first
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @container_type = args[:container_type] if args.key?(:container_type)
          @display_name = args[:display_name] if args.key?(:display_name)
          @display_name_last_first = args[:display_name_last_first] if args.key?(:display_name_last_first)
        end
      end
      
      # IMPORTANT NOTES: - Requesting person.birthday requires membership in the
      # purpose limited data ACL group sgbe-ac-d-birthday-(read|mutate). Contact
      # people-api-eng@ for assistance with initial setup. - The birthday field should
      # not be used to calculate the requester's age! To determine the requester's age,
      # use person.age_range_repeated. - For more details about age see go/peopleapi-
      # howto/age Birthday value may not be present: - Consumer users generally
      # required to have account birthday set (required at account creation), though
      # some users created via legacy flows may not have birthday present. - Dasher
      # users generally don't require birthday, but could optionally have it set by
      # users. - Any other types of accounts (e.g. robot, service) do not have
      # birthdays. - Account Birthday field may be present but without birthday value
      # set for grace period birthday (provisional new birthday). For users that do
      # have birthday data: - "Profile Birthday" (person.birthday.metadata.container
      # is PROFILE) may not have a year set if user "hides" the year. - "Account
      # Birthday" (see api-specific notes below) will only be returned for the
      # requester's own profile. - People API (go/peopleapi): * Account birthday is
      # only supported in GetPeople for PeopleAPI. * If account birthday is needed,
      # use a request mask with: `include_field ` paths: "person.birthday" `` `
      # include_container: ACCOUNT` - People API++ (go/peopleapi++): * Account
      # birthday is supported for most apis in PeopleAPI++. * If account birthday is
      # needed, use a request mask with: `include_field ` paths: "person.
      # account_birthday" `` `include_container: PROFILE` (note: it will also need `
      # include_container: DOMAIN_PROFILE` because they must be requested together: go/
      # people-api-masks#profile-domain_profile) - See go/papi-vs-papi++#birthday for
      # more details.
      class AppsPeopleOzExternalMergedpeopleapiBirthday
        include Google::Apis::Core::Hashable
      
        # Whether this field is set or not determines whether an account is in the grace
        # period. While in the grace period, the user is unable to change their birthday
        # on their own, and will be age-disabled if they don't act in a limited amount
        # of time. Applies only to ServiceData Birthday. Users enter the grace period if
        # they choose a birthday below the Age of Consent (go/aoc). After the grace
        # period ends, the account will be age disabled. See go/age-disable-grace-period-
        # dd.
        # Corresponds to the JSON property `ageDisableGracePeriod`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiBirthdayAgeDisableGracePeriod]
        attr_accessor :age_disable_grace_period
      
        # Whether the user has opted in to display their birthday via photo decorations.
        # Corresponds to the JSON property `birthdayDecoration`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoBirthdayDecoration]
        attr_accessor :birthday_decoration
      
        # 
        # Corresponds to the JSON property `birthdayResolution`
        # @return [String]
        attr_accessor :birthday_resolution
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `calendarDay`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :calendar_day
      
        # Birthdays are currently represented as timestamp values, although the
        # interpretation of these timestamp values is a calendar date. Clients are
        # recommended to read the calendar_day field, which is easier to work with than
        # date_ms. New clients writing to PeopleApi must set calendar_day instead of
        # date_ms. There are a few important details about how this value should be
        # mapped to a calendar date that should be consistent among all clients. 1.
        # Epoch - The epoch or calendar date equivalent to 0 ms is chosen to be 1970-01-
        # 01 UTC. 2. Timezone - All of the conversions to calendars should occur in the
        # UTC timezone. We don't typically think of someones birthday changing when they
        # travel, so clients should not use local times. 3. Calendar - The calendar used
        # for the dates should be a Gregorian proleptic calendar. Proleptic means that
        # the rules of the Gregorian calendar are retrofitted to before its adoption. It
        # is easy to get this wrong, particularly with the java GregorianCalendar class,
        # which by default is a mixed Gregorian/Julian calendar. Joda Time makes this
        # easy, but if it's not an option, look into GregorianCalendar.
        # setGregorianChange(). 4. Omitted years - Clients have chosen to represent
        # birthdays or events without years as timestamps within the year zero. When the
        # computed date has a year of 0, it means the client did not specify a year.
        # Note that a year 0 does not exist in a chronology like the familiar Anno
        # Domini (A.D. and B.C.); clients must agree on year numbering. 5. Year
        # Numbering - The chronology used to map dates to the calendar should use
        # Astronomical Year Numbering so that the year 0 is defined and dates before it
        # have a negative year. If libraries only provide Anno Domini, then the year of
        # 1 BC corresponds to year zero and an omitted user provided year. Other BC
        # values are presumed rare, but clients should still not ignore the era and
        # interpret the year as an A.D. value, especially if writing values back to
        # PeopleApi.
        # Corresponds to the JSON property `dateMs`
        # @return [Fixnum]
        attr_accessor :date_ms
      
        # date_ms_as_number contains the same data as date_ms, but has a different type
        # in generated javascript bindings. Non javascript clients can ignore it.
        # Corresponds to the JSON property `dateMsAsNumber`
        # @return [Fixnum]
        attr_accessor :date_ms_as_number
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Actual value entered. Allows unstructured values.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @age_disable_grace_period = args[:age_disable_grace_period] if args.key?(:age_disable_grace_period)
          @birthday_decoration = args[:birthday_decoration] if args.key?(:birthday_decoration)
          @birthday_resolution = args[:birthday_resolution] if args.key?(:birthday_resolution)
          @calendar_day = args[:calendar_day] if args.key?(:calendar_day)
          @date_ms = args[:date_ms] if args.key?(:date_ms)
          @date_ms_as_number = args[:date_ms_as_number] if args.key?(:date_ms_as_number)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Whether this field is set or not determines whether an account is in the grace
      # period. While in the grace period, the user is unable to change their birthday
      # on their own, and will be age-disabled if they don't act in a limited amount
      # of time. Applies only to ServiceData Birthday. Users enter the grace period if
      # they choose a birthday below the Age of Consent (go/aoc). After the grace
      # period ends, the account will be age disabled. See go/age-disable-grace-period-
      # dd.
      class AppsPeopleOzExternalMergedpeopleapiBirthdayAgeDisableGracePeriod
        include Google::Apis::Core::Hashable
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `calendarDay`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :calendar_day
      
        # Timestamp which signifies the end of the grace period for this account.
        # Corresponds to the JSON property `gracePeriodEnd`
        # @return [String]
        attr_accessor :grace_period_end
      
        # Timestamp which signifies the start of the grace period for this account.
        # Corresponds to the JSON property `gracePeriodStart`
        # @return [String]
        attr_accessor :grace_period_start
      
        # 
        # Corresponds to the JSON property `gracePeriodType`
        # @return [String]
        attr_accessor :grace_period_type
      
        # Information provided within MutateDataRequest when setting a user into
        # AgeDisableGracePeriod manually. When the grace period expires, this info will
        # be forwarded to Gaia when disabling the user. cs//symbol:
        # InitiateAgeDisableGracePeriodArguments
        # Corresponds to the JSON property `manualGracePeriodInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiBirthdayAgeDisableGracePeriodManualGracePeriodInfo]
        attr_accessor :manual_grace_period_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calendar_day = args[:calendar_day] if args.key?(:calendar_day)
          @grace_period_end = args[:grace_period_end] if args.key?(:grace_period_end)
          @grace_period_start = args[:grace_period_start] if args.key?(:grace_period_start)
          @grace_period_type = args[:grace_period_type] if args.key?(:grace_period_type)
          @manual_grace_period_info = args[:manual_grace_period_info] if args.key?(:manual_grace_period_info)
        end
      end
      
      # Information provided within MutateDataRequest when setting a user into
      # AgeDisableGracePeriod manually. When the grace period expires, this info will
      # be forwarded to Gaia when disabling the user. cs//symbol:
      # InitiateAgeDisableGracePeriodArguments
      class AppsPeopleOzExternalMergedpeopleapiBirthdayAgeDisableGracePeriodManualGracePeriodInfo
        include Google::Apis::Core::Hashable
      
        # The Gaia ID of an email that ops can send inquiries to for appeals.
        # Corresponds to the JSON property `escalateTo`
        # @return [Fixnum]
        attr_accessor :escalate_to
      
        # The Gaia ID of a Googler who initiated this disable.
        # Corresponds to the JSON property `executedBy`
        # @return [Fixnum]
        attr_accessor :executed_by
      
        # When setting a user into age grace period manually, the requester can
        # additionally supply a short human-readable reason of why the account is put
        # into manual grace period. The description will be forwarded to Gaia when we
        # disable the account when the grace period expires.
        # Corresponds to the JSON property `reason`
        # @return [String]
        attr_accessor :reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @escalate_to = args[:escalate_to] if args.key?(:escalate_to)
          @executed_by = args[:executed_by] if args.key?(:executed_by)
          @reason = args[:reason] if args.key?(:reason)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiBraggingRights
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A url to the person's calendar. As of 03/2018 is not supported for user
      # Profile.
      class AppsPeopleOzExternalMergedpeopleapiCalendar
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The type of the calendar URL. The type can be free form or one of these
        # predefined values: * `home` * `freeBusy` * `work`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiCallerIdExtendedData
        include Google::Apis::Core::Hashable
      
        # Indicates which data source was used to populate the caller ID result
        # Corresponds to the JSON property `callerIdSource`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCallerIdExtendedDataCallerIdSource]
        attr_accessor :caller_id_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @caller_id_source = args[:caller_id_source] if args.key?(:caller_id_source)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiCallerIdExtendedDataCallerIdSource
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `sourceType`
        # @return [String]
        attr_accessor :source_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_type = args[:source_type] if args.key?(:source_type)
        end
      end
      
      # Information related to domain administrator (or authority) certification of a
      # users age.
      class AppsPeopleOzExternalMergedpeopleapiCertifiedBornBefore
        include Google::Apis::Core::Hashable
      
        # Indicates that the user was born at or before this time.
        # Corresponds to the JSON property `bornBefore`
        # @return [String]
        attr_accessor :born_before
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @born_before = args[:born_before] if args.key?(:born_before)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiChannelData
        include Google::Apis::Core::Hashable
      
        # Unique ID that corresponds to a Youtube channel.
        # Corresponds to the JSON property `channelId`
        # @return [String]
        attr_accessor :channel_id
      
        # Number of comments for a given Youtube channel.
        # Corresponds to the JSON property `commentCount`
        # @return [Fixnum]
        attr_accessor :comment_count
      
        # Description of the channel.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `playlistCount`
        # @return [Fixnum]
        attr_accessor :playlist_count
      
        # A FIFE URL pointing to the channel's profile image (go/avatar-fife-urls) with
        # default fife url options. Also refer to go/people-api-concepts:photos for
        # People API's FIFE best practices. The image could be up to a couple of days
        # stale, though it is much fresher in practice. If a fresh image is required,
        # contact the YouTubeAccountProfileService. The URL itself expires ~30 days
        # after generation.
        # Corresponds to the JSON property `profilePictureUrl`
        # @return [String]
        attr_accessor :profile_picture_url
      
        # URL of user's Youtube channel profile.
        # Corresponds to the JSON property `profileUrl`
        # @return [String]
        attr_accessor :profile_url
      
        # Number of subscribers for a given Youtube channel.
        # Corresponds to the JSON property `subscriberCount`
        # @return [Fixnum]
        attr_accessor :subscriber_count
      
        # Title of the YouTube channel
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Whether or not the channel's profile has a title/avatar that is canonical in
        # YouTube. Used to determine if the product profile card should be part of the
        # core persona or have their own persona.
        # Corresponds to the JSON property `usesYoutubeNames`
        # @return [Boolean]
        attr_accessor :uses_youtube_names
        alias_method :uses_youtube_names?, :uses_youtube_names
      
        # Number of videos uploaded in a given Youtube channel.
        # Corresponds to the JSON property `videoCount`
        # @return [Fixnum]
        attr_accessor :video_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel_id = args[:channel_id] if args.key?(:channel_id)
          @comment_count = args[:comment_count] if args.key?(:comment_count)
          @description = args[:description] if args.key?(:description)
          @playlist_count = args[:playlist_count] if args.key?(:playlist_count)
          @profile_picture_url = args[:profile_picture_url] if args.key?(:profile_picture_url)
          @profile_url = args[:profile_url] if args.key?(:profile_url)
          @subscriber_count = args[:subscriber_count] if args.key?(:subscriber_count)
          @title = args[:title] if args.key?(:title)
          @uses_youtube_names = args[:uses_youtube_names] if args.key?(:uses_youtube_names)
          @video_count = args[:video_count] if args.key?(:video_count)
        end
      end
      
      # A circle membership that the person has. A circle membership is created by
      # adding a person to a circle by person-id or by email.
      class AppsPeopleOzExternalMergedpeopleapiCircleMembership
        include Google::Apis::Core::Hashable
      
        # The circle that the person belongs to.
        # Corresponds to the JSON property `circleId`
        # @return [String]
        attr_accessor :circle_id
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circle_id = args[:circle_id] if args.key?(:circle_id)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Arbitrary client data that is populated based on the client
      class AppsPeopleOzExternalMergedpeopleapiClientData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `namespace`
        # @return [String]
        attr_accessor :namespace
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @metadata = args[:metadata] if args.key?(:metadata)
          @namespace = args[:namespace] if args.key?(:namespace)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Email for Google product communication with the user. This is only allowed in
      # ServiceData. It is purely synthesized and read-only, and contains at most one
      # field. It proxies from RawCommunicationEmail and only includes the primary
      # field if exists. Otherwise if RawCommunicationEmail does not have primary,
      # this includes a field synthesized from valid Gaia primary account email.
      # Otherwise if Gaia primary account email is invalid, this field is empty. See
      # go/comm-email-use for more details.
      class AppsPeopleOzExternalMergedpeopleapiCommunicationEmail
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A membership that the person has. The person can be a member of multiple
      # circles and multiple contact-groups. A circle membership is created by adding
      # a person to a circle by person-id or by email. A contact-group membership is
      # created by adding a contact to a contact-group.
      class AppsPeopleOzExternalMergedpeopleapiContactGroupMembership
        include Google::Apis::Core::Hashable
      
        # The contact-group that the person belong to. The id can be either a hex-
        # formatted id or a camel-cased SystemContactGroup predefined group name. The id
        # will be predefined group name iff the system_contact_group_id has a value.
        # Corresponds to the JSON property `contactGroupId`
        # @return [String]
        attr_accessor :contact_group_id
      
        # Information related to delegated group that this contact belongs to.
        # Corresponds to the JSON property `delegatedGroupInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDelegatedGroupInfo]
        attr_accessor :delegated_group_info
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # This field will be populated when the membership is in a system-reserved
        # contact-group.
        # Corresponds to the JSON property `systemContactGroupId`
        # @return [String]
        attr_accessor :system_contact_group_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_group_id = args[:contact_group_id] if args.key?(:contact_group_id)
          @delegated_group_info = args[:delegated_group_info] if args.key?(:delegated_group_info)
          @metadata = args[:metadata] if args.key?(:metadata)
          @system_contact_group_id = args[:system_contact_group_id] if args.key?(:system_contact_group_id)
        end
      end
      
      # Contact state and related metadata. See go/fbs-contacts-trash. This message is
      # a pure wrapper of the shared ContactState message so that it can be a top-
      # level person field. No other fields should be added to the message.
      class AppsPeopleOzExternalMergedpeopleapiContactStateInfo
        include Google::Apis::Core::Hashable
      
        # Contact state and related metadata. See go/fbs-contacts-trash.
        # Corresponds to the JSON property `contactState`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoContactState]
        attr_accessor :contact_state
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_state = args[:contact_state] if args.key?(:contact_state)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # CoverPhoto is the long banner photo (also called full bleed photo) at the top
      # of G+ profile page.
      class AppsPeopleOzExternalMergedpeopleapiCoverPhoto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `imageHeight`
        # @return [Fixnum]
        attr_accessor :image_height
      
        # 
        # Corresponds to the JSON property `imageId`
        # @return [String]
        attr_accessor :image_id
      
        # 
        # Corresponds to the JSON property `imageUrl`
        # @return [String]
        attr_accessor :image_url
      
        # 
        # Corresponds to the JSON property `imageWidth`
        # @return [Fixnum]
        attr_accessor :image_width
      
        # 
        # Corresponds to the JSON property `isAnimated`
        # @return [Boolean]
        attr_accessor :is_animated
        alias_method :is_animated?, :is_animated
      
        # 
        # Corresponds to the JSON property `isDefault`
        # @return [Boolean]
        attr_accessor :is_default
        alias_method :is_default?, :is_default
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_height = args[:image_height] if args.key?(:image_height)
          @image_id = args[:image_id] if args.key?(:image_id)
          @image_url = args[:image_url] if args.key?(:image_url)
          @image_width = args[:image_width] if args.key?(:image_width)
          @is_animated = args[:is_animated] if args.key?(:is_animated)
          @is_default = args[:is_default] if args.key?(:is_default)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Custom fields associated with a person, from the custom schema defined on the
      # domain. See go/custompeopleapi and go/customfocus. NOTE: these are only
      # updatable via Cloud Directory (go/cd).
      class AppsPeopleOzExternalMergedpeopleapiCustomSchemaField
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fieldDisplayName`
        # @return [String]
        attr_accessor :field_display_name
      
        # 
        # Corresponds to the JSON property `fieldId`
        # @return [String]
        attr_accessor :field_id
      
        # 
        # Corresponds to the JSON property `fieldType`
        # @return [String]
        attr_accessor :field_type
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `multiValued`
        # @return [Boolean]
        attr_accessor :multi_valued
        alias_method :multi_valued?, :multi_valued
      
        # 
        # Corresponds to the JSON property `schemaDisplayName`
        # @return [String]
        attr_accessor :schema_display_name
      
        # 
        # Corresponds to the JSON property `schemaId`
        # @return [String]
        attr_accessor :schema_id
      
        # The type of the custom schema field. The type can be free form or one of these
        # predefined values: * `home` * `other` * `work`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # String representation of the value, based on FieldType
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_display_name = args[:field_display_name] if args.key?(:field_display_name)
          @field_id = args[:field_id] if args.key?(:field_id)
          @field_type = args[:field_type] if args.key?(:field_type)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @multi_valued = args[:multi_valued] if args.key?(:multi_valued)
          @schema_display_name = args[:schema_display_name] if args.key?(:schema_display_name)
          @schema_id = args[:schema_id] if args.key?(:schema_id)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Contains customer data for profile owner proxied from D3.
      class AppsPeopleOzExternalMergedpeopleapiCustomerInfo
        include Google::Apis::Core::Hashable
      
        # DEPRECATED. Use obfuscated_customer_id instead. If result has a GSuite
        # Customer ID, this field will continue to be populated with -1 to indicate the
        # presence of a value for backwards compatibility with clients in the wild. See
        # b/144596193.
        # Corresponds to the JSON property `customerId`
        # @return [Fixnum]
        attr_accessor :customer_id
      
        # Customer organization name for dasher user.
        # Corresponds to the JSON property `customerName`
        # @return [String]
        attr_accessor :customer_name
      
        # Obfuscated FlexOrgs customer ID for Dasher user. See cs/symbol:
        # CustomerIdObfuscator.
        # Corresponds to the JSON property `obfuscatedCustomerId`
        # @return [String]
        attr_accessor :obfuscated_customer_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @customer_id = args[:customer_id] if args.key?(:customer_id)
          @customer_name = args[:customer_name] if args.key?(:customer_name)
          @obfuscated_customer_id = args[:obfuscated_customer_id] if args.key?(:obfuscated_customer_id)
        end
      end
      
      # Container information for deduping. When two fields have the same value and
      # only differ by field.metadata a service implementation can choose to avoid
      # duplicating the fields and instead set field.metadata.other_deduped_containers
      # This type can include information on the dedupe type (for example, strict
      # value match vs. lenient value match)
      class AppsPeopleOzExternalMergedpeopleapiDedupedContainerInfo
        include Google::Apis::Core::Hashable
      
        # See SourceIdentity.container_type
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # See SourceIdentity.id
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @container_type = args[:container_type] if args.key?(:container_type)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # Information related to delegated group that this contact belongs to.
      class AppsPeopleOzExternalMergedpeopleapiDelegatedGroupInfo
        include Google::Apis::Core::Hashable
      
        # Represents a delegated group id, delegated groups refer to groups that are
        # owned by another gaiaId, but this user has access to.
        # Corresponds to the JSON property `delegatedGroupId`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoDelegatedGroupId]
        attr_accessor :delegated_group_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @delegated_group_id = args[:delegated_group_id] if args.key?(:delegated_group_id)
        end
      end
      
      # Extra metadata for an aggregated or raw device contact.
      class AppsPeopleOzExternalMergedpeopleapiDeviceContactExtraMetadata
        include Google::Apis::Core::Hashable
      
        # Attributes for this device contact.
        # Corresponds to the JSON property `attributes`
        # @return [Array<String>]
        attr_accessor :attributes
      
        # Usage info for this device contact.
        # Corresponds to the JSON property `usageInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoUsageInfo>]
        attr_accessor :usage_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attributes = args[:attributes] if args.key?(:attributes)
          @usage_info = args[:usage_info] if args.key?(:usage_info)
        end
      end
      
      # Unique id for an aggregated device contact.
      class AppsPeopleOzExternalMergedpeopleapiDeviceContactId
        include Google::Apis::Core::Hashable
      
        # Aggregated device contact id on the source device.
        # Corresponds to the JSON property `contactId`
        # @return [Fixnum]
        attr_accessor :contact_id
      
        # Source device id (go/client-instance-id) of this device contact.
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_id = args[:contact_id] if args.key?(:contact_id)
          @device_id = args[:device_id] if args.key?(:device_id)
        end
      end
      
      # Device contact information.
      class AppsPeopleOzExternalMergedpeopleapiDeviceContactInfo
        include Google::Apis::Core::Hashable
      
        # Extra metadata for an aggregated or raw device contact.
        # Corresponds to the JSON property `deviceContactMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDeviceContactExtraMetadata]
        attr_accessor :device_contact_metadata
      
        # Output only. True if any of the contact's phone, email or address fields can
        # be used on devices other than the one it originated from. Note that there can
        # be other fields, typically name, and metadata such as some of the
        # raw_contact_infos that can be used on other devices. Assigned by the server.
        # Corresponds to the JSON property `hasCrossDeviceData`
        # @return [Boolean]
        attr_accessor :has_cross_device_data
        alias_method :has_cross_device_data?, :has_cross_device_data
      
        # Unique id for an aggregated device contact.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDeviceContactId]
        attr_accessor :id
      
        # Last time a device contact was updated on device.
        # Corresponds to the JSON property `lastClientUpdateTime`
        # @return [String]
        attr_accessor :last_client_update_time
      
        # An opaque value used by the device to look up this contact if its row id
        # changed as a result of a sync or aggregation. See: https://developer.android.
        # com/reference/android/provider/ContactsContract.ContactsColumns.html#
        # LOOKUP_KEY
        # Corresponds to the JSON property `lookupKey`
        # @return [String]
        attr_accessor :lookup_key
      
        # Info about the raw device contacts that make up this device contact.
        # Corresponds to the JSON property `rawContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRawDeviceContactInfo>]
        attr_accessor :raw_contact_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_contact_metadata = args[:device_contact_metadata] if args.key?(:device_contact_metadata)
          @has_cross_device_data = args[:has_cross_device_data] if args.key?(:has_cross_device_data)
          @id = args[:id] if args.key?(:id)
          @last_client_update_time = args[:last_client_update_time] if args.key?(:last_client_update_time)
          @lookup_key = args[:lookup_key] if args.key?(:lookup_key)
          @raw_contact_info = args[:raw_contact_info] if args.key?(:raw_contact_info)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiEdgeKeyInfo
        include Google::Apis::Core::Hashable
      
        # The container ID of the entity this field creates a join to. See `
        # SourceIdentity.id`.
        # Corresponds to the JSON property `containerId`
        # @return [String]
        attr_accessor :container_id
      
        # The type of container that this edge points to. See `SourceIdentity.
        # container_type`.
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # Data that is added to the proto by peopleapi read extensions.
        # Corresponds to the JSON property `extendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEdgeKeyInfoExtensionData]
        attr_accessor :extended_data
      
        # True indicates this edge links this source to a container represented by this
        # person object. Note: Except for certain legacy clients, EdgeKeyInfo is only
        # created for for edges to an entity in this person and this will always be true.
        # Corresponds to the JSON property `materialized`
        # @return [Boolean]
        attr_accessor :materialized
        alias_method :materialized?, :materialized
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @container_id = args[:container_id] if args.key?(:container_id)
          @container_type = args[:container_type] if args.key?(:container_type)
          @extended_data = args[:extended_data] if args.key?(:extended_data)
          @materialized = args[:materialized] if args.key?(:materialized)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiEdgeKeyInfoExtensionData
        include Google::Apis::Core::Hashable
      
        # The GDataCompatibilityExtension will (temporarily) return mobile_owner_id for
        # profile containers.
        # Corresponds to the JSON property `gdataCompatibilityExtensionId`
        # @return [String]
        attr_accessor :gdata_compatibility_extension_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gdata_compatibility_extension_id = args[:gdata_compatibility_extension_id] if args.key?(:gdata_compatibility_extension_id)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiEmail
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `certificate`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmailCertificate>]
        attr_accessor :certificate
      
        # 
        # Corresponds to the JSON property `classification`
        # @return [String]
        attr_accessor :classification
      
        # To read or update, use the CONTACT_GROUP_PREFERENCE mask field.
        # Corresponds to the JSON property `contactGroupPreference`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmailContactGroupPreference>]
        attr_accessor :contact_group_preference
      
        # 
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Extension data for a person email.
        # Corresponds to the JSON property `extendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmailExtendedData]
        attr_accessor :extended_data
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Additional metadata for a signup email. This will only be set if the email's
        # classification is SIGNUP_EMAIL.
        # Corresponds to the JSON property `signupEmailMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmailSignupEmailMetadata]
        attr_accessor :signup_email_metadata
      
        # The type of the email address. The type can be free form or one of these
        # predefined values: * `home` * `work` * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @certificate = args[:certificate] if args.key?(:certificate)
          @classification = args[:classification] if args.key?(:classification)
          @contact_group_preference = args[:contact_group_preference] if args.key?(:contact_group_preference)
          @display_name = args[:display_name] if args.key?(:display_name)
          @extended_data = args[:extended_data] if args.key?(:extended_data)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @signup_email_metadata = args[:signup_email_metadata] if args.key?(:signup_email_metadata)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Under development. Represents a hosted S/MIME certificate config for use with
      # Gmail. See //caribou/smime/proto/certificate_status.proto. There can be zero
      # or more certificates associated with an email address, be it profile email or
      # contact email.
      class AppsPeopleOzExternalMergedpeopleapiEmailCertificate
        include Google::Apis::Core::Hashable
      
        # The name of this certificate configuration. Examples could be "High security
        # level" or "For domain emails only".
        # Corresponds to the JSON property `configurationName`
        # @return [String]
        attr_accessor :configuration_name
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Minimal S/MIME certificate status i.e. two fields per email address.
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmailCertificateCertificateStatus]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @configuration_name = args[:configuration_name] if args.key?(:configuration_name)
          @metadata = args[:metadata] if args.key?(:metadata)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Minimal S/MIME certificate status i.e. two fields per email address.
      class AppsPeopleOzExternalMergedpeopleapiEmailCertificateCertificateStatus
        include Google::Apis::Core::Hashable
      
        # The certificate expiration timestamp in seconds.
        # Corresponds to the JSON property `notAfterSec`
        # @return [Fixnum]
        attr_accessor :not_after_sec
      
        # Current status of the email's certificate chain.
        # Corresponds to the JSON property `statusCode`
        # @return [String]
        attr_accessor :status_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @not_after_sec = args[:not_after_sec] if args.key?(:not_after_sec)
          @status_code = args[:status_code] if args.key?(:status_code)
        end
      end
      
      # Preferred email addresses for contact groups.
      class AppsPeopleOzExternalMergedpeopleapiEmailContactGroupPreference
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contactGroupId`
        # @return [String]
        attr_accessor :contact_group_id
      
        # If the Preference was implicitly set by PeopleApi. A preference with this bit
        # will not be saved. See go/contact-group-email-preference-papi-problem for more
        # info.
        # Corresponds to the JSON property `isSynthetic`
        # @return [Boolean]
        attr_accessor :is_synthetic
        alias_method :is_synthetic?, :is_synthetic
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_group_id = args[:contact_group_id] if args.key?(:contact_group_id)
          @is_synthetic = args[:is_synthetic] if args.key?(:is_synthetic)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Extension data for a person email.
      class AppsPeopleOzExternalMergedpeopleapiEmailExtendedData
        include Google::Apis::Core::Hashable
      
        # For use with the CUSTOMER_INFO_ADDITIONAL_DATA extension. This includes
        # information on whether the given email is internal to or external to the
        # requesting user's domain.
        # Corresponds to the JSON property `internalExternal`
        # @return [Google::Apis::ContentwarehouseV1::PeoplestackFlexorgsProtoInternalExternal]
        attr_accessor :internal_external
      
        # For ListPeoplebyKnownId to indicate an email is sythesized from a lookup email.
        # Corresponds to the JSON property `isPlaceholder`
        # @return [Boolean]
        attr_accessor :is_placeholder
        alias_method :is_placeholder?, :is_placeholder
      
        # For use with the TLS extension. Whether the SMTP server that handles delivery
        # for this email address supports TLS encryption.
        # Corresponds to the JSON property `smtpServerSupportsTls`
        # @return [Boolean]
        attr_accessor :smtp_server_supports_tls
        alias_method :smtp_server_supports_tls?, :smtp_server_supports_tls
      
        # For use with the Gmail Homograph Warning extension. Whether the email contains
        # mixed character sets that could be used to decieve users. This field is
        # populated by the GMAIL_SECURITY_DATA extension.
        # Corresponds to the JSON property `usesConfusingCharacters`
        # @return [Boolean]
        attr_accessor :uses_confusing_characters
        alias_method :uses_confusing_characters?, :uses_confusing_characters
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @internal_external = args[:internal_external] if args.key?(:internal_external)
          @is_placeholder = args[:is_placeholder] if args.key?(:is_placeholder)
          @smtp_server_supports_tls = args[:smtp_server_supports_tls] if args.key?(:smtp_server_supports_tls)
          @uses_confusing_characters = args[:uses_confusing_characters] if args.key?(:uses_confusing_characters)
        end
      end
      
      # Additional metadata for a signup email. This will only be set if the email's
      # classification is SIGNUP_EMAIL.
      class AppsPeopleOzExternalMergedpeopleapiEmailSignupEmailMetadata
        include Google::Apis::Core::Hashable
      
        # This is considered to be the primary signup email. At most 1 signup email will
        # have this set.
        # Corresponds to the JSON property `primary`
        # @return [Boolean]
        attr_accessor :primary
        alias_method :primary?, :primary
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @primary = args[:primary] if args.key?(:primary)
        end
      end
      
      # Emergency info for Person. See go/emergency-trusted-contacts-papi.
      class AppsPeopleOzExternalMergedpeopleapiEmergencyInfo
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Opaque id from Pomeroy (go/pomeroy). Non-empty pomeroy_id means that this
        # contact has the potential to become trusted contact or it's already trusted
        # contact. Trust is eventually gaia<->gaia link, but when the trust link is
        # initiated gaia might not be known. Until gaia is discovered, pomeroy_id is
        # used to identify the contact uniquely. If trust_level is missing or set to
        # TRUST_LEVEL_UNSPECIFIED pomeroy_id must be empty.
        # Corresponds to the JSON property `pomeroyId`
        # @return [String]
        attr_accessor :pomeroy_id
      
        # 
        # Corresponds to the JSON property `trustLevel`
        # @return [String]
        attr_accessor :trust_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @pomeroy_id = args[:pomeroy_id] if args.key?(:pomeroy_id)
          @trust_level = args[:trust_level] if args.key?(:trust_level)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiEvent
        include Google::Apis::Core::Hashable
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `calendarDay`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :calendar_day
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Clients are recommended to read the calendar_day field instead of
        # timestamp_millis. When writing events, new clients must set calendar_day
        # instead of timestamp_millis. Events are currently represented as timestamp
        # values, although the interpretation of these timestamp values is a calendar
        # date. There are a few important details about how this value should be mapped
        # to a calendar date that should be consistent among all clients. For detailed
        # information, see Birthday.date_ms.
        # Corresponds to the JSON property `timestampMillis`
        # @return [Fixnum]
        attr_accessor :timestamp_millis
      
        # The type of the event. The type can be free form or one of these predefined
        # values: * `anniversary` * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calendar_day = args[:calendar_day] if args.key?(:calendar_day)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @timestamp_millis = args[:timestamp_millis] if args.key?(:timestamp_millis)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # External identifier associated with the person.
      class AppsPeopleOzExternalMergedpeopleapiExternalId
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The type of the external ID. The type can be free form or one of these
        # predefined values: * `account` * `customer` * `loginId` * `network` * `
        # organization`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # The field ACL. Currently only populated on profile fields for the profile
      # owner. A Person field ACL; see http://go/peopleapi-acl
      class AppsPeopleOzExternalMergedpeopleapiFieldAcl
        include Google::Apis::Core::Hashable
      
        # A custom type of field ACL entry. The set of all ACL entries includes those
        # listed in acl_entry as well as predefined_acl_entry.
        # Corresponds to the JSON property `aclEntry`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntry>]
        attr_accessor :acl_entry
      
        # Set of users that will be authorized to view the field by this field ACL. If
        # the ACL is public, this will only contain ALL_USERS. This field is synthesized,
        # read-only, and currently only used for profile photos. It's populated under "
        # person.photo.metadata.field_acl" for the current photo ACL and "person.photo.
        # metadata.acl_choices" for available photo ACL choices. Note: The set of
        # authorized viewers for a given FieldAcl may depend on the user's account type
        # and domain configuration. For example, a PRIVATE_READ FieldAcl could have any
        # of the following authorized viewers: Consumer user: [IDENTITY_ACL_ESTABLISHED]
        # Dasher user without domain contact sharing: [IDENTITY_ACL_ESTABLISHED] Unicorn
        # user: [SAME_UNICORN_FAMILY] Hafez user: []
        # Corresponds to the JSON property `authorizedViewers`
        # @return [Array<String>]
        attr_accessor :authorized_viewers
      
        # A common type of field ACL entry. A predefined ACL entry is a shortcut for a
        # commonly occurring case of role and scope. For example, PUBLIC_READ is the
        # same as an AclEntry with role = READER and scope.all_users = true. The set of
        # all ACL entries includes those listed in acl_entry as well as
        # predefined_acl_entry.
        # Corresponds to the JSON property `predefinedAclEntry`
        # @return [Array<String>]
        attr_accessor :predefined_acl_entry
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acl_entry = args[:acl_entry] if args.key?(:acl_entry)
          @authorized_viewers = args[:authorized_viewers] if args.key?(:authorized_viewers)
          @predefined_acl_entry = args[:predefined_acl_entry] if args.key?(:predefined_acl_entry)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntry
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # 
        # Corresponds to the JSON property `scope`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScope]
        attr_accessor :scope
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @role = args[:role] if args.key?(:role)
          @scope = args[:scope] if args.key?(:scope)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScope
        include Google::Apis::Core::Hashable
      
        # Indicates that the field is accessible to all users including unauthenticated
        # users. For some fields this means "to everyone except blocked users".
        # Corresponds to the JSON property `allUsers`
        # @return [Boolean]
        attr_accessor :all_users
        alias_method :all_users?, :all_users
      
        # This is a "synthetic" field. In reality domains are treated as gaia- groups.
        # This field will be 'true' when the field is ACLed to the gaia-group of the
        # requester's domain.
        # Corresponds to the JSON property `domainUsers`
        # @return [Boolean]
        attr_accessor :domain_users
        alias_method :domain_users?, :domain_users
      
        # Used when the field is accessible to a membership that the person has.
        # Corresponds to the JSON property `membership`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAcl]
        attr_accessor :membership
      
        # Used when a field is accessible to a person. NOTE: ACLs to a circle or to a
        # non-self person are no longer supported, so this can only be applied to the
        # requester self.
        # Corresponds to the JSON property `person`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopePersonAcl]
        attr_accessor :person
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_users = args[:all_users] if args.key?(:all_users)
          @domain_users = args[:domain_users] if args.key?(:domain_users)
          @membership = args[:membership] if args.key?(:membership)
          @person = args[:person] if args.key?(:person)
        end
      end
      
      # Used when the field is accessible to a membership that the person has.
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAcl
        include Google::Apis::Core::Hashable
      
        # Used when a field is accessible to a circle.
        # Corresponds to the JSON property `circle`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAclCircleAcl]
        attr_accessor :circle
      
        # Used when a field is accessible to a legacy contact group. Contact groups are
        # discouraged and may be deprecated soon. ContactGroupAcls are read-only. If
        # they are included as part of an ACL on an Update, an exception is thrown.
        # Corresponds to the JSON property `contactGroup`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAclContactGroupAcl]
        attr_accessor :contact_group
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circle = args[:circle] if args.key?(:circle)
          @contact_group = args[:contact_group] if args.key?(:contact_group)
        end
      end
      
      # Used when a field is accessible to a circle.
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAclCircleAcl
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `circleId`
        # @return [String]
        attr_accessor :circle_id
      
        # 
        # Corresponds to the JSON property `circleSet`
        # @return [String]
        attr_accessor :circle_set
      
        # Equivalent to Circle.display_name for the circle_id. Included when
        # FieldAclOption.FULL_ACL_WITH_DETAILS is requested. This field is read-only and
        # ignored on update.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circle_id = args[:circle_id] if args.key?(:circle_id)
          @circle_set = args[:circle_set] if args.key?(:circle_set)
          @display_name = args[:display_name] if args.key?(:display_name)
        end
      end
      
      # Used when a field is accessible to a legacy contact group. Contact groups are
      # discouraged and may be deprecated soon. ContactGroupAcls are read-only. If
      # they are included as part of an ACL on an Update, an exception is thrown.
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopeMembershipAclContactGroupAcl
        include Google::Apis::Core::Hashable
      
        # A contact group ID. This is either a user-defined contact group hex ID, or it
        # is the string name of the enum constant in Group.PredefinedId in FBS backend.
        # proto for predefined groups. Common values for the predefined name include,
        # but are not limited to: all, myContacts, starred, chatBuddies, friends, family,
        # coworkers, and blocked.
        # Corresponds to the JSON property `contactGroupId`
        # @return [String]
        attr_accessor :contact_group_id
      
        # The localized display name for the predefined group, if known; or, the display
        # name for the user-defined contact group. Included when FieldAclOption.
        # FULL_ACL_WITH_DETAILS is requested.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_group_id = args[:contact_group_id] if args.key?(:contact_group_id)
          @display_name = args[:display_name] if args.key?(:display_name)
        end
      end
      
      # Used when a field is accessible to a person. NOTE: ACLs to a circle or to a
      # non-self person are no longer supported, so this can only be applied to the
      # requester self.
      class AppsPeopleOzExternalMergedpeopleapiFieldAclAclEntryScopePersonAcl
        include Google::Apis::Core::Hashable
      
        # DEPRECATED. This is not different than reading from person.name for a self-
        # read; ACLs to a circle or to a non-self person are no longer supported.
        # Equivalent to Name.display_name for the person_id profile. Included when the
        # profile Name is ACLed to the requester and FieldAclOption.
        # FULL_ACL_WITH_DETAILS is requested. This field is read-only and ignored on
        # update.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # 
        # Corresponds to the JSON property `personId`
        # @return [String]
        attr_accessor :person_id
      
        # DEPRECATED. This is not different than reading from person.photo for a self-
        # read; ACLs to a circle or to a non-self person are no longer supported.
        # Equivalent to Photo.url for the person_id profile. Included when the profile
        # Photo is ACLed to the requester and FieldAclOption.FULL_ACL_WITH_DETAILS is
        # requested. This field is read-only and ignored on update.
        # Corresponds to the JSON property `photoUrl`
        # @return [String]
        attr_accessor :photo_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @person_id = args[:person_id] if args.key?(:person_id)
          @photo_url = args[:photo_url] if args.key?(:photo_url)
        end
      end
      
      # Emergency information for Person field, such as Phone or Email. See go/
      # emergency-trusted-contacts-papi.
      class AppsPeopleOzExternalMergedpeopleapiFieldEmergencyInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `emergencyLevel`
        # @return [String]
        attr_accessor :emergency_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @emergency_level = args[:emergency_level] if args.key?(:emergency_level)
        end
      end
      
      # The FileAs field in Contacts is used to override the DisplayName of a Contact
      # for that User.
      class AppsPeopleOzExternalMergedpeopleapiFileAs
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Extension data for use in GPay Product Profile. go/gpay-product-profile-1-
      # pager Contact: profiles-eng-fe@google.com
      class AppsPeopleOzExternalMergedpeopleapiGPayExtendedData
        include Google::Apis::Core::Hashable
      
        # Product profiles failure type: the status of the rpc to fetch the product
        # profile.
        # Corresponds to the JSON property `failure`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProductProfileFailure]
        attr_accessor :failure
      
        # A number in international format including the country code that is made user
        # readable by including formatting such as spaces. Example: "+41 44 668 1800"
        # DEPRECATED: A user's phone number should be masked and not in an international
        # format
        # Corresponds to the JSON property `internationalNumber`
        # @return [String]
        attr_accessor :international_number
      
        # The masked string of a user's phone number The number will be obfucsated with *
        # except the last 4 digits. Refer to: //java/com/google/nbu/paisa/common/
        # PhoneNumberMasker.java
        # Corresponds to the JSON property `maskedNumber`
        # @return [String]
        attr_accessor :masked_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @failure = args[:failure] if args.key?(:failure)
          @international_number = args[:international_number] if args.key?(:international_number)
          @masked_number = args[:masked_number] if args.key?(:masked_number)
        end
      end
      
      # Gender in PeopleApi has some odd semantics about writing and reading that are
      # not obvious from the proto definition. First, the `type` string, when read,
      # always maps to the constrained domain of "male", "female", and "other", aside
      # from a pathological case that PeopleApi would like to fix. There are two
      # typical patterns: 1. `type` is either "male" or "female" and `custom_type` and
      # `address_me_as` are exactly as specified by an update to PeopleApi, although
      # they are most often absent for "male" and "female" writes. 2. `type` is "other"
      # and `custom_type` is set to a freeform string from the request. `
      # address_me_as` is equal to whatever was provided at write time. When writing,
      # the free-form string for `custom_type` can come from either `custom_type` if
      # the field is present on the request, or if `custom_type` is absent, the string
      # value of `type` will be copied into it. Any value in `type` will be coerced to
      # "other" and the free-form value will be copied into `custom_type`, even if `
      # type` is exactly "other". Prefer to explicitly set `custom_type` and set type
      # to "other" instead of setting type to a free-form value. There are weird edge
      # cases when the value is "unknown". Consider the behavior for `type` == "
      # unknown" unspecified. Clients reading the gender should use the value from `
      # formatted_type` if `type` is "male" or "female". If `type` is "other", `
      # formatted_type` will be "Other" (or some translation) and clients should read `
      # custom_type` for more specificity.
      class AppsPeopleOzExternalMergedpeopleapiGender
        include Google::Apis::Core::Hashable
      
        # Preferred pronoun choice. It's unclear whether this value is constrained to a
        # finite domain by UIs. `address_me_as` may be populated regardless of whether `
        # type` is "male", "female", or "other", although most writers only set it if `
        # type` is "other".
        # Corresponds to the JSON property `addressMeAs`
        # @return [String]
        attr_accessor :address_me_as
      
        # A free-form string indicating what the user entered as their gender. `
        # custom_type` may exist even if the type is "male" or "female", although most
        # writers do not set it unless `type` is "other".
        # Corresponds to the JSON property `customType`
        # @return [String]
        attr_accessor :custom_type
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The gender. "male", "female", or "other". If "other", typically, additional
        # fields will have additional information.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address_me_as = args[:address_me_as] if args.key?(:address_me_as)
          @custom_type = args[:custom_type] if args.key?(:custom_type)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiGplusExtendedData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contentRestriction`
        # @return [String]
        attr_accessor :content_restriction
      
        # Equivalent to having the DASHER_POLICY bit in the REGISTERED state.
        # Corresponds to the JSON property `isEnterpriseUser`
        # @return [Boolean]
        attr_accessor :is_enterprise_user
        alias_method :is_enterprise_user?, :is_enterprise_user
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_restriction = args[:content_restriction] if args.key?(:content_restriction)
          @is_enterprise_user = args[:is_enterprise_user] if args.key?(:is_enterprise_user)
        end
      end
      
      # Extension data for use in Hangouts.
      class AppsPeopleOzExternalMergedpeopleapiHangoutsExtendedData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hadPastHangoutState`
        # @return [String]
        attr_accessor :had_past_hangout_state
      
        # Populated for all contacts. Only set if had_past_hangout_state ==
        # HAD_PAST_HANGOUT. INVITATION_NEEDED is not a valid value because there already
        # is a past hangout, which means either the invitation is still pending or it’s
        # been accepted.
        # Corresponds to the JSON property `invitationStatus`
        # @return [String]
        attr_accessor :invitation_status
      
        # True if this is a Hangouts bot.
        # Corresponds to the JSON property `isBot`
        # @return [Boolean]
        attr_accessor :is_bot
        alias_method :is_bot?, :is_bot
      
        # 
        # Corresponds to the JSON property `isDismissed`
        # @return [Boolean]
        attr_accessor :is_dismissed
        alias_method :is_dismissed?, :is_dismissed
      
        # 
        # Corresponds to the JSON property `isFavorite`
        # @return [Boolean]
        attr_accessor :is_favorite
        alias_method :is_favorite?, :is_favorite
      
        # 
        # Corresponds to the JSON property `isPinned`
        # @return [Boolean]
        attr_accessor :is_pinned
        alias_method :is_pinned?, :is_pinned
      
        # 
        # Corresponds to the JSON property `userType`
        # @return [String]
        attr_accessor :user_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @had_past_hangout_state = args[:had_past_hangout_state] if args.key?(:had_past_hangout_state)
          @invitation_status = args[:invitation_status] if args.key?(:invitation_status)
          @is_bot = args[:is_bot] if args.key?(:is_bot)
          @is_dismissed = args[:is_dismissed] if args.key?(:is_dismissed)
          @is_favorite = args[:is_favorite] if args.key?(:is_favorite)
          @is_pinned = args[:is_pinned] if args.key?(:is_pinned)
          @user_type = args[:user_type] if args.key?(:user_type)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiIdentityInfo
        include Google::Apis::Core::Hashable
      
        # Original lookup token from the request that resulted in this person or one of
        # its containers.
        # Corresponds to the JSON property `originalLookupToken`
        # @return [Array<String>]
        attr_accessor :original_lookup_token
      
        # Any former IDs this person may have had, in the case that their ID may have
        # changed. Populated only for sync requests. Examples of such changes include
        # adding an edge to a contact that links to a profile. The ID will change from
        # being contact-oriented to being profile-oriented. To be used to clear out old
        # versions of a person.
        # Corresponds to the JSON property `previousPersonId`
        # @return [Array<String>]
        attr_accessor :previous_person_id
      
        # A list of sources contributing to the merged person, including profiles (with
        # gaia-id), contacts and synthetic-contacts.
        # Corresponds to the JSON property `sourceIds`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSourceIdentity>]
        attr_accessor :source_ids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @original_lookup_token = args[:original_lookup_token] if args.key?(:original_lookup_token)
          @previous_person_id = args[:previous_person_id] if args.key?(:previous_person_id)
          @source_ids = args[:source_ids] if args.key?(:source_ids)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiIm
        include Google::Apis::Core::Hashable
      
        # The `protocol` translated and formatted in the request locale. See go/people-
        # api-howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedProtocol`
        # @return [String]
        attr_accessor :formatted_protocol
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The protocol of the IM. The protocol can be free form or one of these
        # predefined values: * `aim` * `msn` * `yahoo` * `skype` * `qq` * `googleTalk` *
        # `icq` * `jabber` * `netMeeting`
        # Corresponds to the JSON property `protocol`
        # @return [String]
        attr_accessor :protocol
      
        # The type of the IM. The type can be free form or one of these predefined
        # values: * `home` * `work` * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_protocol = args[:formatted_protocol] if args.key?(:formatted_protocol)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @protocol = args[:protocol] if args.key?(:protocol)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # How and where to send notifications to this person in other apps, and why the
      # requester can do so. See go/reachability for more info. "How" and "where"
      # identify the recipient in a P2P Bridge (glossary/p2p bridge), and "why" may be
      # helpful in a UI to disambiguate which of several ways may be used to contact
      # the recipient. How: Via a Google profile or a reachable-only phone number that
      # the requester has access to. Specified in the target "type" and "value". Where:
      # Apps in which the profile/phone number owner may receive notifications.
      # Specified in the repeated "app". Why: Which fields in, e.g., a contact
      # associated with this person make the notification target info visible to the
      # requester. Specified in the repeated originating_field param. Example: Alice
      # has a contact Bob, with: Email 0 = bob@gmail.com Phone 0 = +12223334444 Phone
      # 1 = +15556667777 Email 0 and Phone 0 let Alice see Bob's public profile (
      # obfuscated gaia ID = 123). Public profiles are visible by email by default,
      # and Bob has explicitly made it visible via Phone 0. Bob says people can send
      # notifications to his public profile in YouTube. Phone 2 is associated with
      # another Google profile that Bob owns, but he doesn't want others to see it. He
      # is okay with people sending notifications to him in Who's Down if they have
      # this phone number, however. There will be separate InAppNotificationTargets:
      # one for Bob's public Google profile, and one for the second phone number,
      # which is in his private profile. IANT #1 - targeting Bob's public profile (
      # visible via Email 0 and Phone 0): app = [YOUTUBE] type = OBFUSCATED_GAIA_ID
      # value = 123 originating_field: [ ` field_type = EMAIL, field_index = 0 ` //
      # For Email 0 ` field_type = PHONE, field_index = 0 ` // For Phone 0 ] IANT #2 -
      # targeting Bob's private profile phone number Phone 1: app = [WHOS_DOWN] type =
      # PHONE value = +15556667777 originating_field: [ ` field_type = PHONE,
      # field_index = 1 ` // For Phone 1 ]
      class AppsPeopleOzExternalMergedpeopleapiInAppNotificationTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `app`
        # @return [Array<String>]
        attr_accessor :app
      
        # 
        # Corresponds to the JSON property `clientData`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInAppNotificationTargetClientData>]
        attr_accessor :client_data
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # There may be more than one field from which this IANT originates, as in the
        # case of Bob's public profile.
        # Corresponds to the JSON property `originatingField`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInAppNotificationTargetOriginatingField>]
        attr_accessor :originating_field
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The value of the target, used for delivery. E.g., the obfuscated gaia ID for a
        # visible profile.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app = args[:app] if args.key?(:app)
          @client_data = args[:client_data] if args.key?(:client_data)
          @metadata = args[:metadata] if args.key?(:metadata)
          @originating_field = args[:originating_field] if args.key?(:originating_field)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Client-specific data pertaining to app reachability. No PII data or user
      # content should be stored in this blob.
      class AppsPeopleOzExternalMergedpeopleapiInAppNotificationTargetClientData
        include Google::Apis::Core::Hashable
      
        # The app to which this client data applies.
        # Corresponds to the JSON property `app`
        # @return [String]
        attr_accessor :app
      
        # 
        # Corresponds to the JSON property `byteValue`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :byte_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app = args[:app] if args.key?(:app)
          @byte_value = args[:byte_value] if args.key?(:byte_value)
        end
      end
      
      # Info for identifying the specific field in this person that lets the requester
      # send them notifications. These are typically fields added to a contact (e.g.,
      # email). There will not always be in originating field, typically in the case
      # that whatever permits the requester to see this target info is not something
      # that can be used on its own for contacting this person.
      class AppsPeopleOzExternalMergedpeopleapiInAppNotificationTargetOriginatingField
        include Google::Apis::Core::Hashable
      
        # The index of the relevant field in the merged person
        # Corresponds to the JSON property `fieldIndex`
        # @return [Fixnum]
        attr_accessor :field_index
      
        # 
        # Corresponds to the JSON property `fieldType`
        # @return [String]
        attr_accessor :field_type
      
        # The value of the origin field
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_index = args[:field_index] if args.key?(:field_index)
          @field_type = args[:field_type] if args.key?(:field_type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # This is deprecated in PEOPLE_API/SHARPEN, and should only be used for PROFILES.
      # Which apps the person has indicated they are reachable at for the requester.
      # See go/d13y and com.google.focus.proto.InAppReachability.
      class AppsPeopleOzExternalMergedpeopleapiInAppReachability
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `appType`
        # @return [String]
        attr_accessor :app_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Information pertaining to how this reachable state was established.
        # Corresponds to the JSON property `reachabilityKey`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInAppReachabilityReachabilityKey]
        attr_accessor :reachability_key
      
        # 
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_type = args[:app_type] if args.key?(:app_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @reachability_key = args[:reachability_key] if args.key?(:reachability_key)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Information pertaining to how this reachable state was established.
      class AppsPeopleOzExternalMergedpeopleapiInAppReachabilityReachabilityKey
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `keyType`
        # @return [String]
        attr_accessor :key_type
      
        # The value of the key by which the user said they may be reachable. E.g., the
        # phone number.
        # Corresponds to the JSON property `keyValue`
        # @return [String]
        attr_accessor :key_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key_type = args[:key_type] if args.key?(:key_type)
          @key_value = args[:key_value] if args.key?(:key_value)
        end
      end
      
      # Defines interactions that are allowed or disallowed with this person.
      class AppsPeopleOzExternalMergedpeopleapiInteractionSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `allowed`
        # @return [Boolean]
        attr_accessor :allowed
        alias_method :allowed?, :allowed
      
        # 
        # Corresponds to the JSON property `interaction`
        # @return [String]
        attr_accessor :interaction
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowed = args[:allowed] if args.key?(:allowed)
          @interaction = args[:interaction] if args.key?(:interaction)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiInterest
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # The value can either by a language code conforming to the IETF BCP 47
      # specification or a custom freeform value. By default the returned value is
      # proxied from FBS Profile.Language. If `include_account_locale` is set on the `
      # MergePersonSourceOptions` the language from go/uls is preferred and returned
      # as primary along with a secondary language from FBS.
      class AppsPeopleOzExternalMergedpeopleapiLanguage
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiLatLng
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lat`
        # @return [Float]
        attr_accessor :lat
      
        # 
        # Corresponds to the JSON property `lng`
        # @return [Float]
        attr_accessor :lng
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lat = args[:lat] if args.key?(:lat)
          @lng = args[:lng] if args.key?(:lng)
        end
      end
      
      # Fields used in legacy applications. Useful for joining legacy and new data
      # streams. Most applications should not care about these fields.
      class AppsPeopleOzExternalMergedpeopleapiLegacyFields
        include Google::Apis::Core::Hashable
      
        # Mobile obfuscated gaia id. This is the same gaia id in metadata.owner_id, but
        # obfuscated with the legacy mobile obfuscator.
        # Corresponds to the JSON property `mobileOwnerId`
        # @return [String]
        attr_accessor :mobile_owner_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mobile_owner_id = args[:mobile_owner_id] if args.key?(:mobile_owner_id)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiLimitedProfileSettingsField
        include Google::Apis::Core::Hashable
      
        # Next ID: 9
        # Corresponds to the JSON property `limitedProfileSettings`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoLimitedProfileSettings]
        attr_accessor :limited_profile_settings
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @limited_profile_settings = args[:limited_profile_settings] if args.key?(:limited_profile_settings)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiLocation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `buildingId`
        # @return [String]
        attr_accessor :building_id
      
        # The building_name field is only filled if the DESK_LOCATION_ADDITIONAL_DATA
        # extension is active.
        # Corresponds to the JSON property `buildingName`
        # @return [String]
        attr_accessor :building_name
      
        # 
        # Corresponds to the JSON property `current`
        # @return [Boolean]
        attr_accessor :current
        alias_method :current?, :current
      
        # Most specific textual description of individual desk location.
        # Corresponds to the JSON property `deskCode`
        # @return [String]
        attr_accessor :desk_code
      
        # 
        # Corresponds to the JSON property `extendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLocationExtendedData]
        attr_accessor :extended_data
      
        # 
        # Corresponds to the JSON property `floorName`
        # @return [String]
        attr_accessor :floor_name
      
        # 
        # Corresponds to the JSON property `floorSection`
        # @return [String]
        attr_accessor :floor_section
      
        # Indicates the time this location was added or last edited.
        # Corresponds to the JSON property `lastUpdateTime`
        # @return [String]
        attr_accessor :last_update_time
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Value indicates the origin of this location information.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # Describes the type of location. For e.g. Grew_up, Desk. Corresponds to FBS
        # backend.proto Location.StandardTag
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @building_id = args[:building_id] if args.key?(:building_id)
          @building_name = args[:building_name] if args.key?(:building_name)
          @current = args[:current] if args.key?(:current)
          @desk_code = args[:desk_code] if args.key?(:desk_code)
          @extended_data = args[:extended_data] if args.key?(:extended_data)
          @floor_name = args[:floor_name] if args.key?(:floor_name)
          @floor_section = args[:floor_section] if args.key?(:floor_section)
          @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
          @metadata = args[:metadata] if args.key?(:metadata)
          @source = args[:source] if args.key?(:source)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiLocationExtendedData
        include Google::Apis::Core::Hashable
      
        # Corp Deskbooking-related extension data for use with Location.
        # Corresponds to the JSON property `corpDeskbookingExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionCorpDeskbookingLocationExtendedData]
        attr_accessor :corp_deskbooking_extended_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @corp_deskbooking_extended_data = args[:corp_deskbooking_extended_data] if args.key?(:corp_deskbooking_extended_data)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiManagementUpchain
        include Google::Apis::Core::Hashable
      
        # List of managers in the chain. If user has manager email "abc@google.com" and
        # manager's manager has email "xyz@google.com" then the list will be: [0]: `
        # email: "abc@google.com" ` [1]: ` email: "xyz@google.com" `
        # Corresponds to the JSON property `indirectManager`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiManagementUpchainIndirectManager>]
        attr_accessor :indirect_manager
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @indirect_manager = args[:indirect_manager] if args.key?(:indirect_manager)
          @metadata = args[:metadata] if args.key?(:metadata)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiManagementUpchainIndirectManager
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `personId`
        # @return [String]
        attr_accessor :person_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @person_id = args[:person_id] if args.key?(:person_id)
        end
      end
      
      # Extension data for use in Maps Product Profile.
      class AppsPeopleOzExternalMergedpeopleapiMapsExtendedData
        include Google::Apis::Core::Hashable
      
        # Product profiles failure type: the status of the rpc to fetch the product
        # profile.
        # Corresponds to the JSON property `failure`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProductProfileFailure]
        attr_accessor :failure
      
        # Number of people the user is following.
        # Corresponds to the JSON property `followeeCount`
        # @return [Fixnum]
        attr_accessor :followee_count
      
        # Number of people who are following the user.
        # Corresponds to the JSON property `followerCount`
        # @return [Fixnum]
        attr_accessor :follower_count
      
        # Sum of creators contributions i.e. reviews, rating, questions, etc.
        # Corresponds to the JSON property `numContributions`
        # @return [Fixnum]
        attr_accessor :num_contributions
      
        # The user's profile photo that might have a badge rendered at the corner if the
        # user is eligible for a badge.
        # Corresponds to the JSON property `profilePhotoUrl`
        # @return [String]
        attr_accessor :profile_photo_url
      
        # A user's bio, or tagline.
        # Corresponds to the JSON property `tagline`
        # @return [String]
        attr_accessor :tagline
      
        # A topic that creator has expertise in. This will be in the format: emoji
        # associated with the topic, display name of the topic, topic score
        # Corresponds to the JSON property `topicExpertise`
        # @return [Array<String>]
        attr_accessor :topic_expertise
      
        # A user's caption displayed under the user name on their profile page i.e. '
        # Local Guide Level 8'
        # Corresponds to the JSON property `userCaption`
        # @return [String]
        attr_accessor :user_caption
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @failure = args[:failure] if args.key?(:failure)
          @followee_count = args[:followee_count] if args.key?(:followee_count)
          @follower_count = args[:follower_count] if args.key?(:follower_count)
          @num_contributions = args[:num_contributions] if args.key?(:num_contributions)
          @profile_photo_url = args[:profile_photo_url] if args.key?(:profile_photo_url)
          @tagline = args[:tagline] if args.key?(:tagline)
          @topic_expertise = args[:topic_expertise] if args.key?(:topic_expertise)
          @user_caption = args[:user_caption] if args.key?(:user_caption)
        end
      end
      
      # Maps Profile Data. See go/product-profiles-backend-api.
      class AppsPeopleOzExternalMergedpeopleapiMapsProfile
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fieldRestriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMapsProfileFieldRestriction>]
        attr_accessor :field_restriction
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `tagline`
        # @return [String]
        attr_accessor :tagline
      
        # A link to the profile owner's website to be displayed in profile.
        # Corresponds to the JSON property `websiteLink`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMapsProfileUrlLink]
        attr_accessor :website_link
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_restriction = args[:field_restriction] if args.key?(:field_restriction)
          @metadata = args[:metadata] if args.key?(:metadata)
          @tagline = args[:tagline] if args.key?(:tagline)
          @website_link = args[:website_link] if args.key?(:website_link)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiMapsProfileFieldRestriction
        include Google::Apis::Core::Hashable
      
        # Opaque data associated with this restriction e.g. abuse status.
        # Corresponds to the JSON property `clientData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :client_data
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_data = args[:client_data] if args.key?(:client_data)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiMapsProfileUrlLink
        include Google::Apis::Core::Hashable
      
        # Anchor text to be displayed as clickable link. If not present, the URL should
        # be displayed directly.
        # Corresponds to the JSON property `anchorText`
        # @return [String]
        attr_accessor :anchor_text
      
        # The URL to be linked to.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_text = args[:anchor_text] if args.key?(:anchor_text)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Represents the matching information for a field when there is a query.
      class AppsPeopleOzExternalMergedpeopleapiMatchInfo
        include Google::Apis::Core::Hashable
      
        # The list of matches ordered by most relevant matching for autocomplete coming
        # first.
        # Corresponds to the JSON property `match`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMatchInfoLookupTokenMatch>]
        attr_accessor :match
      
        # The query token we are matching against.
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @match = args[:match] if args.key?(:match)
          @query = args[:query] if args.key?(:query)
        end
      end
      
      # All the substring that were matched for the given query against the current
      # field. Represents a substring of another string.
      class AppsPeopleOzExternalMergedpeopleapiMatchInfoLookupTokenMatch
        include Google::Apis::Core::Hashable
      
        # Index right after the last character that matches the query. length = end-
        # start, we have substring = [start, end).
        # Corresponds to the JSON property `endIndex`
        # @return [Fixnum]
        attr_accessor :end_index
      
        # Index of the first unicode character that matches the query.
        # Corresponds to the JSON property `startIndex`
        # @return [Fixnum]
        attr_accessor :start_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_index = args[:end_index] if args.key?(:end_index)
          @start_index = args[:start_index] if args.key?(:start_index)
        end
      end
      
      # A membership that the person has. The person can be a member of multiple
      # circles and multiple contact-groups. A circle membership is created by adding
      # a person to a circle by person-id or by email. A contact-group membership is
      # created by adding a contact to a contact-group.
      class AppsPeopleOzExternalMergedpeopleapiMembership
        include Google::Apis::Core::Hashable
      
        # A circle that the person belongs to.
        # Corresponds to the JSON property `circleId`
        # @return [String]
        attr_accessor :circle_id
      
        # A contact-group that the person belong to. The id can be either a hex-
        # formatted id or a camel-cased SystemContactGroup predefined group name. The id
        # will be predefined group name iff the system_contact_group_id has a value.
        # Corresponds to the JSON property `contactGroupId`
        # @return [String]
        attr_accessor :contact_group_id
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The membership has a contact_group_id, this field will be populated when the
        # membership is in a system-reserved contact-group.
        # Corresponds to the JSON property `systemContactGroupId`
        # @return [String]
        attr_accessor :system_contact_group_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circle_id = args[:circle_id] if args.key?(:circle_id)
          @contact_group_id = args[:contact_group_id] if args.key?(:contact_group_id)
          @metadata = args[:metadata] if args.key?(:metadata)
          @system_contact_group_id = args[:system_contact_group_id] if args.key?(:system_contact_group_id)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiMission
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # See go/people-api-howto:names for an overview of name usage in PeopleAPI. The `
      # unstructured_name` field contains a free form name value. The `given_name`, `
      # middle_name`, `family_name`, etc, fields contain the structured name. For
      # CONTACT mutates, (i.e. when Name.metadata.container is CONTACT), it is
      # recommended for clients to set either the `unstructured_name` or the set of
      # structured name fields, not both. * When only the `unstructured_name` is set,
      # it is parsed to produce a best-guess set of structured name values for the `
      # given_name`, `family_name`, etc. * When only the structured name fields are
      # set, the various values are combined to produce an `unstructured_name`. * When
      # both are set, the `unstructured_name` is saved as-is and the structured name
      # fields are saved as-is. This may be confusing as they might not "match". For
      # PROFILE mutates, (i.e. when Name.metadata.container is PROFILE), it is
      # _required_ for clients to use the structured name fields as the unstructured
      # field value is ignored on write. The unstructured name fields are generated
      # for convenience on read. For DEVICE_CONTACTS, see b/156020778.
      class AppsPeopleOzExternalMergedpeopleapiName
        include Google::Apis::Core::Hashable
      
        # Read-only. A name synthesized based on `unstructured_name` and the structured
        # name fields. Example: "John Smith" If a language code is passed in the side
        # channel using http://cs/symbol:framework.rpc.DeprecatedPropagatedLanguageCode.
        # value or http://cs/symbol:google.rpc.context.OriginContext.accept_language and
        # the name does not have `honorific_prefix`, `middle_name`, or `honorific_suffix`
        # set, the language code will be used to format `display_name`. If `
        # include_account_locale` is set on the `MergePersonSourceOptions` and a
        # language code is not passed in the side channel. The language code from go/uls
        # will be used as the language code for formatting `display_name`.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Read-only. A name synthesized based on `unstructured_name` and the structured
        # name fields with the last name first. Example: "Smith, John"
        # Corresponds to the JSON property `displayNameLastFirst`
        # @return [String]
        attr_accessor :display_name_last_first
      
        # Read-only. The source of the display name.
        # Corresponds to the JSON property `displayNameSource`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoDisplayNameSource]
        attr_accessor :display_name_source
      
        # 
        # Corresponds to the JSON property `familyName`
        # @return [String]
        attr_accessor :family_name
      
        # DEPRECATED(b/70571931). Use `unstructured_name` instead.
        # Corresponds to the JSON property `formattedName`
        # @return [String]
        attr_accessor :formatted_name
      
        # 
        # Corresponds to the JSON property `givenName`
        # @return [String]
        attr_accessor :given_name
      
        # 
        # Corresponds to the JSON property `honorificPrefix`
        # @return [String]
        attr_accessor :honorific_prefix
      
        # 
        # Corresponds to the JSON property `honorificSuffix`
        # @return [String]
        attr_accessor :honorific_suffix
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `middleName`
        # @return [String]
        attr_accessor :middle_name
      
        # Container proto for repeated pronunciation objects. For example, a set of
        # pronunciations that can be added to a single name field.
        # Corresponds to the JSON property `pronunciations`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPronunciations]
        attr_accessor :pronunciations
      
        # Read-only. A possibly shorter version of the user's name. - The purpose of
        # this field is to address the needs of UIs where a full display name might be
        # too large to fit. Instead of relying on `first_name`, which might not be
        # present, `short_display_name` is preferred. - This is only available for
        # PROFILE and DOMAIN_PROFILE container types. - About the actual content in this
        # field: will be the first name when it's visible to the requester, or the same
        # as `display_name`, otherwise. A sample scenario where the first name may not
        # be visible is when the limited profile is returned. For more info, see: http://
        # shortn/_9iV7TJ33la
        # Corresponds to the JSON property `shortDisplayName`
        # @return [String]
        attr_accessor :short_display_name
      
        # The free form name value. For contact mutates it is recommended for clients to
        # set either the `unstructured_name` or the set of structured name fields, not
        # both.
        # Corresponds to the JSON property `unstructuredName`
        # @return [String]
        attr_accessor :unstructured_name
      
        # 
        # Corresponds to the JSON property `yomiFamilyName`
        # @return [String]
        attr_accessor :yomi_family_name
      
        # 
        # Corresponds to the JSON property `yomiFullName`
        # @return [String]
        attr_accessor :yomi_full_name
      
        # 
        # Corresponds to the JSON property `yomiGivenName`
        # @return [String]
        attr_accessor :yomi_given_name
      
        # 
        # Corresponds to the JSON property `yomiHonorificPrefix`
        # @return [String]
        attr_accessor :yomi_honorific_prefix
      
        # 
        # Corresponds to the JSON property `yomiHonorificSuffix`
        # @return [String]
        attr_accessor :yomi_honorific_suffix
      
        # 
        # Corresponds to the JSON property `yomiMiddleName`
        # @return [String]
        attr_accessor :yomi_middle_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @display_name_last_first = args[:display_name_last_first] if args.key?(:display_name_last_first)
          @display_name_source = args[:display_name_source] if args.key?(:display_name_source)
          @family_name = args[:family_name] if args.key?(:family_name)
          @formatted_name = args[:formatted_name] if args.key?(:formatted_name)
          @given_name = args[:given_name] if args.key?(:given_name)
          @honorific_prefix = args[:honorific_prefix] if args.key?(:honorific_prefix)
          @honorific_suffix = args[:honorific_suffix] if args.key?(:honorific_suffix)
          @metadata = args[:metadata] if args.key?(:metadata)
          @middle_name = args[:middle_name] if args.key?(:middle_name)
          @pronunciations = args[:pronunciations] if args.key?(:pronunciations)
          @short_display_name = args[:short_display_name] if args.key?(:short_display_name)
          @unstructured_name = args[:unstructured_name] if args.key?(:unstructured_name)
          @yomi_family_name = args[:yomi_family_name] if args.key?(:yomi_family_name)
          @yomi_full_name = args[:yomi_full_name] if args.key?(:yomi_full_name)
          @yomi_given_name = args[:yomi_given_name] if args.key?(:yomi_given_name)
          @yomi_honorific_prefix = args[:yomi_honorific_prefix] if args.key?(:yomi_honorific_prefix)
          @yomi_honorific_suffix = args[:yomi_honorific_suffix] if args.key?(:yomi_honorific_suffix)
          @yomi_middle_name = args[:yomi_middle_name] if args.key?(:yomi_middle_name)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiNickname
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOccupation
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # The periods that this place is open during the week. The periods are in
      # chronological order, starting with today in the place-local timezone. An empty
      # (but not absent) value indicates a place that is never open, e.g. because it
      # is closed temporarily for renovations.
      class AppsPeopleOzExternalMergedpeopleapiOpeningHours
        include Google::Apis::Core::Hashable
      
        # Is this place open right now? Always present unless we lack time-of-day or
        # timezone data for these opening hours.
        # Corresponds to the JSON property `openNow`
        # @return [Boolean]
        attr_accessor :open_now
        alias_method :open_now?, :open_now
      
        # 
        # Corresponds to the JSON property `periods`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOpeningHoursPeriod>]
        attr_accessor :periods
      
        # Localized strings describing the opening hours of this place, one string for
        # each day of the week. Will be empty if the hours are unknown or could not be
        # converted to localized text. Example: "Sun: 18:00-06:00"
        # Corresponds to the JSON property `weekdayTexts`
        # @return [Array<String>]
        attr_accessor :weekday_texts
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @open_now = args[:open_now] if args.key?(:open_now)
          @periods = args[:periods] if args.key?(:periods)
          @weekday_texts = args[:weekday_texts] if args.key?(:weekday_texts)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOpeningHoursEndpoint
        include Google::Apis::Core::Hashable
      
        # A day of the week, as an integer in the range 0-6. 0 is Sunday, 1 is Monday,
        # etc.
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # A time in 24-hour "hhmm" format (i.e. range is 0000 to 2359).
        # Corresponds to the JSON property `time`
        # @return [String]
        attr_accessor :time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @time = args[:time] if args.key?(:time)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOpeningHoursPeriod
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `close`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOpeningHoursEndpoint]
        attr_accessor :close
      
        # 
        # Corresponds to the JSON property `open`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOpeningHoursEndpoint]
        attr_accessor :open
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @close = args[:close] if args.key?(:close)
          @open = args[:open] if args.key?(:open)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOrganization
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `assignment`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOrganizationAssignment>]
        attr_accessor :assignment
      
        # 
        # Corresponds to the JSON property `certification`
        # @return [String]
        attr_accessor :certification
      
        # 
        # Corresponds to the JSON property `costCenter`
        # @return [String]
        attr_accessor :cost_center
      
        # 
        # Corresponds to the JSON property `current`
        # @return [Boolean]
        attr_accessor :current
        alias_method :current?, :current
      
        # 
        # Corresponds to the JSON property `department`
        # @return [String]
        attr_accessor :department
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `endCalendarDay`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :end_calendar_day
      
        # Clients are encouraged to read the end_calendar_day instead. PeopleApi writes
        # will still use end_ms for legacy callers that are in the
        # legacy_timestamp_event_write_behavior_enabled capability allowlist. New
        # writers must use the calendar_day fields.
        # Corresponds to the JSON property `endMs`
        # @return [Fixnum]
        attr_accessor :end_ms
      
        # 
        # Corresponds to the JSON property `endMsAsNumber`
        # @return [Fixnum]
        attr_accessor :end_ms_as_number
      
        # The `string_type` translated and formatted in the request locale. See go/
        # people-api-howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedStringType`
        # @return [String]
        attr_accessor :formatted_string_type
      
        # 
        # Corresponds to the JSON property `fteMilliPercent`
        # @return [Fixnum]
        attr_accessor :fte_milli_percent
      
        # 
        # Corresponds to the JSON property `importance`
        # @return [Float]
        attr_accessor :importance
      
        # 
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `project`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOrganizationProject>]
        attr_accessor :project
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `startCalendarDay`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :start_calendar_day
      
        # Clients are encouraged to read the start_calendar_day instead. PeopleApi
        # writes will still use start_ms for legacy callers that are in the
        # legacy_timestamp_event_write_behavior_enabled capability allowlist. New
        # writers must use the calendar_day fields.
        # Corresponds to the JSON property `startMs`
        # @return [Fixnum]
        attr_accessor :start_ms
      
        # 
        # Corresponds to the JSON property `startMsAsNumber`
        # @return [Fixnum]
        attr_accessor :start_ms_as_number
      
        # The type of the organization. The type can be free form or one of these
        # predefined values: * `work` * `school`
        # Corresponds to the JSON property `stringType`
        # @return [String]
        attr_accessor :string_type
      
        # 
        # Corresponds to the JSON property `symbol`
        # @return [String]
        attr_accessor :symbol
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `yomiName`
        # @return [String]
        attr_accessor :yomi_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @assignment = args[:assignment] if args.key?(:assignment)
          @certification = args[:certification] if args.key?(:certification)
          @cost_center = args[:cost_center] if args.key?(:cost_center)
          @current = args[:current] if args.key?(:current)
          @department = args[:department] if args.key?(:department)
          @description = args[:description] if args.key?(:description)
          @domain = args[:domain] if args.key?(:domain)
          @end_calendar_day = args[:end_calendar_day] if args.key?(:end_calendar_day)
          @end_ms = args[:end_ms] if args.key?(:end_ms)
          @end_ms_as_number = args[:end_ms_as_number] if args.key?(:end_ms_as_number)
          @formatted_string_type = args[:formatted_string_type] if args.key?(:formatted_string_type)
          @fte_milli_percent = args[:fte_milli_percent] if args.key?(:fte_milli_percent)
          @importance = args[:importance] if args.key?(:importance)
          @location = args[:location] if args.key?(:location)
          @metadata = args[:metadata] if args.key?(:metadata)
          @name = args[:name] if args.key?(:name)
          @project = args[:project] if args.key?(:project)
          @start_calendar_day = args[:start_calendar_day] if args.key?(:start_calendar_day)
          @start_ms = args[:start_ms] if args.key?(:start_ms)
          @start_ms_as_number = args[:start_ms_as_number] if args.key?(:start_ms_as_number)
          @string_type = args[:string_type] if args.key?(:string_type)
          @symbol = args[:symbol] if args.key?(:symbol)
          @title = args[:title] if args.key?(:title)
          @type = args[:type] if args.key?(:type)
          @yomi_name = args[:yomi_name] if args.key?(:yomi_name)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOrganizationAssignment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOrganizationProject
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # Mapped from StandardProjectTag / CustomProjectTag
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @name = args[:name] if args.key?(:name)
          @role = args[:role] if args.key?(:role)
          @type = args[:type] if args.key?(:type)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiOtherKeyword
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The type of the event. The type depends on the `OtherKeyword.source`. `OUTLOOK`
        # source fields must be one of: * `billing_information` * `directory_server` * `
        # keyword` * `mileage` * `sensitivity` * `user` * `subject` All other fields are
        # treated as a `CUSTOM` source field. The value can be free form or one of these
        # predefined values: * `home` * `other` * `work`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @source = args[:source] if args.key?(:source)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Merged-person combines multiple sources of data like contacts and profiles.
      # See go/people-api and go/understanding-merged-person NOTE: Why are all the
      # fields repeated? See go/people-api-concepts#repeated
      class AppsPeopleOzExternalMergedpeopleapiPerson
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `about`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAbout>]
        attr_accessor :about
      
        # 
        # Corresponds to the JSON property `address`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAddress>]
        attr_accessor :address
      
        # Deprecated. If age is needed use `person.age_range_repeated` instead. Please
        # see go/people-api-howto:age on how to correctly get age data.
        # Corresponds to the JSON property `ageRange`
        # @return [String]
        attr_accessor :age_range
      
        # Data on the person's age range, adult status, and age of consent. NOTE: Please
        # read go/people-api-howto:age on how to correctly get age data.
        # Corresponds to the JSON property `ageRangeRepeated`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAgeRangeType>]
        attr_accessor :age_range_repeated
      
        # 
        # Corresponds to the JSON property `birthday`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiBirthday>]
        attr_accessor :birthday
      
        # Used only by contacts, no data will be returned for profiles.
        # Corresponds to the JSON property `braggingRights`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiBraggingRights>]
        attr_accessor :bragging_rights
      
        # b/145671020: Deprecated for Profiles, but not for Contacts.
        # Corresponds to the JSON property `calendar`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCalendar>]
        attr_accessor :calendar
      
        # 
        # Corresponds to the JSON property `certifiedBornBefore`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCertifiedBornBefore>]
        attr_accessor :certified_born_before
      
        # Circles that this person is a member of.
        # Corresponds to the JSON property `circleMembership`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCircleMembership>]
        attr_accessor :circle_membership
      
        # 
        # Corresponds to the JSON property `clientData`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiClientData>]
        attr_accessor :client_data
      
        # 
        # Corresponds to the JSON property `communicationEmail`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCommunicationEmail>]
        attr_accessor :communication_email
      
        # Contact groups that this person is a member of.
        # Corresponds to the JSON property `contactGroupMembership`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiContactGroupMembership>]
        attr_accessor :contact_group_membership
      
        # Contact state and related metadata. See go/fbs-contacts-trash. If this field
        # was requested but is not set on the Person then the contact is in the DEFAULT
        # contact state. This field is read-only, and should not be set on a mutate (e.g.
        # UpdatePerson) call. Clients must call the explicit APIs (e.g. UntrashPerson)
        # to change contact state.
        # Corresponds to the JSON property `contactStateInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiContactStateInfo>]
        attr_accessor :contact_state_info
      
        # DEPRECATED. Now always returns a default cover photo. See go/sunset-cover-
        # photo.
        # Corresponds to the JSON property `coverPhoto`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCoverPhoto>]
        attr_accessor :cover_photo
      
        # 
        # Corresponds to the JSON property `customSchemaField`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCustomSchemaField>]
        attr_accessor :custom_schema_field
      
        # 
        # Corresponds to the JSON property `email`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmail>]
        attr_accessor :email
      
        # Emergency information. See go/emergency-trusted-contacts-papi.
        # Corresponds to the JSON property `emergencyInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEmergencyInfo>]
        attr_accessor :emergency_info
      
        # Event is currently in use by contacts.
        # Corresponds to the JSON property `event`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEvent>]
        attr_accessor :event
      
        # Extension data for the whole person entity.
        # Corresponds to the JSON property `extendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonExtendedData]
        attr_accessor :extended_data
      
        # 
        # Corresponds to the JSON property `externalId`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiExternalId>]
        attr_accessor :external_id
      
        # 
        # Corresponds to the JSON property `fileAs`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFileAs>]
        attr_accessor :file_as
      
        # A fingerprint that can be used to reliably determine if a resource has changed.
        # Externally it is used as part of the etag.
        # Corresponds to the JSON property `fingerprint`
        # @return [String]
        attr_accessor :fingerprint
      
        # 
        # Corresponds to the JSON property `gender`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiGender>]
        attr_accessor :gender
      
        # 
        # Corresponds to the JSON property `im`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiIm>]
        attr_accessor :im
      
        # Ways to send in-app notifications to this person. See go/reachability. This
        # field is read-only and ignored for mutates.
        # Corresponds to the JSON property `inAppNotificationTarget`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInAppNotificationTarget>]
        attr_accessor :in_app_notification_target
      
        # Used only by profile service, deprecated for PeopleAPI and Sharpen. If you
        # aren't sure, contact people-api-users@ and profile-service-eng@.
        # Corresponds to the JSON property `inAppReachability`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInAppReachability>]
        attr_accessor :in_app_reachability
      
        # DEPRECATED. This field isn't populated in people.list.
        # Corresponds to the JSON property `interactionSettings`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInteractionSettings>]
        attr_accessor :interaction_settings
      
        # 
        # Corresponds to the JSON property `interest`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiInterest>]
        attr_accessor :interest
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLanguage>]
        attr_accessor :language
      
        # Fields used in legacy applications. Useful for joining legacy and new data
        # streams. Most applications should not care about these fields.
        # Corresponds to the JSON property `legacyFields`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLegacyFields]
        attr_accessor :legacy_fields
      
        # Settings for the limited profile. See go/limited-profiles-api.
        # Corresponds to the JSON property `limitedProfileSettings`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLimitedProfileSettingsField>]
        attr_accessor :limited_profile_settings
      
        # Other person resources linked indirectly by an edge. The full person or just
        # the IDs may be populated depending on request parameters. We consider linked
        # people distinct people, but they share information. Example: A contact with
        # two outgoing edges. The two edges are considered separate, but linked people.
        # Corresponds to the JSON property `linkedPerson`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :linked_person
      
        # 
        # Corresponds to the JSON property `location`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLocation>]
        attr_accessor :location
      
        # 
        # Corresponds to the JSON property `managementUpchain`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiManagementUpchain>]
        attr_accessor :management_upchain
      
        # MapsProfile, see go/product-profiles-backend-api
        # Corresponds to the JSON property `mapsProfile`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMapsProfile>]
        attr_accessor :maps_profile
      
        # DEPRECATED. Please use `circle_membership` or `contact_group_membership`
        # instead. Contact-groups and circles that this person is a member of.
        # Corresponds to the JSON property `membership`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMembership>]
        attr_accessor :membership
      
        # Metadata for the entire Person resource.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `mission`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMission>]
        attr_accessor :mission
      
        # See go/people-api-howto:names for details about names in PeopleAPI.
        # Corresponds to the JSON property `name`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiName>]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `nickname`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiNickname>]
        attr_accessor :nickname
      
        # 
        # Corresponds to the JSON property `occupation`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOccupation>]
        attr_accessor :occupation
      
        # 
        # Corresponds to the JSON property `organization`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOrganization>]
        attr_accessor :organization
      
        # Legacy arbitrary key value fields
        # Corresponds to the JSON property `otherKeyword`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOtherKeyword>]
        attr_accessor :other_keyword
      
        # DEPRECATED. This feature was stubbed, but never implemented. This field will
        # not be populated with any results.
        # Corresponds to the JSON property `peopleInCommon`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :people_in_common
      
        # In order to request this field, the client must set desired PersonAttributeKey
        # in the dedicated RequestMask field `person_attribute`. Unlike other person
        # fields, this field cannot be requested in the `include_field` field mask.
        # Corresponds to the JSON property `personAttribute`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonAttribute>]
        attr_accessor :person_attribute
      
        # The ID of the person. This is determined by the backend, is unstable, and may
        # not be the same as a user_id. Internally referred as 'personKey' to
        # distinguish from the common PersonId pojo. See go/fwgau
        # Corresponds to the JSON property `personId`
        # @return [String]
        attr_accessor :person_id
      
        # 
        # Corresponds to the JSON property `phone`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPhone>]
        attr_accessor :phone
      
        # See go/people-api-concepts/photos for usage details
        # Corresponds to the JSON property `photo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPhoto>]
        attr_accessor :photo
      
        # Data specific to places. Data which also applies to contacts and profiles such
        # as name, phone, photo, etc. are returned in the corresponding Person fields.
        # Corresponds to the JSON property `placeDetails`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPlaceDetails>]
        attr_accessor :place_details
      
        # DEPRECATED. Info about plus pages in the person.
        # Corresponds to the JSON property `plusPageInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPlusPageInfo>]
        attr_accessor :plus_page_info
      
        # 
        # Corresponds to the JSON property `posixAccount`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPosixAccount>]
        attr_accessor :posix_account
      
        # DEPRECATED. (go/people-api-concepts#repeated): Use person.profile_url_repeated
        # instead. Access to this field is restricted to a set of legacy clients. This
        # is a Google+-only field. See go/fbs-g+-deprecation. NOTE: `Person.profile_url`
        # is only populated for profile-centric person.
        # Corresponds to the JSON property `profileUrl`
        # @return [String]
        attr_accessor :profile_url
      
        # This is a Google+-only field. See go/fbs-g+-deprecation.
        # Corresponds to the JSON property `profileUrlRepeated`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProfileUrl>]
        attr_accessor :profile_url_repeated
      
        # 
        # Corresponds to the JSON property `pronoun`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPronoun>]
        attr_accessor :pronoun
      
        # Information about the profiles that are a part of this Person. This is only
        # applicable to PROFILE and DOMAIN_PROFILE containers.
        # Corresponds to the JSON property `readOnlyProfileInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiReadOnlyProfileInfo>]
        attr_accessor :read_only_profile_info
      
        # 
        # Corresponds to the JSON property `relation`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRelation>]
        attr_accessor :relation
      
        # DEPRECATED. No data is returned for this field anymore.
        # Corresponds to the JSON property `relationshipInterest`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRelationshipInterest>]
        attr_accessor :relationship_interest
      
        # DEPRECATED. No data is returned for this field anymore.
        # Corresponds to the JSON property `relationshipStatus`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRelationshipStatus>]
        attr_accessor :relationship_status
      
        # 
        # Corresponds to the JSON property `rightOfPublicityState`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRightOfPublicityState>]
        attr_accessor :right_of_publicity_state
      
        # Data specific to rosters (such as Google Groups and Chat Rooms). Data which
        # also applies to contacts and profiles such as name, email, and photo, etc are
        # returned in the corresponding Person fields.
        # Corresponds to the JSON property `rosterDetails`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRosterDetails>]
        attr_accessor :roster_details
      
        # Profile for Janata and Search. go/janata-profile-in-sgbe
        # Corresponds to the JSON property `searchProfile`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSearchProfile>]
        attr_accessor :search_profile
      
        # SipAddress is currently in use by contacts.
        # Corresponds to the JSON property `sipAddress`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSipAddress>]
        attr_accessor :sip_address
      
        # 
        # Corresponds to the JSON property `skills`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSkills>]
        attr_accessor :skills
      
        # NOTE: this is used by go/starlight, but not actually used or returned in
        # PeopleAPI. See b/27281119 for context. Please reach out to people-api-eng@ if
        # you have questions.
        # Corresponds to the JSON property `socialConnection`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSocialConnection>]
        attr_accessor :social_connection
      
        # 
        # Corresponds to the JSON property `sortKeys`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSortKeys]
        attr_accessor :sort_keys
      
        # 
        # Corresponds to the JSON property `sshPublicKey`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiSshPublicKey>]
        attr_accessor :ssh_public_key
      
        # Only supported for PLACE container results, no data will be returned for
        # profiles.
        # Corresponds to the JSON property `tagline`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiTagline>]
        attr_accessor :tagline
      
        # *UNSUPPORTED*. This message is never populated and is no longer used.
        # Corresponds to the JSON property `teamsExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiTeamsExtendedData]
        attr_accessor :teams_extended_data
      
        # UserDefined is currently in use by contacts.
        # Corresponds to the JSON property `userDefined`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiUserDefined>]
        attr_accessor :user_defined
      
        # Add annotation_id and metadata (product_source) for visible to guests contacts
        # go/visible-to-guests.
        # Corresponds to the JSON property `visibleToGuests`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiVisibleToGuests>]
        attr_accessor :visible_to_guests
      
        # 
        # Corresponds to the JSON property `website`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiWebsite>]
        attr_accessor :website
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @about = args[:about] if args.key?(:about)
          @address = args[:address] if args.key?(:address)
          @age_range = args[:age_range] if args.key?(:age_range)
          @age_range_repeated = args[:age_range_repeated] if args.key?(:age_range_repeated)
          @birthday = args[:birthday] if args.key?(:birthday)
          @bragging_rights = args[:bragging_rights] if args.key?(:bragging_rights)
          @calendar = args[:calendar] if args.key?(:calendar)
          @certified_born_before = args[:certified_born_before] if args.key?(:certified_born_before)
          @circle_membership = args[:circle_membership] if args.key?(:circle_membership)
          @client_data = args[:client_data] if args.key?(:client_data)
          @communication_email = args[:communication_email] if args.key?(:communication_email)
          @contact_group_membership = args[:contact_group_membership] if args.key?(:contact_group_membership)
          @contact_state_info = args[:contact_state_info] if args.key?(:contact_state_info)
          @cover_photo = args[:cover_photo] if args.key?(:cover_photo)
          @custom_schema_field = args[:custom_schema_field] if args.key?(:custom_schema_field)
          @email = args[:email] if args.key?(:email)
          @emergency_info = args[:emergency_info] if args.key?(:emergency_info)
          @event = args[:event] if args.key?(:event)
          @extended_data = args[:extended_data] if args.key?(:extended_data)
          @external_id = args[:external_id] if args.key?(:external_id)
          @file_as = args[:file_as] if args.key?(:file_as)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @gender = args[:gender] if args.key?(:gender)
          @im = args[:im] if args.key?(:im)
          @in_app_notification_target = args[:in_app_notification_target] if args.key?(:in_app_notification_target)
          @in_app_reachability = args[:in_app_reachability] if args.key?(:in_app_reachability)
          @interaction_settings = args[:interaction_settings] if args.key?(:interaction_settings)
          @interest = args[:interest] if args.key?(:interest)
          @language = args[:language] if args.key?(:language)
          @legacy_fields = args[:legacy_fields] if args.key?(:legacy_fields)
          @limited_profile_settings = args[:limited_profile_settings] if args.key?(:limited_profile_settings)
          @linked_person = args[:linked_person] if args.key?(:linked_person)
          @location = args[:location] if args.key?(:location)
          @management_upchain = args[:management_upchain] if args.key?(:management_upchain)
          @maps_profile = args[:maps_profile] if args.key?(:maps_profile)
          @membership = args[:membership] if args.key?(:membership)
          @metadata = args[:metadata] if args.key?(:metadata)
          @mission = args[:mission] if args.key?(:mission)
          @name = args[:name] if args.key?(:name)
          @nickname = args[:nickname] if args.key?(:nickname)
          @occupation = args[:occupation] if args.key?(:occupation)
          @organization = args[:organization] if args.key?(:organization)
          @other_keyword = args[:other_keyword] if args.key?(:other_keyword)
          @people_in_common = args[:people_in_common] if args.key?(:people_in_common)
          @person_attribute = args[:person_attribute] if args.key?(:person_attribute)
          @person_id = args[:person_id] if args.key?(:person_id)
          @phone = args[:phone] if args.key?(:phone)
          @photo = args[:photo] if args.key?(:photo)
          @place_details = args[:place_details] if args.key?(:place_details)
          @plus_page_info = args[:plus_page_info] if args.key?(:plus_page_info)
          @posix_account = args[:posix_account] if args.key?(:posix_account)
          @profile_url = args[:profile_url] if args.key?(:profile_url)
          @profile_url_repeated = args[:profile_url_repeated] if args.key?(:profile_url_repeated)
          @pronoun = args[:pronoun] if args.key?(:pronoun)
          @read_only_profile_info = args[:read_only_profile_info] if args.key?(:read_only_profile_info)
          @relation = args[:relation] if args.key?(:relation)
          @relationship_interest = args[:relationship_interest] if args.key?(:relationship_interest)
          @relationship_status = args[:relationship_status] if args.key?(:relationship_status)
          @right_of_publicity_state = args[:right_of_publicity_state] if args.key?(:right_of_publicity_state)
          @roster_details = args[:roster_details] if args.key?(:roster_details)
          @search_profile = args[:search_profile] if args.key?(:search_profile)
          @sip_address = args[:sip_address] if args.key?(:sip_address)
          @skills = args[:skills] if args.key?(:skills)
          @social_connection = args[:social_connection] if args.key?(:social_connection)
          @sort_keys = args[:sort_keys] if args.key?(:sort_keys)
          @ssh_public_key = args[:ssh_public_key] if args.key?(:ssh_public_key)
          @tagline = args[:tagline] if args.key?(:tagline)
          @teams_extended_data = args[:teams_extended_data] if args.key?(:teams_extended_data)
          @user_defined = args[:user_defined] if args.key?(:user_defined)
          @visible_to_guests = args[:visible_to_guests] if args.key?(:visible_to_guests)
          @website = args[:website] if args.key?(:website)
        end
      end
      
      # Client-specific binary blob stored with Person data. This differs from
      # ClientData, which stores structured, key-value pairs.
      class AppsPeopleOzExternalMergedpeopleapiPersonAttribute
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attributeKey`
        # @return [String]
        attr_accessor :attribute_key
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_key = args[:attribute_key] if args.key?(:attribute_key)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Extension data for the whole person entity.
      class AppsPeopleOzExternalMergedpeopleapiPersonExtendedData
        include Google::Apis::Core::Hashable
      
        # Extension data for use in AboutMe.
        # Corresponds to the JSON property `aboutMeExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAboutMeExtendedData]
        attr_accessor :about_me_extended_data
      
        # Waldo-related extension data.
        # Corresponds to the JSON property `appsWaldoExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionAppsWaldoExtendedData]
        attr_accessor :apps_waldo_extended_data
      
        # For use with caller ID extension
        # Corresponds to the JSON property `callerIdExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCallerIdExtendedData]
        attr_accessor :caller_id_extended_data
      
        # For use with Contacts extension.
        # Corresponds to the JSON property `contactsExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiWebContactsExtendedData]
        attr_accessor :contacts_extended_data
      
        # Hosted domain this person is a member of. The domain_name is also returned as
        # part of the person's ReadOnlyProfileInfo, so requesting it via this extension
        # is no longer necessary.
        # Corresponds to the JSON property `domainName`
        # @return [Array<String>]
        attr_accessor :domain_name
      
        # Dynamite-related extension data.
        # Corresponds to the JSON property `dynamiteExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionDynamiteExtendedData]
        attr_accessor :dynamite_extended_data
      
        # Extension data for use in GPay Product Profile. go/gpay-product-profile-1-
        # pager Contact: profiles-eng-fe@google.com
        # Corresponds to the JSON property `gpayExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiGPayExtendedData]
        attr_accessor :gpay_extended_data
      
        # For use with Google+ extension.
        # Corresponds to the JSON property `gplusExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiGplusExtendedData]
        attr_accessor :gplus_extended_data
      
        # Extension data for use in Hangouts.
        # Corresponds to the JSON property `hangoutsExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiHangoutsExtendedData]
        attr_accessor :hangouts_extended_data
      
        # For use with gmail extensions and lookup by email. If true, no person was
        # actually found using the specified email address, but we want to return TLS
        # info about the email address regardless.
        # Corresponds to the JSON property `isPlaceholder`
        # @return [Boolean]
        attr_accessor :is_placeholder
        alias_method :is_placeholder?, :is_placeholder
      
        # Extension data for use in Maps Product Profile.
        # Corresponds to the JSON property `mapsExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMapsExtendedData]
        attr_accessor :maps_extended_data
      
        # Next tag number: 3
        # Corresponds to the JSON property `paisaExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionPaisaExtendedData]
        attr_accessor :paisa_extended_data
      
        # DEPRECATED: Use people_stack_person_extended_data instead. For use with
        # PeopleStack extension.
        # Corresponds to the JSON property `peopleStackExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionPeopleStackExtendedData]
        attr_accessor :people_stack_extended_data
      
        # NEXT_ID: 5
        # Corresponds to the JSON property `peopleStackPersonExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiExtensionPeopleStackPersonExtendedData]
        attr_accessor :people_stack_person_extended_data
      
        # Extension data for use in Play Games Product Profile. See go/jam-games-profile.
        # Corresponds to the JSON property `playGamesExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPlayGamesExtendedData]
        attr_accessor :play_games_extended_data
      
        # For use with the TLS extension and lookup by email. If true, no person was
        # actually found using the specified email address, but we want to return TLS
        # info about the email address regardless. DEPRECATED: Use is_placeholder
        # instead.
        # Corresponds to the JSON property `tlsIsPlaceholder`
        # @return [Boolean]
        attr_accessor :tls_is_placeholder
        alias_method :tls_is_placeholder?, :tls_is_placeholder
      
        # Extension data for use in Youtube Product Profile.
        # Corresponds to the JSON property `youtubeExtendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiYoutubeExtendedData]
        attr_accessor :youtube_extended_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @about_me_extended_data = args[:about_me_extended_data] if args.key?(:about_me_extended_data)
          @apps_waldo_extended_data = args[:apps_waldo_extended_data] if args.key?(:apps_waldo_extended_data)
          @caller_id_extended_data = args[:caller_id_extended_data] if args.key?(:caller_id_extended_data)
          @contacts_extended_data = args[:contacts_extended_data] if args.key?(:contacts_extended_data)
          @domain_name = args[:domain_name] if args.key?(:domain_name)
          @dynamite_extended_data = args[:dynamite_extended_data] if args.key?(:dynamite_extended_data)
          @gpay_extended_data = args[:gpay_extended_data] if args.key?(:gpay_extended_data)
          @gplus_extended_data = args[:gplus_extended_data] if args.key?(:gplus_extended_data)
          @hangouts_extended_data = args[:hangouts_extended_data] if args.key?(:hangouts_extended_data)
          @is_placeholder = args[:is_placeholder] if args.key?(:is_placeholder)
          @maps_extended_data = args[:maps_extended_data] if args.key?(:maps_extended_data)
          @paisa_extended_data = args[:paisa_extended_data] if args.key?(:paisa_extended_data)
          @people_stack_extended_data = args[:people_stack_extended_data] if args.key?(:people_stack_extended_data)
          @people_stack_person_extended_data = args[:people_stack_person_extended_data] if args.key?(:people_stack_person_extended_data)
          @play_games_extended_data = args[:play_games_extended_data] if args.key?(:play_games_extended_data)
          @tls_is_placeholder = args[:tls_is_placeholder] if args.key?(:tls_is_placeholder)
          @youtube_extended_data = args[:youtube_extended_data] if args.key?(:youtube_extended_data)
        end
      end
      
      # Metadata for a single Person field. See go/understanding-merged-person
      class AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata
        include Google::Apis::Core::Hashable
      
        # When the container is PROFILE/DOMAIN_PROFILE and the profile owner is the
        # requester, this read-only, synthesized field indicates which ACLs the user is
        # allowed to set on the profile field. This is distinct from field_acl, which is
        # the field's currently set ACL. field_acl will always be a valid ACL choice,
        # except for the case of default synthesized profile fields like monogram
        # profile photos. For those, field_acl does not represent a user-set field ACL,
        # so it may or may not be a valid choice. In all cases, default_acl_choice will
        # always be a valid choice. This is currently only populated on the photo field
        # when the "person.photo.metadata.acl_choices" mask is set.
        # Corresponds to the JSON property `aclChoices`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAcl>]
        attr_accessor :acl_choices
      
        # Additional information about a container. TO BE DELETED: replaced by
        # DeviceContactInfo.
        # Corresponds to the JSON property `additionalContainerInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAdditionalContainerInfo]
        attr_accessor :additional_container_info
      
        # For field-level affinity scores. The affinity between the requester and this
        # particular field in the Person (e.g., frequency of calling a particular phone
        # number).
        # Corresponds to the JSON property `affinity`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAffinity>]
        attr_accessor :affinity
      
        # Each field can have different visibility settings Only returned when
        # explicitly requested.
        # Corresponds to the JSON property `contactVisibility`
        # @return [Array<String>]
        attr_accessor :contact_visibility
      
        # DEPRECATED. Use container_type instead. Having the Container be an enum at the
        # PFM message level causes circular dependency when other types try to refer to
        # it. It breaks javascript build targets.
        # Corresponds to the JSON property `container`
        # @return [String]
        attr_accessor :container
      
        # DEPRECATED. Use encoded_container_id instead. The numeric id of the data
        # source. The id is only unique within a single container type. This is only set
        # when the id of the container is numeric, e.g. contact id.
        # Corresponds to the JSON property `containerId`
        # @return [Fixnum]
        attr_accessor :container_id
      
        # Indicates if this field is the primary field for the container and
        # container_id.
        # Corresponds to the JSON property `containerPrimary`
        # @return [Boolean]
        attr_accessor :container_primary
        alias_method :container_primary?, :container_primary
      
        # The source for the data in the field.
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # True if this field can be used on other devices than the one it originated
        # from. Assigned by the server. Currently only used for device contacts.
        # Corresponds to the JSON property `crossDeviceAllowed`
        # @return [Boolean]
        attr_accessor :cross_device_allowed
        alias_method :cross_device_allowed?, :cross_device_allowed
      
        # The field ACL. Currently only populated on profile fields for the profile
        # owner. A Person field ACL; see http://go/peopleapi-acl
        # Corresponds to the JSON property `defaultAclChoice`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAcl]
        attr_accessor :default_acl_choice
      
        # DEPRECATED. Use container_id. Not populated or used at all.
        # Corresponds to the JSON property `deprecatedContactContainerId`
        # @return [Fixnum]
        attr_accessor :deprecated_contact_container_id
      
        # Field is an edge key for this person. Modifying it breaks the link between
        # data sources. This is equivalent to edge_key_info having at least one entry
        # with materialized = true.
        # Corresponds to the JSON property `edgeKey`
        # @return [Boolean]
        attr_accessor :edge_key
        alias_method :edge_key?, :edge_key
      
        # Edges that this field creates. This includes all edges and not necessarily
        # just the edge relevant to the joined entities.
        # Corresponds to the JSON property `edgeKeyInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiEdgeKeyInfo>]
        attr_accessor :edge_key_info
      
        # The encoded id of the data source. The id is only unique within a single
        # container type. This field correlates to person.metadata.identity_info.
        # source_id.id. This field may not be populated in some special cases, where the
        # id is not visible to the querying user. e.g. ListAutocompletions with full
        # phone number query.
        # Corresponds to the JSON property `encodedContainerId`
        # @return [String]
        attr_accessor :encoded_container_id
      
        # The field ACL. Currently only populated on profile fields for the profile
        # owner. A Person field ACL; see http://go/peopleapi-acl
        # Corresponds to the JSON property `fieldAcl`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldAcl]
        attr_accessor :field_acl
      
        # Indicates the time that the field was added or last edited. Currently this is
        # populated for: (1) person.birthday with ContainerType PROFILE, DOMAIN_PROFILE
        # or ACCOUNT. (2) person.name, person.address, person.relation, person.email and
        # person.phone with ContainerType CONTACT_ANNOTATION;
        # Corresponds to the JSON property `lastUpdateTime`
        # @return [String]
        attr_accessor :last_update_time
      
        # The matching informations if there was a query against this field.
        # Corresponds to the JSON property `matchingInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiMatchInfo>]
        attr_accessor :matching_info
      
        # When deduping fields by value, list of containers of the fields that where
        # deduped.
        # Corresponds to the JSON property `otherDedupedContainers`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDedupedContainerInfo>]
        attr_accessor :other_deduped_containers
      
        # If true, indicates this field is the Person's primary field eg. Contact, and (
        # Profile) Person could have different Name fields, and the Name represented by
        # the Person is primary. For selecting a primary field from RepeatedFields
        # within a Person, use container_primary.
        # Corresponds to the JSON property `primary`
        # @return [Boolean]
        attr_accessor :primary
        alias_method :primary?, :primary
      
        # The product(s) that generated the data in this field. Empty is equivalent to
        # DEFAULT. ST_USER_METADATA
        # Corresponds to the JSON property `productMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProductMetadata>]
        attr_accessor :product_metadata
      
        # Indicates whether this is a verified field. It is synthesized from
        # verification and is read-only. If there is at least one verification with
        # status PASSED, the field is considered verified. Currently this is applicable
        # to address, email, name, and phone for PROFILE and DOMAIN_PROFILE. Use .
        # metadata.verified in the request mask.
        # Corresponds to the JSON property `verified`
        # @return [Boolean]
        attr_accessor :verified
        alias_method :verified?, :verified
      
        # Currently, only people.get may set this value
        # Corresponds to the JSON property `visibility`
        # @return [String]
        attr_accessor :visibility
      
        # Whether the field is writeable to the requester.
        # Corresponds to the JSON property `writeable`
        # @return [Boolean]
        attr_accessor :writeable
        alias_method :writeable?, :writeable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acl_choices = args[:acl_choices] if args.key?(:acl_choices)
          @additional_container_info = args[:additional_container_info] if args.key?(:additional_container_info)
          @affinity = args[:affinity] if args.key?(:affinity)
          @contact_visibility = args[:contact_visibility] if args.key?(:contact_visibility)
          @container = args[:container] if args.key?(:container)
          @container_id = args[:container_id] if args.key?(:container_id)
          @container_primary = args[:container_primary] if args.key?(:container_primary)
          @container_type = args[:container_type] if args.key?(:container_type)
          @cross_device_allowed = args[:cross_device_allowed] if args.key?(:cross_device_allowed)
          @default_acl_choice = args[:default_acl_choice] if args.key?(:default_acl_choice)
          @deprecated_contact_container_id = args[:deprecated_contact_container_id] if args.key?(:deprecated_contact_container_id)
          @edge_key = args[:edge_key] if args.key?(:edge_key)
          @edge_key_info = args[:edge_key_info] if args.key?(:edge_key_info)
          @encoded_container_id = args[:encoded_container_id] if args.key?(:encoded_container_id)
          @field_acl = args[:field_acl] if args.key?(:field_acl)
          @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
          @matching_info = args[:matching_info] if args.key?(:matching_info)
          @other_deduped_containers = args[:other_deduped_containers] if args.key?(:other_deduped_containers)
          @primary = args[:primary] if args.key?(:primary)
          @product_metadata = args[:product_metadata] if args.key?(:product_metadata)
          @verified = args[:verified] if args.key?(:verified)
          @visibility = args[:visibility] if args.key?(:visibility)
          @writeable = args[:writeable] if args.key?(:writeable)
        end
      end
      
      # A person list with total number specified.
      class AppsPeopleOzExternalMergedpeopleapiPersonListWithTotalNumber
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `people`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :people
      
        # The total number of people, which is aways no less than the size of the above
        # list.
        # Corresponds to the JSON property `totalNumber`
        # @return [Fixnum]
        attr_accessor :total_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @people = args[:people] if args.key?(:people)
          @total_number = args[:total_number] if args.key?(:total_number)
        end
      end
      
      # Metadata for the entire Person resource.
      class AppsPeopleOzExternalMergedpeopleapiPersonMetadata
        include Google::Apis::Core::Hashable
      
        # Affinities associated with the person, with respect to the requester.
        # Corresponds to the JSON property `affinity`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAffinity>]
        attr_accessor :affinity
      
        # Populated when the data for the MergedPerson comes from a 3rd party provider
        # or data source. Clients must display these attributions to the user if they
        # are present. NOTE: This field is only relevant when requesting the following
        # containers: - PLACE (data read from Maps)
        # Corresponds to the JSON property `attribution`
        # @return [Array<String>]
        attr_accessor :attribution
      
        # The best suggested name to use for the Person from the available source fields,
        # which may include FileAs, Name, Org, Email, IM, Phone, ... Rough source
        # container priority order is Contact, then Profile, then Place.
        # Corresponds to the JSON property `bestDisplayName`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiBestDisplayName]
        attr_accessor :best_display_name
      
        # DEPRECATED. Indicates whether the profile owner has blocked this person.
        # Please use `person.read_only_profile_info.block_type` instead.
        # Corresponds to the JSON property `blockType`
        # @return [Array<String>]
        attr_accessor :block_type
      
        # DEPRECATED. The circles the person belongs to.
        # Corresponds to the JSON property `circleId`
        # @return [Array<String>]
        attr_accessor :circle_id
      
        # DEPRECATED. Please use `person.contact_group_memberships` instead. The contact
        # groups the person belongs to.
        # Corresponds to the JSON property `contactGroupId`
        # @return [Array<String>]
        attr_accessor :contact_group_id
      
        # The IDs of all contacts contributing to this person.
        # Corresponds to the JSON property `contactId`
        # @return [Array<Fixnum>]
        attr_accessor :contact_id
      
        # DEPRECATED. Customized masking of the response similar to the legacy
        # People2RequestMask People2Params request message. NOTE: This param is
        # inherently client-specific, limited to specific legacy clients, and not open
        # to new usage. NOTE: Effects may be applied to a subset of people in the
        # response.
        # Corresponds to the JSON property `customResponseMaskingType`
        # @return [String]
        attr_accessor :custom_response_masking_type
      
        # For sync requests (i.e., changed since the provided sync_token), indicates the
        # resource is a tombstone for a Person resource that has been entirely deleted.
        # Corresponds to the JSON property `deleted`
        # @return [Boolean]
        attr_accessor :deleted
        alias_method :deleted?, :deleted
      
        # DEPRECATED. Please use `person.read_only_profile_info.block_type` instead.
        # Corresponds to the JSON property `deprecatedBlocked`
        # @return [Boolean]
        attr_accessor :deprecated_blocked
        alias_method :deprecated_blocked?, :deprecated_blocked
      
        # DEPRECATED. This field is no longer populated or read.
        # Corresponds to the JSON property `deprecatedMembershipCircleId`
        # @return [Array<Fixnum>]
        attr_accessor :deprecated_membership_circle_id
      
        # DEPRECATED. This field is no longer populated or read.
        # Corresponds to the JSON property `deprecatedMembershipContactGroupId`
        # @return [Array<Fixnum>]
        attr_accessor :deprecated_membership_contact_group_id
      
        # Info about the aggregated device contacts. When the person contains
        # RAW_DEVICE_CONTACT containers, each DeviceContactInfo represents a single
        # aggregate device contact made up of one or more raw device contacts.
        # Corresponds to the JSON property `deviceContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDeviceContactInfo>]
        attr_accessor :device_contact_info
      
        # Detailed metadata about the lookup IDs and data sources included in a
        # MergedPerson result.
        # Corresponds to the JSON property `identityInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiIdentityInfo]
        attr_accessor :identity_info
      
        # DEPRECATED. Indicates whether this person is in the same domain as the viewer.
        # For proxying trust between two users based on organization membership, see: -
        # go/flex-orgs-platform - go/flex-orgs-compliance-handbook (especially http://
        # shortn/_ChwfAY36Ys)
        # Corresponds to the JSON property `inViewerDomain`
        # @return [Boolean]
        attr_accessor :in_viewer_domain
        alias_method :in_viewer_domain?, :in_viewer_domain
      
        # DEPRECATED. Indicates whether this person is blocking the profile owner.
        # Please use `person.read_only_profile_info.incoming_block_type` instead.
        # Corresponds to the JSON property `incomingBlockType`
        # @return [Array<String>]
        attr_accessor :incoming_block_type
      
        # DEPRECATED. The last update timestamps for the constituent components of this
        # person are available in `identity_info.source_ids`. The time of the most
        # recent change to this person, in !!!NANOS!!! (due to a bug). May be a change
        # to any of the underlying parts of the person (profile, contact, etc.). Not
        # guaranteed to be the timestamp of the most recent change, due to limitations
        # in the backend. This field is not fully deprecated for backend container-
        # specific storage services like ProfileService which lack identity_info. The
        # use is still discouraged in such systems and they should prefer to use the `
        # last_update_time` field of this message instead.
        # Corresponds to the JSON property `lastUpdateTimeMicros`
        # @return [Fixnum]
        attr_accessor :last_update_time_micros
      
        # The person model that is used to construct this person.
        # Corresponds to the JSON property `model`
        # @return [String]
        attr_accessor :model
      
        # DEPRECATED.
        # Corresponds to the JSON property `objectType`
        # @return [String]
        attr_accessor :object_type
      
        # DEPRECATED. Please use `person.read_only_profile_info.owner_id` instead.
        # Corresponds to the JSON property `ownerId`
        # @return [String]
        attr_accessor :owner_id
      
        # DEPRECATED. See `person.read_only_profile_info.owner_user_type` instead.
        # Corresponds to the JSON property `ownerUserType`
        # @return [Array<String>]
        attr_accessor :owner_user_type
      
        # DEPRECATED. Please use `Person.plus_page_info` instead.
        # Corresponds to the JSON property `plusPageType`
        # @return [String]
        attr_accessor :plus_page_type
      
        # DEPRECATED. This field is no longer populated or read.
        # Corresponds to the JSON property `previousPersonId`
        # @return [Array<String>]
        attr_accessor :previous_person_id
      
        # Stats pertaining to incoming edges and views, visible to the requester (with
        # acls applied). Related to, but not equal to, com.google.focus.proto.Storage.
        # UserVisibleStats.
        # Corresponds to the JSON property `profileOwnerStats`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProfileOwnerStats]
        attr_accessor :profile_owner_stats
      
        # Contact people-directory-dev-team@ if you want to use this field.
        # Corresponds to the JSON property `scoringInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonMetadataScoringInfo]
        attr_accessor :scoring_info
      
        # DEPRECATED in favor of ProfileStats. Stats pertaining to incoming edges and
        # views, visible to the requester (with acls applied). Related to, but not equal
        # to, com.google.focus.proto.Storage.UserVisibleStats.
        # Corresponds to the JSON property `userVisibleStats`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiUserVisibleStats]
        attr_accessor :user_visible_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @affinity = args[:affinity] if args.key?(:affinity)
          @attribution = args[:attribution] if args.key?(:attribution)
          @best_display_name = args[:best_display_name] if args.key?(:best_display_name)
          @block_type = args[:block_type] if args.key?(:block_type)
          @circle_id = args[:circle_id] if args.key?(:circle_id)
          @contact_group_id = args[:contact_group_id] if args.key?(:contact_group_id)
          @contact_id = args[:contact_id] if args.key?(:contact_id)
          @custom_response_masking_type = args[:custom_response_masking_type] if args.key?(:custom_response_masking_type)
          @deleted = args[:deleted] if args.key?(:deleted)
          @deprecated_blocked = args[:deprecated_blocked] if args.key?(:deprecated_blocked)
          @deprecated_membership_circle_id = args[:deprecated_membership_circle_id] if args.key?(:deprecated_membership_circle_id)
          @deprecated_membership_contact_group_id = args[:deprecated_membership_contact_group_id] if args.key?(:deprecated_membership_contact_group_id)
          @device_contact_info = args[:device_contact_info] if args.key?(:device_contact_info)
          @identity_info = args[:identity_info] if args.key?(:identity_info)
          @in_viewer_domain = args[:in_viewer_domain] if args.key?(:in_viewer_domain)
          @incoming_block_type = args[:incoming_block_type] if args.key?(:incoming_block_type)
          @last_update_time_micros = args[:last_update_time_micros] if args.key?(:last_update_time_micros)
          @model = args[:model] if args.key?(:model)
          @object_type = args[:object_type] if args.key?(:object_type)
          @owner_id = args[:owner_id] if args.key?(:owner_id)
          @owner_user_type = args[:owner_user_type] if args.key?(:owner_user_type)
          @plus_page_type = args[:plus_page_type] if args.key?(:plus_page_type)
          @previous_person_id = args[:previous_person_id] if args.key?(:previous_person_id)
          @profile_owner_stats = args[:profile_owner_stats] if args.key?(:profile_owner_stats)
          @scoring_info = args[:scoring_info] if args.key?(:scoring_info)
          @user_visible_stats = args[:user_visible_stats] if args.key?(:user_visible_stats)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiPersonMetadataScoringInfo
        include Google::Apis::Core::Hashable
      
        # Only populated on a SearchDirectoryPeople call, when results are scored.
        # Contact people-directory-dev-team@ if you want to use this field.
        # Corresponds to the JSON property `rawMatchQualityScore`
        # @return [Float]
        attr_accessor :raw_match_quality_score
      
        # Only populated on a SearchDirectoryPeople call that sends a request with
        # StFieldSpecExpressions. - Used for linking indexed terms with query terms for
        # go/better-name-matching - Name should be alphanumeric or underscores - Value
        # should be an st expression following the syntax at go/stsyntax Contact people-
        # directory-dev-team@ if you want to use this field.
        # Corresponds to the JSON property `stExpressionResults`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonMetadataScoringInfoStExpressionResult>]
        attr_accessor :st_expression_results
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_match_quality_score = args[:raw_match_quality_score] if args.key?(:raw_match_quality_score)
          @st_expression_results = args[:st_expression_results] if args.key?(:st_expression_results)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiPersonMetadataScoringInfoStExpressionResult
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiPhone
        include Google::Apis::Core::Hashable
      
        # Canonicalized form that follows ITU-T E.164 international public
        # telecommunication numbering plan.
        # Corresponds to the JSON property `canonicalizedForm`
        # @return [String]
        attr_accessor :canonicalized_form
      
        # Emergency information for Person field, such as Phone or Email. See go/
        # emergency-trusted-contacts-papi.
        # Corresponds to the JSON property `emergencyInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiFieldEmergencyInfo]
        attr_accessor :emergency_info
      
        # Read-only. Field requested by specifying `HANGOUTS_PHONE_DATA` in `
        # extension_set.extension_names`.
        # Corresponds to the JSON property `extendedData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPhoneExtendedData]
        attr_accessor :extended_data
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The type of the phone number. The type can be free form or one of these
        # predefined values: * `home` * `work` * `mobile` * `homeFax` * `workFax` * `
        # otherFax` * `pager` * `workMobile` * `workPager` * `main` * `googleVoice` * `
        # other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `uri`
        # @return [String]
        attr_accessor :uri
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonicalized_form = args[:canonicalized_form] if args.key?(:canonicalized_form)
          @emergency_info = args[:emergency_info] if args.key?(:emergency_info)
          @extended_data = args[:extended_data] if args.key?(:extended_data)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
          @uri = args[:uri] if args.key?(:uri)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiPhoneExtendedData
        include Google::Apis::Core::Hashable
      
        # This message mirrors the ContactPhoneNumber message in ccc/grand_central/
        # common/types.proto. For various reasons, we cannot take on a direct dependency.
        # See other proto file for most recent documentation.
        # Corresponds to the JSON property `structuredPhone`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiStructuredPhone]
        attr_accessor :structured_phone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @structured_phone = args[:structured_phone] if args.key?(:structured_phone)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiPhoto
        include Google::Apis::Core::Hashable
      
        # URL of an emoji avatar as an image. See go/emoji-cdn. PeopleAPI will return
        # the SVG format so that it can be scaled client side and so that the images
        # will not be animated. All clients that use this field must also have fall-back
        # handling for using the `Photo.url` field if this is empty. When we have FIFE-
        # compatible emoji-image URLs we will drop this field and return the Photo.url
        # instead. Clients that have their own go/emoji-rendering integration may prefer
        # to render the emoji-avatar from `Photo.glyph` field using their rendering
        # system so that the emoji version/style match the rest of the application. For
        # further background, see go/chatroom-avatar-as-roster-metadata. This field will
        # only be populated if all of: - The PersonFieldMetadata `container_type` for
        # the Photo is NAMED_CHAT_ROOM - The chat room has an emoji type avatar image
        # set
        # Corresponds to the JSON property `emojiAvatarUrl`
        # @return [String]
        attr_accessor :emoji_avatar_url
      
        # Unicode emoji representation of the chat room emoji avatar. This can be used
        # by clients that use go/emoji-rendering directly so that they can present this
        # with the same version/style as the rest of their application. This value may
        # also be useful to clients as alt-text for the image. This field will only be
        # populated if all of: - The PersonFieldMetadata `container_type` for the Photo
        # is NAMED_CHAT_ROOM - The chat room has an emoji type avatar image set
        # Corresponds to the JSON property `glyph`
        # @return [String]
        attr_accessor :glyph
      
        # A set of HTML data provider attributions that must be shown with the result.
        # Supported for PLACES photos only. See: go/understanding-places-api-attribution-
        # requirements
        # Corresponds to the JSON property `htmlAttribution`
        # @return [Array<String>]
        attr_accessor :html_attribution
      
        # True when the photo is synthetic or generated (i.e. a monogram or default
        # photo), false when the person has a custom photo.
        # Corresponds to the JSON property `isDefault`
        # @return [Boolean]
        attr_accessor :is_default
        alias_method :is_default?, :is_default
      
        # Indicates if the photo is a monogram avatar. Combined with is_default, the
        # type of photo can be determined by: is_default=true, is_monogram=true: Default
        # monogram avatar. is_default=true, is_monogram=false: Default silhouette avatar.
        # is_default=false: Custom photo. is_monogram is irrelevant in this case.
        # Corresponds to the JSON property `isMonogram`
        # @return [Boolean]
        attr_accessor :is_monogram
        alias_method :is_monogram?, :is_monogram
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # When is_monogram=true, this is the background color of the monogram photo as a
        # hex RGB formatted string "RRGGBB".
        # Corresponds to the JSON property `monogramBackground`
        # @return [String]
        attr_accessor :monogram_background
      
        # Info necessary for looking up a photo in storage.
        # Corresponds to the JSON property `photoId`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPhotoPhotoStorageId]
        attr_accessor :photo_id
      
        # Most clients don't need to worry about this field and should just use the `url`
        # to fetch the photo. See go/phototoken-migration-plan for some more context
        # about this field. If you think you want to use this please talk with people-
        # api-eng@ first.
        # Corresponds to the JSON property `photoToken`
        # @return [String]
        attr_accessor :photo_token
      
        # See go/people-api-concepts/photos for info on the different representations of
        # URLs.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # A URL for a UI to view the photo in its original context. For example, for a
        # place photo, this is the url of a Google Maps page displaying the photo.
        # Supported for place photos only.
        # Corresponds to the JSON property `viewerUrl`
        # @return [String]
        attr_accessor :viewer_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @emoji_avatar_url = args[:emoji_avatar_url] if args.key?(:emoji_avatar_url)
          @glyph = args[:glyph] if args.key?(:glyph)
          @html_attribution = args[:html_attribution] if args.key?(:html_attribution)
          @is_default = args[:is_default] if args.key?(:is_default)
          @is_monogram = args[:is_monogram] if args.key?(:is_monogram)
          @metadata = args[:metadata] if args.key?(:metadata)
          @monogram_background = args[:monogram_background] if args.key?(:monogram_background)
          @photo_id = args[:photo_id] if args.key?(:photo_id)
          @photo_token = args[:photo_token] if args.key?(:photo_token)
          @url = args[:url] if args.key?(:url)
          @viewer_url = args[:viewer_url] if args.key?(:viewer_url)
        end
      end
      
      # Info necessary for looking up a photo in storage.
      class AppsPeopleOzExternalMergedpeopleapiPhotoPhotoStorageId
        include Google::Apis::Core::Hashable
      
        # For writes only, pass the media key that represents the image in photos
        # backend. Note, this is not populated on reads.
        # Corresponds to the JSON property `mediaKey`
        # @return [String]
        attr_accessor :media_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @media_key = args[:media_key] if args.key?(:media_key)
        end
      end
      
      # Metadata specific to places.
      class AppsPeopleOzExternalMergedpeopleapiPlaceDetails
        include Google::Apis::Core::Hashable
      
        # A URL hosted by Google providing more information about this place This is the
        # URL returned by Places API in the Place.Url.google field
        # Corresponds to the JSON property `googleUrl`
        # @return [String]
        attr_accessor :google_url
      
        # 
        # Corresponds to the JSON property `latLng`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiLatLng]
        attr_accessor :lat_lng
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The periods that this place is open during the week. The periods are in
        # chronological order, starting with today in the place-local timezone. An empty
        # (but not absent) value indicates a place that is never open, e.g. because it
        # is closed temporarily for renovations.
        # Corresponds to the JSON property `openingHours`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiOpeningHours]
        attr_accessor :opening_hours
      
        # The name of the primary type. Examples of primary type are: "art_school", "
        # clothing_wholesaler", etc. All primary types can be found at http://shortn/
        # _veqh6UwWdc
        # Corresponds to the JSON property `primaryTypeName`
        # @return [String]
        attr_accessor :primary_type_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @google_url = args[:google_url] if args.key?(:google_url)
          @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
          @metadata = args[:metadata] if args.key?(:metadata)
          @opening_hours = args[:opening_hours] if args.key?(:opening_hours)
          @primary_type_name = args[:primary_type_name] if args.key?(:primary_type_name)
        end
      end
      
      # Extension data for use in Play Games Product Profile. See go/jam-games-profile.
      class AppsPeopleOzExternalMergedpeopleapiPlayGamesExtendedData
        include Google::Apis::Core::Hashable
      
        # User's top achievements that are sorted for example by rarity.
        # Corresponds to the JSON property `achievements`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPlayGamesExtendedDataAchievement>]
        attr_accessor :achievements
      
        # The avatar image to display for the user.
        # Corresponds to the JSON property `avatarImageUrl`
        # @return [String]
        attr_accessor :avatar_image_url
      
        # Product profiles failure type: the status of the rpc to fetch the product
        # profile.
        # Corresponds to the JSON property `failure`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProductProfileFailure]
        attr_accessor :failure
      
        # The gamer tag set by the user. Not set if the user hasn't set a gamer tag yet.
        # Corresponds to the JSON property `gamerTag`
        # @return [String]
        attr_accessor :gamer_tag
      
        # User's level.
        # Corresponds to the JSON property `playerLevel`
        # @return [Fixnum]
        attr_accessor :player_level
      
        # Specifies the visibility of the player's profile.
        # Corresponds to the JSON property `profileVisibility`
        # @return [String]
        attr_accessor :profile_visibility
      
        # Total number of friends.
        # Corresponds to the JSON property `totalFriendsCount`
        # @return [Fixnum]
        attr_accessor :total_friends_count
      
        # How many achievements this player has unlocked.
        # Corresponds to the JSON property `totalUnlockedAchievements`
        # @return [Fixnum]
        attr_accessor :total_unlocked_achievements
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @achievements = args[:achievements] if args.key?(:achievements)
          @avatar_image_url = args[:avatar_image_url] if args.key?(:avatar_image_url)
          @failure = args[:failure] if args.key?(:failure)
          @gamer_tag = args[:gamer_tag] if args.key?(:gamer_tag)
          @player_level = args[:player_level] if args.key?(:player_level)
          @profile_visibility = args[:profile_visibility] if args.key?(:profile_visibility)
          @total_friends_count = args[:total_friends_count] if args.key?(:total_friends_count)
          @total_unlocked_achievements = args[:total_unlocked_achievements] if args.key?(:total_unlocked_achievements)
        end
      end
      
      # Details of an achievement that the user has unlocked.
      class AppsPeopleOzExternalMergedpeopleapiPlayGamesExtendedDataAchievement
        include Google::Apis::Core::Hashable
      
        # The name of the achievement.
        # Corresponds to the JSON property `achievementName`
        # @return [String]
        attr_accessor :achievement_name
      
        # The achievement icon url shown to the user if it is unlocked.
        # Corresponds to the JSON property `achievementUnlockedIconUrl`
        # @return [String]
        attr_accessor :achievement_unlocked_icon_url
      
        # Rarity of unlocking this achievement (3% of players unlocked would be 3)
        # Corresponds to the JSON property `rarityPercentage`
        # @return [Float]
        attr_accessor :rarity_percentage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @achievement_name = args[:achievement_name] if args.key?(:achievement_name)
          @achievement_unlocked_icon_url = args[:achievement_unlocked_icon_url] if args.key?(:achievement_unlocked_icon_url)
          @rarity_percentage = args[:rarity_percentage] if args.key?(:rarity_percentage)
        end
      end
      
      # Information about a plus page and the entity it represents.
      class AppsPeopleOzExternalMergedpeopleapiPlusPageInfo
        include Google::Apis::Core::Hashable
      
        # Int64 ID of packaging-service entry; if set, the plus page is associated with
        # a third-party application.
        # Corresponds to the JSON property `applicationId`
        # @return [Fixnum]
        attr_accessor :application_id
      
        # 
        # Corresponds to the JSON property `entityType`
        # @return [String]
        attr_accessor :entity_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_id = args[:application_id] if args.key?(:application_id)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Map marker location for an address.
      class AppsPeopleOzExternalMergedpeopleapiPointSpec
        include Google::Apis::Core::Hashable
      
        # A latitude-longitude rectangle, represented as two diagonally opposite points "
        # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
        # includes its boundary. The latitude bounds must be in the range -90 to 90
        # degrees inclusive, and the longitude bounds must be in the range -180 to 180
        # degrees inclusive. Various cases include: - If lo == hi, the rectangle
        # consists of a single point. - If lo.longitude > hi.longitude, the longitude
        # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
        # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
        # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
        # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
        # latitude range is empty.
        # Corresponds to the JSON property `bounds`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRectProto]
        attr_accessor :bounds
      
        # 
        # Corresponds to the JSON property `point`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point
      
        # 
        # Corresponds to the JSON property `pointSource`
        # @return [String]
        attr_accessor :point_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounds = args[:bounds] if args.key?(:bounds)
          @point = args[:point] if args.key?(:point)
          @point_source = args[:point_source] if args.key?(:point_source)
        end
      end
      
      # Custom field that represents POSIX account information. Description of the
      # field family: go/fbs-posix. If account has non-empty Username or Uid we will
      # enforce global uniqueness of (AccountNamespace, CustomerKey, SystemId, Uid)
      # and (AccountNamespace, CustomerKey, SystemId, Username) tuples to ensure there
      # are no duplicates.
      class AppsPeopleOzExternalMergedpeopleapiPosixAccount
        include Google::Apis::Core::Hashable
      
        # The user visible value is used to distinguish identical posix account fields
        # with different customer key values.
        # Corresponds to the JSON property `accountId`
        # @return [String]
        attr_accessor :account_id
      
        # Value indicates the uniqueness namespace that applies to the POSIX information.
        # The value is included in all POSIX account uniqueness indices. The indexing
        # prevents two accounts within the same customer from having the same username.
        # Namespacing allows Windows and Linux users to share the same username.
        # Corresponds to the JSON property `accountNamespace`
        # @return [String]
        attr_accessor :account_namespace
      
        # Value indicates whether the POSIX information is associated with a non-human
        # entity and the validation logic to apply during PosixAccount mutation.
        # Corresponds to the JSON property `accountType`
        # @return [String]
        attr_accessor :account_type
      
        # The customer associated with the POSIX identity. If the user is already
        # associated with a G Suite Customer, this field has the same value as http://
        # google3/ccc/hosted/policies/settings/dthree_customer_info.proto
        # Corresponds to the JSON property `customerKey`
        # @return [Fixnum]
        attr_accessor :customer_key
      
        # The value is automatically set to a SHA-256 fingerprint of the POSIX account.
        # A fingerprint should uniquely identify a POSIX account entry.
        # Corresponds to the JSON property `fingerprint`
        # @return [String]
        attr_accessor :fingerprint
      
        # The GECOS (user information) entry for this account.
        # Corresponds to the JSON property `gecos`
        # @return [String]
        attr_accessor :gecos
      
        # The default group ID.
        # Corresponds to the JSON property `gid`
        # @return [Fixnum]
        attr_accessor :gid
      
        # The path to the home directory for this account.
        # Corresponds to the JSON property `homeDirectory`
        # @return [String]
        attr_accessor :home_directory
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Value indicates whether to use Linux or Windows specific validation logic
        # during PosixAccount mutation.
        # Corresponds to the JSON property `operatingSystemType`
        # @return [String]
        attr_accessor :operating_system_type
      
        # The path to the login shell for this account.
        # Corresponds to the JSON property `shell`
        # @return [String]
        attr_accessor :shell
      
        # System identifier for which account Username or Uid apply to. If not specified
        # on mutate by a caller it will default to empty value if either Username or Uid
        # are being set. SystemId does require to have a value (even an empty one)
        # because it is included into null-filtered Spanner index used to enforce
        # uniqueness on Username and Uid fields.
        # Corresponds to the JSON property `systemId`
        # @return [String]
        attr_accessor :system_id
      
        # The user ID.
        # Corresponds to the JSON property `uid`
        # @return [Fixnum]
        attr_accessor :uid
      
        # The username of the account.
        # Corresponds to the JSON property `username`
        # @return [String]
        attr_accessor :username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_id = args[:account_id] if args.key?(:account_id)
          @account_namespace = args[:account_namespace] if args.key?(:account_namespace)
          @account_type = args[:account_type] if args.key?(:account_type)
          @customer_key = args[:customer_key] if args.key?(:customer_key)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @gecos = args[:gecos] if args.key?(:gecos)
          @gid = args[:gid] if args.key?(:gid)
          @home_directory = args[:home_directory] if args.key?(:home_directory)
          @metadata = args[:metadata] if args.key?(:metadata)
          @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
          @shell = args[:shell] if args.key?(:shell)
          @system_id = args[:system_id] if args.key?(:system_id)
          @uid = args[:uid] if args.key?(:uid)
          @username = args[:username] if args.key?(:username)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiProductMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `productSource`
        # @return [String]
        attr_accessor :product_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @product_source = args[:product_source] if args.key?(:product_source)
        end
      end
      
      # Product profiles failure type: the status of the rpc to fetch the product
      # profile.
      class AppsPeopleOzExternalMergedpeopleapiProductProfileFailure
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `failureType`
        # @return [String]
        attr_accessor :failure_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @failure_type = args[:failure_type] if args.key?(:failure_type)
        end
      end
      
      # Stats pertaining to incoming edges and views, visible to the requester (with
      # acls applied). Related to, but not equal to, com.google.focus.proto.Storage.
      # UserVisibleStats.
      class AppsPeopleOzExternalMergedpeopleapiProfileOwnerStats
        include Google::Apis::Core::Hashable
      
        # Replacement for deprecated follower_count. Comes from the EdgeSummary.
        # Corresponds to the JSON property `incomingAnyCircleCount`
        # @return [Fixnum]
        attr_accessor :incoming_any_circle_count
      
        # Deprecated. This field is no longer populated by the server.
        # Corresponds to the JSON property `viewCount`
        # @return [Fixnum]
        attr_accessor :view_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @incoming_any_circle_count = args[:incoming_any_circle_count] if args.key?(:incoming_any_circle_count)
          @view_count = args[:view_count] if args.key?(:view_count)
        end
      end
      
      # This is a Google+-only field (and thus does not exist for consumer users). See
      # go/fbs-g+-deprecation.
      class AppsPeopleOzExternalMergedpeopleapiProfileUrl
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Message to represent a user's set of preferred pronouns, see go/pronouns-
      # backend.
      class AppsPeopleOzExternalMergedpeopleapiPronoun
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Design doc: go/pronouns-backend Represents a user's preferred pronouns.
        # Corresponds to the JSON property `pronounData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPronounData]
        attr_accessor :pronoun_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @pronoun_data = args[:pronoun_data] if args.key?(:pronoun_data)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiRawDeviceContactAnalyticalInfo
        include Google::Apis::Core::Hashable
      
        # The data set within the account that this raw contact belongs to.
        # Corresponds to the JSON property `dataSet`
        # @return [String]
        attr_accessor :data_set
      
        # The CP2 dirty field which indicates the sync state of the raw contact: https://
        # developer.android.com/reference/android/provider/ContactsContract.SyncColumns#
        # DIRTY True if the row is changed but not synced
        # Corresponds to the JSON property `dirty`
        # @return [Boolean]
        attr_accessor :dirty
        alias_method :dirty?, :dirty
      
        # Whether the source ID exists for non-Google contacts. Won't set for Google
        # contacts.
        # Corresponds to the JSON property `sourceIdExist`
        # @return [Boolean]
        attr_accessor :source_id_exist
        alias_method :source_id_exist?, :source_id_exist
      
        # LINT.IfChange
        # Corresponds to the JSON property `syncInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSyncInfo]
        attr_accessor :sync_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_set = args[:data_set] if args.key?(:data_set)
          @dirty = args[:dirty] if args.key?(:dirty)
          @source_id_exist = args[:source_id_exist] if args.key?(:source_id_exist)
          @sync_info = args[:sync_info] if args.key?(:sync_info)
        end
      end
      
      # Raw device contact information.
      class AppsPeopleOzExternalMergedpeopleapiRawDeviceContactInfo
        include Google::Apis::Core::Hashable
      
        # Account name of raw contact, e.g. "google@gmail.com".
        # Corresponds to the JSON property `accountName`
        # @return [String]
        attr_accessor :account_name
      
        # Account type of raw contact, e.g. "com.google" or "com.linkedin.android".
        # Corresponds to the JSON property `accountType`
        # @return [String]
        attr_accessor :account_type
      
        # The detailed app-specific endpoint data available for the given
        # RawDeviceContactInfo instance. This proto should be used to obtain the list of
        # actions and mimetypes supported by the third-party app. Design: go/3p-contact-
        # upload
        # Corresponds to the JSON property `appContactData`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiAppContactData>]
        attr_accessor :app_contact_data
      
        # Store all app unique info that are needed for app action fulfillment.
        # Corresponds to the JSON property `appInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAppUniqueInfo]
        attr_accessor :app_info
      
        # If true, this raw contact can be used on other devices than the one it
        # originated from. Assigned by the server.
        # Corresponds to the JSON property `crossDeviceAllowed`
        # @return [Boolean]
        attr_accessor :cross_device_allowed
        alias_method :cross_device_allowed?, :cross_device_allowed
      
        # Extra metadata for an aggregated or raw device contact.
        # Corresponds to the JSON property `deviceContactMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiDeviceContactExtraMetadata]
        attr_accessor :device_contact_metadata
      
        # The focus contact id for Google contacts.
        # Corresponds to the JSON property `googleContactId`
        # @return [Fixnum]
        attr_accessor :google_contact_id
      
        # The base64 serialized social.graph.peopleapi.proto.internal.RawDeviceContactId.
        # This id should be used to correlate to field.metadata.encoded_container_id
        # when the field.metadata.container_type is RAW_DEVICE_CONTACT The id also
        # correlates to person.metadata.identity_info.source_id.id.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The type of photo from the device (if any).
        # Corresponds to the JSON property `photoType`
        # @return [String]
        attr_accessor :photo_type
      
        # The id of the raw contact on the device.
        # Corresponds to the JSON property `rawContactId`
        # @return [Fixnum]
        attr_accessor :raw_contact_id
      
        # Only to be used by Romanesco team specifically for analytics.
        # Corresponds to the JSON property `rawDeviceContactAnalyticalInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRawDeviceContactAnalyticalInfo]
        attr_accessor :raw_device_contact_analytical_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_name = args[:account_name] if args.key?(:account_name)
          @account_type = args[:account_type] if args.key?(:account_type)
          @app_contact_data = args[:app_contact_data] if args.key?(:app_contact_data)
          @app_info = args[:app_info] if args.key?(:app_info)
          @cross_device_allowed = args[:cross_device_allowed] if args.key?(:cross_device_allowed)
          @device_contact_metadata = args[:device_contact_metadata] if args.key?(:device_contact_metadata)
          @google_contact_id = args[:google_contact_id] if args.key?(:google_contact_id)
          @id = args[:id] if args.key?(:id)
          @photo_type = args[:photo_type] if args.key?(:photo_type)
          @raw_contact_id = args[:raw_contact_id] if args.key?(:raw_contact_id)
          @raw_device_contact_analytical_info = args[:raw_device_contact_analytical_info] if args.key?(:raw_device_contact_analytical_info)
        end
      end
      
      # Metadata information about a profile. This message replaces legacy profile-
      # specific singleton fields from the PersonMetadata proto (singleton top level
      # Person fields are not compatible with non-profile-centric person results,
      # which may include multiple profile containers).
      class AppsPeopleOzExternalMergedpeopleapiReadOnlyProfileInfo
        include Google::Apis::Core::Hashable
      
        # The account email linked to the profile, if any exists and is visible to the
        # requester.
        # Corresponds to the JSON property `accountEmail`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAccountEmail]
        attr_accessor :account_email
      
        # Indicates whether the profile owner has blocked this person.
        # Corresponds to the JSON property `blockType`
        # @return [Array<String>]
        attr_accessor :block_type
      
        # Contains customer data for profile owner proxied from D3.
        # Corresponds to the JSON property `customerInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiCustomerInfo]
        attr_accessor :customer_info
      
        # DEPRECATED.
        # Corresponds to the JSON property `domainInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiReadOnlyProfileInfoDomainInfo]
        attr_accessor :domain_info
      
        # DEPRECATED. Proxying trust between users in a domain should use go/flex-orgs-
        # platform. For more info see: http://doc/18i0-
        # C7vWcz2UuXYBsmulnriVCK3_EuMPpRlPa2OmMHw#heading=h.dobotdwx25kg Indicates
        # whether the profile owner is in the same domain as the viewer.
        # Corresponds to the JSON property `inViewerDomain`
        # @return [Boolean]
        attr_accessor :in_viewer_domain
        alias_method :in_viewer_domain?, :in_viewer_domain
      
        # Indicates whether this person is blocking the profile owner.
        # Corresponds to the JSON property `incomingBlockType`
        # @return [Array<String>]
        attr_accessor :incoming_block_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # DEPRECATED.
        # Corresponds to the JSON property `objectType`
        # @return [String]
        attr_accessor :object_type
      
        # The Focus-obfuscated Gaia ID of the profile owner (go/obfuscated-ids).
        # Corresponds to the JSON property `ownerId`
        # @return [String]
        attr_accessor :owner_id
      
        # 
        # Corresponds to the JSON property `ownerUserType`
        # @return [Array<String>]
        attr_accessor :owner_user_type
      
        # DEPRECATED. Please use `person.plus_page_info` instead.
        # Corresponds to the JSON property `plusPageType`
        # @return [String]
        attr_accessor :plus_page_type
      
        # Stats pertaining to incoming edges and views, visible to the requester (with
        # acls applied). Related to, but not equal to, com.google.focus.proto.Storage.
        # UserVisibleStats.
        # Corresponds to the JSON property `profileOwnerStats`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProfileOwnerStats]
        attr_accessor :profile_owner_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_email = args[:account_email] if args.key?(:account_email)
          @block_type = args[:block_type] if args.key?(:block_type)
          @customer_info = args[:customer_info] if args.key?(:customer_info)
          @domain_info = args[:domain_info] if args.key?(:domain_info)
          @in_viewer_domain = args[:in_viewer_domain] if args.key?(:in_viewer_domain)
          @incoming_block_type = args[:incoming_block_type] if args.key?(:incoming_block_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @object_type = args[:object_type] if args.key?(:object_type)
          @owner_id = args[:owner_id] if args.key?(:owner_id)
          @owner_user_type = args[:owner_user_type] if args.key?(:owner_user_type)
          @plus_page_type = args[:plus_page_type] if args.key?(:plus_page_type)
          @profile_owner_stats = args[:profile_owner_stats] if args.key?(:profile_owner_stats)
        end
      end
      
      # DEPRECATED.
      class AppsPeopleOzExternalMergedpeopleapiReadOnlyProfileInfoDomainInfo
        include Google::Apis::Core::Hashable
      
        # DEPRECATED. Organization badge for the domain this person is a member of. The
        # badge is the primary hosted domain.
        # Corresponds to the JSON property `domainBadge`
        # @return [Array<String>]
        attr_accessor :domain_badge
      
        # DEPRECATED. Hosted domain this person is a member of. Formerly only available
        # via PersonExtendedData.
        # Corresponds to the JSON property `domainName`
        # @return [Array<String>]
        attr_accessor :domain_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain_badge = args[:domain_badge] if args.key?(:domain_badge)
          @domain_name = args[:domain_name] if args.key?(:domain_name)
        end
      end
      
      # Relation stores the related person between the contact or profile and a third
      # person This field currently includes RelationshipToMe data in fields value and
      # canonical_value for ContainerType CONTACT_ANNOTATION. This will be moved to
      # RelationshipToMe in b/221081499.
      class AppsPeopleOzExternalMergedpeopleapiRelation
        include Google::Apis::Core::Hashable
      
        # Canonicalized `value` of the relation from this person to the user. This is
        # currently used for data from contact annotations. Possible canonical values
        # are based from http://google3/googledata/quality/aliases/relationship_en.
        # config.
        # Corresponds to the JSON property `canonicalValue`
        # @return [String]
        attr_accessor :canonical_value
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The person whose email matches the Relation.value field, if it is a valid
        # email address. This field is read-only and ignored on update.
        # Corresponds to the JSON property `relationDetails`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRelationRelationDetails]
        attr_accessor :relation_details
      
        # The relation type. The type can be free form or one of these predefined values:
        # * `spouse` * `child` * `mother` * `father` * `parent` * `brother` * `sister` *
        # `friend` * `relative` * `domesticPartner` * `manager` * `assistant` * `
        # referredBy` * `partner`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The person this relation applies to. Custom value provided by the user.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_value = args[:canonical_value] if args.key?(:canonical_value)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @relation_details = args[:relation_details] if args.key?(:relation_details)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiRelationRelationDetails
        include Google::Apis::Core::Hashable
      
        # Equivalent to Name.display_name for the person_id profile.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Equivalent to Organization.title for the primary organization of the person_id
        # profile.
        # Corresponds to the JSON property `jobTitle`
        # @return [String]
        attr_accessor :job_title
      
        # 
        # Corresponds to the JSON property `personId`
        # @return [String]
        attr_accessor :person_id
      
        # Equivalent to Photo.url for the person_id profile.
        # Corresponds to the JSON property `photoUrl`
        # @return [String]
        attr_accessor :photo_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @job_title = args[:job_title] if args.key?(:job_title)
          @person_id = args[:person_id] if args.key?(:person_id)
          @photo_url = args[:photo_url] if args.key?(:photo_url)
        end
      end
      
      # Deprecated in b/122464133. No data returned for this field.
      class AppsPeopleOzExternalMergedpeopleapiRelationshipInterest
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # These fields may give away the sexual orientation of the user.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Deprecated in b/122464133. No data returned for this field.
      class AppsPeopleOzExternalMergedpeopleapiRelationshipStatus
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # User preference for shared endorsements. See go/se-devguide and go/
      # sharedendorsements for details, including guidance on which contexts are which.
      class AppsPeopleOzExternalMergedpeopleapiRightOfPublicityState
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Information specific to rosters like Google Groups and Chatrooms.
      class AppsPeopleOzExternalMergedpeopleapiRosterDetails
        include Google::Apis::Core::Hashable
      
        # Abridged / sample subset of member details of the roster. NOTE: This field is
        # only returned if the request's field mask includes "person.roster_details.
        # abridged_roster_memberships". http://cs/symbol:google.apps.cloudidentity.
        # groups.internal.GroupSummary.abridged_memberships
        # Corresponds to the JSON property `abridgedRosterMemberships`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRosterMember>]
        attr_accessor :abridged_roster_memberships
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Represents the summary of member counts of a roster. Used in RosterDetails.
        # Corresponds to http://cs/symbol:google.apps.cloudidentity.groups.internal.
        # Group.DirectMemberCountPerType
        # Corresponds to the JSON property `rosterMemberCount`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiRosterMemberCount]
        attr_accessor :roster_member_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abridged_roster_memberships = args[:abridged_roster_memberships] if args.key?(:abridged_roster_memberships)
          @metadata = args[:metadata] if args.key?(:metadata)
          @roster_member_count = args[:roster_member_count] if args.key?(:roster_member_count)
        end
      end
      
      # Represents details of a member of a roster. Used in RosterDetails. Corresponds
      # to http://cs/symbol:google.apps.cloudidentity.groups.internal.Membership
      class AppsPeopleOzExternalMergedpeopleapiRosterMember
        include Google::Apis::Core::Hashable
      
        # Type of the member.
        # Corresponds to the JSON property `memberType`
        # @return [String]
        attr_accessor :member_type
      
        # Focus-Obfuscated Gaia Id of the member.
        # Corresponds to the JSON property `personId`
        # @return [String]
        attr_accessor :person_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @member_type = args[:member_type] if args.key?(:member_type)
          @person_id = args[:person_id] if args.key?(:person_id)
        end
      end
      
      # Represents the summary of member counts of a roster. Used in RosterDetails.
      # Corresponds to http://cs/symbol:google.apps.cloudidentity.groups.internal.
      # Group.DirectMemberCountPerType
      class AppsPeopleOzExternalMergedpeopleapiRosterMemberCount
        include Google::Apis::Core::Hashable
      
        # Indicates the number of direct sub-rosters of the roster. This comes from http:
        # //cs/symbol:google.apps.cloudidentity.groups.internal.Group.
        # DirectMemberCountPerType.group_count
        # Corresponds to the JSON property `directGroupCount`
        # @return [Fixnum]
        attr_accessor :direct_group_count
      
        # Indicates the number of direct, non-roster members of the roster. This comes
        # from http://cs/symbol:google.apps.cloudidentity.groups.internal.Group.
        # DirectMemberCountPerType.user_count
        # Corresponds to the JSON property `directUserCount`
        # @return [Fixnum]
        attr_accessor :direct_user_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @direct_group_count = args[:direct_group_count] if args.key?(:direct_group_count)
          @direct_user_count = args[:direct_user_count] if args.key?(:direct_user_count)
        end
      end
      
      # Profile for Janata and Search. go/janata-profile-in-sgbe
      class AppsPeopleOzExternalMergedpeopleapiSearchProfile
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Data contained in every search profile. go/janata-profile-in-sgbe.
        # Corresponds to the JSON property `searchProfileData`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileData]
        attr_accessor :search_profile_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @search_profile_data = args[:search_profile_data] if args.key?(:search_profile_data)
        end
      end
      
      # As of 03/2018 is not supported for user Profile.
      class AppsPeopleOzExternalMergedpeopleapiSipAddress
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # The type of the SIP address. The type can be free form or or one of these
        # predefined values: * `home` * `work` * `mobile` * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiSkills
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # The social connection of this person to the viewer. NOTE: this is used by go/
      # starlight, but not actually used or returned in PeopleAPI. See b/27281119 for
      # context.
      class AppsPeopleOzExternalMergedpeopleapiSocialConnection
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `type`
        # @return [Array<String>]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiSortKeys
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `affinity`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiAffinity>]
        attr_accessor :affinity
      
        # Deprecated. This field is only populated with 0.000 for legacy reasons.
        # Clients should not use this field.
        # Corresponds to the JSON property `interactionRank`
        # @return [String]
        attr_accessor :interaction_rank
      
        # 
        # Corresponds to the JSON property `lastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `lastNameRaw`
        # @return [String]
        attr_accessor :last_name_raw
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Raw name strings that were used to generate the name and last_name sort keys
        # fields above. Contacts+ need them to generate section headers for list view (b/
        # 30642866).
        # Corresponds to the JSON property `nameRaw`
        # @return [String]
        attr_accessor :name_raw
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @affinity = args[:affinity] if args.key?(:affinity)
          @interaction_rank = args[:interaction_rank] if args.key?(:interaction_rank)
          @last_name = args[:last_name] if args.key?(:last_name)
          @last_name_raw = args[:last_name_raw] if args.key?(:last_name_raw)
          @name = args[:name] if args.key?(:name)
          @name_raw = args[:name_raw] if args.key?(:name_raw)
        end
      end
      
      # Id of a single source from the merged person.
      class AppsPeopleOzExternalMergedpeopleapiSourceIdentity
        include Google::Apis::Core::Hashable
      
        # The type of source. To be deprecated infavor of container_type
        # Corresponds to the JSON property `container`
        # @return [String]
        attr_accessor :container
      
        # The type of the source.
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # In sync responses, indicates whether the identity source has been deleted. Not
        # applicable to GOOGLE_GROUP.
        # Corresponds to the JSON property `deleted`
        # @return [Boolean]
        attr_accessor :deleted
        alias_method :deleted?, :deleted
      
        # The encoded id of the data source. This field correlates to
        # PersonFieldMetadata.encoded_container_id. The possible values of this `id`
        # field are as follows based on the value of the `container_type` field: CONTACT:
        # Hex-encoded contact id. PROFILE: DOMAIN_PROFILE: GOOGLE_GROUP:
        # NAMED_CHAT_ROOM: Focus-obfuscated Gaia ID. DOMAIN_CONTACT: Synthetic-contact
        # id representing the domain shared contact. PLACE: Encoded PlaceId, encoded
        # using go/djlcf (PlaceIdEncoder.java) RAW_DEVICE_CONTACT: Pair of device_id and
        # raw_contact_id, encoded as base64 serialized social.graph.peopleapi.proto.
        # internal.RawDeviceContactId proto. CONTACT_ANNOTATION: Pair of annotation_id
        # and event_timestamp, encoded as base64 serialized social.graph.peopleapi.proto.
        # internal.ContactAnnotationId proto. -- DEPRECATED container types -- If the
        # container is CIRCLE, then the id is going to be the synthetic- contact id
        # representing the email-only circle member or gaia circle member for which the
        # requester does not have a contact for.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Last update timestamp of this source. NOTE: Only populated for CONTACT
        # container type in Java PeopleAPI. Populated for CONTACT, PROFILE,
        # DOMAIN_PROFILE in Sharpen implementation. NOTE: Not populated for GOOGLE_GROUP.
        # Corresponds to the JSON property `lastUpdated`
        # @return [String]
        attr_accessor :last_updated
      
        # **DEPRECATED** Please use `last_updated` field instead. Last update timestamp
        # of this source in microseconds. NOTE: Only populated for CONTACT container
        # type.
        # Corresponds to the JSON property `lastUpdatedMicros`
        # @return [Fixnum]
        attr_accessor :last_updated_micros
      
        # NOTE: Not populated for GOOGLE_GROUP.
        # Corresponds to the JSON property `sourceEtag`
        # @return [String]
        attr_accessor :source_etag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @container = args[:container] if args.key?(:container)
          @container_type = args[:container_type] if args.key?(:container_type)
          @deleted = args[:deleted] if args.key?(:deleted)
          @id = args[:id] if args.key?(:id)
          @last_updated = args[:last_updated] if args.key?(:last_updated)
          @last_updated_micros = args[:last_updated_micros] if args.key?(:last_updated_micros)
          @source_etag = args[:source_etag] if args.key?(:source_etag)
        end
      end
      
      # Custom field that represents SSH public keys associated with the user. We can
      # treat the field as a map from a string fingerprint to the SSH public key
      # information.
      class AppsPeopleOzExternalMergedpeopleapiSshPublicKey
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `expirationTime`
        # @return [String]
        attr_accessor :expiration_time
      
        # The value is automatically set to a SHA-256 fingerprint of an SSH public key.
        # A fingerprint should uniquely identify an SSH public key.
        # Corresponds to the JSON property `fingerprint`
        # @return [String]
        attr_accessor :fingerprint
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @key = args[:key] if args.key?(:key)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # This message mirrors the ContactPhoneNumber message in ccc/grand_central/
      # common/types.proto. For various reasons, we cannot take on a direct dependency.
      # See other proto file for most recent documentation.
      class AppsPeopleOzExternalMergedpeopleapiStructuredPhone
        include Google::Apis::Core::Hashable
      
        # The phone formatted type. See docs from mirrored proto: http://google3/ccc/
        # grand_central/common/types.proto?l=128&rcl=241000760
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # 
        # Corresponds to the JSON property `phoneNumber`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiStructuredPhonePhoneNumber]
        attr_accessor :phone_number
      
        # 
        # Corresponds to the JSON property `shortCode`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiStructuredPhoneShortCode]
        attr_accessor :short_code
      
        # The type of phone. See docs from mirrored proto: http://google3/ccc/
        # grand_central/common/types.proto?l=125&rcl=241000760
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @phone_number = args[:phone_number] if args.key?(:phone_number)
          @short_code = args[:short_code] if args.key?(:short_code)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiStructuredPhonePhoneNumber
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `e164`
        # @return [String]
        attr_accessor :e164
      
        # 
        # Corresponds to the JSON property `i18nData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiStructuredPhonePhoneNumberI18nData]
        attr_accessor :i18n_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @e164 = args[:e164] if args.key?(:e164)
          @i18n_data = args[:i18n_data] if args.key?(:i18n_data)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiStructuredPhonePhoneNumberI18nData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [Fixnum]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `internationalNumber`
        # @return [String]
        attr_accessor :international_number
      
        # 
        # Corresponds to the JSON property `isValid`
        # @return [Boolean]
        attr_accessor :is_valid
        alias_method :is_valid?, :is_valid
      
        # 
        # Corresponds to the JSON property `nationalNumber`
        # @return [String]
        attr_accessor :national_number
      
        # 
        # Corresponds to the JSON property `regionCode`
        # @return [String]
        attr_accessor :region_code
      
        # 
        # Corresponds to the JSON property `validationResult`
        # @return [String]
        attr_accessor :validation_result
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @international_number = args[:international_number] if args.key?(:international_number)
          @is_valid = args[:is_valid] if args.key?(:is_valid)
          @national_number = args[:national_number] if args.key?(:national_number)
          @region_code = args[:region_code] if args.key?(:region_code)
          @validation_result = args[:validation_result] if args.key?(:validation_result)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiStructuredPhoneShortCode
        include Google::Apis::Core::Hashable
      
        # The phone code. See docs from mirrored proto: http://google3/ccc/grand_central/
        # common/types.proto?l=70&rcl=241000760
        # Corresponds to the JSON property `code`
        # @return [String]
        attr_accessor :code
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @country_code = args[:country_code] if args.key?(:country_code)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiTagline
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # *UNSUPPORTED*. This message is never populated and is no longer used.
      class AppsPeopleOzExternalMergedpeopleapiTeamsExtendedData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `adminTo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :admin_to
      
        # 
        # Corresponds to the JSON property `admins`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :admins
      
        # 
        # Corresponds to the JSON property `dottedLineManagers`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :dotted_line_managers
      
        # A person list with total number specified.
        # Corresponds to the JSON property `dottedLineReports`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonListWithTotalNumber]
        attr_accessor :dotted_line_reports
      
        # 
        # Corresponds to the JSON property `failures`
        # @return [Array<String>]
        attr_accessor :failures
      
        # 
        # Corresponds to the JSON property `managementChain`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson>]
        attr_accessor :management_chain
      
        # A person list with total number specified.
        # Corresponds to the JSON property `reports`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonListWithTotalNumber]
        attr_accessor :reports
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @admin_to = args[:admin_to] if args.key?(:admin_to)
          @admins = args[:admins] if args.key?(:admins)
          @dotted_line_managers = args[:dotted_line_managers] if args.key?(:dotted_line_managers)
          @dotted_line_reports = args[:dotted_line_reports] if args.key?(:dotted_line_reports)
          @failures = args[:failures] if args.key?(:failures)
          @management_chain = args[:management_chain] if args.key?(:management_chain)
          @reports = args[:reports] if args.key?(:reports)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiUserDefined
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # DEPRECATED in favor of ProfileStats. Stats pertaining to incoming edges and
      # views, visible to the requester (with acls applied). Related to, but not equal
      # to, com.google.focus.proto.Storage.UserVisibleStats.
      class AppsPeopleOzExternalMergedpeopleapiUserVisibleStats
        include Google::Apis::Core::Hashable
      
        # Replacement for deprecated follower_count. Comes from the EdgeSummary.
        # Corresponds to the JSON property `incomingAnyCircleCount`
        # @return [Fixnum]
        attr_accessor :incoming_any_circle_count
      
        # 
        # Corresponds to the JSON property `viewCount`
        # @return [Fixnum]
        attr_accessor :view_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @incoming_any_circle_count = args[:incoming_any_circle_count] if args.key?(:incoming_any_circle_count)
          @view_count = args[:view_count] if args.key?(:view_count)
        end
      end
      
      # Store metadata information like annotation-id and product source for visible
      # to guests contacts go/visible-to-guests.
      class AppsPeopleOzExternalMergedpeopleapiVisibleToGuests
        include Google::Apis::Core::Hashable
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiWebContactsExtendedData
        include Google::Apis::Core::Hashable
      
        # Used by Contacts client-side to indicate whether a person is not completed.
        # Corresponds to the JSON property `isIncomplete`
        # @return [Boolean]
        attr_accessor :is_incomplete
        alias_method :is_incomplete?, :is_incomplete
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_incomplete = args[:is_incomplete] if args.key?(:is_incomplete)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiWebsite
        include Google::Apis::Core::Hashable
      
        # The `type` translated and formatted in the request locale. See go/people-api-
        # howto/localization for details on how to usage.
        # Corresponds to the JSON property `formattedType`
        # @return [String]
        attr_accessor :formatted_type
      
        # Metadata for a single Person field. See go/understanding-merged-person
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPersonFieldMetadata]
        attr_accessor :metadata
      
        # Currently in Oz: "Links": Links with no rel. "Other profiles": Links with rel=
        # ME. "Contributor to": Links with rel=CONTRIBUTOR_TO or PAST_CONTRIBUTOR_TO.
        # Corresponds to the JSON property `rel`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiWebsiteRelationshipInfo>]
        attr_accessor :rel
      
        # The type of the website. The type can be free form or one of these predefined
        # values: * `home` * `work` * `blog` * `profile` * `homePage` * `ftp` * `
        # reservations` * `appInstallPage`: website for a Currents application. * `other`
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted_type = args[:formatted_type] if args.key?(:formatted_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @rel = args[:rel] if args.key?(:rel)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class AppsPeopleOzExternalMergedpeopleapiWebsiteRelationshipInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Extension data for use in Youtube Product Profile.
      class AppsPeopleOzExternalMergedpeopleapiYoutubeExtendedData
        include Google::Apis::Core::Hashable
      
        # Information about a channel created by the user. A user can create multiple
        # Youtube channels.
        # Corresponds to the JSON property `channelData`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiChannelData>]
        attr_accessor :channel_data
      
        # Product profiles failure type: the status of the rpc to fetch the product
        # profile.
        # Corresponds to the JSON property `failure`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiProductProfileFailure]
        attr_accessor :failure
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel_data = args[:channel_data] if args.key?(:channel_data)
          @failure = args[:failure] if args.key?(:failure)
        end
      end
      
      # Access settings for providers.
      class AssistantApiAccessControlOutput
        include Google::Apis::Core::Hashable
      
        # If true, the user consented to use YouTube Kids as a video provider for non-
        # unicorn users(voice recognized adults or guest). Unicorn accounts shouldn’t
        # use this setting.
        # Corresponds to the JSON property `allowNonUnicornUserAccessYoutubeKids`
        # @return [Boolean]
        attr_accessor :allow_non_unicorn_user_access_youtube_kids
        alias_method :allow_non_unicorn_user_access_youtube_kids?, :allow_non_unicorn_user_access_youtube_kids
      
        # 
        # Corresponds to the JSON property `guestAccessOnYoutube`
        # @return [String]
        attr_accessor :guest_access_on_youtube
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_non_unicorn_user_access_youtube_kids = args[:allow_non_unicorn_user_access_youtube_kids] if args.key?(:allow_non_unicorn_user_access_youtube_kids)
          @guest_access_on_youtube = args[:guest_access_on_youtube] if args.key?(:guest_access_on_youtube)
        end
      end
      
      # The features supported by the ActionV2 protocol. Note that after we move on to
      # ConversationProto for all surfaces we can remove this message.
      class AssistantApiActionV2SupportedFeatures
        include Google::Apis::Core::Hashable
      
        # This flag is used to work around a bug in AGSA 6.8 that got away. The bug
        # prevents users from accessing their shopping list if the URL of the shopping
        # list is not a keep.google.com URL. This will happen when switch the backend
        # that stores the shopping list from Keep to a backend maintained by the Google
        # Shopping Express team.
        # Corresponds to the JSON property `expressUrlInSettingsResponseSupported`
        # @return [Boolean]
        attr_accessor :express_url_in_settings_response_supported
        alias_method :express_url_in_settings_response_supported?, :express_url_in_settings_response_supported
      
        # Whether client supports reconnect client input in action v2 payload. This
        # capability is needed to determine if client supports parsing client input
        # payload from actionv2 proto for workflow purposes. See go/personal-workflow.
        # OWNER:nyzstar,vvvemuri.
        # Corresponds to the JSON property `reconnectClientInputSupported`
        # @return [Boolean]
        attr_accessor :reconnect_client_input_supported
        alias_method :reconnect_client_input_supported?, :reconnect_client_input_supported
      
        # Whether or not the surface supports a simple UnsupportedAction instead of a
        # ModalState punt card for rendering. For ActionV2 punt cards, the ModalState
        # extension on the ResourceSet is the canonical way of building punt cards.
        # However, while most all devices support the ActionV2 protocol, not all devices
        # handle the ModalState rendering as part of the ActionV2. For these devices, we
        # want to build a modified ActionV2 for punt cards which omits this ModalState.
        # At present, this is only Android Wear and should not be used for other devices
        # if they support ModalState or Conversation protocol.
        # Corresponds to the JSON property `simpleActionV2PuntSupported`
        # @return [Boolean]
        attr_accessor :simple_action_v2_punt_supported
        alias_method :simple_action_v2_punt_supported?, :simple_action_v2_punt_supported
      
        # A list of all the action types supported by the client. These should be the
        # string representation of majel.ActionTypes within "quality/majel/api/proto/
        # action_v2.proto".
        # Corresponds to the JSON property `supportedActionType`
        # @return [Array<String>]
        attr_accessor :supported_action_type
      
        # Checks if screenshots can be taken on the client. This field is set on the
        # client from AGSA 7.2 onwards.
        # Corresponds to the JSON property `takeScreenshotSupported`
        # @return [Boolean]
        attr_accessor :take_screenshot_supported
        alias_method :take_screenshot_supported?, :take_screenshot_supported
      
        # If IMMERSIVE_ACTIONS UiType is supported by the client.
        # Corresponds to the JSON property `voiceDelightImmersiveUiSupported`
        # @return [Boolean]
        attr_accessor :voice_delight_immersive_ui_supported
        alias_method :voice_delight_immersive_ui_supported?, :voice_delight_immersive_ui_supported
      
        # If Voice Delight Stickers are supported by the client. In order to support
        # Voice Delight stickers, the client should know how to extract sticker_url from
        # VoiceDelightSystemInteractionSegment.
        # Corresponds to the JSON property `voiceDelightStickersSupported`
        # @return [Boolean]
        attr_accessor :voice_delight_stickers_supported
        alias_method :voice_delight_stickers_supported?, :voice_delight_stickers_supported
      
        # If Voice Delight Suggestion Chips are supported by the client. In order to
        # support Voice Delight Suggestion Chips, the client should know how to extract
        # suggestions form VoiceDelightSystemInteraction.ResourceSet.
        # Corresponds to the JSON property `voiceDelightSuggestionsSupported`
        # @return [Boolean]
        attr_accessor :voice_delight_suggestions_supported
        alias_method :voice_delight_suggestions_supported?, :voice_delight_suggestions_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @express_url_in_settings_response_supported = args[:express_url_in_settings_response_supported] if args.key?(:express_url_in_settings_response_supported)
          @reconnect_client_input_supported = args[:reconnect_client_input_supported] if args.key?(:reconnect_client_input_supported)
          @simple_action_v2_punt_supported = args[:simple_action_v2_punt_supported] if args.key?(:simple_action_v2_punt_supported)
          @supported_action_type = args[:supported_action_type] if args.key?(:supported_action_type)
          @take_screenshot_supported = args[:take_screenshot_supported] if args.key?(:take_screenshot_supported)
          @voice_delight_immersive_ui_supported = args[:voice_delight_immersive_ui_supported] if args.key?(:voice_delight_immersive_ui_supported)
          @voice_delight_stickers_supported = args[:voice_delight_stickers_supported] if args.key?(:voice_delight_stickers_supported)
          @voice_delight_suggestions_supported = args[:voice_delight_suggestions_supported] if args.key?(:voice_delight_suggestions_supported)
        end
      end
      
      # Capabilities related to Android intent support. These capabilities can apply
      # to any device on the Android platform. Provides the list of Android package
      # names that support a given Android intent.
      class AssistantApiAndroidIntentCapabilities
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `androidIntentCapability`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiAndroidIntentCapabilitiesAndroidIntentCapability>]
        attr_accessor :android_intent_capability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_intent_capability = args[:android_intent_capability] if args.key?(:android_intent_capability)
        end
      end
      
      # 
      class AssistantApiAndroidIntentCapabilitiesAndroidIntentCapability
        include Google::Apis::Core::Hashable
      
        # The Action name of the Android Intent in standard notation (https://developer.
        # android.com/reference/android/content/Intent#getAction()).
        # Corresponds to the JSON property `intentActionName`
        # @return [String]
        attr_accessor :intent_action_name
      
        # The Android provider packages that support the intent, e.g. "com.google.
        # android.deskclock".
        # Corresponds to the JSON property `packageNames`
        # @return [Array<String>]
        attr_accessor :package_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent_action_name = args[:intent_action_name] if args.key?(:intent_action_name)
          @package_names = args[:package_names] if args.key?(:package_names)
        end
      end
      
      # Used to describe app capabilities of the device installed apps reported to the
      # server.
      class AssistantApiAppCapabilities
        include Google::Apis::Core::Hashable
      
        # Indicates whether the provider is compatible for media fulfillment on this
        # surface. For example, Amazon Music isn't compatible with the driving mode.
        # Corresponds to the JSON property `allowlistedForMediaFulfillment`
        # @return [Boolean]
        attr_accessor :allowlisted_for_media_fulfillment
        alias_method :allowlisted_for_media_fulfillment?, :allowlisted_for_media_fulfillment
      
        # Contains the app privacy bits used for App Integrations implicit request. (go/
        # app-privacy-settings-for-implicit-requests)
        # Corresponds to the JSON property `appIntegrationsSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAppIntegrationsSettings]
        attr_accessor :app_integrations_settings
      
        # This system app is disabled in settings.
        # Corresponds to the JSON property `disabledSystemApp`
        # @return [Boolean]
        attr_accessor :disabled_system_app
        alias_method :disabled_system_app?, :disabled_system_app
      
        # Provider. Like, Spotify or iHeartRadio. Next ID: 13
        # Corresponds to the JSON property `provider`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProvider]
        attr_accessor :provider
      
        # This provider has integrated its cloud backend with Google, and Google can
        # route the user queries to the provider's cloud.
        # Corresponds to the JSON property `routableToProviderCloud`
        # @return [Boolean]
        attr_accessor :routable_to_provider_cloud
        alias_method :routable_to_provider_cloud?, :routable_to_provider_cloud
      
        # This provider has an app that supports on-device search through the provider's
        # own inventory.
        # Corresponds to the JSON property `searchableOnDevice`
        # @return [Boolean]
        attr_accessor :searchable_on_device
        alias_method :searchable_on_device?, :searchable_on_device
      
        # This provider has integrated its content with Google, and Google has enabled
        # to serve its content as a server-side solution.
        # Corresponds to the JSON property `searchableOnServer`
        # @return [Boolean]
        attr_accessor :searchable_on_server
        alias_method :searchable_on_server?, :searchable_on_server
      
        # This provider has an app that supports starting new media playback when there
        # is no screen (e.g. by integrating with the Bisto SDK).
        # Corresponds to the JSON property `supportsScreenlessInitiation`
        # @return [Boolean]
        attr_accessor :supports_screenless_initiation
        alias_method :supports_screenless_initiation?, :supports_screenless_initiation
      
        # This provider is an app which should be used for query annotations. This is
        # useful for apps which may not be already indexed by Google or are client
        # specific.
        # Corresponds to the JSON property `whitelistedForAnnotation`
        # @return [Boolean]
        attr_accessor :whitelisted_for_annotation
        alias_method :whitelisted_for_annotation?, :whitelisted_for_annotation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowlisted_for_media_fulfillment = args[:allowlisted_for_media_fulfillment] if args.key?(:allowlisted_for_media_fulfillment)
          @app_integrations_settings = args[:app_integrations_settings] if args.key?(:app_integrations_settings)
          @disabled_system_app = args[:disabled_system_app] if args.key?(:disabled_system_app)
          @provider = args[:provider] if args.key?(:provider)
          @routable_to_provider_cloud = args[:routable_to_provider_cloud] if args.key?(:routable_to_provider_cloud)
          @searchable_on_device = args[:searchable_on_device] if args.key?(:searchable_on_device)
          @searchable_on_server = args[:searchable_on_server] if args.key?(:searchable_on_server)
          @supports_screenless_initiation = args[:supports_screenless_initiation] if args.key?(:supports_screenless_initiation)
          @whitelisted_for_annotation = args[:whitelisted_for_annotation] if args.key?(:whitelisted_for_annotation)
        end
      end
      
      # Used to describe the incremental change of app capabilities of the device
      # installed apps reported to the server.
      class AssistantApiAppCapabilitiesDelta
        include Google::Apis::Core::Hashable
      
        # Contains the app privacy bits used for App Integrations implicit request. (go/
        # app-privacy-settings-for-implicit-requests)
        # Corresponds to the JSON property `appIntegrationsSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAppIntegrationsSettings]
        attr_accessor :app_integrations_settings
      
        # ProviderDelta. The incremental change, e.g. installation or deletion for
        # Spotify or iHeartRadio. Currently it is for Android only. A few considerations
        # for edge cases: - If the app being deleted is not found from Footprints, it is
        # ignored. - For Footprint upload through Geller, the gPRC response is available
        # for client to retry in the next upload if the upload fails. - For Assistant
        # Request, there is no upload status similar to the current AppCapabilities.
        # Next ID: 4
        # Corresponds to the JSON property `providerDelta`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProviderDelta]
        attr_accessor :provider_delta
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_integrations_settings = args[:app_integrations_settings] if args.key?(:app_integrations_settings)
          @provider_delta = args[:provider_delta] if args.key?(:provider_delta)
        end
      end
      
      # 
      class AssistantApiAppControlSupport
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
        end
      end
      
      # Contains the app privacy bits used for App Integrations implicit request. (go/
      # app-privacy-settings-for-implicit-requests)
      class AssistantApiAppIntegrationsSettings
        include Google::Apis::Core::Hashable
      
        # Whether to enable Assistant to handle request with predicted apps.
        # Corresponds to the JSON property `handleRequestsWithPredictedApps`
        # @return [String]
        attr_accessor :handle_requests_with_predicted_apps
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @handle_requests_with_predicted_apps = args[:handle_requests_with_predicted_apps] if args.key?(:handle_requests_with_predicted_apps)
        end
      end
      
      # 
      class AssistantApiAssistantContinuedPresenceSupport
        include Google::Apis::Core::Hashable
      
        # Indicates in what cases assistant continued presence can be shown as a plate.
        # This field is white-listed as being PII-free. Please do not add PII here.
        # Corresponds to the JSON property `plateSupport`
        # @return [String]
        attr_accessor :plate_support
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @plate_support = args[:plate_support] if args.key?(:plate_support)
        end
      end
      
      # These capabilities represent the audio input features associated with the
      # device. This includes what kind of audio input the device can handle, and what
      # the privacy circumstances of that input are.
      class AssistantApiAudioInput
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `environment`
        # @return [String]
        attr_accessor :environment
      
        # 
        # Corresponds to the JSON property `quality`
        # @return [String]
        attr_accessor :quality
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @environment = args[:environment] if args.key?(:environment)
          @quality = args[:quality] if args.key?(:quality)
        end
      end
      
      # These capabilities represent the audio output features associated with the
      # device. This includes what kind of audio output the device can handle, and
      # what the privacy circumstances of that output are.
      class AssistantApiAudioOutput
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `alwaysOnSpeaker`
        # @return [String]
        attr_accessor :always_on_speaker
      
        # 
        # Corresponds to the JSON property `environment`
        # @return [String]
        attr_accessor :environment
      
        # 
        # Corresponds to the JSON property `mediaTtsMixable`
        # @return [String]
        attr_accessor :media_tts_mixable
      
        # 
        # Corresponds to the JSON property `quality`
        # @return [String]
        attr_accessor :quality
      
        # 
        # Corresponds to the JSON property `volumeProperties`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiVolumeProperties]
        attr_accessor :volume_properties
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @always_on_speaker = args[:always_on_speaker] if args.key?(:always_on_speaker)
          @environment = args[:environment] if args.key?(:environment)
          @media_tts_mixable = args[:media_tts_mixable] if args.key?(:media_tts_mixable)
          @quality = args[:quality] if args.key?(:quality)
          @volume_properties = args[:volume_properties] if args.key?(:volume_properties)
        end
      end
      
      # CallCapabilities supported by a surface. See go/call-capabilities. Next ID: 7
      class AssistantApiCallCapabilities
        include Google::Apis::Core::Hashable
      
        # The supported call formats on the surface.
        # Corresponds to the JSON property `callFormats`
        # @return [Array<String>]
        attr_accessor :call_formats
      
        # The supported call mediums on the surface.
        # Corresponds to the JSON property `callMediums`
        # @return [Array<String>]
        attr_accessor :call_mediums
      
        # The call options this surface can provide. For example, SPEAKERPHONE is
        # available on Android OPA while iOPA doesn't support it yet.
        # Corresponds to the JSON property `callOptions`
        # @return [Array<String>]
        attr_accessor :call_options
      
        # If true, APP_ID queries initiated by this device should fall back to execution
        # on the tethered device if it's available and if the primary device cannot
        # perform the action (e.g. due to the app not being installed).
        # Corresponds to the JSON property `fallbackToTetheredDeviceAppCapabilities`
        # @return [Boolean]
        attr_accessor :fallback_to_tethered_device_app_capabilities
        alias_method :fallback_to_tethered_device_app_capabilities?, :fallback_to_tethered_device_app_capabilities
      
        # Should only be checked if nonempty.
        # Corresponds to the JSON property `supportedRecipientTypes`
        # @return [Array<String>]
        attr_accessor :supported_recipient_types
      
        # Whether the surface supports Duo calling email endpoints.
        # Corresponds to the JSON property `supportsDuoEmailEndpoint`
        # @return [Boolean]
        attr_accessor :supports_duo_email_endpoint
        alias_method :supports_duo_email_endpoint?, :supports_duo_email_endpoint
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @call_formats = args[:call_formats] if args.key?(:call_formats)
          @call_mediums = args[:call_mediums] if args.key?(:call_mediums)
          @call_options = args[:call_options] if args.key?(:call_options)
          @fallback_to_tethered_device_app_capabilities = args[:fallback_to_tethered_device_app_capabilities] if args.key?(:fallback_to_tethered_device_app_capabilities)
          @supported_recipient_types = args[:supported_recipient_types] if args.key?(:supported_recipient_types)
          @supports_duo_email_endpoint = args[:supports_duo_email_endpoint] if args.key?(:supports_duo_email_endpoint)
        end
      end
      
      # These capabilities represent the camera features associated with the device.
      class AssistantApiCameraCapabilities
        include Google::Apis::Core::Hashable
      
        # Whether the device supports Face Match.
        # Corresponds to the JSON property `faceMatchCapable`
        # @return [Boolean]
        attr_accessor :face_match_capable
        alias_method :face_match_capable?, :face_match_capable
      
        # Whether the device has a camera.
        # Corresponds to the JSON property `hasCamera`
        # @return [Boolean]
        attr_accessor :has_camera
        alias_method :has_camera?, :has_camera
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @face_match_capable = args[:face_match_capable] if args.key?(:face_match_capable)
          @has_camera = args[:has_camera] if args.key?(:has_camera)
        end
      end
      
      # These capabilities present the capability of the device running camera
      # receiver apps.
      class AssistantApiCameraReceiverCapabilities
        include Google::Apis::Core::Hashable
      
        # Whether the device has limited camera stream capability. If true, check
        # supported_camera_receivers for detailed supported cameras.
        # Corresponds to the JSON property `hasLimitedCameraStreamCapability`
        # @return [Boolean]
        attr_accessor :has_limited_camera_stream_capability
        alias_method :has_limited_camera_stream_capability?, :has_limited_camera_stream_capability
      
        # The camera receiver cast apps the device supports. Only used if
        # has_limited_camera_stream_capability is true.
        # Corresponds to the JSON property `supportedCameraReceivers`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCastAppInfo>]
        attr_accessor :supported_camera_receivers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_limited_camera_stream_capability = args[:has_limited_camera_stream_capability] if args.key?(:has_limited_camera_stream_capability)
          @supported_camera_receivers = args[:supported_camera_receivers] if args.key?(:supported_camera_receivers)
        end
      end
      
      # Capabilities that are associated with Assistants on auto surfaces. This is
      # different from other capabilities such as CarSettingsCapabilities,
      # CloudCarCapabilities since they are specific to settings and 3P cloud
      # information. All the auto/car Assistant specific capabilities should live here.
      class AssistantApiCarAssistantCapabilities
        include Google::Apis::Core::Hashable
      
        # Indicates whether the current Assistant should provide a multi Assistant
        # specific punt when there are multiple Auto specific Google Assistants (Android
        # Auto Projected (AAP) and Android Auto Embedded (AAE)) in the same GAS enabled
        # car. This will be used by both AAP and AAE. Design doc: go/doubledash++
        # Corresponds to the JSON property `shouldPuntMultiAssistantMode`
        # @return [Boolean]
        attr_accessor :should_punt_multi_assistant_mode
        alias_method :should_punt_multi_assistant_mode?, :should_punt_multi_assistant_mode
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @should_punt_multi_assistant_mode = args[:should_punt_multi_assistant_mode] if args.key?(:should_punt_multi_assistant_mode)
        end
      end
      
      # Capabilities that are associated with Assistant Settings on auto surfaces.
      class AssistantApiCarSettingsCapabilities
        include Google::Apis::Core::Hashable
      
        # If true, it indicates that the auto surface client should receive a warmer
        # welcome TTS for signed-out users. For signed-in user, we will rely on server
        # side metadata. go/aaae:preview-lang
        # Corresponds to the JSON property `playWarmerWelcome`
        # @return [Boolean]
        attr_accessor :play_warmer_welcome
        alias_method :play_warmer_welcome?, :play_warmer_welcome
      
        # If true, it indicates that the client can be used to add cars after account
        # linking with the OEM.
        # Corresponds to the JSON property `supportsAddingCars`
        # @return [Boolean]
        attr_accessor :supports_adding_cars
        alias_method :supports_adding_cars?, :supports_adding_cars
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @play_warmer_welcome = args[:play_warmer_welcome] if args.key?(:play_warmer_welcome)
          @supports_adding_cars = args[:supports_adding_cars] if args.key?(:supports_adding_cars)
        end
      end
      
      # 
      class AssistantApiCastAssistantSettingLinkingResult
        include Google::Apis::Core::Hashable
      
        # Cast linking status for ATV surfaces. This is derived from error messages
        # returned from Cast Orchestration Server and will be used for data profiling
        # only(go/katniss-settings-dashboard).
        # Corresponds to the JSON property `castLinkingStatus`
        # @return [String]
        attr_accessor :cast_linking_status
      
        # The error msg returned from COS, truncated in case it's too large.
        # Corresponds to the JSON property `truncatedErrorMsg`
        # @return [String]
        attr_accessor :truncated_error_msg
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cast_linking_status = args[:cast_linking_status] if args.key?(:cast_linking_status)
          @truncated_error_msg = args[:truncated_error_msg] if args.key?(:truncated_error_msg)
        end
      end
      
      # These capabilities represent capabilities that have to do with casting that
      # pertain to this device. Next ID: 9
      class AssistantApiCastCapabilities
        include Google::Apis::Core::Hashable
      
        # These capabilities present the capability of the device running camera
        # receiver apps.
        # Corresponds to the JSON property `cameraReceiverCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCameraReceiverCapabilities]
        attr_accessor :camera_receiver_capabilities
      
        # The supported protocols for camera streaming. The value is used as string in
        # go/smarthome-internal-api#camera-stream, so using a string for this field
        # instead of an enum. Supported protocols: (align the definition in go/smarthome-
        # camerastream-trait) - "hls": HTTP Live Streaming - "dash": Dynamic Adaptive
        # Streaming over HTTP - "smooth_stream": Smooth Streaming - "progressive_mp4":
        # Progressive MP4 (will likely only be used for Clips) - "webrtc": WebRTC (
        # currently, only H.264 is supported) - "nexustalk": Internal-only protocol used
        # for Nest
        # Corresponds to the JSON property `cameraStreamSupportedProtocols`
        # @return [Array<String>]
        attr_accessor :camera_stream_supported_protocols
      
        # True if we can cast things to this device.
        # Corresponds to the JSON property `canReceiveCast`
        # @return [Boolean]
        attr_accessor :can_receive_cast
        alias_method :can_receive_cast?, :can_receive_cast
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # Whether this device supports dynamic groups or not. It implies if a Stream
        # Control operation (transfer, expansion, and contraction) could be applied on
        # this device since Stream Control is implemented as part of dynamic groups (ie,
        # adding/removing devices from playback)
        # Corresponds to the JSON property `dynamicGroupsSupported`
        # @return [Boolean]
        attr_accessor :dynamic_groups_supported
        alias_method :dynamic_groups_supported?, :dynamic_groups_supported
      
        # 
        # Corresponds to the JSON property `groupType`
        # @return [String]
        attr_accessor :group_type
      
        # Whether UI overlay applications are supported on this device. It's used by
        # Chromecast only.
        # Corresponds to the JSON property `overlayApplicationsSupported`
        # @return [Boolean]
        attr_accessor :overlay_applications_supported
        alias_method :overlay_applications_supported?, :overlay_applications_supported
      
        # Whether the device supports playing games through Yeti. This is set by the
        # cast device when the device is updated: Chromecast updates -> Chromecast
        # registers its capabilities with CCS -> CCS passes the capabilities to the
        # AssistantSettingsService -> AssistantSettingsService stores the device's
        # capabilities. go/yeti-gaming-supported-cast-capability
        # Corresponds to the JSON property `yetiGamingSupported`
        # @return [Boolean]
        attr_accessor :yeti_gaming_supported
        alias_method :yeti_gaming_supported?, :yeti_gaming_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @camera_receiver_capabilities = args[:camera_receiver_capabilities] if args.key?(:camera_receiver_capabilities)
          @camera_stream_supported_protocols = args[:camera_stream_supported_protocols] if args.key?(:camera_stream_supported_protocols)
          @can_receive_cast = args[:can_receive_cast] if args.key?(:can_receive_cast)
          @device_id = args[:device_id] if args.key?(:device_id)
          @dynamic_groups_supported = args[:dynamic_groups_supported] if args.key?(:dynamic_groups_supported)
          @group_type = args[:group_type] if args.key?(:group_type)
          @overlay_applications_supported = args[:overlay_applications_supported] if args.key?(:overlay_applications_supported)
          @yeti_gaming_supported = args[:yeti_gaming_supported] if args.key?(:yeti_gaming_supported)
        end
      end
      
      # The properties of the client op device.MODIFY_SETTING. This proto is stored in
      # the SupportedClientOp proto.
      class AssistantApiClientOpPropertiesDeviceModifySettingClientOpProperty
        include Google::Apis::Core::Hashable
      
        # Additional specific setting capabilities. This boolean is used to indicate
        # whether we want to skip the Android and GSA version check in
        # CheckSettingSchemaAndMaybeGetUris() from assistant/vertical/device/fulfillment/
        # utils/setting_utils.h. Consider setting this field to true if your device is
        # neither Android or GSA (especially when the UserAgent string of your device's
        # TaskRequest will not contain a valid/up-to-date Android/GSA version).
        # Corresponds to the JSON property `skipAndroidAndGsaVersionCheck`
        # @return [Boolean]
        attr_accessor :skip_android_and_gsa_version_check
        alias_method :skip_android_and_gsa_version_check?, :skip_android_and_gsa_version_check
      
        # Uses DeviceSetting enum which corresponds to setting_id. This indicates which
        # specific settings are supported by client. An empty list implies all settings
        # are supported.
        # Corresponds to the JSON property `supportedSettings`
        # @return [Array<String>]
        attr_accessor :supported_settings
      
        # Additional specific setting capabilities. This boolean is used to indicate if
        # do not disturb with duration is supported through device.MODIFY_SETTING
        # clientop on a client or not.
        # Corresponds to the JSON property `supportsDoNotDisturbWithDuration`
        # @return [Boolean]
        attr_accessor :supports_do_not_disturb_with_duration
        alias_method :supports_do_not_disturb_with_duration?, :supports_do_not_disturb_with_duration
      
        # Additional specific setting capabilities. This boolean is used to indicate if
        # new unmute logic is enabled on a client or not.
        # Corresponds to the JSON property `supportsMuteUnmute`
        # @return [Boolean]
        attr_accessor :supports_mute_unmute
        alias_method :supports_mute_unmute?, :supports_mute_unmute
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @skip_android_and_gsa_version_check = args[:skip_android_and_gsa_version_check] if args.key?(:skip_android_and_gsa_version_check)
          @supported_settings = args[:supported_settings] if args.key?(:supported_settings)
          @supports_do_not_disturb_with_duration = args[:supports_do_not_disturb_with_duration] if args.key?(:supports_do_not_disturb_with_duration)
          @supports_mute_unmute = args[:supports_mute_unmute] if args.key?(:supports_mute_unmute)
        end
      end
      
      # The properties of the provider.OPEN ClientOp. This proto is stored in the
      # SupportedClientOp proto with the key provider.OPEN.
      class AssistantApiClientOpPropertiesProviderOpenClientOpProperty
        include Google::Apis::Core::Hashable
      
        # Whether conversation is kept alive after opening the app. See go/keep-opa-
        # conversation-alive for details.
        # Corresponds to the JSON property `keepsConversationAliveAfterOpeningApp`
        # @return [Boolean]
        attr_accessor :keeps_conversation_alive_after_opening_app
        alias_method :keeps_conversation_alive_after_opening_app?, :keeps_conversation_alive_after_opening_app
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @keeps_conversation_alive_after_opening_app = args[:keeps_conversation_alive_after_opening_app] if args.key?(:keeps_conversation_alive_after_opening_app)
        end
      end
      
      # Used to describe clock capabilities of the device (for example, capabilities
      # related to maximum number of supported alarms and timers that can be created
      # on the device). Fields may be populated by clients or be backfilled by SAL (in
      # case of Timon, for example).
      class AssistantApiClockCapabilities
        include Google::Apis::Core::Hashable
      
        # Maximum number of alarms that can be created on the client.
        # Corresponds to the JSON property `maxSupportedAlarms`
        # @return [Fixnum]
        attr_accessor :max_supported_alarms
      
        # A Duration represents a signed, fixed-length span of time represented as a
        # count of seconds and fractions of seconds at nanosecond resolution. It is
        # independent of any calendar and concepts like "day" or "month". It is related
        # to Timestamp in that the difference between two Timestamp values is a Duration
        # and it can be added or subtracted from a Timestamp. Range is approximately +-
        # 10,000 years.
        # Corresponds to the JSON property `maxSupportedExtendedTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDuration]
        attr_accessor :max_supported_extended_timer_duration
      
        # A Duration represents a signed, fixed-length span of time represented as a
        # count of seconds and fractions of seconds at nanosecond resolution. It is
        # independent of any calendar and concepts like "day" or "month". It is related
        # to Timestamp in that the difference between two Timestamp values is a Duration
        # and it can be added or subtracted from a Timestamp. Range is approximately +-
        # 10,000 years.
        # Corresponds to the JSON property `maxSupportedTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDuration]
        attr_accessor :max_supported_timer_duration
      
        # Maximum number of timers that can be created on the client.
        # Corresponds to the JSON property `maxSupportedTimers`
        # @return [Fixnum]
        attr_accessor :max_supported_timers
      
        # Provider. Like, Spotify or iHeartRadio. Next ID: 13
        # Corresponds to the JSON property `preferredStopwatchProvider`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProvider]
        attr_accessor :preferred_stopwatch_provider
      
        # Whether the client restricts alarms to ring within the next 24 hours.
        # Corresponds to the JSON property `restrictAlarmsToNext24h`
        # @return [Boolean]
        attr_accessor :restrict_alarms_to_next24h
        alias_method :restrict_alarms_to_next24h?, :restrict_alarms_to_next24h
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_supported_alarms = args[:max_supported_alarms] if args.key?(:max_supported_alarms)
          @max_supported_extended_timer_duration = args[:max_supported_extended_timer_duration] if args.key?(:max_supported_extended_timer_duration)
          @max_supported_timer_duration = args[:max_supported_timer_duration] if args.key?(:max_supported_timer_duration)
          @max_supported_timers = args[:max_supported_timers] if args.key?(:max_supported_timers)
          @preferred_stopwatch_provider = args[:preferred_stopwatch_provider] if args.key?(:preferred_stopwatch_provider)
          @restrict_alarms_to_next24h = args[:restrict_alarms_to_next24h] if args.key?(:restrict_alarms_to_next24h)
        end
      end
      
      # UI capabilities for the surfaces rendering Comms features. See go/rohan-comms-
      # fluid-actions-customization.
      class AssistantApiCommunicationUiCapabilities
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fluidActionsUiType`
        # @return [String]
        attr_accessor :fluid_actions_ui_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fluid_actions_ui_type = args[:fluid_actions_ui_type] if args.key?(:fluid_actions_ui_type)
        end
      end
      
      # 
      class AssistantApiContactLookupCapabilities
        include Google::Apis::Core::Hashable
      
        # If true, contact.LOOKUP should be routed to the tethered device (if present)
        # if the tethered device supports contact.LOOKUP and the primary device does not.
        # Corresponds to the JSON property `fallbackToTetheredDevice`
        # @return [Boolean]
        attr_accessor :fallback_to_tethered_device
        alias_method :fallback_to_tethered_device?, :fallback_to_tethered_device
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fallback_to_tethered_device = args[:fallback_to_tethered_device] if args.key?(:fallback_to_tethered_device)
        end
      end
      
      # The android app information of the provider. Like, Spotify. Next ID: 15 LINT.
      # IfChange
      class AssistantApiCoreTypesAndroidAppInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `accountType`
        # @return [String]
        attr_accessor :account_type
      
        # Intent associated with the app. We include intents here as different versions
        # of the same app may support different intents. In those cases, the
        # package_name is not enough to identify the app and we should use the
        # combination of package_name and android_intent. This field might contain
        # sensitive data, if represents ClientOp with encapsulated PII such as user
        # query.
        # Corresponds to the JSON property `androidIntent`
        # @return [String]
        attr_accessor :android_intent
      
        # Store the app unique id endpoint. This will be passed over to app to fulfill
        # the action.
        # Corresponds to the JSON property `appUniqueId`
        # @return [String]
        attr_accessor :app_unique_id
      
        # The android app version. Deprecated because https://developer.android.com/
        # reference/android/content/pm/PackageInfo.html#getLongVersionCode
        # Corresponds to the JSON property `appVersion`
        # @return [Fixnum]
        attr_accessor :app_version
      
        # data_mimetype and account_type are the what AGSA uses to filter which contacts
        # support this Android app in ContactProvider.
        # Corresponds to the JSON property `dataMimetype`
        # @return [String]
        attr_accessor :data_mimetype
      
        # If true, client should broadcast the intent instead of open the intent.
        # Corresponds to the JSON property `isBroadcastIntent`
        # @return [Boolean]
        attr_accessor :is_broadcast_intent
        alias_method :is_broadcast_intent?, :is_broadcast_intent
      
        # App is the default app for it's core functionality. For example, it will be
        # true for Android messages if it is the default app to send and receive SMS on
        # the phone.
        # Corresponds to the JSON property `isDefault`
        # @return [Boolean]
        attr_accessor :is_default
        alias_method :is_default?, :is_default
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # The long android app version.
        # Corresponds to the JSON property `longVersionCode`
        # @return [Fixnum]
        attr_accessor :long_version_code
      
        # Store mimetype of this endpoint. We will use this as the differentiator for
        # Assistant to know whether to use the RawContact for messaging, call or video
        # call. For example, send message mimetype for whatsapp: "vnd.android.cursor.
        # item/vnd.com.whatsapp.profile" voice call mimetype for whatsapp: "vnd.android.
        # cursor.item/vnd.com.whatsapp.voip.call"
        # Corresponds to the JSON property `mimetype`
        # @return [String]
        attr_accessor :mimetype
      
        # The android app package of the provider, like "com.spotify.music".
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        # The OemProviderType is specific for OEM system Android apps. For example, in
        # Auto Embedded, the OEM will have a system Radio/Media app. The system app’s
        # capabilities/core functionalities are captured here. For physical media
        # sources, the OEM may decide to implement one media app (thus, one package name)
        # that handles multiple physical media sources. For these cases, each physical
        # media source will be sent as different providers even though the package name
        # is the same.
        # Corresponds to the JSON property `providerType`
        # @return [String]
        attr_accessor :provider_type
      
        # Id of the app's Android shortcut to be launched by Assistant. The client is
        # expected to use the Android LauncherApps API to execute this shortcut which in
        # turn will open the app. For example, Whatsapp may create an Android shortcut
        # for a frequently messaged contact with an id "contact_123". This field will
        # contain that id and the client can execute it to open up the chat with that
        # particular contact. If this field is set, the package_name field must also be
        # set since both will be used by the LauncherApps API for execution. If this
        # field is set, the intent related fields will be ignored and not used as a
        # fallback. Design: go/shortcut-id-in-provider-open-clientop This field should
        # only be set for devices with Android API level >= 25 (since that is the
        # version from which the LauncherApps startShortcut API is available)
        # Corresponds to the JSON property `shortcutId`
        # @return [String]
        attr_accessor :shortcut_id
      
        # The android app version name, like "4.1.091.05.40d", "11.2.7.21.alpha".
        # Android Docs: https://developer.android.com/reference/android/content/pm/
        # PackageInfo#versionName
        # Corresponds to the JSON property `versionName`
        # @return [String]
        attr_accessor :version_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_type = args[:account_type] if args.key?(:account_type)
          @android_intent = args[:android_intent] if args.key?(:android_intent)
          @app_unique_id = args[:app_unique_id] if args.key?(:app_unique_id)
          @app_version = args[:app_version] if args.key?(:app_version)
          @data_mimetype = args[:data_mimetype] if args.key?(:data_mimetype)
          @is_broadcast_intent = args[:is_broadcast_intent] if args.key?(:is_broadcast_intent)
          @is_default = args[:is_default] if args.key?(:is_default)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @long_version_code = args[:long_version_code] if args.key?(:long_version_code)
          @mimetype = args[:mimetype] if args.key?(:mimetype)
          @package_name = args[:package_name] if args.key?(:package_name)
          @provider_type = args[:provider_type] if args.key?(:provider_type)
          @shortcut_id = args[:shortcut_id] if args.key?(:shortcut_id)
          @version_name = args[:version_name] if args.key?(:version_name)
        end
      end
      
      # The change of AndroidAppInfo, e.g. app installation or deletion for
      # incremental delta app info upload.
      class AssistantApiCoreTypesAndroidAppInfoDelta
        include Google::Apis::Core::Hashable
      
        # The android app information of the provider. Like, Spotify. Next ID: 15 LINT.
        # IfChange
        # Corresponds to the JSON property `androidAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesAndroidAppInfo]
        attr_accessor :android_app_info
      
        # The client-side timestamp in millis when the app is last updated, installed or
        # deleted.
        # Corresponds to the JSON property `lastUpdateTimestamp`
        # @return [String]
        attr_accessor :last_update_timestamp
      
        # App is installed or deleted.
        # Corresponds to the JSON property `updateType`
        # @return [String]
        attr_accessor :update_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_app_info = args[:android_app_info] if args.key?(:android_app_info)
          @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
          @update_type = args[:update_type] if args.key?(:update_type)
        end
      end
      
      # This proto contains the information of a calendar event, including title,
      # start time, end time, etc. IMPORTANT: The definition of CalendarEvent proto is
      # being moved to //assistant/api/core_types/governed/calendar_event_type.proto.
      # All existing references will be updated to point to the new location. If you
      # are adding a reference, use the new one instead. LINT.IfChange(CalendarEvent)
      # NEXT_ID: 26
      class AssistantApiCoreTypesCalendarEvent
        include Google::Apis::Core::Hashable
      
        # Attendees invited to the event, usually includes also the organizer.
        # Corresponds to the JSON property `attendees`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventAttendee>]
        attr_accessor :attendees
      
        # The background color of the event, in RGB format.
        # Corresponds to the JSON property `backgroundColor`
        # @return [Fixnum]
        attr_accessor :background_color
      
        # Optional calendar containing the event.
        # Corresponds to the JSON property `calendarId`
        # @return [String]
        attr_accessor :calendar_id
      
        # Next id: 8
        # Corresponds to the JSON property `creator`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventAttendee]
        attr_accessor :creator
      
        # Optional description of the event (plain text).
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `end`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :end
      
        # Optional event id provided by assistant server. Needs to be unique, at least
        # on a per-user and calendar level, ideally globally unique. If none is given,
        # the server will assign an id.
        # Corresponds to the JSON property `eventId`
        # @return [String]
        attr_accessor :event_id
      
        # The flair name, calculated according to the event title (go/as-cal-flair).
        # With the flair name, background images can be got from gstatic (go/scs): https:
        # //ssl.gstatic.com/tmly/f8944938hffheth4ew890ht4i8/flairs/
        # Corresponds to the JSON property `flairName`
        # @return [String]
        attr_accessor :flair_name
      
        # The foreground color of the event, in RGB format.
        # Corresponds to the JSON property `foregroundColor`
        # @return [Fixnum]
        attr_accessor :foreground_color
      
        # Whether the guests can invite other guests.
        # Corresponds to the JSON property `guestsCanInviteOthers`
        # @return [Boolean]
        attr_accessor :guests_can_invite_others
        alias_method :guests_can_invite_others?, :guests_can_invite_others
      
        # Whether the guests can modify the event.
        # Corresponds to the JSON property `guestsCanModify`
        # @return [Boolean]
        attr_accessor :guests_can_modify
        alias_method :guests_can_modify?, :guests_can_modify
      
        # Whether the guests of the event can be seen. If false, the user is reported as
        # the only attendee to the event, even though there may be more attendees.
        # Corresponds to the JSON property `guestsCanSeeGuests`
        # @return [Boolean]
        attr_accessor :guests_can_see_guests
        alias_method :guests_can_see_guests?, :guests_can_see_guests
      
        # Optional id of the Habit (Calendar Goal) this event is linked to
        # Corresponds to the JSON property `habitId`
        # @return [String]
        attr_accessor :habit_id
      
        # Optional status for this habit event instance.
        # Corresponds to the JSON property `habitStatus`
        # @return [String]
        attr_accessor :habit_status
      
        # Absolute link to this event in the Calendar web UI.
        # Corresponds to the JSON property `htmlLink`
        # @return [String]
        attr_accessor :html_link
      
        # Optional location of the event (plain text).
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        # 
        # Corresponds to the JSON property `meetingContacts`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventMeetingContact>]
        attr_accessor :meeting_contacts
      
        # Next id: 8
        # Corresponds to the JSON property `organizer`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventAttendee]
        attr_accessor :organizer
      
        # Whether not all attendees are included in the attendee list. This is set when
        # the attendees list has been truncated (e.g., when the number of attendees is
        # beyond the maxAttendees limitation).
        # Corresponds to the JSON property `otherAttendeesExcluded`
        # @return [Boolean]
        attr_accessor :other_attendees_excluded
        alias_method :other_attendees_excluded?, :other_attendees_excluded
      
        # The user's response (the owner of this copy of the event) to this event.
        # Corresponds to the JSON property `participationResponse`
        # @return [String]
        attr_accessor :participation_response
      
        # If this is an instance of a recurring event, recurring_event_id identifies the
        # recurring series as a whole.
        # Corresponds to the JSON property `recurringEventId`
        # @return [String]
        attr_accessor :recurring_event_id
      
        # Meeting rooms associated to this event.
        # Corresponds to the JSON property `rooms`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventRoom>]
        attr_accessor :rooms
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `start`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :start
      
        # The title of the event.
        # Corresponds to the JSON property `summary`
        # @return [String]
        attr_accessor :summary
      
        # Optional visibility of the event.
        # Corresponds to the JSON property `visibility`
        # @return [String]
        attr_accessor :visibility
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attendees = args[:attendees] if args.key?(:attendees)
          @background_color = args[:background_color] if args.key?(:background_color)
          @calendar_id = args[:calendar_id] if args.key?(:calendar_id)
          @creator = args[:creator] if args.key?(:creator)
          @description = args[:description] if args.key?(:description)
          @end = args[:end] if args.key?(:end)
          @event_id = args[:event_id] if args.key?(:event_id)
          @flair_name = args[:flair_name] if args.key?(:flair_name)
          @foreground_color = args[:foreground_color] if args.key?(:foreground_color)
          @guests_can_invite_others = args[:guests_can_invite_others] if args.key?(:guests_can_invite_others)
          @guests_can_modify = args[:guests_can_modify] if args.key?(:guests_can_modify)
          @guests_can_see_guests = args[:guests_can_see_guests] if args.key?(:guests_can_see_guests)
          @habit_id = args[:habit_id] if args.key?(:habit_id)
          @habit_status = args[:habit_status] if args.key?(:habit_status)
          @html_link = args[:html_link] if args.key?(:html_link)
          @location = args[:location] if args.key?(:location)
          @meeting_contacts = args[:meeting_contacts] if args.key?(:meeting_contacts)
          @organizer = args[:organizer] if args.key?(:organizer)
          @other_attendees_excluded = args[:other_attendees_excluded] if args.key?(:other_attendees_excluded)
          @participation_response = args[:participation_response] if args.key?(:participation_response)
          @recurring_event_id = args[:recurring_event_id] if args.key?(:recurring_event_id)
          @rooms = args[:rooms] if args.key?(:rooms)
          @start = args[:start] if args.key?(:start)
          @summary = args[:summary] if args.key?(:summary)
          @visibility = args[:visibility] if args.key?(:visibility)
        end
      end
      
      # Next id: 8
      class AssistantApiCoreTypesCalendarEventAttendee
        include Google::Apis::Core::Hashable
      
        # Display name, present only if available.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Email address of the attendee (calendar), for regular events. For +Events,
        # this field is not populated, instead "id" is used.
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # Given (first) name, present only if available. This is used for generating
        # meeting titles as given name is preferred over display (full) name (ie: "Jeff :
        # Sundar" is better than "Jeff Dean : Sundar Pichai").
        # Corresponds to the JSON property `givenName`
        # @return [String]
        attr_accessor :given_name
      
        # Profile ID of the principal, for +Events. For regular events, this field is
        # not populated, instead "email" is used.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Is this the organizer?
        # Corresponds to the JSON property `organizer`
        # @return [Boolean]
        attr_accessor :organizer
        alias_method :organizer?, :organizer
      
        # Attendees response status.
        # Corresponds to the JSON property `responseStatus`
        # @return [String]
        attr_accessor :response_status
      
        # Is this the owner of this copy of the event?
        # Corresponds to the JSON property `self`
        # @return [Boolean]
        attr_accessor :self
        alias_method :self?, :self
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @email = args[:email] if args.key?(:email)
          @given_name = args[:given_name] if args.key?(:given_name)
          @id = args[:id] if args.key?(:id)
          @organizer = args[:organizer] if args.key?(:organizer)
          @response_status = args[:response_status] if args.key?(:response_status)
          @self = args[:self] if args.key?(:self)
        end
      end
      
      # Next id: 10
      class AssistantApiCoreTypesCalendarEventMeetingContact
        include Google::Apis::Core::Hashable
      
        # ID that corresponds to in ConferenceData.conference_id in calendar.common.
        # ConferenceData proto. For Meet, this is the identifier used to join a meeting
        # via URL.
        # Corresponds to the JSON property `conferenceId`
        # @return [String]
        attr_accessor :conference_id
      
        # 
        # Corresponds to the JSON property `dialInNumberClasses`
        # @return [Array<String>]
        attr_accessor :dial_in_number_classes
      
        # Default meeting phone number, for example: "tel:+1-475-777-1840"
        # Corresponds to the JSON property `phoneNumberUri`
        # @return [String]
        attr_accessor :phone_number_uri
      
        # A PIN that the participant will need to input after dialing in the conference.
        # Corresponds to the JSON property `pinNumber`
        # @return [String]
        attr_accessor :pin_number
      
        # Provider. Like, Spotify or iHeartRadio. Next ID: 13
        # Corresponds to the JSON property `provider`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProvider]
        attr_accessor :provider
      
        # The region code for the default meeting phone number
        # Corresponds to the JSON property `regionCode`
        # @return [String]
        attr_accessor :region_code
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The universal meeting PIN number for phone numbers in all available countries
        # Corresponds to the JSON property `universalPinNumber`
        # @return [String]
        attr_accessor :universal_pin_number
      
        # URL that can be used to join the meeting.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conference_id = args[:conference_id] if args.key?(:conference_id)
          @dial_in_number_classes = args[:dial_in_number_classes] if args.key?(:dial_in_number_classes)
          @phone_number_uri = args[:phone_number_uri] if args.key?(:phone_number_uri)
          @pin_number = args[:pin_number] if args.key?(:pin_number)
          @provider = args[:provider] if args.key?(:provider)
          @region_code = args[:region_code] if args.key?(:region_code)
          @source = args[:source] if args.key?(:source)
          @universal_pin_number = args[:universal_pin_number] if args.key?(:universal_pin_number)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # A room that is available for a potential meeting or has been booked for a
      # scheduled meeting. Next id: 4
      class AssistantApiCoreTypesCalendarEventRoom
        include Google::Apis::Core::Hashable
      
        # Room email that identifies the room and is used to book it.
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # Room location details. Read-only, populated on request. Next id: 8
        # Corresponds to the JSON property `locationDetails`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventRoomRoomLocationDetails]
        attr_accessor :location_details
      
        # Room name (ex: "MTV-PR55-5-A-Shadow 5K0 (13) GVC (No external guests)").
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @location_details = args[:location_details] if args.key?(:location_details)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Room location details. Read-only, populated on request. Next id: 8
      class AssistantApiCoreTypesCalendarEventRoomRoomLocationDetails
        include Google::Apis::Core::Hashable
      
        # Building where the room is (ex: "PR55").
        # Corresponds to the JSON property `building`
        # @return [String]
        attr_accessor :building
      
        # City where the room is (ex: "MTV").
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # Floor where the room is (ex: "5").
        # Corresponds to the JSON property `floor`
        # @return [String]
        attr_accessor :floor
      
        # The latitude in degrees.
        # Corresponds to the JSON property `latitude`
        # @return [Float]
        attr_accessor :latitude
      
        # The longitude in degrees.
        # Corresponds to the JSON property `longitude`
        # @return [Float]
        attr_accessor :longitude
      
        # Section in the floor (ex: "A").
        # Corresponds to the JSON property `section`
        # @return [String]
        attr_accessor :section
      
        # Room name (ex: "Shadow 5K0").
        # Corresponds to the JSON property `simpleName`
        # @return [String]
        attr_accessor :simple_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @building = args[:building] if args.key?(:building)
          @city = args[:city] if args.key?(:city)
          @floor = args[:floor] if args.key?(:floor)
          @latitude = args[:latitude] if args.key?(:latitude)
          @longitude = args[:longitude] if args.key?(:longitude)
          @section = args[:section] if args.key?(:section)
          @simple_name = args[:simple_name] if args.key?(:simple_name)
        end
      end
      
      # This empty type allows us to publish sensitive calendar events to go/
      # attentional-entities, while maintaining BUILD visibility protection for their
      # contents. The BUILD-visibility-protected extension to this message is defined
      # at http://google3/assistant/verticals/calendar/proto/
      # multi_account_calendar_event.proto IMPORTANT: The definition of
      # CalendarEventWrapper proto is being moved to //assistant/api/core_types/
      # governed/calendar_event_type.proto. All existing references will be updated to
      # point to the new location. If you are adding a reference, use the new one
      # instead.
      class AssistantApiCoreTypesCalendarEventWrapper
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The cast app information of the provider.
      class AssistantApiCoreTypesCastAppInfo
        include Google::Apis::Core::Hashable
      
        # The cast app id. |cast_app_id| is the ID of the cast app used on the current
        # device and |content_app_id| is the ID of the app that provides the actual
        # content. For example, in a group playback, on a follower device, the |
        # cast_app_id| is the follower cast app ID and the |content_app_id| is the
        # leader cast app ID.
        # Corresponds to the JSON property `castAppId`
        # @return [String]
        attr_accessor :cast_app_id
      
        # The id of the cast app that provides the content in a group. The field will
        # always be filled. In the case of a group playback and the current device is a
        # follower, the |cast_app_id| has the ID of the follower app, and |
        # content_app_id| has ID of the actual content app. In all other cases, |
        # content_app_id| and |cast_app_id| will be the same.
        # Corresponds to the JSON property `contentAppId`
        # @return [String]
        attr_accessor :content_app_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cast_app_id = args[:cast_app_id] if args.key?(:cast_app_id)
          @content_app_id = args[:content_app_id] if args.key?(:content_app_id)
        end
      end
      
      # The ChromeOS app information of the provider. Next ID: 3
      class AssistantApiCoreTypesChromeOsAppInfo
        include Google::Apis::Core::Hashable
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # Unique package name that identifies a ChromeOS app of the provider.
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @package_name = args[:package_name] if args.key?(:package_name)
        end
      end
      
      # The third party provider information.
      class AssistantApiCoreTypesCloudProviderInfo
        include Google::Apis::Core::Hashable
      
        # The style customizations for the 3p agent.
        # Corresponds to the JSON property `agentStyle`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCloudProviderInfoAgentStyle]
        attr_accessor :agent_style
      
        # URL to a directory page about the third party agent in Assistant HQ. This is a
        # universal (https) URL that may be handled natively by clients to show HQ or
        # launch to the HQ directory web page.
        # Corresponds to the JSON property `directoryUrl`
        # @return [String]
        attr_accessor :directory_url
      
        # The logo url for the third party provider.
        # Corresponds to the JSON property `logoUrl`
        # @return [String]
        attr_accessor :logo_url
      
        # The user visible name of the cloud provider, which may be used for example in
        # the chat header during a conversation with the third party.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_style = args[:agent_style] if args.key?(:agent_style)
          @directory_url = args[:directory_url] if args.key?(:directory_url)
          @logo_url = args[:logo_url] if args.key?(:logo_url)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # The style customizations for the 3p agent.
      class AssistantApiCoreTypesCloudProviderInfoAgentStyle
        include Google::Apis::Core::Hashable
      
        # Represents a color in the RGBA color space. This message mirrors google.type.
        # Color.
        # Corresponds to the JSON property `backgroundColor`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedColor]
        attr_accessor :background_color
      
        # 
        # Corresponds to the JSON property `headerTheme`
        # @return [String]
        attr_accessor :header_theme
      
        # URL for the background image of the agent on landscape display.
        # Corresponds to the JSON property `landscapeBackgroundImageUrl`
        # @return [String]
        attr_accessor :landscape_background_image_url
      
        # URL for the image containing the 3p logo. This can include logomark and
        # logotype, or logotype only. If present, this can be used in place of the
        # square logo contained in the top level logo_url field in CloudProviderInfo.
        # See go/cards-logo-customization for details on applying this logo.
        # Corresponds to the JSON property `logoUrl`
        # @return [String]
        attr_accessor :logo_url
      
        # Represents a color in the RGBA color space. This message mirrors google.type.
        # Color.
        # Corresponds to the JSON property `maskColor`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedColor]
        attr_accessor :mask_color
      
        # URL for the background image of the agent on portrait display.
        # Corresponds to the JSON property `portraitBackgroundImageUrl`
        # @return [String]
        attr_accessor :portrait_background_image_url
      
        # Represents a color in the RGBA color space. This message mirrors google.type.
        # Color.
        # Corresponds to the JSON property `primaryColor`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedColor]
        attr_accessor :primary_color
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @background_color = args[:background_color] if args.key?(:background_color)
          @header_theme = args[:header_theme] if args.key?(:header_theme)
          @landscape_background_image_url = args[:landscape_background_image_url] if args.key?(:landscape_background_image_url)
          @logo_url = args[:logo_url] if args.key?(:logo_url)
          @mask_color = args[:mask_color] if args.key?(:mask_color)
          @portrait_background_image_url = args[:portrait_background_image_url] if args.key?(:portrait_background_image_url)
          @primary_color = args[:primary_color] if args.key?(:primary_color)
        end
      end
      
      # The identification information for third party devices that integrates with
      # the assistant. All of these fields will be populated by the third party when
      # the query is sent from the third party device. Next Id: 5
      class AssistantApiCoreTypesDeviceConfig
        include Google::Apis::Core::Hashable
      
        # Pantheon Project ID that uniquely identifies the consumer project ID. Required
        # Corresponds to the JSON property `agentId`
        # @return [String]
        attr_accessor :agent_id
      
        # Unique identifier for the device. Example: DBCDW098234. Required
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_id = args[:agent_id] if args.key?(:agent_id)
          @device_id = args[:device_id] if args.key?(:device_id)
        end
      end
      
      # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
      # there may be multiple device ids for the same physical device E.g. Allo app
      # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
      # depend on it for surface specific logic. Please use google3/assistant/api/
      # capabilities.proto instead. IMPORTANT: When checking for equality between two `
      # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
      # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
      # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
      # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
      # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
      # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
      # for more details. Next ID: 14
      class AssistantApiCoreTypesDeviceId
        include Google::Apis::Core::Hashable
      
        # The client_instance_id on devices with GSA. See 'client_instance_field' in go/
        # androidids.
        # Corresponds to the JSON property `agsaClientInstanceId`
        # @return [String]
        attr_accessor :agsa_client_instance_id
      
        # Allo Id. Corresponds to the GBotRequest.Sender.sender. NOTE(dychen): This may
        # change to standard android/ios physical device ids in order to enable shared
        # data (e.g. installed app on physical device shared between Allo and Opa apps
        # on Nexus).
        # Corresponds to the JSON property `alloDeviceId`
        # @return [String]
        attr_accessor :allo_device_id
      
        # A unique device ID for Assistant devices as proposed by go/ocelot-team to
        # solve the device id fragmentation problem. The value of this id is the
        # HomeGraph id of the device. See go/ocelot-track-0-registry-design. New
        # surfaces should use the canonical_device_id instead of using other ids, and
        # the registration should utilize the DeviceDataLayer (go/ddl-v0). Please
        # contact the assistant-state-management@ team for guidance. Note: We didn't
        # reuse |home_graph_device_id| because in Assistant code base |
        # home_graph_device_id| is common to associate it with 3P devices. See go/
        # project-yellowstone for more context.
        # Corresponds to the JSON property `canonicalDeviceId`
        # @return [String]
        attr_accessor :canonical_device_id
      
        # If set, indicates that the device is a cast device, and contains the UUID of
        # the cast device. Corresponds to the device_id field of the CastDevice proto.
        # Corresponds to the JSON property `castDeviceId`
        # @return [String]
        attr_accessor :cast_device_id
      
        # DUSI (go/dusi) is used as the identifier here. This identifier is unique to
        # the user and device. This will help identify which device or application the
        # user's request originated from. This is not to be confused with the
        # client_instance_id that android devices provide. This is currently used by
        # surfaces that use the assistant-legacy-nexus and assistant-legacy-clockwork
        # pipelines. DUSI is created and set in S3. This field is only filled for GAIA
        # requests.
        # Corresponds to the JSON property `clientInstanceId`
        # @return [String]
        attr_accessor :client_instance_id
      
        # A device ID produced by a connected dock, which is registered in HomeGraph.
        # Corresponds to the JSON property `connectedDockId`
        # @return [String]
        attr_accessor :connected_dock_id
      
        # The identification information for third party devices that integrates with
        # the assistant. All of these fields will be populated by the third party when
        # the query is sent from the third party device. Next Id: 5
        # Corresponds to the JSON property `deviceConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceConfig]
        attr_accessor :device_config
      
        # The device's surface type. This is the string version of surface_type. The
        # server should use the SurfaceType value derived from this string. If the
        # device_type isn't supported within the SurfaceType enum, it will be set as
        # UNKNOWN. Developers should use the enum in ServerParams instead of this string.
        # Corresponds to the JSON property `deviceType`
        # @return [String]
        attr_accessor :device_type
      
        # The unique device ID for HomeGraph devices. This is the HomeGraph ID, created
        # when the device is registered into HomeGraph. It is immutable for the same
        # device unless it is completely deleted and recreated. See go/home-graph for
        # details.
        # Corresponds to the JSON property `homeGraphDeviceId`
        # @return [String]
        attr_accessor :home_graph_device_id
      
        # The unique ID for libassistant based devices. See go/libassistant-id for
        # details.
        # Corresponds to the JSON property `libassistantDeviceId`
        # @return [String]
        attr_accessor :libassistant_device_id
      
        # If set, indicates that the device is participating the multi-hotword
        # arbitration and the id is an UUID to distinguish it from other devices. It
        # should also be consistent between requests from a single device within a
        # session (or short duration).
        # Corresponds to the JSON property `multiHotwordArbitrationDeviceId`
        # @return [String]
        attr_accessor :multi_hotword_arbitration_device_id
      
        # The unique device ID for the Assistant App on iOS. See go/opa-ios-design for
        # details.
        # Corresponds to the JSON property `opaIosDeviceId`
        # @return [String]
        attr_accessor :opa_ios_device_id
      
        # The unique ID of a Quartz device. See go/quartz-design-doc for more details.
        # Quartz ID is a hash of (android_id + gaia).
        # Corresponds to the JSON property `quartzDeviceId`
        # @return [String]
        attr_accessor :quartz_device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agsa_client_instance_id = args[:agsa_client_instance_id] if args.key?(:agsa_client_instance_id)
          @allo_device_id = args[:allo_device_id] if args.key?(:allo_device_id)
          @canonical_device_id = args[:canonical_device_id] if args.key?(:canonical_device_id)
          @cast_device_id = args[:cast_device_id] if args.key?(:cast_device_id)
          @client_instance_id = args[:client_instance_id] if args.key?(:client_instance_id)
          @connected_dock_id = args[:connected_dock_id] if args.key?(:connected_dock_id)
          @device_config = args[:device_config] if args.key?(:device_config)
          @device_type = args[:device_type] if args.key?(:device_type)
          @home_graph_device_id = args[:home_graph_device_id] if args.key?(:home_graph_device_id)
          @libassistant_device_id = args[:libassistant_device_id] if args.key?(:libassistant_device_id)
          @multi_hotword_arbitration_device_id = args[:multi_hotword_arbitration_device_id] if args.key?(:multi_hotword_arbitration_device_id)
          @opa_ios_device_id = args[:opa_ios_device_id] if args.key?(:opa_ios_device_id)
          @quartz_device_id = args[:quartz_device_id] if args.key?(:quartz_device_id)
        end
      end
      
      # IMPORTANT: The definition of DeviceUserIdentity is being moved to //assistant/
      # api/core_types/governed/device_user_identity.proto. All existing references
      # will be updated to point to the new location. If you are adding a reference,
      # use the new DeviceUserIdentity instead of this one. // LINT.IfChange
      class AssistantApiCoreTypesDeviceUserIdentity
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # The identifier of the user.
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
        end
      end
      
      # Represents a color in the RGBA color space. This message mirrors google.type.
      # Color.
      class AssistantApiCoreTypesGovernedColor
        include Google::Apis::Core::Hashable
      
        # The fraction of this color that should be applied to the pixel. That is, the
        # final pixel color is defined by the equation: pixel color = alpha * (this
        # color) + (1.0 - alpha) * (background color) This means that a value of 1.0
        # corresponds to a solid color, whereas a value of 0.0 corresponds to a
        # completely transparent color. If omitted, this color object is to be rendered
        # as a solid color (as if the alpha value had been explicitly given with a value
        # of 1.0).
        # Corresponds to the JSON property `alpha`
        # @return [Float]
        attr_accessor :alpha
      
        # The amount of blue in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `blue`
        # @return [Float]
        attr_accessor :blue
      
        # The amount of green in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `green`
        # @return [Float]
        attr_accessor :green
      
        # The amount of red in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `red`
        # @return [Float]
        attr_accessor :red
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alpha = args[:alpha] if args.key?(:alpha)
          @blue = args[:blue] if args.key?(:blue)
          @green = args[:green] if args.key?(:green)
          @red = args[:red] if args.key?(:red)
        end
      end
      
      # Task metadata information describing the ringtone. Next id: 11
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadata
        include Google::Apis::Core::Hashable
      
        # The category related with the ringtone. It's used to generate ringtone related
        # with the category if the entity_mid is not be populated. E.g. for instrument,
        # the ringtone may be piano sound.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `characterAlarmMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataCharacterAlarmMetadata]
        attr_accessor :character_alarm_metadata
      
        # 
        # Corresponds to the JSON property `characterTag`
        # @return [String]
        attr_accessor :character_tag
      
        # The freebase mid of the entity related to the ringtone. It will be used to
        # generate the ringtone for the alarm or timer (with support for i18n). For
        # instance, for the "cat" mid, the related ringtone will be a cat sound in some
        # language, and for the "Beyonce" mid, the ringtone will be, e.g., a playlist of
        # Beyonce's best hits.
        # Corresponds to the JSON property `entityMid`
        # @return [String]
        attr_accessor :entity_mid
      
        # Used to make timers and alarms more delightful. See go/funtime-engdesign for
        # more details.
        # Corresponds to the JSON property `funtimeMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataFuntimeMetadata]
        attr_accessor :funtime_metadata
      
        # Metadata for machine learning generated audio samples. This will be similar to
        # character alarms, Category will be set MEDIA but this metadata field will be
        # used to identify the ringtone type on surface. (go/magenta-alarm-ringtones).
        # Corresponds to the JSON property `genMlAlarmMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataGenMlAlarmMetadata]
        attr_accessor :gen_ml_alarm_metadata
      
        # Gentle wake actions like slowly brightening the room/device screen leading up
        # to the alarm firing (go/cube-gentle-wake-up).
        # Corresponds to the JSON property `gentleWakeInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataGentleWakeInfo]
        attr_accessor :gentle_wake_info
      
        # This describes the alarm sound resource enum and the alarm sound label for the
        # on device alarm sound. On-device ringtones are product specific, hence Opal/UI
        # layer will be responsible for populating this metadata at creation/edit. The
        # enum map will be used to convert to an internal resource id used by
        # libassistant for accessing the asset which are not exposed to UI.
        # Corresponds to the JSON property `onDeviceAlarmMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataOnDeviceAlarmMetadata]
        attr_accessor :on_device_alarm_metadata
      
        # Will be deprecated. Use OnDeviceAlarmMetadata.
        # Corresponds to the JSON property `onDeviceAlarmSound`
        # @return [String]
        attr_accessor :on_device_alarm_sound
      
        # 
        # Corresponds to the JSON property `routineAlarmMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadataRoutineAlarmMetadata]
        attr_accessor :routine_alarm_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @character_alarm_metadata = args[:character_alarm_metadata] if args.key?(:character_alarm_metadata)
          @character_tag = args[:character_tag] if args.key?(:character_tag)
          @entity_mid = args[:entity_mid] if args.key?(:entity_mid)
          @funtime_metadata = args[:funtime_metadata] if args.key?(:funtime_metadata)
          @gen_ml_alarm_metadata = args[:gen_ml_alarm_metadata] if args.key?(:gen_ml_alarm_metadata)
          @gentle_wake_info = args[:gentle_wake_info] if args.key?(:gentle_wake_info)
          @on_device_alarm_metadata = args[:on_device_alarm_metadata] if args.key?(:on_device_alarm_metadata)
          @on_device_alarm_sound = args[:on_device_alarm_sound] if args.key?(:on_device_alarm_sound)
          @routine_alarm_metadata = args[:routine_alarm_metadata] if args.key?(:routine_alarm_metadata)
        end
      end
      
      # 
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataCharacterAlarmMetadata
        include Google::Apis::Core::Hashable
      
        # For character alarm, the media resources are provided through AOG apps. During
        # alarm trigger phase, aog apps with the specified agent_ids are used to get the
        # media resources. Multiple "AoG agents" can satisfy a character_tag. So the
        # user will select the agents they want at alarm creation time. The chosen
        # agents will be recorded so that the resources only from those agents will be
        # used at trigger time. The number of selected agent_ids will not exceed 3. See
        # go/character-alarm-aog.
        # Corresponds to the JSON property `agentIds`
        # @return [Array<String>]
        attr_accessor :agent_ids
      
        # The Character Alarm tag. Tags are needed to identify the theme of the alarm.
        # For example, if the tag is 'astronaut', astronaut based audio is played during
        # alarm ring. Note : We have made it repeated so that the user can choose
        # multiple character alarm themes at one go. At present, the user is allowed to
        # choose only one theme during alarm creation.
        # Corresponds to the JSON property `characterTags`
        # @return [Array<String>]
        attr_accessor :character_tags
      
        # Icons urls corresponding to a character. Note : We have made it repeated so
        # that we can show different images when the alarm rings. At present, we only
        # support only one image.
        # Corresponds to the JSON property `iconUrls`
        # @return [Array<String>]
        attr_accessor :icon_urls
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_ids = args[:agent_ids] if args.key?(:agent_ids)
          @character_tags = args[:character_tags] if args.key?(:character_tags)
          @icon_urls = args[:icon_urls] if args.key?(:icon_urls)
        end
      end
      
      # Used to make timers and alarms more delightful. See go/funtime-engdesign for
      # more details.
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataFuntimeMetadata
        include Google::Apis::Core::Hashable
      
        # For FunTime alarms and timers, the media resources are provided through AOG
        # apps during their ringtone. Multiple AoG agents can satisfy a label. So a
        # random agent will be chosen from those that are supplied. See go/funtime-
        # engdesign.
        # Corresponds to the JSON property `agentIds`
        # @return [Array<String>]
        attr_accessor :agent_ids
      
        # These bytes may represent the blob of the Rive animation that we pass to the
        # Opal App. We will deprecate this field if we figure out a solution to load the
        # animation from the web.
        # Corresponds to the JSON property `animationBlob`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :animation_blob
      
        # Url for Rive animation that is brought up on ring. Rive is a lightweight
        # animation library that is compatible with Flutter on Opal. See https://rive.
        # app/.
        # Corresponds to the JSON property `animationUrl`
        # @return [String]
        attr_accessor :animation_url
      
        # The url used to load the image that is at the center of the timer during timer
        # countdown visuals.
        # Corresponds to the JSON property `timerHeroUrl`
        # @return [String]
        attr_accessor :timer_hero_url
      
        # This is used to call S3 to realize the TTS. Is in the form of bytes because of
        # a circular dependency issue in libassistant protos. It is a serialized proto
        # of type speech.s3.TtsServiceRequest.
        # Corresponds to the JSON property `ttsServiceRequestBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :tts_service_request_bytes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_ids = args[:agent_ids] if args.key?(:agent_ids)
          @animation_blob = args[:animation_blob] if args.key?(:animation_blob)
          @animation_url = args[:animation_url] if args.key?(:animation_url)
          @timer_hero_url = args[:timer_hero_url] if args.key?(:timer_hero_url)
          @tts_service_request_bytes = args[:tts_service_request_bytes] if args.key?(:tts_service_request_bytes)
        end
      end
      
      # Metadata for machine learning generated audio samples. This will be similar to
      # character alarms, Category will be set MEDIA but this metadata field will be
      # used to identify the ringtone type on surface. (go/magenta-alarm-ringtones).
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataGenMlAlarmMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isEnabled`
        # @return [Boolean]
        attr_accessor :is_enabled
        alias_method :is_enabled?, :is_enabled
      
        # Label for the generated ringtone.
        # Corresponds to the JSON property `ringtoneLabel`
        # @return [String]
        attr_accessor :ringtone_label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_enabled = args[:is_enabled] if args.key?(:is_enabled)
          @ringtone_label = args[:ringtone_label] if args.key?(:ringtone_label)
        end
      end
      
      # Gentle wake actions like slowly brightening the room/device screen leading up
      # to the alarm firing (go/cube-gentle-wake-up).
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataGentleWakeInfo
        include Google::Apis::Core::Hashable
      
        # Specifies how long the effect lasts. Allowed for effect to last after the
        # alarm has started ringing. If unset or negative or 0, effect is assumed to
        # last until alarm trigger time.
        # Corresponds to the JSON property `effectDurationMs`
        # @return [Fixnum]
        attr_accessor :effect_duration_ms
      
        # Indicates if gentle wake action is to be performed before this alarm fires.
        # This is enabled only if the device supports sunrise alarm capability. http://
        # cs/symbol:assistant.api.SunriseFeaturesSupport
        # Corresponds to the JSON property `isEnabled`
        # @return [Boolean]
        attr_accessor :is_enabled
        alias_method :is_enabled?, :is_enabled
      
        # Specifies how long before the alarm fire time, the wakeup effect will start.
        # ALWAYS POSITIVE.
        # Corresponds to the JSON property `startTimedeltaMs`
        # @return [Fixnum]
        attr_accessor :start_timedelta_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @effect_duration_ms = args[:effect_duration_ms] if args.key?(:effect_duration_ms)
          @is_enabled = args[:is_enabled] if args.key?(:is_enabled)
          @start_timedelta_ms = args[:start_timedelta_ms] if args.key?(:start_timedelta_ms)
        end
      end
      
      # This describes the alarm sound resource enum and the alarm sound label for the
      # on device alarm sound. On-device ringtones are product specific, hence Opal/UI
      # layer will be responsible for populating this metadata at creation/edit. The
      # enum map will be used to convert to an internal resource id used by
      # libassistant for accessing the asset which are not exposed to UI.
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataOnDeviceAlarmMetadata
        include Google::Apis::Core::Hashable
      
        # Opal/UI layer will set this bit based on the user selection.
        # Corresponds to the JSON property `onDeviceAlarmSound`
        # @return [String]
        attr_accessor :on_device_alarm_sound
      
        # A string label to identify the alarm sound name. Opal/UI layer will set this
        # as per product definition. This will be used to display the name of the
        # selected ringtone.
        # Corresponds to the JSON property `onDeviceAlarmSoundLabel`
        # @return [String]
        attr_accessor :on_device_alarm_sound_label
      
        # This is used to call S3 to realize the TTS. Is in the form of bytes because of
        # a circular dependency issue in libassistant protos. It is a serialized proto
        # of type speech.s3.TtsServiceRequest. This request will contain an ssml with
        # the url to the ringtone files hosted on gstatic.
        # Corresponds to the JSON property `ttsServiceRequestBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :tts_service_request_bytes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @on_device_alarm_sound = args[:on_device_alarm_sound] if args.key?(:on_device_alarm_sound)
          @on_device_alarm_sound_label = args[:on_device_alarm_sound_label] if args.key?(:on_device_alarm_sound_label)
          @tts_service_request_bytes = args[:tts_service_request_bytes] if args.key?(:tts_service_request_bytes)
        end
      end
      
      # 
      class AssistantApiCoreTypesGovernedRingtoneTaskMetadataRoutineAlarmMetadata
        include Google::Apis::Core::Hashable
      
        # The unique id for each routine. When the alrm is dismissed, it will trigger
        # the routine of the routine alarm's creator if feasible.
        # Corresponds to the JSON property `routineId`
        # @return [String]
        attr_accessor :routine_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @routine_id = args[:routine_id] if args.key?(:routine_id)
        end
      end
      
      # The Home app information of the provider. Next ID: 3
      class AssistantApiCoreTypesHomeAppInfo
        include Google::Apis::Core::Hashable
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # Unique package name that identifies a Home app of the provider.
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @package_name = args[:package_name] if args.key?(:package_name)
        end
      end
      
      # An image represents the data about an image or a photo. IMPORTANT: The
      # definition of the Image message is being moved to //assistant/api/core_types/
      # governed/image_type.proto. All existing references will be updated to point to
      # the new location. If you are adding a reference, use the new Image message
      # instead of this one. LINT.IfChange NextId: 13
      class AssistantApiCoreTypesImage
        include Google::Apis::Core::Hashable
      
        # A text description of the image to be used for accessibility, e.g. screen
        # readers.
        # Corresponds to the JSON property `accessibilityText`
        # @return [String]
        attr_accessor :accessibility_text
      
        # App identifier. This field is specific to mobile surfaces and stands for app
        # package name for Android surface, and app bundle identifier for iOS. In case
        # identifier is specified but invalid, some default icon will be used, e.g.
        # PackageManager.getDefaultActivityIcon() for Android. If you want to show image
        # for AGSA versions which don't support this field, you can specify source_url
        # as backup.
        # Corresponds to the JSON property `appIconIdentifier`
        # @return [String]
        attr_accessor :app_icon_identifier
      
        # An image represents the data about an image or a photo. IMPORTANT: The
        # definition of the Image message is being moved to //assistant/api/core_types/
        # governed/image_type.proto. All existing references will be updated to point to
        # the new location. If you are adding a reference, use the new Image message
        # instead of this one. LINT.IfChange NextId: 13
        # Corresponds to the JSON property `badgeImage`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesImage]
        attr_accessor :badge_image
      
        # Content of the image in bytes.
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Indicate the data source where the image is fetched.
        # Corresponds to the JSON property `imageSource`
        # @return [String]
        attr_accessor :image_source
      
        # Content of image in form of JSON representation.
        # Corresponds to the JSON property `jsonContent`
        # @return [String]
        attr_accessor :json_content
      
        # Text used to generate a letter drawable (a letter icon with color). It will be
        # the default icon if the source_url is empty or cannot be rendered.
        # Corresponds to the JSON property `letterDrawableText`
        # @return [String]
        attr_accessor :letter_drawable_text
      
        # Url of the image provider, which is the website containing the image. For
        # example, https://www.agentx.com.
        # Corresponds to the JSON property `providerUrl`
        # @return [String]
        attr_accessor :provider_url
      
        # The source url of the image. For example, https://www.agentx.com/logo.png
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # Type of the source url.
        # Corresponds to the JSON property `sourceUrlType`
        # @return [String]
        attr_accessor :source_url_type
      
        # The width and height of the image in pixels.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @accessibility_text = args[:accessibility_text] if args.key?(:accessibility_text)
          @app_icon_identifier = args[:app_icon_identifier] if args.key?(:app_icon_identifier)
          @badge_image = args[:badge_image] if args.key?(:badge_image)
          @content = args[:content] if args.key?(:content)
          @height = args[:height] if args.key?(:height)
          @image_source = args[:image_source] if args.key?(:image_source)
          @json_content = args[:json_content] if args.key?(:json_content)
          @letter_drawable_text = args[:letter_drawable_text] if args.key?(:letter_drawable_text)
          @provider_url = args[:provider_url] if args.key?(:provider_url)
          @source_url = args[:source_url] if args.key?(:source_url)
          @source_url_type = args[:source_url_type] if args.key?(:source_url_type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Info for targeting a feature provided directly by the Assistant surface itself.
      # i.e Could be pointing to AGSA audio player for AUDIO_PLAYER on AGSA.
      class AssistantApiCoreTypesInternalProviderInfo
        include Google::Apis::Core::Hashable
      
        # Specifying which type of internal provider.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # The iOS app information of the provider. Next ID: 4
      class AssistantApiCoreTypesIosAppInfo
        include Google::Apis::Core::Hashable
      
        # Bundle identifier that identifies an iOS app of the provider.
        # Corresponds to the JSON property `bundleIdentifier`
        # @return [String]
        attr_accessor :bundle_identifier
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # A URL to open the provider's app.
        # Corresponds to the JSON property `openAppUrl`
        # @return [String]
        attr_accessor :open_app_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bundle_identifier = args[:bundle_identifier] if args.key?(:bundle_identifier)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @open_app_url = args[:open_app_url] if args.key?(:open_app_url)
        end
      end
      
      # The KaiOS app information of the provider. Next ID: 4
      class AssistantApiCoreTypesKaiOsAppInfo
        include Google::Apis::Core::Hashable
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # A URL to open the provider's app.
        # Corresponds to the JSON property `openAppUrl`
        # @return [String]
        attr_accessor :open_app_url
      
        # Unique package name that identifies a KaiOS app of the provider.
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @open_app_url = args[:open_app_url] if args.key?(:open_app_url)
          @package_name = args[:package_name] if args.key?(:package_name)
        end
      end
      
      # Geographic coordinate information for location.
      class AssistantApiCoreTypesLocationCoordinates
        include Google::Apis::Core::Hashable
      
        # The accuracy of the coordinates in meters.
        # Corresponds to the JSON property `accuracyMeters`
        # @return [Float]
        attr_accessor :accuracy_meters
      
        # Latitude degrees.
        # Corresponds to the JSON property `latDegrees`
        # @return [Float]
        attr_accessor :lat_degrees
      
        # Longitude degrees.
        # Corresponds to the JSON property `lngDegrees`
        # @return [Float]
        attr_accessor :lng_degrees
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @accuracy_meters = args[:accuracy_meters] if args.key?(:accuracy_meters)
          @lat_degrees = args[:lat_degrees] if args.key?(:lat_degrees)
          @lng_degrees = args[:lng_degrees] if args.key?(:lng_degrees)
        end
      end
      
      # This proto captures the contents of a messaging app notification that is
      # typically part of a conversation thread. Next Id: 20
      class AssistantApiCoreTypesMessageNotification
        include Google::Apis::Core::Hashable
      
        # App name of the message notification, e.g. Hangouts.
        # Corresponds to the JSON property `appName`
        # @return [String]
        attr_accessor :app_name
      
        # The key used to group this notification into a cluster.
        # Corresponds to the JSON property `bundleId`
        # @return [String]
        attr_accessor :bundle_id
      
        # Uri for the attachment (image, audio, video etc.).
        # Corresponds to the JSON property `dataUri`
        # @return [String]
        attr_accessor :data_uri
      
        # Name of the group associated with the message notification. This field is set
        # iff this is a group message.
        # Corresponds to the JSON property `groupName`
        # @return [String]
        attr_accessor :group_name
      
        # The group key of a proactive notification. Details in assistant.api.client_op.
        # NotificationArgs.grouping_key.
        # Corresponds to the JSON property `groupingKey`
        # @return [String]
        attr_accessor :grouping_key
      
        # Index of the message notification.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # Boolean indicating if the mark_as_read action is available for this message.
        # Corresponds to the JSON property `markAsReadActionAvailable`
        # @return [Boolean]
        attr_accessor :mark_as_read_action_available
        alias_method :mark_as_read_action_available?, :mark_as_read_action_available
      
        # Length of the message/notification content in characters. Note: We can't send
        # the full content because of privacy restriction, preventing sending client
        # content to our backends. Concatenated message_length of all
        # notification_entries.
        # Corresponds to the JSON property `messageLength`
        # @return [Fixnum]
        attr_accessor :message_length
      
        # 
        # Corresponds to the JSON property `messageRecipientType`
        # @return [String]
        attr_accessor :message_recipient_type
      
        # Mime type of the data_uri. e.g. 'audio/wav', 'video/mp4', 'image/png'.
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # 
        # Corresponds to the JSON property `notificationEntries`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesMessageNotificationNotificationEntry>]
        attr_accessor :notification_entries
      
        # On-device cache key for notification icon.
        # Corresponds to the JSON property `notificationIconKey`
        # @return [String]
        attr_accessor :notification_icon_key
      
        # String key of the notification. It is the key from original
        # StatusBarNotification received from Android OS. It is used to identify the
        # original notification to send a reply.
        # Corresponds to the JSON property `notificationKey`
        # @return [String]
        attr_accessor :notification_key
      
        # The opaque_token of a proactive notification. Details in assistant.api.
        # client_op.NotificationArgs.opaque_token.
        # Corresponds to the JSON property `opaqueToken`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :opaque_token
      
        # App pkg of the message notification, e.g. "com.google.android.talk".
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        # Timestamp of the last notification's post time.
        # Corresponds to the JSON property `postTime`
        # @return [Fixnum]
        attr_accessor :post_time
      
        # Boolean indicating if the reply action is available for this message.
        # Corresponds to the JSON property `replyActionAvailable`
        # @return [Boolean]
        attr_accessor :reply_action_available
        alias_method :reply_action_available?, :reply_action_available
      
        # Mirrors part of https://developer.android.com/reference/android/app/Person
        # Next Id: 4
        # Corresponds to the JSON property `sender`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesMessageNotificationPerson]
        attr_accessor :sender
      
        # Sender's name of the message notification, e.g. Elsa. Last sender name in case
        # of a group conversation.
        # Corresponds to the JSON property `senderName`
        # @return [String]
        attr_accessor :sender_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_name = args[:app_name] if args.key?(:app_name)
          @bundle_id = args[:bundle_id] if args.key?(:bundle_id)
          @data_uri = args[:data_uri] if args.key?(:data_uri)
          @group_name = args[:group_name] if args.key?(:group_name)
          @grouping_key = args[:grouping_key] if args.key?(:grouping_key)
          @index = args[:index] if args.key?(:index)
          @mark_as_read_action_available = args[:mark_as_read_action_available] if args.key?(:mark_as_read_action_available)
          @message_length = args[:message_length] if args.key?(:message_length)
          @message_recipient_type = args[:message_recipient_type] if args.key?(:message_recipient_type)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @notification_entries = args[:notification_entries] if args.key?(:notification_entries)
          @notification_icon_key = args[:notification_icon_key] if args.key?(:notification_icon_key)
          @notification_key = args[:notification_key] if args.key?(:notification_key)
          @opaque_token = args[:opaque_token] if args.key?(:opaque_token)
          @package_name = args[:package_name] if args.key?(:package_name)
          @post_time = args[:post_time] if args.key?(:post_time)
          @reply_action_available = args[:reply_action_available] if args.key?(:reply_action_available)
          @sender = args[:sender] if args.key?(:sender)
          @sender_name = args[:sender_name] if args.key?(:sender_name)
        end
      end
      
      # Structure of each notification in the MessageNotification Bundle. Attribute
      # sender_name could be different in case of group messages. Next Id: 6
      class AssistantApiCoreTypesMessageNotificationNotificationEntry
        include Google::Apis::Core::Hashable
      
        # Uri for the attachment (image, audio, video etc.).
        # Corresponds to the JSON property `dataUri`
        # @return [String]
        attr_accessor :data_uri
      
        # Content of the message body in the notification.
        # Corresponds to the JSON property `messageBody`
        # @return [String]
        attr_accessor :message_body
      
        # Mime type of the data_uri. e.g. 'audio/wav', 'video/mp4', 'image/png'.
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # Timestamp of the notification's post time.
        # Corresponds to the JSON property `postTime`
        # @return [String]
        attr_accessor :post_time
      
        # Mirrors part of https://developer.android.com/reference/android/app/Person
        # Next Id: 4
        # Corresponds to the JSON property `sender`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesMessageNotificationPerson]
        attr_accessor :sender
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_uri = args[:data_uri] if args.key?(:data_uri)
          @message_body = args[:message_body] if args.key?(:message_body)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @post_time = args[:post_time] if args.key?(:post_time)
          @sender = args[:sender] if args.key?(:sender)
        end
      end
      
      # Mirrors part of https://developer.android.com/reference/android/app/Person
      # Next Id: 4
      class AssistantApiCoreTypesMessageNotificationPerson
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isImportant`
        # @return [Boolean]
        attr_accessor :is_important
        alias_method :is_important?, :is_important
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_important = args[:is_important] if args.key?(:is_important)
          @key = args[:key] if args.key?(:key)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Provider. Like, Spotify or iHeartRadio. Next ID: 13
      class AssistantApiCoreTypesProvider
        include Google::Apis::Core::Hashable
      
        # The android app information of the provider. Like, Spotify. Next ID: 15 LINT.
        # IfChange
        # Corresponds to the JSON property `androidAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesAndroidAppInfo]
        attr_accessor :android_app_info
      
        # The cast app information of the provider.
        # Corresponds to the JSON property `castAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCastAppInfo]
        attr_accessor :cast_app_info
      
        # The ChromeOS app information of the provider. Next ID: 3
        # Corresponds to the JSON property `chromeosAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesChromeOsAppInfo]
        attr_accessor :chromeos_app_info
      
        # The third party provider information.
        # Corresponds to the JSON property `cloudProviderInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCloudProviderInfo]
        attr_accessor :cloud_provider_info
      
        # A URL to fallback to if app can not be opened.
        # Corresponds to the JSON property `fallbackUrl`
        # @return [String]
        attr_accessor :fallback_url
      
        # The Home app information of the provider. Next ID: 3
        # Corresponds to the JSON property `homeAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesHomeAppInfo]
        attr_accessor :home_app_info
      
        # Public URL pointing to an icon image for the provider. e.g. https://lh3.
        # googleusercontent.com/UrY7BAZ-XfXGpfkeWg0zCCeo-
        # 7ras4DCoRalC_WXXWTK9q5b0Iw7B0YQMsVxZaNB7DM
        # Corresponds to the JSON property `iconImageUrl`
        # @return [String]
        attr_accessor :icon_image_url
      
        # Info for targeting a feature provided directly by the Assistant surface itself.
        # i.e Could be pointing to AGSA audio player for AUDIO_PLAYER on AGSA.
        # Corresponds to the JSON property `internalProviderInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesInternalProviderInfo]
        attr_accessor :internal_provider_info
      
        # The iOS app information of the provider. Next ID: 4
        # Corresponds to the JSON property `iosAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesIosAppInfo]
        attr_accessor :ios_app_info
      
        # The KaiOS app information of the provider. Next ID: 4
        # Corresponds to the JSON property `kaiosAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesKaiOsAppInfo]
        attr_accessor :kaios_app_info
      
        # Session Initiation Protocol (SIP) information for providers that use SIP to
        # initiate multimedia communication sessions, like Google Voice and Fi. https://
        # en.wikipedia.org/wiki/Session_Initiation_Protocol
        # Corresponds to the JSON property `sipProviderInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesSipProviderInfo]
        attr_accessor :sip_provider_info
      
        # The web information of the provider. Next ID: 5
        # Corresponds to the JSON property `webProviderInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesWebProviderInfo]
        attr_accessor :web_provider_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_app_info = args[:android_app_info] if args.key?(:android_app_info)
          @cast_app_info = args[:cast_app_info] if args.key?(:cast_app_info)
          @chromeos_app_info = args[:chromeos_app_info] if args.key?(:chromeos_app_info)
          @cloud_provider_info = args[:cloud_provider_info] if args.key?(:cloud_provider_info)
          @fallback_url = args[:fallback_url] if args.key?(:fallback_url)
          @home_app_info = args[:home_app_info] if args.key?(:home_app_info)
          @icon_image_url = args[:icon_image_url] if args.key?(:icon_image_url)
          @internal_provider_info = args[:internal_provider_info] if args.key?(:internal_provider_info)
          @ios_app_info = args[:ios_app_info] if args.key?(:ios_app_info)
          @kaios_app_info = args[:kaios_app_info] if args.key?(:kaios_app_info)
          @sip_provider_info = args[:sip_provider_info] if args.key?(:sip_provider_info)
          @web_provider_info = args[:web_provider_info] if args.key?(:web_provider_info)
        end
      end
      
      # ProviderDelta. The incremental change, e.g. installation or deletion for
      # Spotify or iHeartRadio. Currently it is for Android only. A few considerations
      # for edge cases: - If the app being deleted is not found from Footprints, it is
      # ignored. - For Footprint upload through Geller, the gPRC response is available
      # for client to retry in the next upload if the upload fails. - For Assistant
      # Request, there is no upload status similar to the current AppCapabilities.
      # Next ID: 4
      class AssistantApiCoreTypesProviderDelta
        include Google::Apis::Core::Hashable
      
        # The change of AndroidAppInfo, e.g. app installation or deletion for
        # incremental delta app info upload.
        # Corresponds to the JSON property `androidAppInfoDelta`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesAndroidAppInfoDelta]
        attr_accessor :android_app_info_delta
      
        # A URL to fallback to if app can not be opened.
        # Corresponds to the JSON property `fallbackUrl`
        # @return [String]
        attr_accessor :fallback_url
      
        # Public URL pointing to an icon image for the provider. e.g. https://lh3.
        # googleusercontent.com/UrY7BAZ-XfXGpfkeWg0zCCeo-
        # 7ras4DCoRalC_WXXWTK9q5b0Iw7B0YQMsVxZaNB7DM
        # Corresponds to the JSON property `iconImageUrl`
        # @return [String]
        attr_accessor :icon_image_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_app_info_delta = args[:android_app_info_delta] if args.key?(:android_app_info_delta)
          @fallback_url = args[:fallback_url] if args.key?(:fallback_url)
          @icon_image_url = args[:icon_image_url] if args.key?(:icon_image_url)
        end
      end
      
      # Session Initiation Protocol (SIP) information for providers that use SIP to
      # initiate multimedia communication sessions, like Google Voice and Fi. https://
      # en.wikipedia.org/wiki/Session_Initiation_Protocol
      class AssistantApiCoreTypesSipProviderInfo
        include Google::Apis::Core::Hashable
      
        # The providers id (MID) which is the primary identifier for a call provider
        # within the Assistant. A MID, or machine identifier, is a unique identifier
        # issued by Knowledge Graph for all entities contained in it's graph.
        # Corresponds to the JSON property `providerId`
        # @return [String]
        attr_accessor :provider_id
      
        # Calling realm to be use for each call. i.e. For anonymous, this would be set
        # to anonymous.chirp.google.com
        # Corresponds to the JSON property `realm`
        # @return [String]
        attr_accessor :realm
      
        # If true, client should use the Birdsong TaCL API for this call. Uses the
        # VoiceCallManager API by default. For more details: go/birdsong-migration-
        # google-home
        # Corresponds to the JSON property `useBirdsongTacl`
        # @return [Boolean]
        attr_accessor :use_birdsong_tacl
        alias_method :use_birdsong_tacl?, :use_birdsong_tacl
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provider_id = args[:provider_id] if args.key?(:provider_id)
          @realm = args[:realm] if args.key?(:realm)
          @use_birdsong_tacl = args[:use_birdsong_tacl] if args.key?(:use_birdsong_tacl)
        end
      end
      
      # The set of information that helps the server identify the surface. This
      # replaces the User-Agent string within the Assistant Server. Note: The
      # SurfaceIdentity proto should only be used to derive the capabilities of a
      # surface. It should not be accessed outside of the CapabilityBuilder or
      # CapabilityChecker. NEXT ID: 5 IMPORTANT: The definitions of the
      # SurfaceIdentity and SurfaceVersion protos are being moved to //assistant/api/
      # core_types/governed/surface_identity.proto All existing references will be
      # updated to point to the new location. If you are adding a reference, use the
      # new SurfaceIdentity and SurfaceVersion protos instead of the protos defined
      # here. LINT.IfChange
      class AssistantApiCoreTypesSurfaceIdentity
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # The device's surface type. The types are defined at google3/assistant/api/
        # core_types/surfaces.gcl. NOTE: This is the new field that is going to replace
        # the `surface_type_string` field above. For more details please refer to go/
        # ontologicalize-surface-type.
        # Corresponds to the JSON property `surfaceType`
        # @return [String]
        attr_accessor :surface_type
      
        # The device's surface type. This is the string version of the assistant.api.
        # core_types.SurfaceType enum. The server should not use this field, rather it
        # should use the SurfaceType value derived from this string.
        # Corresponds to the JSON property `surfaceTypeString`
        # @return [String]
        attr_accessor :surface_type_string
      
        # The version of the surface/client. New surfaces are encouraged to only use the
        # “major” field to keep track of version number. The “minor” field may be used
        # for surfaces that rely on both the “major” and “minor” fields to define their
        # version.
        # Corresponds to the JSON property `surfaceVersion`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesSurfaceVersion]
        attr_accessor :surface_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @surface_type = args[:surface_type] if args.key?(:surface_type)
          @surface_type_string = args[:surface_type_string] if args.key?(:surface_type_string)
          @surface_version = args[:surface_version] if args.key?(:surface_version)
        end
      end
      
      # Specifies the types of device surfaces. LINT.IfChange When adding new surface
      # types make sure that My Activity (https://myactivity.google.com/product/
      # assistant) will correctly render by adding your enum to http://cs/symbol:
      # GetAssistSurfaceName%20f:%5C.cc$ If your type doesn't fit in to any of the
      # existing surfaces messages, add a new message in http://google3/
      # personalization/footprints/boq/uservisible/events/intl/smh_frontend_messages.h.
      class AssistantApiCoreTypesSurfaceType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # The version of the surface/client. New surfaces are encouraged to only use the
      # “major” field to keep track of version number. The “minor” field may be used
      # for surfaces that rely on both the “major” and “minor” fields to define their
      # version.
      class AssistantApiCoreTypesSurfaceVersion
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `major`
        # @return [Fixnum]
        attr_accessor :major
      
        # 
        # Corresponds to the JSON property `minor`
        # @return [Fixnum]
        attr_accessor :minor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @major = args[:major] if args.key?(:major)
          @minor = args[:minor] if args.key?(:minor)
        end
      end
      
      # The web information of the provider. Next ID: 5
      class AssistantApiCoreTypesWebProviderInfo
        include Google::Apis::Core::Hashable
      
        # Serialized storage (context) persisted and retrieved for the app and home.
        # Corresponds to the JSON property `homeStorage`
        # @return [String]
        attr_accessor :home_storage
      
        # The localized app name.
        # Corresponds to the JSON property `localizedAppName`
        # @return [String]
        attr_accessor :localized_app_name
      
        # A URL to open the provider's app.
        # Corresponds to the JSON property `openAppUrl`
        # @return [String]
        attr_accessor :open_app_url
      
        # Info about 3P Custom NLU used in this web provider. TODO(b/321644453) remove
        # when QRewrite is able to call SERoot.
        # Corresponds to the JSON property `thirdPartyCustomNluInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesWebProviderInfoThirdPartyCustomNluInfo]
        attr_accessor :third_party_custom_nlu_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @home_storage = args[:home_storage] if args.key?(:home_storage)
          @localized_app_name = args[:localized_app_name] if args.key?(:localized_app_name)
          @open_app_url = args[:open_app_url] if args.key?(:open_app_url)
          @third_party_custom_nlu_info = args[:third_party_custom_nlu_info] if args.key?(:third_party_custom_nlu_info)
        end
      end
      
      # 
      class AssistantApiCoreTypesWebProviderInfoThirdPartyCustomNluInfo
        include Google::Apis::Core::Hashable
      
        # The locale of this agent version, represented by BCP-47 language strings, such
        # as "en", "en-US", "fr", "fr-CA", "sr-Latn", "zh-Hans-CN", etc.
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # Unique internal identifier of 3P Custom NLU agent. UUID.
        # Corresponds to the JSON property `nluAgentId`
        # @return [String]
        attr_accessor :nlu_agent_id
      
        # Identifies the 3P Custom NLU agent version.
        # Corresponds to the JSON property `nluAgentVersion`
        # @return [Fixnum]
        attr_accessor :nlu_agent_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
          @nlu_agent_id = args[:nlu_agent_id] if args.key?(:nlu_agent_id)
          @nlu_agent_version = args[:nlu_agent_version] if args.key?(:nlu_agent_version)
        end
      end
      
      # 
      class AssistantApiCrossDeviceExecutionCapability
        include Google::Apis::Core::Hashable
      
        # Whether the device has torus/usonia capabililities enabled or not.
        # Corresponds to the JSON property `localConnectivityEnabled`
        # @return [Boolean]
        attr_accessor :local_connectivity_enabled
        alias_method :local_connectivity_enabled?, :local_connectivity_enabled
      
        # Whether the device supports cast media originated from a remote device to be
        # executed through local execution and can upload results asynchronously. Needs
        # to be checked before sending remote media initiation through local channel
        # since it needs an async result upload path.
        # Corresponds to the JSON property `remoteCastMediaEnabled`
        # @return [Boolean]
        attr_accessor :remote_cast_media_enabled
        alias_method :remote_cast_media_enabled?, :remote_cast_media_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @local_connectivity_enabled = args[:local_connectivity_enabled] if args.key?(:local_connectivity_enabled)
          @remote_cast_media_enabled = args[:remote_cast_media_enabled] if args.key?(:remote_cast_media_enabled)
        end
      end
      
      # A Gregorian calendar date. IMPORTANT: The definition of Date proto is being
      # moved to //assistant/api/core_types/governed/datetime_type.proto. All existing
      # references will be updated to point to the new location. If you are adding a
      # reference, use the new one instead.
      class AssistantApiDate
        include Google::Apis::Core::Hashable
      
        # The day, in 1...31.
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # The month, in 1...12.
        # Corresponds to the JSON property `month`
        # @return [Fixnum]
        attr_accessor :month
      
        # The year, e.g. 2016.
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @month = args[:month] if args.key?(:month)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # A date-time specification, combining a date and civil time (relative to a
      # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
      # //assistant/api/core_types/governed/datetime_type.proto. All existing
      # references will be updated to point to the new location. If you are adding a
      # reference, use the new one instead.
      class AssistantApiDateTime
        include Google::Apis::Core::Hashable
      
        # A Gregorian calendar date. IMPORTANT: The definition of Date proto is being
        # moved to //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `date`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDate]
        attr_accessor :date
      
        # A civil time relative to a timezone. IMPORTANT: The definition of TimeOfDay
        # proto is being moved to //assistant/api/core_types/governed/datetime_type.
        # proto. All existing references will be updated to point to the new location.
        # If you are adding a reference, use the new one instead.
        # Corresponds to the JSON property `timeOfDay`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimeOfDay]
        attr_accessor :time_of_day
      
        # A time zone. Conceptually, a time zone is a set of rules associated with a
        # location that describes a UTC offset and how it changes over time (e.g.
        # Daylight Saving Time). The offset is used to compute the local date and time.
        # IMPORTANT: The definition of TimeZone enum is being moved to //assistant/api/
        # core_types/governed/datetime_type.proto. All existing references will be
        # updated to point to the new location. If you are adding a reference, use the
        # new one instead.
        # Corresponds to the JSON property `timeZone`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimeZone]
        attr_accessor :time_zone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date = args[:date] if args.key?(:date)
          @time_of_day = args[:time_of_day] if args.key?(:time_of_day)
          @time_zone = args[:time_zone] if args.key?(:time_zone)
        end
      end
      
      # This message describes roughly what a surface is capable of doing and metadata
      # around those capabilities. These capabilities are determined based on: -
      # device hardware - software - status (e.g. volume level, battery percentage)
      # These capabilities refer to the surface and not the physical device. The list
      # of supported surfaces can be found in the assistant.api.core_types.SurfaceType
      # enum. A surface's capabilities can differ from the device's. An example would
      # be ANDROID_ALLO running on Pixel. Allo does not support AudioInput while the
      # Pixel does. In this case, audio_input will be set to false for Assistant Allo
      # requests while it might be set to true for OPA_NEXUS requests. Next ID: 32
      class AssistantApiDeviceCapabilities
        include Google::Apis::Core::Hashable
      
        # Capabilities related to Android intent support. These capabilities can apply
        # to any device on the Android platform. Provides the list of Android package
        # names that support a given Android intent.
        # Corresponds to the JSON property `androidIntentCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAndroidIntentCapabilities]
        attr_accessor :android_intent_capabilities
      
        # These capabilities represent the audio input features associated with the
        # device. This includes what kind of audio input the device can handle, and what
        # the privacy circumstances of that input are.
        # Corresponds to the JSON property `audioInput`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAudioInput]
        attr_accessor :audio_input
      
        # These capabilities represent the audio output features associated with the
        # device. This includes what kind of audio output the device can handle, and
        # what the privacy circumstances of that output are.
        # Corresponds to the JSON property `audioOutput`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAudioOutput]
        attr_accessor :audio_output
      
        # CallCapabilities supported by a surface. See go/call-capabilities. Next ID: 7
        # Corresponds to the JSON property `callCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCallCapabilities]
        attr_accessor :call_capabilities
      
        # These capabilities represent the camera features associated with the device.
        # Corresponds to the JSON property `camera`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCameraCapabilities]
        attr_accessor :camera
      
        # These capabilities represent capabilities that have to do with casting that
        # pertain to this device. Next ID: 9
        # Corresponds to the JSON property `cast`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCastCapabilities]
        attr_accessor :cast
      
        # UI capabilities for the surfaces rendering Comms features. See go/rohan-comms-
        # fluid-actions-customization.
        # Corresponds to the JSON property `communicationUiCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCommunicationUiCapabilities]
        attr_accessor :communication_ui_capabilities
      
        # 
        # Corresponds to the JSON property `contactLookupCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiContactLookupCapabilities]
        attr_accessor :contact_lookup_capabilities
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # Capabilities related to Android tablet UX experience.
        # Corresponds to the JSON property `deviceUxMode`
        # @return [String]
        attr_accessor :device_ux_mode
      
        # Indicates that the device has connection to cellular network that allows it to
        # make voice calls. This is distinct from device just being capable of voice
        # telephony, because the device can be capable yet miss the suitable SIM card (
        # for example, it could miss SIM card altogether, or have data-only SIM card).
        # Corresponds to the JSON property `hasVoiceTelephony`
        # @return [Boolean]
        attr_accessor :has_voice_telephony
        alias_method :has_voice_telephony?, :has_voice_telephony
      
        # These capabilities are used to determine the jwn libraries and their versions
        # that are present on the client.
        # Corresponds to the JSON property `jwnCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiJwnCapabilities]
        attr_accessor :jwn_capabilities
      
        # Capabilities related to Lens Perception, i.e. image understanding. See go/loa-
        # lens-device-capabilities. Next ID: 6
        # Corresponds to the JSON property `lensPerceptionCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilities]
        attr_accessor :lens_perception_capabilities
      
        # These capabilities are scoped to the location abilities of this device.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLocationCapabilities]
        attr_accessor :location
      
        # Data which is produced for logging and debugging. Servers MUST NOT use this
        # for any other purposes, such as branching on it.
        # Corresponds to the JSON property `loggingOnlyData`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLoggingOnlyData]
        attr_accessor :logging_only_data
      
        # 
        # Corresponds to the JSON property `messageCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiMessageCapabilities]
        attr_accessor :message_capabilities
      
        # These capabilities are scoped to abilities of the device to move around.
        # Corresponds to the JSON property `movement`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiMovementCapabilities]
        attr_accessor :movement
      
        # DEPRECATED: Use SystemNotificationRestrictions instead. Specifies whether the
        # surface is able to display notifications. This field is superficially similar
        # to ProactiveNotificationOutput, but unlike that field which tracks a per-user
        # preference on the OPA side, this field captures whether the surface is capable
        # of displaying notifications.
        # Corresponds to the JSON property `notificationCapabilities`
        # @return [String]
        attr_accessor :notification_capabilities
      
        # Settings, that reflect whether a specific notification type is allowed for
        # current device, e.g. if the user opted out from notification category or
        # category group. This settings are server-side stored and evaluated unlike
        # SystemNotificationRestrictions field.
        # Corresponds to the JSON property `notificationOutputRestrictions`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiNotificationOutputRestrictions]
        attr_accessor :notification_output_restrictions
      
        # These are user configurable permissions representing what the device is
        # allowed to output. Next ID: 11
        # Corresponds to the JSON property `outputRestrictions`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiOutputRestrictions]
        attr_accessor :output_restrictions
      
        # Indicates if the client has safety related restriction.
        # Corresponds to the JSON property `safetyRestrictions`
        # @return [String]
        attr_accessor :safety_restrictions
      
        # These capabilities represent the tactile features associated with the device.
        # This includes, for example, whether the device has a screen, how big the
        # screen is, and privacy of the screen. Next ID: 10
        # Corresponds to the JSON property `screen`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiScreenCapabilities]
        attr_accessor :screen
      
        # Capabilities related to SODA (Speech On-Device API). Next ID: 5
        # Corresponds to the JSON property `sodaCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSodaCapabilities]
        attr_accessor :soda_capabilities
      
        # These capabilities represent what software features the client supports. This
        # should be determined based on the client's various software versions (OS, GSA
        # version, etc). Next ID: 26
        # Corresponds to the JSON property `software`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSoftwareCapabilities]
        attr_accessor :software
      
        # DEPRECATED These capabilties are associated with speech detection on devices.
        # Corresponds to the JSON property `speechCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSpeechCapabilities]
        attr_accessor :speech_capabilities
      
        # Locales supported by assistant settings for speaking and display. This is
        # independent from device language that is defined in device setting. New
        # locales are added based on rollout, whitelist and app version releases because
        # older versions does not have model support. Currently supported locale list
        # differs by surface type.
        # Corresponds to the JSON property `supportedLocale`
        # @return [Array<String>]
        attr_accessor :supported_locale
      
        # The set of information that helps the server identify the surface. This
        # replaces the User-Agent string within the Assistant Server. Note: The
        # SurfaceIdentity proto should only be used to derive the capabilities of a
        # surface. It should not be accessed outside of the CapabilityBuilder or
        # CapabilityChecker. NEXT ID: 5 IMPORTANT: The definitions of the
        # SurfaceIdentity and SurfaceVersion protos are being moved to //assistant/api/
        # core_types/governed/surface_identity.proto All existing references will be
        # updated to point to the new location. If you are adding a reference, use the
        # new SurfaceIdentity and SurfaceVersion protos instead of the protos defined
        # here. LINT.IfChange
        # Corresponds to the JSON property `surfaceIdentity`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesSurfaceIdentity]
        attr_accessor :surface_identity
      
        # The device's surface type. This is the string version of the assistant.api.
        # core_types.SurfaceType enum. The server should not use this field, rather it
        # should use the SurfaceType value derived from this string.
        # Corresponds to the JSON property `surfaceTypeString`
        # @return [String]
        attr_accessor :surface_type_string
      
        # Restrictions related to system-level notifications.
        # Corresponds to the JSON property `systemNotificationRestrictions`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSystemNotificationRestrictions]
        attr_accessor :system_notification_restrictions
      
        # Capabilities related to third party integration.
        # Corresponds to the JSON property `thirdPartyCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiThirdPartyCapabilities]
        attr_accessor :third_party_capabilities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_intent_capabilities = args[:android_intent_capabilities] if args.key?(:android_intent_capabilities)
          @audio_input = args[:audio_input] if args.key?(:audio_input)
          @audio_output = args[:audio_output] if args.key?(:audio_output)
          @call_capabilities = args[:call_capabilities] if args.key?(:call_capabilities)
          @camera = args[:camera] if args.key?(:camera)
          @cast = args[:cast] if args.key?(:cast)
          @communication_ui_capabilities = args[:communication_ui_capabilities] if args.key?(:communication_ui_capabilities)
          @contact_lookup_capabilities = args[:contact_lookup_capabilities] if args.key?(:contact_lookup_capabilities)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_ux_mode = args[:device_ux_mode] if args.key?(:device_ux_mode)
          @has_voice_telephony = args[:has_voice_telephony] if args.key?(:has_voice_telephony)
          @jwn_capabilities = args[:jwn_capabilities] if args.key?(:jwn_capabilities)
          @lens_perception_capabilities = args[:lens_perception_capabilities] if args.key?(:lens_perception_capabilities)
          @location = args[:location] if args.key?(:location)
          @logging_only_data = args[:logging_only_data] if args.key?(:logging_only_data)
          @message_capabilities = args[:message_capabilities] if args.key?(:message_capabilities)
          @movement = args[:movement] if args.key?(:movement)
          @notification_capabilities = args[:notification_capabilities] if args.key?(:notification_capabilities)
          @notification_output_restrictions = args[:notification_output_restrictions] if args.key?(:notification_output_restrictions)
          @output_restrictions = args[:output_restrictions] if args.key?(:output_restrictions)
          @safety_restrictions = args[:safety_restrictions] if args.key?(:safety_restrictions)
          @screen = args[:screen] if args.key?(:screen)
          @soda_capabilities = args[:soda_capabilities] if args.key?(:soda_capabilities)
          @software = args[:software] if args.key?(:software)
          @speech_capabilities = args[:speech_capabilities] if args.key?(:speech_capabilities)
          @supported_locale = args[:supported_locale] if args.key?(:supported_locale)
          @surface_identity = args[:surface_identity] if args.key?(:surface_identity)
          @surface_type_string = args[:surface_type_string] if args.key?(:surface_type_string)
          @system_notification_restrictions = args[:system_notification_restrictions] if args.key?(:system_notification_restrictions)
          @third_party_capabilities = args[:third_party_capabilities] if args.key?(:third_party_capabilities)
        end
      end
      
      # A Duration represents a signed, fixed-length span of time represented as a
      # count of seconds and fractions of seconds at nanosecond resolution. It is
      # independent of any calendar and concepts like "day" or "month". It is related
      # to Timestamp in that the difference between two Timestamp values is a Duration
      # and it can be added or subtracted from a Timestamp. Range is approximately +-
      # 10,000 years.
      class AssistantApiDuration
        include Google::Apis::Core::Hashable
      
        # Signed fractions of a second at nanosecond resolution of the span of time.
        # Durations less than one second are represented with a 0 `seconds` field and a
        # positive or negative `nanos` field. For durations of one second or more, a non-
        # zero value for the `nanos` field must be of the same sign as the `seconds`
        # field. Must be from -999,999,999 to +999,999,999 inclusive.
        # Corresponds to the JSON property `nanos`
        # @return [Fixnum]
        attr_accessor :nanos
      
        # Signed seconds of the span of time. Must be from -315,576,000,000 to +315,576,
        # 000,000 inclusive.
        # Corresponds to the JSON property `seconds`
        # @return [Fixnum]
        attr_accessor :seconds
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @nanos = args[:nanos] if args.key?(:nanos)
          @seconds = args[:seconds] if args.key?(:seconds)
        end
      end
      
      # 
      class AssistantApiFeatureSpecificActionSupport
        include Google::Apis::Core::Hashable
      
        # Whether client supports clarification suggestion chip to be displayed see |
        # assistant.suggestions.ClarificationData|
        # Corresponds to the JSON property `clarificationDataSupported`
        # @return [Boolean]
        attr_accessor :clarification_data_supported
        alias_method :clarification_data_supported?, :clarification_data_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @clarification_data_supported = args[:clarification_data_supported] if args.key?(:clarification_data_supported)
        end
      end
      
      # 
      class AssistantApiFitnessFeatureSupport
        include Google::Apis::Core::Hashable
      
        # A list of fitness activity types supported by this client.
        # Corresponds to the JSON property `supportedActivities`
        # @return [Array<String>]
        attr_accessor :supported_activities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supported_activities = args[:supported_activities] if args.key?(:supported_activities)
        end
      end
      
      # 
      class AssistantApiFluidActionsSupport
        include Google::Apis::Core::Hashable
      
        # Specifies the params proto that Fluid Actions uses to sync state with server.
        # Corresponds to the JSON property `stateSyncMethod`
        # @return [String]
        attr_accessor :state_sync_method
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state_sync_method = args[:state_sync_method] if args.key?(:state_sync_method)
        end
      end
      
      # Capabilities of Google assistant conversation service(GACS) devices. These
      # capabilites including supported GACS actions and response size limitations.
      class AssistantApiGacsCapabilities
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # Configuration for the response. Next Id: 11
        # Corresponds to the JSON property `responseConfig`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1ResponseConfig]
        attr_accessor :response_config
      
        # DEPRECATED: Format of TTS audio requested by the device.
        # Corresponds to the JSON property `ttsEncoding`
        # @return [String]
        attr_accessor :tts_encoding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @response_config = args[:response_config] if args.key?(:response_config)
          @tts_encoding = args[:tts_encoding] if args.key?(:tts_encoding)
        end
      end
      
      # Capabilities related to GCM.
      class AssistantApiGcmCapabilities
        include Google::Apis::Core::Hashable
      
        # GCM registration id for the device. Used to pass messages to the device.
        # Corresponds to the JSON property `gcmRegistrationId`
        # @return [String]
        attr_accessor :gcm_registration_id
      
        # Assistant supports GCM on the device. ClientOps can be sent to it over GCM and
        # will be executed.
        # Corresponds to the JSON property `supportsAssistantGcm`
        # @return [Boolean]
        attr_accessor :supports_assistant_gcm
        alias_method :supports_assistant_gcm?, :supports_assistant_gcm
      
        # If it is set to true, then it indicates to server that device is capable of
        # receiving a GCM payload with serialized client input. The client input will be
        # sent back to Assistant Server over conversation protocol.
        # Corresponds to the JSON property `supportsClientInputOverGcm`
        # @return [Boolean]
        attr_accessor :supports_client_input_over_gcm
        alias_method :supports_client_input_over_gcm?, :supports_client_input_over_gcm
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcm_registration_id = args[:gcm_registration_id] if args.key?(:gcm_registration_id)
          @supports_assistant_gcm = args[:supports_assistant_gcm] if args.key?(:supports_assistant_gcm)
          @supports_client_input_over_gcm = args[:supports_client_input_over_gcm] if args.key?(:supports_client_input_over_gcm)
        end
      end
      
      # The gesture capabilities related to Selina. Next ID: 4
      class AssistantApiGestureCapabilities
        include Google::Apis::Core::Hashable
      
        # Whether Gesture is supported. When false, override the value for tap and
        # omniswipe.
        # Corresponds to the JSON property `gestureSensing`
        # @return [Boolean]
        attr_accessor :gesture_sensing
        alias_method :gesture_sensing?, :gesture_sensing
      
        # Whether omniswipe is supported
        # Corresponds to the JSON property `omniswipeGestureCapable`
        # @return [Boolean]
        attr_accessor :omniswipe_gesture_capable
        alias_method :omniswipe_gesture_capable?, :omniswipe_gesture_capable
      
        # Whether tap is supported
        # Corresponds to the JSON property `tapGestureCapable`
        # @return [Boolean]
        attr_accessor :tap_gesture_capable
        alias_method :tap_gesture_capable?, :tap_gesture_capable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gesture_sensing = args[:gesture_sensing] if args.key?(:gesture_sensing)
          @omniswipe_gesture_capable = args[:omniswipe_gesture_capable] if args.key?(:omniswipe_gesture_capable)
          @tap_gesture_capable = args[:tap_gesture_capable] if args.key?(:tap_gesture_capable)
        end
      end
      
      # DEPRECATED: Use AccessControlOutput instead. Access settings for guests.
      class AssistantApiGuestAccessOutput
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `guestAccessOnYoutube`
        # @return [String]
        attr_accessor :guest_access_on_youtube
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @guest_access_on_youtube = args[:guest_access_on_youtube] if args.key?(:guest_access_on_youtube)
        end
      end
      
      # 
      class AssistantApiImmersiveCanvasSupport
        include Google::Apis::Core::Hashable
      
        # Whether the client supports confirmation messages in Immersive Canvas actions.
        # Corresponds to the JSON property `confirmationMessageSupported`
        # @return [Boolean]
        attr_accessor :confirmation_message_supported
        alias_method :confirmation_message_supported?, :confirmation_message_supported
      
        # Whether the client support canvas pause signal. If true, the Assistant Server
        # will send a signal when canvas transitioning to pause mode.
        # Corresponds to the JSON property `pauseSignalSupported`
        # @return [Boolean]
        attr_accessor :pause_signal_supported
        alias_method :pause_signal_supported?, :pause_signal_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confirmation_message_supported = args[:confirmation_message_supported] if args.key?(:confirmation_message_supported)
          @pause_signal_supported = args[:pause_signal_supported] if args.key?(:pause_signal_supported)
        end
      end
      
      # These capabilities are used to determine the jwn libraries and their versions
      # that are present on the client.
      class AssistantApiJwnCapabilities
        include Google::Apis::Core::Hashable
      
        # The name and version of the jwn libraries currently stored on the client.
        # These are the same that the server communicated when the library was first
        # sent down.
        # Corresponds to the JSON property `librariesVersionMap`
        # @return [Hash<String,String>]
        attr_accessor :libraries_version_map
      
        # Compression algorithms supported on the client. Server can choose one of these
        # to compress WhatsNext Javascript programs and libraries.
        # Corresponds to the JSON property `supportedCompressionMode`
        # @return [Array<String>]
        attr_accessor :supported_compression_mode
      
        # Whether the client supports running jwn code.
        # Corresponds to the JSON property `supportsJwn`
        # @return [Boolean]
        attr_accessor :supports_jwn
        alias_method :supports_jwn?, :supports_jwn
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @libraries_version_map = args[:libraries_version_map] if args.key?(:libraries_version_map)
          @supported_compression_mode = args[:supported_compression_mode] if args.key?(:supported_compression_mode)
          @supports_jwn = args[:supports_jwn] if args.key?(:supports_jwn)
        end
      end
      
      # Capabilities related to Lens Perception, i.e. image understanding. See go/loa-
      # lens-device-capabilities. Next ID: 6
      class AssistantApiLensPerceptionCapabilities
        include Google::Apis::Core::Hashable
      
        # Whether the device supports Lens Perception.
        # Corresponds to the JSON property `hasLensPerception`
        # @return [Boolean]
        attr_accessor :has_lens_perception
        alias_method :has_lens_perception?, :has_lens_perception
      
        # Indicates whether Lens supports Lens Direct Intent (go/lensdirectintent).
        # Corresponds to the JSON property `isLensDirectIntentAvailable`
        # @return [Boolean]
        attr_accessor :is_lens_direct_intent_available
        alias_method :is_lens_direct_intent_available?, :is_lens_direct_intent_available
      
        # Indicates whether Lens supports Live view-finder experience.
        # Corresponds to the JSON property `isLensLiveViewfinderAvailable`
        # @return [Boolean]
        attr_accessor :is_lens_live_viewfinder_available
        alias_method :is_lens_live_viewfinder_available?, :is_lens_live_viewfinder_available
      
        # Indicates whether Lens supports Post-capture experience with an image payload.
        # Corresponds to the JSON property `isLensPostCaptureAvailable`
        # @return [Boolean]
        attr_accessor :is_lens_post_capture_available
        alias_method :is_lens_post_capture_available?, :is_lens_post_capture_available
      
        # The set of capabilities that Lens can support. This is the Assistant proto
        # representation of Lens capabilities defined at j/c/g/android/apps/gsa/search/
        # shared/service/proto/lens_service_event.proto Next ID: 7
        # Corresponds to the JSON property `lensCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilities]
        attr_accessor :lens_capabilities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_lens_perception = args[:has_lens_perception] if args.key?(:has_lens_perception)
          @is_lens_direct_intent_available = args[:is_lens_direct_intent_available] if args.key?(:is_lens_direct_intent_available)
          @is_lens_live_viewfinder_available = args[:is_lens_live_viewfinder_available] if args.key?(:is_lens_live_viewfinder_available)
          @is_lens_post_capture_available = args[:is_lens_post_capture_available] if args.key?(:is_lens_post_capture_available)
          @lens_capabilities = args[:lens_capabilities] if args.key?(:lens_capabilities)
        end
      end
      
      # The set of capabilities that Lens can support. This is the Assistant proto
      # representation of Lens capabilities defined at j/c/g/android/apps/gsa/search/
      # shared/service/proto/lens_service_event.proto Next ID: 7
      class AssistantApiLensPerceptionCapabilitiesLensCapabilities
        include Google::Apis::Core::Hashable
      
        # Dining recognition capability. For example popular dishes on a given
        # restaurant menu image.
        # Corresponds to the JSON property `dining`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesDining]
        attr_accessor :dining
      
        # Education recognition capability.
        # Corresponds to the JSON property `education`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesEducation]
        attr_accessor :education
      
        # Outdoor place recognition capability. For example recognizing storefronts.
        # Corresponds to the JSON property `outdoor`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesOutdoor]
        attr_accessor :outdoor
      
        # Shopping recognition capability.
        # Corresponds to the JSON property `shopping`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesShopping]
        attr_accessor :shopping
      
        # Text recognition capability.
        # Corresponds to the JSON property `text`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesText]
        attr_accessor :text
      
        # Translation capability.
        # Corresponds to the JSON property `translate`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLensPerceptionCapabilitiesLensCapabilitiesTranslate]
        attr_accessor :translate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dining = args[:dining] if args.key?(:dining)
          @education = args[:education] if args.key?(:education)
          @outdoor = args[:outdoor] if args.key?(:outdoor)
          @shopping = args[:shopping] if args.key?(:shopping)
          @text = args[:text] if args.key?(:text)
          @translate = args[:translate] if args.key?(:translate)
        end
      end
      
      # Dining recognition capability. For example popular dishes on a given
      # restaurant menu image.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesDining
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Education recognition capability.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesEducation
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Outdoor place recognition capability. For example recognizing storefronts.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesOutdoor
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Shopping recognition capability.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesShopping
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Text recognition capability.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesText
        include Google::Apis::Core::Hashable
      
        # Indicates whether text-to-speech is supported.
        # Corresponds to the JSON property `isTextToSpeechSupported`
        # @return [Boolean]
        attr_accessor :is_text_to_speech_supported
        alias_method :is_text_to_speech_supported?, :is_text_to_speech_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_text_to_speech_supported = args[:is_text_to_speech_supported] if args.key?(:is_text_to_speech_supported)
        end
      end
      
      # Translation capability.
      class AssistantApiLensPerceptionCapabilitiesLensCapabilitiesTranslate
        include Google::Apis::Core::Hashable
      
        # The list of language IETF BCP 47 tags that are supported. See the full list at
        # go/androidlanguages.
        # Corresponds to the JSON property `supportedLanguageTags`
        # @return [Array<String>]
        attr_accessor :supported_language_tags
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supported_language_tags = args[:supported_language_tags] if args.key?(:supported_language_tags)
        end
      end
      
      # 
      class AssistantApiLiveTvChannelCapabilities
        include Google::Apis::Core::Hashable
      
        # A list of channel providers each of which provides a list of its channels.
        # Corresponds to the JSON property `channelsByProvider`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiLiveTvChannelCapabilitiesChannelsByProvider>]
        attr_accessor :channels_by_provider
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channels_by_provider = args[:channels_by_provider] if args.key?(:channels_by_provider)
        end
      end
      
      # 
      class AssistantApiLiveTvChannelCapabilitiesChannelsByProvider
        include Google::Apis::Core::Hashable
      
        # A list of channels provided by this input. Keep the performance impact in mind
        # when the number/size of the channels is large. When there are too many
        # channels, consider stripping out some data.
        # Corresponds to the JSON property `channels`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiLiveTvChannelCapabilitiesLiveTvChannel>]
        attr_accessor :channels
      
        # An identifier to identify the input source. For example for TIF based channels,
        # this will be the TIF input ID to differentiate different tuner apps. See
        # https://source.android.com/devices/tv
        # Corresponds to the JSON property `inputId`
        # @return [String]
        attr_accessor :input_id
      
        # Type of provider who provides this channel input.
        # Corresponds to the JSON property `providerType`
        # @return [String]
        attr_accessor :provider_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channels = args[:channels] if args.key?(:channels)
          @input_id = args[:input_id] if args.key?(:input_id)
          @provider_type = args[:provider_type] if args.key?(:provider_type)
        end
      end
      
      # 
      class AssistantApiLiveTvChannelCapabilitiesLiveTvChannel
        include Google::Apis::Core::Hashable
      
        # Unique channel identifier.
        # Corresponds to the JSON property `channelId`
        # @return [String]
        attr_accessor :channel_id
      
        # A list of channel names and synonyms.
        # Corresponds to the JSON property `channelName`
        # @return [Array<String>]
        attr_accessor :channel_name
      
        # Channel number displayed to user. Optional.
        # Corresponds to the JSON property `channelNumber`
        # @return [String]
        attr_accessor :channel_number
      
        # A deep link into the Live player app that tunes to this channel.
        # Corresponds to the JSON property `deeplink`
        # @return [String]
        attr_accessor :deeplink
      
        # KG mid of the channel if it exists in KG.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Network KG mid of the channel if it exists in KG
        # Corresponds to the JSON property `networkMid`
        # @return [String]
        attr_accessor :network_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel_id = args[:channel_id] if args.key?(:channel_id)
          @channel_name = args[:channel_name] if args.key?(:channel_name)
          @channel_number = args[:channel_number] if args.key?(:channel_number)
          @deeplink = args[:deeplink] if args.key?(:deeplink)
          @mid = args[:mid] if args.key?(:mid)
          @network_mid = args[:network_mid] if args.key?(:network_mid)
        end
      end
      
      # 
      class AssistantApiLiveTvProvider
        include Google::Apis::Core::Hashable
      
        # Provider. Like, Spotify or iHeartRadio. Next ID: 13
        # Corresponds to the JSON property `providerInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProvider]
        attr_accessor :provider_info
      
        # An provider enum string for OTT providers. The available key can be found in
        # go/ump-provider-enum For Tuner provider, the provider key would be an ID the
        # tuner app uploaded from TIF. See https://source.android.com/devices/tv
        # Corresponds to the JSON property `providerKey`
        # @return [String]
        attr_accessor :provider_key
      
        # 
        # Corresponds to the JSON property `providerType`
        # @return [String]
        attr_accessor :provider_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provider_info = args[:provider_info] if args.key?(:provider_info)
          @provider_key = args[:provider_key] if args.key?(:provider_key)
          @provider_type = args[:provider_type] if args.key?(:provider_type)
        end
      end
      
      # 
      class AssistantApiLocationCapabilities
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `gpsAvailable`
        # @return [Boolean]
        attr_accessor :gps_available
        alias_method :gps_available?, :gps_available
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gps_available = args[:gps_available] if args.key?(:gps_available)
        end
      end
      
      # Data which is produced for logging and debugging. Servers MUST NOT use this
      # for any other purposes, such as branching on it.
      class AssistantApiLoggingOnlyData
        include Google::Apis::Core::Hashable
      
        # A user-readable string describing the ACP version (go/acp-version) of the
        # client app used by the user to originate the conversation.
        # Corresponds to the JSON property `acpVersion`
        # @return [String]
        attr_accessor :acp_version
      
        # A user-readable string describing the version of the client app used by the
        # user to originate the conversation.
        # Corresponds to the JSON property `appVersion`
        # @return [String]
        attr_accessor :app_version
      
        # An enum specifying when was this ATV AssistantSettings entry initially created.
        # Corresponds to the JSON property `assistantSettingsSource`
        # @return [String]
        attr_accessor :assistant_settings_source
      
        # The type of board used by manufacturer for this device
        # Corresponds to the JSON property `boardName`
        # @return [String]
        attr_accessor :board_name
      
        # The revision of board used
        # Corresponds to the JSON property `boardRevision`
        # @return [String]
        attr_accessor :board_revision
      
        # This field records the linking status between Assistant setting entry and Cast
        # setting entry. Currently only ATV surface populates this field for profiling
        # purpose.
        # Corresponds to the JSON property `castAssistantSettingLinkingResult`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCastAssistantSettingLinkingResult]
        attr_accessor :cast_assistant_setting_linking_result
      
        # A user-readable string describing the device's hardware platform.
        # Corresponds to the JSON property `deviceModel`
        # @return [String]
        attr_accessor :device_model
      
        # Any relevant info concerning the build options of the embedder (that is the
        # software which runs as the 'driver' of an Assistant library, such as
        # libassistant. the embedder is typically built by a third party)
        # Corresponds to the JSON property `embedderBuildInfo`
        # @return [String]
        attr_accessor :embedder_build_info
      
        # A string recording the app version that is initially used to created this
        # settings entry.
        # Corresponds to the JSON property `initialAppVersion`
        # @return [String]
        attr_accessor :initial_app_version
      
        # default display name of device over mdns. This is specified at the factory,
        # not specified by the user.
        # Corresponds to the JSON property `mdnsDisplayName`
        # @return [String]
        attr_accessor :mdns_display_name
      
        # A user-readable string describing the device's software platform.
        # Corresponds to the JSON property `platformBuild`
        # @return [String]
        attr_accessor :platform_build
      
        # A string describing device's release channel. For cast devices, the string
        # will look like "qa-beta-channel", "eng-no-update", etc.
        # Corresponds to the JSON property `virtualReleaseChannel`
        # @return [String]
        attr_accessor :virtual_release_channel
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acp_version = args[:acp_version] if args.key?(:acp_version)
          @app_version = args[:app_version] if args.key?(:app_version)
          @assistant_settings_source = args[:assistant_settings_source] if args.key?(:assistant_settings_source)
          @board_name = args[:board_name] if args.key?(:board_name)
          @board_revision = args[:board_revision] if args.key?(:board_revision)
          @cast_assistant_setting_linking_result = args[:cast_assistant_setting_linking_result] if args.key?(:cast_assistant_setting_linking_result)
          @device_model = args[:device_model] if args.key?(:device_model)
          @embedder_build_info = args[:embedder_build_info] if args.key?(:embedder_build_info)
          @initial_app_version = args[:initial_app_version] if args.key?(:initial_app_version)
          @mdns_display_name = args[:mdns_display_name] if args.key?(:mdns_display_name)
          @platform_build = args[:platform_build] if args.key?(:platform_build)
          @virtual_release_channel = args[:virtual_release_channel] if args.key?(:virtual_release_channel)
        end
      end
      
      # 
      class AssistantApiMediaControlSupport
        include Google::Apis::Core::Hashable
      
        # Whether to prevent confirmations (text, tts) for media control actions while
        # media is playing so that the media session is not interrupted.
        # Corresponds to the JSON property `skipConfirmationsWhilePlaying`
        # @return [Boolean]
        attr_accessor :skip_confirmations_while_playing
        alias_method :skip_confirmations_while_playing?, :skip_confirmations_while_playing
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @skip_confirmations_while_playing = args[:skip_confirmations_while_playing] if args.key?(:skip_confirmations_while_playing)
        end
      end
      
      # 
      class AssistantApiMessageCapabilities
        include Google::Apis::Core::Hashable
      
        # If true, APP_ID queries initiated by this device should fall back to execution
        # on the tethered device if it's available and if the primary device cannot
        # perform the action (e.g. due to the app not being installed).
        # Corresponds to the JSON property `fallbackToTetheredDeviceAppCapabilities`
        # @return [Boolean]
        attr_accessor :fallback_to_tethered_device_app_capabilities
        alias_method :fallback_to_tethered_device_app_capabilities?, :fallback_to_tethered_device_app_capabilities
      
        # Should only be checked if nonempty.
        # Corresponds to the JSON property `supportedRecipientTypes`
        # @return [Array<String>]
        attr_accessor :supported_recipient_types
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fallback_to_tethered_device_app_capabilities = args[:fallback_to_tethered_device_app_capabilities] if args.key?(:fallback_to_tethered_device_app_capabilities)
          @supported_recipient_types = args[:supported_recipient_types] if args.key?(:supported_recipient_types)
        end
      end
      
      # 
      class AssistantApiMovementCapabilities
        include Google::Apis::Core::Hashable
      
        # Indicates how much the device moves around. E.g., TV has a low mobility level,
        # while Auto has a very high level.
        # Corresponds to the JSON property `mobility`
        # @return [String]
        attr_accessor :mobility
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mobility = args[:mobility] if args.key?(:mobility)
        end
      end
      
      # 
      class AssistantApiNotificationOutputRestrictions
        include Google::Apis::Core::Hashable
      
        # Per category/category group notification opt out settings.
        # Corresponds to the JSON property `optOutState`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiNotificationOutputRestrictionsOptOutState]
        attr_accessor :opt_out_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @opt_out_state = args[:opt_out_state] if args.key?(:opt_out_state)
        end
      end
      
      # Per category/category group notification opt out settings.
      class AssistantApiNotificationOutputRestrictionsOptOutState
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `categoryGroupState`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiNotificationOutputRestrictionsOptOutStateCategoryGroupState>]
        attr_accessor :category_group_state
      
        # 
        # Corresponds to the JSON property `categoryState`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiNotificationOutputRestrictionsOptOutStateCategoryState>]
        attr_accessor :category_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_group_state = args[:category_group_state] if args.key?(:category_group_state)
          @category_state = args[:category_state] if args.key?(:category_state)
        end
      end
      
      # 
      class AssistantApiNotificationOutputRestrictionsOptOutStateCategoryGroupState
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `categoryGroup`
        # @return [String]
        attr_accessor :category_group
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_group = args[:category_group] if args.key?(:category_group)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # 
      class AssistantApiNotificationOutputRestrictionsOptOutStateCategoryState
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Encapsulates the action capabilities of the OEM device. This data is merged
      # from Device Model lookup, per-device registration, and per-request context.
      # This data is sent to NLU layer for query understanding.
      class AssistantApiOemCapabilities
        include Google::Apis::Core::Hashable
      
        # States the cloud capabilities of the device, i.e. the endpoint(s) to use for
        # cloud execution of Actions or Registration.
        # Corresponds to the JSON property `cloudCapability`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoCloudCapability]
        attr_accessor :cloud_capability
      
        # If fulfillment is done via 3P cloud and 3P supports device capabilities, this
        # field will be set.
        # Corresponds to the JSON property `cloudDeviceCapabilities`
        # @return [Hash<String,Object>]
        attr_accessor :cloud_device_capabilities
      
        # Device Model Id from DeviceModelPackage.
        # Corresponds to the JSON property `deviceModelId`
        # @return [String]
        attr_accessor :device_model_id
      
        # Device Model Revision Id from DeviceModelPackage.
        # Corresponds to the JSON property `deviceModelRevisionId`
        # @return [Fixnum]
        attr_accessor :device_model_revision_id
      
        # Opaque supported action data related to a specific domain of devices, for
        # example for car. go/car-talk-registration-model
        # Corresponds to the JSON property `deviceSpecificData`
        # @return [String]
        attr_accessor :device_specific_data
      
        # Capabilities that may only be set internally. Only internal callers (i.e.
        # Googlers or Google owned projects) will be able to set these, thanks to go/
        # assistant-device-model-package-ownership.
        # Corresponds to the JSON property `internalCapability`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoInternalCapability]
        attr_accessor :internal_capability
      
        # 3P Action Metadata. Next ID: 3
        # Corresponds to the JSON property `thirdPartyActionConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiThirdPartyActionConfig]
        attr_accessor :third_party_action_config
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_capability = args[:cloud_capability] if args.key?(:cloud_capability)
          @cloud_device_capabilities = args[:cloud_device_capabilities] if args.key?(:cloud_device_capabilities)
          @device_model_id = args[:device_model_id] if args.key?(:device_model_id)
          @device_model_revision_id = args[:device_model_revision_id] if args.key?(:device_model_revision_id)
          @device_specific_data = args[:device_specific_data] if args.key?(:device_specific_data)
          @internal_capability = args[:internal_capability] if args.key?(:internal_capability)
          @third_party_action_config = args[:third_party_action_config] if args.key?(:third_party_action_config)
        end
      end
      
      # Definitions of on-device assistant capabilities.
      class AssistantApiOnDeviceAssistantCapabilities
        include Google::Apis::Core::Hashable
      
        # Capabilities related to local network arbitration (go/local-network-
        # arbitration). Indicates if the device is capable of being a host device in the
        # LAN whiling doing local network arbitration.
        # Corresponds to the JSON property `isLocalNetworkArbitrationSupported`
        # @return [Boolean]
        attr_accessor :is_local_network_arbitration_supported
        alias_method :is_local_network_arbitration_supported?, :is_local_network_arbitration_supported
      
        # Capabilities related to on-device arbitration(go/arbitration-on-device).
        # Corresponds to the JSON property `isOnDeviceArbitrationSupported`
        # @return [Boolean]
        attr_accessor :is_on_device_arbitration_supported
        alias_method :is_on_device_arbitration_supported?, :is_on_device_arbitration_supported
      
        # Indicates if on-device assistant is enabled on this device. Example usecases:
        # NGA (go/nga) or Marble (go/marble).
        # Corresponds to the JSON property `isOnDeviceAssistantSupported`
        # @return [Boolean]
        attr_accessor :is_on_device_assistant_supported
        alias_method :is_on_device_assistant_supported?, :is_on_device_assistant_supported
      
        # This may be used by NGA. E.g. if understanding happens on device, we can have
        # more aggressive logic when fulfilling some features on the server side, like
        # teleport.
        # Corresponds to the JSON property `isOnDeviceUnderstandingSupported`
        # @return [Boolean]
        attr_accessor :is_on_device_understanding_supported
        alias_method :is_on_device_understanding_supported?, :is_on_device_understanding_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_local_network_arbitration_supported = args[:is_local_network_arbitration_supported] if args.key?(:is_local_network_arbitration_supported)
          @is_on_device_arbitration_supported = args[:is_on_device_arbitration_supported] if args.key?(:is_on_device_arbitration_supported)
          @is_on_device_assistant_supported = args[:is_on_device_assistant_supported] if args.key?(:is_on_device_assistant_supported)
          @is_on_device_understanding_supported = args[:is_on_device_understanding_supported] if args.key?(:is_on_device_understanding_supported)
        end
      end
      
      # Definitions of on-device Smart Home capabilities. Next ID: 2
      class AssistantApiOnDeviceSmartHomeCapabilities
        include Google::Apis::Core::Hashable
      
        # Master bit for on-device Smart Home features.
        # Corresponds to the JSON property `isOnDeviceSmartHomeSupported`
        # @return [Boolean]
        attr_accessor :is_on_device_smart_home_supported
        alias_method :is_on_device_smart_home_supported?, :is_on_device_smart_home_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_on_device_smart_home_supported = args[:is_on_device_smart_home_supported] if args.key?(:is_on_device_smart_home_supported)
        end
      end
      
      # The on-device storage capabilities found on the device.
      class AssistantApiOnDeviceStorageCapabilities
        include Google::Apis::Core::Hashable
      
        # Determines if an on-device storage is supported.
        # Corresponds to the JSON property `isSupported`
        # @return [Boolean]
        attr_accessor :is_supported
        alias_method :is_supported?, :is_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_supported = args[:is_supported] if args.key?(:is_supported)
        end
      end
      
      # These are user configurable permissions representing what the device is
      # allowed to output. Next ID: 11
      class AssistantApiOutputRestrictions
        include Google::Apis::Core::Hashable
      
        # Access settings for providers.
        # Corresponds to the JSON property `accessControlOutput`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAccessControlOutput]
        attr_accessor :access_control_output
      
        # The type of Google Photo content which the device can output.
        # Corresponds to the JSON property `googlePhotoContent`
        # @return [String]
        attr_accessor :google_photo_content
      
        # DEPRECATED: Use AccessControlOutput instead. Access settings for guests.
        # Corresponds to the JSON property `guestAccessOutput`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiGuestAccessOutput]
        attr_accessor :guest_access_output
      
        # The level of personal data which the device can output. See go/personal-
        # readout for detail.
        # Corresponds to the JSON property `personalData`
        # @return [String]
        attr_accessor :personal_data
      
        # This controls if the server can proactively send notification to users, and it
        # does not affect scenarios that users ask for information. The notification may
        # include TTS and lights. It could be only lights for chirp.
        # Corresponds to the JSON property `proactiveNotificationOutput`
        # @return [String]
        attr_accessor :proactive_notification_output
      
        # Next ID: 7
        # Corresponds to the JSON property `proactiveOutput`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiProactiveOutput]
        attr_accessor :proactive_output
      
        # Whether YouTube autoplay is allowed for queries from the user to this device.
        # See go/assistant-youtube-settings for details.
        # Corresponds to the JSON property `youtubeAutoplayRestriction`
        # @return [String]
        attr_accessor :youtube_autoplay_restriction
      
        # The type of YouTube content which the device can output.
        # Corresponds to the JSON property `youtubeContent`
        # @return [String]
        attr_accessor :youtube_content
      
        # The type of YouTube TV content which the device can output.
        # Corresponds to the JSON property `youtubeTvContent`
        # @return [String]
        attr_accessor :youtube_tv_content
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_control_output = args[:access_control_output] if args.key?(:access_control_output)
          @google_photo_content = args[:google_photo_content] if args.key?(:google_photo_content)
          @guest_access_output = args[:guest_access_output] if args.key?(:guest_access_output)
          @personal_data = args[:personal_data] if args.key?(:personal_data)
          @proactive_notification_output = args[:proactive_notification_output] if args.key?(:proactive_notification_output)
          @proactive_output = args[:proactive_output] if args.key?(:proactive_output)
          @youtube_autoplay_restriction = args[:youtube_autoplay_restriction] if args.key?(:youtube_autoplay_restriction)
          @youtube_content = args[:youtube_content] if args.key?(:youtube_content)
          @youtube_tv_content = args[:youtube_tv_content] if args.key?(:youtube_tv_content)
        end
      end
      
      # Next ID: 7
      class AssistantApiProactiveOutput
        include Google::Apis::Core::Hashable
      
        # Allows displaying all personal data on proactive surfaces with no face match
        # capability.
        # Corresponds to the JSON property `allowAllPersonalData`
        # @return [Boolean]
        attr_accessor :allow_all_personal_data
        alias_method :allow_all_personal_data?, :allow_all_personal_data
      
        # For ANDROID_TV devices, the location that this setting was last changed from.
        # Note: this structure allows to extend to more per-vertical bits in the future.
        # Corresponds to the JSON property `androidTvAssistantSettingsSource`
        # @return [String]
        attr_accessor :android_tv_assistant_settings_source
      
        # Allows displaying Health and Fitness content on proactive surfaces. This is a
        # sub bit of the device-wide PR bit - the device-wide PR bit must be enabled AND
        # this vertical sub bit must be enabled for H&F content to be shown. This bit
        # will be available on all surfaces that have the proactive-bit enabled. If the
        # proactive-bit is not enabled, then we do not show health and fitness content
        # at all (or even allow access to this setting).
        # Corresponds to the JSON property `healthAndFitnessProactive`
        # @return [String]
        attr_accessor :health_and_fitness_proactive
      
        # Allows displaying photos content on Dragonglass proactive surfaces. This is a
        # sub bit of the device-wide PR bit - the device-wide PR bit must be enabled AND
        # this vertical sub bit must be enabled for photos content to be shown on
        # Dragonglass surfaces. This bit will be available on all Dragonglass surfaces
        # that have the proactive-bit enabled. If the proactive-bit is not enabled or it'
        # s not a Dragonglass surface, then we do not show proactive photos content at
        # all, nor allow access to this setting. See go/opa-photos-sg-settings for more
        # details.
        # Corresponds to the JSON property `photosProactive`
        # @return [String]
        attr_accessor :photos_proactive
      
        # Whether a device supports proactive output. Note that this is assumed to be
        # true for all Smart Display devices, but surfaces that newly start supporting
        # proactive_output should set this bit.
        # Corresponds to the JSON property `supportsProactiveOutput`
        # @return [Boolean]
        attr_accessor :supports_proactive_output
        alias_method :supports_proactive_output?, :supports_proactive_output
      
        # Settings for displaying personal data on proactive surfaces with face match
        # capability.
        # Corresponds to the JSON property `userMatchProactive`
        # @return [String]
        attr_accessor :user_match_proactive
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_all_personal_data = args[:allow_all_personal_data] if args.key?(:allow_all_personal_data)
          @android_tv_assistant_settings_source = args[:android_tv_assistant_settings_source] if args.key?(:android_tv_assistant_settings_source)
          @health_and_fitness_proactive = args[:health_and_fitness_proactive] if args.key?(:health_and_fitness_proactive)
          @photos_proactive = args[:photos_proactive] if args.key?(:photos_proactive)
          @supports_proactive_output = args[:supports_proactive_output] if args.key?(:supports_proactive_output)
          @user_match_proactive = args[:user_match_proactive] if args.key?(:user_match_proactive)
        end
      end
      
      # Also known as "Extensions Without Extensions" or "The Poor Man's Any", this
      # simple proto is used to transmit arbitrary protocol buffers over the wire.
      # Unlike extensions: - It does not require the proto type to be compiled into
      # the binary. (Useful so that the proto declaration can be inside the
      # conversation package) - It is compatible with all versions of proto, including
      # proto3 and the wack-tastic version used on ChromecastOS. Server libraries for
      # dealing with it live in google3/assistant/protocol/protobuf_lib.h.
      class AssistantApiProtobuf
        include Google::Apis::Core::Hashable
      
        # The serialized protocol buffer.
        # Corresponds to the JSON property `protobufData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :protobuf_data
      
        # The type of the protocol buffer to use. This must be a resolvable name (
        # Namespace.ProtoName) and refer to a proto which is either compiled in to both
        # client and server (e.g. a base proto type) or to one which is part of the
        # conversation package.
        # Corresponds to the JSON property `protobufType`
        # @return [String]
        attr_accessor :protobuf_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @protobuf_data = args[:protobuf_data] if args.key?(:protobuf_data)
          @protobuf_type = args[:protobuf_type] if args.key?(:protobuf_type)
        end
      end
      
      # Date-based recurrences specify repeating events. Conceptually, a recurrence is
      # a (possibly unbounded) sequence of dates on which an event falls, described by
      # a list of constraints. A date is in a recurrence if and only if it satisfies
      # all of the constraints. Note that devices may support some constraints, but
      # not all. IMPORTANT: The definition of Recurrence proto is being moved to //
      # assistant/api/core_types/governed/datetime_type.proto. All existing references
      # will be updated to point to the new location. If you are adding a reference,
      # use the new one instead.
      class AssistantApiRecurrence
        include Google::Apis::Core::Hashable
      
        # A Gregorian calendar date. IMPORTANT: The definition of Date proto is being
        # moved to //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `begin`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDate]
        attr_accessor :begin
      
        # A list of blacklisted dates to skip the alarm on.
        # Corresponds to the JSON property `blacklistedRanges`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiRecurrenceDatetimeRange>]
        attr_accessor :blacklisted_ranges
      
        # Specifies the date in a month. For example, if day_of_month is 15, then it
        # represent the 15th day of the specified month.
        # Corresponds to the JSON property `dayOfMonth`
        # @return [Array<Fixnum>]
        attr_accessor :day_of_month
      
        # Specifies a weekly or daily recurrence. Constraint: The date falls on one of
        # these days of the week, in 0...6 (Sunday...Saturday).
        # Corresponds to the JSON property `dayOfWeek`
        # @return [Array<Fixnum>]
        attr_accessor :day_of_week
      
        # A Gregorian calendar date. IMPORTANT: The definition of Date proto is being
        # moved to //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `end`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDate]
        attr_accessor :end
      
        # Multiplier on the frequency of the recurrence. Use this to specify patterns
        # that recur every X days, months, years, etc. Example: [remind me to call mom
        # every 2nd week]. Default is 1 (every day, every month, every year).
        # Corresponds to the JSON property `every`
        # @return [Fixnum]
        attr_accessor :every
      
        # Specifies the month in a year. Constrain: the month falls on one of these
        # months, in 1, 2, ... 12 (January...December).
        # Corresponds to the JSON property `monthOfYear`
        # @return [Array<Fixnum>]
        attr_accessor :month_of_year
      
        # The number of occurrences after which the recurrence should end.
        # Corresponds to the JSON property `numOccurrences`
        # @return [Fixnum]
        attr_accessor :num_occurrences
      
        # Specifies the index of week in a month. For example, the second Tuesday every
        # month, in this case, week_of_month should be 2.
        # Corresponds to the JSON property `weekOfMonth`
        # @return [Array<Fixnum>]
        attr_accessor :week_of_month
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @blacklisted_ranges = args[:blacklisted_ranges] if args.key?(:blacklisted_ranges)
          @day_of_month = args[:day_of_month] if args.key?(:day_of_month)
          @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
          @end = args[:end] if args.key?(:end)
          @every = args[:every] if args.key?(:every)
          @month_of_year = args[:month_of_year] if args.key?(:month_of_year)
          @num_occurrences = args[:num_occurrences] if args.key?(:num_occurrences)
          @week_of_month = args[:week_of_month] if args.key?(:week_of_month)
        end
      end
      
      # A representation of a range of time with start and end datetime specified.
      class AssistantApiRecurrenceDatetimeRange
        include Google::Apis::Core::Hashable
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `endDate`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :end_date
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `startDate`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :start_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_date = args[:end_date] if args.key?(:end_date)
          @start_date = args[:start_date] if args.key?(:start_date)
        end
      end
      
      # These capabilities represent the tactile features associated with the device.
      # This includes, for example, whether the device has a screen, how big the
      # screen is, and privacy of the screen. Next ID: 10
      class AssistantApiScreenCapabilities
        include Google::Apis::Core::Hashable
      
        # The types of input that this screen supports. Note that this can be empty in
        # which case the screen's input type is unknown.
        # Corresponds to the JSON property `inputType`
        # @return [Array<String>]
        attr_accessor :input_type
      
        # A mask applied to the screen's pixel space to determine regions not visible on
        # the physical device.
        # Corresponds to the JSON property `mask`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiScreenCapabilitiesMask]
        attr_accessor :mask
      
        # Version info for ProtoLayout requests.
        # Corresponds to the JSON property `protoLayoutTargetedSchema`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiScreenCapabilitiesProtoLayoutVersion]
        attr_accessor :proto_layout_targeted_schema
      
        # A Resolution proto indicates the size of the application window. All fields
        # are required.
        # Corresponds to the JSON property `resolution`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiScreenCapabilitiesResolution]
        attr_accessor :resolution
      
        # If screen is turned off.
        # Corresponds to the JSON property `screenOff`
        # @return [Boolean]
        attr_accessor :screen_off
        alias_method :screen_off?, :screen_off
      
        # The ability of the client to correctly report screen state.
        # Corresponds to the JSON property `screenStateDetection`
        # @return [String]
        attr_accessor :screen_state_detection
      
        # The primary supported rendering format for display on the device's screen.
        # This may be used to determine what format of card to be returned when
        # rendering cards.
        # Corresponds to the JSON property `supportedRenderingFormat`
        # @return [String]
        attr_accessor :supported_rendering_format
      
        # The screen states that the client supports. The current screen state is
        # specified in DeviceProperties.screen.
        # Corresponds to the JSON property `supportedScreenStates`
        # @return [Array<String>]
        attr_accessor :supported_screen_states
      
        # Whether the device enabled vision help features in accessiblity settings. The
        # settings is config in Assistant App and on-device settings, and stored in
        # footprints. When enabled, font, color and TTS will be adjusted.
        # Corresponds to the JSON property `visionHelpEnabled`
        # @return [Boolean]
        attr_accessor :vision_help_enabled
        alias_method :vision_help_enabled?, :vision_help_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @input_type = args[:input_type] if args.key?(:input_type)
          @mask = args[:mask] if args.key?(:mask)
          @proto_layout_targeted_schema = args[:proto_layout_targeted_schema] if args.key?(:proto_layout_targeted_schema)
          @resolution = args[:resolution] if args.key?(:resolution)
          @screen_off = args[:screen_off] if args.key?(:screen_off)
          @screen_state_detection = args[:screen_state_detection] if args.key?(:screen_state_detection)
          @supported_rendering_format = args[:supported_rendering_format] if args.key?(:supported_rendering_format)
          @supported_screen_states = args[:supported_screen_states] if args.key?(:supported_screen_states)
          @vision_help_enabled = args[:vision_help_enabled] if args.key?(:vision_help_enabled)
        end
      end
      
      # A mask applied to the screen's pixel space to determine regions not visible on
      # the physical device.
      class AssistantApiScreenCapabilitiesMask
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Version info for ProtoLayout requests.
      class AssistantApiScreenCapabilitiesProtoLayoutVersion
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `major`
        # @return [Fixnum]
        attr_accessor :major
      
        # 
        # Corresponds to the JSON property `minor`
        # @return [Fixnum]
        attr_accessor :minor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @major = args[:major] if args.key?(:major)
          @minor = args[:minor] if args.key?(:minor)
        end
      end
      
      # A Resolution proto indicates the size of the application window. All fields
      # are required.
      class AssistantApiScreenCapabilitiesResolution
        include Google::Apis::Core::Hashable
      
        # Dots (pixels) per inch of the screen.
        # Corresponds to the JSON property `dpi`
        # @return [Fixnum]
        attr_accessor :dpi
      
        # 
        # Corresponds to the JSON property `heightPx`
        # @return [Fixnum]
        attr_accessor :height_px
      
        # m_size is the smallest square box size to display a capital letter M so that
        # the user can still easily understand it.
        # Corresponds to the JSON property `mSize`
        # @return [Fixnum]
        attr_accessor :m_size
      
        # neng_size is the smallest square box size to display a letter 螚 (Neng, U+879A)
        # so that the user can easily understand it. (Neng is a visually dense Chinese
        # letter, and so may require a larger box than an M.)
        # Corresponds to the JSON property `nengSize`
        # @return [Fixnum]
        attr_accessor :neng_size
      
        # The dimensions of the application window, in pixels.
        # Corresponds to the JSON property `widthPx`
        # @return [Fixnum]
        attr_accessor :width_px
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dpi = args[:dpi] if args.key?(:dpi)
          @height_px = args[:height_px] if args.key?(:height_px)
          @m_size = args[:m_size] if args.key?(:m_size)
          @neng_size = args[:neng_size] if args.key?(:neng_size)
          @width_px = args[:width_px] if args.key?(:width_px)
        end
      end
      
      # The Soli capabilities on Elaine, including gestures and sleep sensing. go/
      # dingo-dc-software Next ID: 4
      class AssistantApiSelinaCapabilites
        include Google::Apis::Core::Hashable
      
        # The gesture capabilities related to Selina. Next ID: 4
        # Corresponds to the JSON property `gestureCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiGestureCapabilities]
        attr_accessor :gesture_capabilities
      
        # Whether the client supports selina.
        # Corresponds to the JSON property `selinaSupported`
        # @return [Boolean]
        attr_accessor :selina_supported
        alias_method :selina_supported?, :selina_supported
      
        # Whether the client can monitor sleep. This allows us to show sleep CUJ related
        # information: go/TwilightDesign
        # Corresponds to the JSON property `sleepSensingSupported`
        # @return [Boolean]
        attr_accessor :sleep_sensing_supported
        alias_method :sleep_sensing_supported?, :sleep_sensing_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gesture_capabilities = args[:gesture_capabilities] if args.key?(:gesture_capabilities)
          @selina_supported = args[:selina_supported] if args.key?(:selina_supported)
          @sleep_sensing_supported = args[:sleep_sensing_supported] if args.key?(:sleep_sensing_supported)
        end
      end
      
      # 
      class AssistantApiSettingsAmbientSettings
        include Google::Apis::Core::Hashable
      
        # Whether any user sets personal photos on this device. See go/ambient-setting-
        # in-assistant-design.
        # Corresponds to the JSON property `anyUserHasSetPersonalPhotos`
        # @return [Boolean]
        attr_accessor :any_user_has_set_personal_photos
        alias_method :any_user_has_set_personal_photos?, :any_user_has_set_personal_photos
      
        # Whether or not the user's current selection for their ambient photo frame
        # includes the auto-generated "Recent Highlights" album. This is used to
        # determine which users to display the go/opa-photos-memories-tile. See go/opa-
        # photo-memories-imax-optin for more discussion on why this bit was created.
        # Corresponds to the JSON property `recentHighlightsEnabled`
        # @return [Boolean]
        attr_accessor :recent_highlights_enabled
        alias_method :recent_highlights_enabled?, :recent_highlights_enabled
      
        # Whether to enable the personal photo data in the ambient settings: https://
        # screenshot.googleplex.com/Wd4OFkQfOyF See go/opa-photos-ambient-location-date-
        # dd#heading=h.5x4iaouuiett for explanation.
        # Corresponds to the JSON property `showPersonalPhotoData`
        # @return [Boolean]
        attr_accessor :show_personal_photo_data
        alias_method :show_personal_photo_data?, :show_personal_photo_data
      
        # Whether current user sets personal photos on this device. See go/ambient-
        # setting-in-assistant-design.
        # Corresponds to the JSON property `showPersonalPhotos`
        # @return [Boolean]
        attr_accessor :show_personal_photos
        alias_method :show_personal_photos?, :show_personal_photos
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @any_user_has_set_personal_photos = args[:any_user_has_set_personal_photos] if args.key?(:any_user_has_set_personal_photos)
          @recent_highlights_enabled = args[:recent_highlights_enabled] if args.key?(:recent_highlights_enabled)
          @show_personal_photo_data = args[:show_personal_photo_data] if args.key?(:show_personal_photo_data)
          @show_personal_photos = args[:show_personal_photos] if args.key?(:show_personal_photos)
        end
      end
      
      # These capabilties are associated with Assistant Settings on devices.
      class AssistantApiSettingsAppCapabilities
        include Google::Apis::Core::Hashable
      
        # Capabilities that are associated with Assistant Settings on auto surfaces.
        # Corresponds to the JSON property `carSettingsCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCarSettingsCapabilities]
        attr_accessor :car_settings_capabilities
      
        # Whether the client supports reissuing query after setting up in Music Settings.
        # Corresponds to the JSON property `reissueQueryAfterMusicSetup`
        # @return [Boolean]
        attr_accessor :reissue_query_after_music_setup
        alias_method :reissue_query_after_music_setup?, :reissue_query_after_music_setup
      
        # Whether the client supports updating payments setting.
        # Corresponds to the JSON property `supportsPaymentsSettingsUpdate`
        # @return [Boolean]
        attr_accessor :supports_payments_settings_update
        alias_method :supports_payments_settings_update?, :supports_payments_settings_update
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @car_settings_capabilities = args[:car_settings_capabilities] if args.key?(:car_settings_capabilities)
          @reissue_query_after_music_setup = args[:reissue_query_after_music_setup] if args.key?(:reissue_query_after_music_setup)
          @supports_payments_settings_update = args[:supports_payments_settings_update] if args.key?(:supports_payments_settings_update)
        end
      end
      
      # Settings pertaining to auto framing. See go/auto-framing-presentation.
      class AssistantApiSettingsAutoFramingSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isAutoFramingEnabled`
        # @return [Boolean]
        attr_accessor :is_auto_framing_enabled
        alias_method :is_auto_framing_enabled?, :is_auto_framing_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_auto_framing_enabled = args[:is_auto_framing_enabled] if args.key?(:is_auto_framing_enabled)
        end
      end
      
      # Carrier related call settings on the device.
      class AssistantApiSettingsCarrierCallDeviceSettings
        include Google::Apis::Core::Hashable
      
        # Whether this device is allowed to receive incoming PSTN calls.
        # Corresponds to the JSON property `allowIncomingCalls`
        # @return [Boolean]
        attr_accessor :allow_incoming_calls
        alias_method :allow_incoming_calls?, :allow_incoming_calls
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_incoming_calls = args[:allow_incoming_calls] if args.key?(:allow_incoming_calls)
        end
      end
      
      # Specification of which communication features can be used.
      class AssistantApiSettingsCommunicationsFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Specification of times when most features on a device are disabled for certain
      # users. During these periods, the device will respond to most interactions with
      # something like "sorry, I'm sleeping right now". Design: go/home-ft-settings-
      # storage PRD: go/home-family-tools-prd
      class AssistantApiSettingsDeviceDowntimeSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `schedules`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSettingsLabeledDowntimeSchedule>]
        attr_accessor :schedules
      
        # The set of users of this device that will have these downtime settings applied.
        # Must have at least one element.
        # Corresponds to the JSON property `targets`
        # @return [Array<String>]
        attr_accessor :targets
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @schedules = args[:schedules] if args.key?(:schedules)
          @targets = args[:targets] if args.key?(:targets)
        end
      end
      
      # Defines a set of restrictions on particular device features for a certain set
      # of users. Design: go/home-ft-settings-storage PRD: go/home-family-tools-prd
      class AssistantApiSettingsDeviceFeatureFilters
        include Google::Apis::Core::Hashable
      
        # Enables/disables all the filters at the same time. For new devices or non-Cast
        # devices this is always false.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # Specification of which assistant features are allowed for a particular device
        # or user account.
        # Corresponds to the JSON property `featureFilters`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsFeatureFilters]
        attr_accessor :feature_filters
      
        # The set of users of this device that will have these settings applied. Must
        # have at least one element.
        # Corresponds to the JSON property `targets`
        # @return [Array<String>]
        attr_accessor :targets
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
          @feature_filters = args[:feature_filters] if args.key?(:feature_filters)
          @targets = args[:targets] if args.key?(:targets)
        end
      end
      
      # 
      class AssistantApiSettingsDeviceLogsOptIn
        include Google::Apis::Core::Hashable
      
        # Indicates whether the crash logs can be uploaded and the device logs can be
        # enabled
        # Corresponds to the JSON property `optInEnabled`
        # @return [Boolean]
        attr_accessor :opt_in_enabled
        alias_method :opt_in_enabled?, :opt_in_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @opt_in_enabled = args[:opt_in_enabled] if args.key?(:opt_in_enabled)
        end
      end
      
      # Next ID: 73
      class AssistantApiSettingsDeviceSettings
        include Google::Apis::Core::Hashable
      
        # LINT.ThenChange(//depot/google3/assistant/ui/assistant_device_settings_ui.
        # proto)
        # Corresponds to the JSON property `ackStatus`
        # @return [String]
        attr_accessor :ack_status
      
        # A human-readable address string for the location; generally a one-line address
        # such as "34 Masonic Ave, San Francisco CA 94117, United States". Set this
        # field to empty string for deletion, in which case the rest of the location
        # related fields below will be cleared as well.
        # Corresponds to the JSON property `address`
        # @return [String]
        attr_accessor :address
      
        # The alias names of the device, e.g. my living room tv, tv, living room and etc.
        # , which user will usually use to refer to the device in addition to
        # human_friendly_name. It can help speech biasing and query understanding. This
        # field is set by the user and already localized.
        # Corresponds to the JSON property `aliasName`
        # @return [Array<String>]
        attr_accessor :alias_name
      
        # Whether this device is allowed to receive incoming calls.
        # Corresponds to the JSON property `allowIncomingCalls`
        # @return [Boolean]
        attr_accessor :allow_incoming_calls
        alias_method :allow_incoming_calls?, :allow_incoming_calls
      
        # Ambient settings contains the configuration of Photo Frame on DG device. This
        # field relies on IMAX service to do the update, sync happenes after user
        # updates IMAX device settings or a device registers in CloudCastDevice. So it's
        # more like a cached version instead of definitive source-of-truth. More details
        # at go/ambient-setting-in-assistant-design.
        # Corresponds to the JSON property `ambientSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsAmbientSettings]
        attr_accessor :ambient_settings
      
        # Represents supporting device ids.
        # Corresponds to the JSON property `ancillaryDeviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsInternalAncillaryDeviceId]
        attr_accessor :ancillary_device_id
      
        # Settings pertaining to auto framing. See go/auto-framing-presentation.
        # Corresponds to the JSON property `autoFramingSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsAutoFramingSettings]
        attr_accessor :auto_framing_settings
      
        # Indicates whether the user has enabled Blue Steel. See go/blue-steel for more
        # info on this project.
        # Corresponds to the JSON property `blueSteelEnabled`
        # @return [Boolean]
        attr_accessor :blue_steel_enabled
        alias_method :blue_steel_enabled?, :blue_steel_enabled
      
        # This message describes roughly what a surface is capable of doing and metadata
        # around those capabilities. These capabilities are determined based on: -
        # device hardware - software - status (e.g. volume level, battery percentage)
        # These capabilities refer to the surface and not the physical device. The list
        # of supported surfaces can be found in the assistant.api.core_types.SurfaceType
        # enum. A surface's capabilities can differ from the device's. An example would
        # be ANDROID_ALLO running on Pixel. Allo does not support AudioInput while the
        # Pixel does. In this case, audio_input will be set to false for Assistant Allo
        # requests while it might be set to true for OPA_NEXUS requests. Next ID: 32
        # Corresponds to the JSON property `capabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDeviceCapabilities]
        attr_accessor :capabilities
      
        # city and postal_code are sent to third party AoG Apps as location when
        # permission is granted for precise or coarse location. https://developers.
        # google.com/actions/reference/rest/Shared.Types/Permission city and postal_code
        # have the same description as in Proto Postal Address: https://cs.corp.google.
        # com/piper///depot/google3/location/country/postaladdress.proto city
        # corresponds to locality_name, postal_code corresponds to postal_code_number.
        # These two fields are set in assistant_settings_service by AddressConverter.
        # https://cs.corp.google.com/piper///depot/google3/location/addressformatter/
        # public/addressconverter.h See go/aog-i18n-address-parse for more information
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # Status of colocation. go/co-location-work-v2 Note: this is a cache at the
        # Assistant level. The source of truth is inside CastAuthenticationServer, which
        # is only used for Home devices.
        # Corresponds to the JSON property `colocationStatus`
        # @return [String]
        attr_accessor :colocation_status
      
        # The timestamp that the device is linked with the user in milliseconds.
        # Corresponds to the JSON property `creationTimestampMs`
        # @return [Fixnum]
        attr_accessor :creation_timestamp_ms
      
        # Availability of this device for Assistant Cross-surface handoffs. (go/
        # assistant-cross-surface)
        # Corresponds to the JSON property `crossSurfaceAvailability`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceSettingsCrossSurfaceAvailability]
        attr_accessor :cross_surface_availability
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `defaultAudioDeviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :default_audio_device_id
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `defaultVideoDeviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :default_video_device_id
      
        # The brand of the device, populated from DeviceOemParams. Examples: "google", "
        # samsung".
        # Corresponds to the JSON property `deviceBrand`
        # @return [String]
        attr_accessor :device_brand
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # The model ID of the device. This should be globally unique across manufactures/
        # OEMs. Examples: "nest_cam_iq_2017", "comcast_voice_box_2017".
        # Corresponds to the JSON property `deviceModelId`
        # @return [String]
        attr_accessor :device_model_id
      
        # The Device Platform Service lookup revision. (go/device-model-revision) For 1p
        # devices, and most 3p devices with no custom feature, this should be always 0,
        # which means no lookup needed. For 3p devices with custom assistant feature,
        # this is provided directly by OEM as incremental (e.g. 1, 2, 3, ...)
        # Corresponds to the JSON property `deviceModelRevision`
        # @return [Fixnum]
        attr_accessor :device_model_revision
      
        # Only valid for ATV. Stores the android DUSI for the corresponding user. More
        # details: go/auto-logout-on-unlink.
        # Corresponds to the JSON property `dusi`
        # @return [String]
        attr_accessor :dusi
      
        # List of errors that happened during the face enrollment process if it failed.
        # See go/face-match-enrollment-error for more info.
        # Corresponds to the JSON property `faceEnrollmentErrors`
        # @return [Array<String>]
        attr_accessor :face_enrollment_errors
      
        # Indicates whether the user's face has been successfully enrolled on this
        # device. See go/face-match-server-design for more info.
        # Corresponds to the JSON property `faceEnrollmentStatus`
        # @return [String]
        attr_accessor :face_enrollment_status
      
        # Indicates whether the user has enabled Face Match for this device. See go/face-
        # match-server-design for more info on this project.
        # Corresponds to the JSON property `faceMatchEnabled`
        # @return [Boolean]
        attr_accessor :face_match_enabled
        alias_method :face_match_enabled?, :face_match_enabled
      
        # When true, allow data collection of audio on this device for Federated
        # Learning.
        # Corresponds to the JSON property `flAudioCacheEnabled`
        # @return [Boolean]
        attr_accessor :fl_audio_cache_enabled
        alias_method :fl_audio_cache_enabled?, :fl_audio_cache_enabled
      
        # When true, allow data collection of frames on this device.
        # Corresponds to the JSON property `flVisualFramesCacheEnabled`
        # @return [Boolean]
        attr_accessor :fl_visual_frames_cache_enabled
        alias_method :fl_visual_frames_cache_enabled?, :fl_visual_frames_cache_enabled
      
        # Stores GCM info associated with a device. See go/quartz-design-doc for more
        # info.
        # Corresponds to the JSON property `gcmSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsGcmSettings]
        attr_accessor :gcm_settings
      
        # Next ID: 8
        # Corresponds to the JSON property `homeGraphData`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsHomeGraphData]
        attr_accessor :home_graph_data
      
        # The home graph ID that can be used to lookup the corresponding entry in
        # HomeGraph. go/home-graph. Note: when this field is empty, it doesn't
        # necessarily mean that the device is not in home graph. It just means that
        # Assistant doesn't know about the mapping.
        # Corresponds to the JSON property `homeGraphId`
        # @return [String]
        attr_accessor :home_graph_id
      
        # Hospitality mode config for the current device. go/hospitality-mode-design.
        # Next ID: 17
        # Corresponds to the JSON property `hospitalityModeStatus`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsHospitalityMode]
        attr_accessor :hospitality_mode_status
      
        # The level of hotword sensitivity. go/hotword-sensitivity-prd
        # Corresponds to the JSON property `hotwordSensitivity`
        # @return [String]
        attr_accessor :hotword_sensitivity
      
        # HotwordThresholdAdjustmentFactor contains threshold_adjustment_factor, and it'
        # s validity. value should only be considered when is_valid = true.
        # Corresponds to the JSON property `hotwordThresholdAdjustmentFactor`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsHotwordThresholdAdjustmentFactor]
        attr_accessor :hotword_threshold_adjustment_factor
      
        # The human-friendly name of the cast device, e.g., my living room tv. This
        # field is set by the user and already localized.
        # Corresponds to the JSON property `humanFriendlyName`
        # @return [String]
        attr_accessor :human_friendly_name
      
        # Represents a version of a specifit setting, e.g. DeviceSettings.
        # Corresponds to the JSON property `internalVersion`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsInternalVersion]
        attr_accessor :internal_version
      
        # Indicates whether the device is also managed through HA cloud sync. go/ha-dev-
        # guide
        # Corresponds to the JSON property `isCloudSyncDevice`
        # @return [Boolean]
        attr_accessor :is_cloud_sync_device
        alias_method :is_cloud_sync_device?, :is_cloud_sync_device
      
        # When true, the user has explicitly allowed audio and visual data collection on
        # this device
        # Corresponds to the JSON property `isDeviceActivationCacheEnabled`
        # @return [Boolean]
        attr_accessor :is_device_activation_cache_enabled
        alias_method :is_device_activation_cache_enabled?, :is_device_activation_cache_enabled
      
        # Kids mode config for the current device. go/aff-parentalsupervision-dd
        # Corresponds to the JSON property `kidsMode`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsKidsMode]
        attr_accessor :kids_mode
      
        # Device's latest registration timestamp provided by Cast side. This field is
        # not necessarily up to date. The update frequency is defined in
        # last_registration_update_frequency_in_days field of AssistantConfig in java/
        # com/google/chrome/dongle/common/proto/home_assistant_config.proto. go/cast-
        # last-registration-time
        # Corresponds to the JSON property `lastCastRegistrationTimestamp`
        # @return [String]
        attr_accessor :last_cast_registration_timestamp
      
        # Coarsened hourly timestamp of when the device was last used.
        # Corresponds to the JSON property `lastUsedCoarseTimestamp`
        # @return [String]
        attr_accessor :last_used_coarse_timestamp
      
        # Stores pairing between different devices. See go/quartz-design-doc for more
        # info.
        # Corresponds to the JSON property `linkedDeviceId`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId>]
        attr_accessor :linked_device_id
      
        # Please do NOT use this field without prior approval from PWG. Users who have
        # signed in onto this device, go/linked-users-in-pkg.
        # Corresponds to the JSON property `linkedUsers`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSettingsLinkedUser>]
        attr_accessor :linked_users
      
        # The locale for the device: language + region, i.e., en-US, ja-JP.
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # Geographic coordinate information for location.
        # Corresponds to the JSON property `locationCoordinates`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesLocationCoordinates]
        attr_accessor :location_coordinates
      
        # Every entry in the GeoStore database is called a "feature". A feature is
        # represented as a discriminated union of all the different feature types, where
        # the actual feature type is specified by the "type" field. There are also
        # various fields that are meaningful for most or all feature types, such as
        # bounding regions and names. Every feature has a globally unique id that can be
        # used to refer to it from other features.
        # Corresponds to the JSON property `locationFeature`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureProto]
        attr_accessor :location_feature
      
        # See go/marketplace-disclosure for more info.
        # Corresponds to the JSON property `marketplaceDisclosure`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsMarketplaceDisclosure]
        attr_accessor :marketplace_disclosure
      
        # Guest mode for the current device. go/assistant-guest-mode-summary
        # Corresponds to the JSON property `masqueradeMode`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsMasqueradeMode]
        attr_accessor :masquerade_mode
      
        # Information about how to send the user a notification. This won't be populated
        # for fb-conv users (allo group chat users).
        # Corresponds to the JSON property `notificationProfile`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsNotificationProfile]
        attr_accessor :notification_profile
      
        # OAuth client id for the device. This field is available for Assistant SDK
        # devices. It is written when the device is registered to the user (
        # AssistantSettingsUiService.LinkAssistantDeviceUi). When user revokes grant on
        # the Assistant device, Assistant Devices Platform Service will receive Pubsub
        # notification with OAuth client id for the revoked device, and we will compare
        # that with this stored id to identity device to remove.
        # Corresponds to the JSON property `oauthClientId`
        # @return [String]
        attr_accessor :oauth_client_id
      
        # Device specific app related settings.
        # Corresponds to the JSON property `onDeviceAppSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsOnDeviceAppSettings]
        attr_accessor :on_device_app_settings
      
        # Specifies if device logs and crashes can be captured during SendFeedback
        # Corresponds to the JSON property `optInStatus`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceLogsOptIn]
        attr_accessor :opt_in_status
      
        # DEPRECATED: Use DeviceCapabilities.OutputRestrictions.personal_data instead.
        # Whether the user has enabled payments for this device.
        # Corresponds to the JSON property `paymentsEnabled`
        # @return [Boolean]
        attr_accessor :payments_enabled
        alias_method :payments_enabled?, :payments_enabled
      
        # Metadata about how personalization settings were configured.
        # Corresponds to the JSON property `personalizationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsPersonalizationMetadata]
        attr_accessor :personalization_metadata
      
        # Polite mode config for the current device. go/polite-mode-dd
        # Corresponds to the JSON property `politeMode`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsPoliteMode]
        attr_accessor :polite_mode
      
        # 
        # Corresponds to the JSON property `postalCode`
        # @return [String]
        attr_accessor :postal_code
      
        # Settings related to Assistant reauth. go/assistant-reauth-verify-skip Next id:
        # 2
        # Corresponds to the JSON property `reauthTrustedDeviceSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsReauthTrustedDeviceSettings]
        attr_accessor :reauth_trusted_device_settings
      
        # A human-readable shortened address. This is usually the street address. Note:
        # client does not need to populate this. It will be auto-populated based on "
        # address" field on server side. Developers can use this field to avoid reading
        # out the full address everytime.
        # Corresponds to the JSON property `shortenedAddress`
        # @return [String]
        attr_accessor :shortened_address
      
        # Indicates whether the user has enabled speaker-id for this device. See go/
        # google-assistant-multi-user for more info on this project.
        # Corresponds to the JSON property `speakerIdEnabled`
        # @return [Boolean]
        attr_accessor :speaker_id_enabled
        alias_method :speaker_id_enabled?, :speaker_id_enabled
      
        # Settings related to TTS output.
        # Corresponds to the JSON property `speechOutputSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsSpeechOutputSettings]
        attr_accessor :speech_output_settings
      
        # Settings related to speech detection. See go/hotword-settings-on-cloud for
        # more info. Next ID: 16
        # Corresponds to the JSON property `speechSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsSpeechSettings]
        attr_accessor :speech_settings
      
        # Restrictions on how and when certain users can use a device. See go/home-ft-
        # prd.
        # Corresponds to the JSON property `supervisionSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceSupervisionSettings]
        attr_accessor :supervision_settings
      
        # Specifies the types of device surfaces. LINT.IfChange When adding new surface
        # types make sure that My Activity (https://myactivity.google.com/product/
        # assistant) will correctly render by adding your enum to http://cs/symbol:
        # GetAssistSurfaceName%20f:%5C.cc$ If your type doesn't fit in to any of the
        # existing surfaces messages, add a new message in http://google3/
        # personalization/footprints/boq/uservisible/events/intl/smh_frontend_messages.h.
        # Corresponds to the JSON property `surfaceType`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesSurfaceType]
        attr_accessor :surface_type
      
        # Presence indicates a tethered wearable. go/wearable-device-ids.
        # Corresponds to the JSON property `tetheredInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsTetheredInfo]
        attr_accessor :tethered_info
      
        # A time zone. Conceptually, a time zone is a set of rules associated with a
        # location that describes a UTC offset and how it changes over time (e.g.
        # Daylight Saving Time). The offset is used to compute the local date and time.
        # IMPORTANT: The definition of TimeZone enum is being moved to //assistant/api/
        # core_types/governed/datetime_type.proto. All existing references will be
        # updated to point to the new location. If you are adding a reference, use the
        # new one instead.
        # Corresponds to the JSON property `timeZone`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimeZone]
        attr_accessor :time_zone
      
        # Local network ID of the device (truncated to obfuscate devices and households
        # globally). This is a temporary signal to determine proximity of Assistant
        # devices in a house (HGS place).
        # Corresponds to the JSON property `truncatedLocalNetworkId`
        # @return [String]
        attr_accessor :truncated_local_network_id
      
        # DEPRECATED: Use speech_settings instead. Indicates whether the user has
        # enabled trusted voice for this device. See go/hotword-settings-on-cloud for
        # more info on this project.
        # Corresponds to the JSON property `trustedVoiceEnabled`
        # @return [Boolean]
        attr_accessor :trusted_voice_enabled
        alias_method :trusted_voice_enabled?, :trusted_voice_enabled
      
        # The type of the device. Note: this should only be used for grouping devices
        # for UI presentation purpose. Use |capabilities| to decide what the device can
        # do.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Indicates whether to play verbose tts for Elementary on chirp. See: go/opa-
        # cast-a11y-impl-design fore more info on this project. Note: this should
        # probably be in SpeechOutputSetting below.
        # Corresponds to the JSON property `verboseTtsForChromecastEnabled`
        # @return [Boolean]
        attr_accessor :verbose_tts_for_chromecast_enabled
        alias_method :verbose_tts_for_chromecast_enabled?, :verbose_tts_for_chromecast_enabled
      
        # Coarsened hourly timestamp of when the user was last verified by VoiceMatch on
        # this device. This is used for enforcing VoiceMatch model TTL. go/voicematch-
        # pdd-ttl
        # Corresponds to the JSON property `vmLastUsedCoarseTimestamp`
        # @return [String]
        attr_accessor :vm_last_used_coarse_timestamp
      
        # Indicates whether the user's voice has been successfully enrolled on this
        # device.
        # Corresponds to the JSON property `voiceEnrollmentStatus`
        # @return [String]
        attr_accessor :voice_enrollment_status
      
        # A boolean indicates whether voice input (mic-button, hotword, etc) is enabled.
        # Corresponds to the JSON property `voiceInputEnabled`
        # @return [Boolean]
        attr_accessor :voice_input_enabled
        alias_method :voice_input_enabled?, :voice_input_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ack_status = args[:ack_status] if args.key?(:ack_status)
          @address = args[:address] if args.key?(:address)
          @alias_name = args[:alias_name] if args.key?(:alias_name)
          @allow_incoming_calls = args[:allow_incoming_calls] if args.key?(:allow_incoming_calls)
          @ambient_settings = args[:ambient_settings] if args.key?(:ambient_settings)
          @ancillary_device_id = args[:ancillary_device_id] if args.key?(:ancillary_device_id)
          @auto_framing_settings = args[:auto_framing_settings] if args.key?(:auto_framing_settings)
          @blue_steel_enabled = args[:blue_steel_enabled] if args.key?(:blue_steel_enabled)
          @capabilities = args[:capabilities] if args.key?(:capabilities)
          @city = args[:city] if args.key?(:city)
          @colocation_status = args[:colocation_status] if args.key?(:colocation_status)
          @creation_timestamp_ms = args[:creation_timestamp_ms] if args.key?(:creation_timestamp_ms)
          @cross_surface_availability = args[:cross_surface_availability] if args.key?(:cross_surface_availability)
          @default_audio_device_id = args[:default_audio_device_id] if args.key?(:default_audio_device_id)
          @default_video_device_id = args[:default_video_device_id] if args.key?(:default_video_device_id)
          @device_brand = args[:device_brand] if args.key?(:device_brand)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_model_id = args[:device_model_id] if args.key?(:device_model_id)
          @device_model_revision = args[:device_model_revision] if args.key?(:device_model_revision)
          @dusi = args[:dusi] if args.key?(:dusi)
          @face_enrollment_errors = args[:face_enrollment_errors] if args.key?(:face_enrollment_errors)
          @face_enrollment_status = args[:face_enrollment_status] if args.key?(:face_enrollment_status)
          @face_match_enabled = args[:face_match_enabled] if args.key?(:face_match_enabled)
          @fl_audio_cache_enabled = args[:fl_audio_cache_enabled] if args.key?(:fl_audio_cache_enabled)
          @fl_visual_frames_cache_enabled = args[:fl_visual_frames_cache_enabled] if args.key?(:fl_visual_frames_cache_enabled)
          @gcm_settings = args[:gcm_settings] if args.key?(:gcm_settings)
          @home_graph_data = args[:home_graph_data] if args.key?(:home_graph_data)
          @home_graph_id = args[:home_graph_id] if args.key?(:home_graph_id)
          @hospitality_mode_status = args[:hospitality_mode_status] if args.key?(:hospitality_mode_status)
          @hotword_sensitivity = args[:hotword_sensitivity] if args.key?(:hotword_sensitivity)
          @hotword_threshold_adjustment_factor = args[:hotword_threshold_adjustment_factor] if args.key?(:hotword_threshold_adjustment_factor)
          @human_friendly_name = args[:human_friendly_name] if args.key?(:human_friendly_name)
          @internal_version = args[:internal_version] if args.key?(:internal_version)
          @is_cloud_sync_device = args[:is_cloud_sync_device] if args.key?(:is_cloud_sync_device)
          @is_device_activation_cache_enabled = args[:is_device_activation_cache_enabled] if args.key?(:is_device_activation_cache_enabled)
          @kids_mode = args[:kids_mode] if args.key?(:kids_mode)
          @last_cast_registration_timestamp = args[:last_cast_registration_timestamp] if args.key?(:last_cast_registration_timestamp)
          @last_used_coarse_timestamp = args[:last_used_coarse_timestamp] if args.key?(:last_used_coarse_timestamp)
          @linked_device_id = args[:linked_device_id] if args.key?(:linked_device_id)
          @linked_users = args[:linked_users] if args.key?(:linked_users)
          @locale = args[:locale] if args.key?(:locale)
          @location_coordinates = args[:location_coordinates] if args.key?(:location_coordinates)
          @location_feature = args[:location_feature] if args.key?(:location_feature)
          @marketplace_disclosure = args[:marketplace_disclosure] if args.key?(:marketplace_disclosure)
          @masquerade_mode = args[:masquerade_mode] if args.key?(:masquerade_mode)
          @notification_profile = args[:notification_profile] if args.key?(:notification_profile)
          @oauth_client_id = args[:oauth_client_id] if args.key?(:oauth_client_id)
          @on_device_app_settings = args[:on_device_app_settings] if args.key?(:on_device_app_settings)
          @opt_in_status = args[:opt_in_status] if args.key?(:opt_in_status)
          @payments_enabled = args[:payments_enabled] if args.key?(:payments_enabled)
          @personalization_metadata = args[:personalization_metadata] if args.key?(:personalization_metadata)
          @polite_mode = args[:polite_mode] if args.key?(:polite_mode)
          @postal_code = args[:postal_code] if args.key?(:postal_code)
          @reauth_trusted_device_settings = args[:reauth_trusted_device_settings] if args.key?(:reauth_trusted_device_settings)
          @shortened_address = args[:shortened_address] if args.key?(:shortened_address)
          @speaker_id_enabled = args[:speaker_id_enabled] if args.key?(:speaker_id_enabled)
          @speech_output_settings = args[:speech_output_settings] if args.key?(:speech_output_settings)
          @speech_settings = args[:speech_settings] if args.key?(:speech_settings)
          @supervision_settings = args[:supervision_settings] if args.key?(:supervision_settings)
          @surface_type = args[:surface_type] if args.key?(:surface_type)
          @tethered_info = args[:tethered_info] if args.key?(:tethered_info)
          @time_zone = args[:time_zone] if args.key?(:time_zone)
          @truncated_local_network_id = args[:truncated_local_network_id] if args.key?(:truncated_local_network_id)
          @trusted_voice_enabled = args[:trusted_voice_enabled] if args.key?(:trusted_voice_enabled)
          @type = args[:type] if args.key?(:type)
          @verbose_tts_for_chromecast_enabled = args[:verbose_tts_for_chromecast_enabled] if args.key?(:verbose_tts_for_chromecast_enabled)
          @vm_last_used_coarse_timestamp = args[:vm_last_used_coarse_timestamp] if args.key?(:vm_last_used_coarse_timestamp)
          @voice_enrollment_status = args[:voice_enrollment_status] if args.key?(:voice_enrollment_status)
          @voice_input_enabled = args[:voice_input_enabled] if args.key?(:voice_input_enabled)
        end
      end
      
      # 
      class AssistantApiSettingsDeviceSettingsCrossSurfaceAvailability
        include Google::Apis::Core::Hashable
      
        # Last known locale of the client.
        # Corresponds to the JSON property `lastKnownClientLocale`
        # @return [String]
        attr_accessor :last_known_client_locale
      
        # This is the timestamp when the AssistantRequestParams (in ASSISTANT_SNAPSHOT
        # corpus) were last written for this device.
        # Corresponds to the JSON property `lastParamsWriteTimestamp`
        # @return [String]
        attr_accessor :last_params_write_timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_known_client_locale = args[:last_known_client_locale] if args.key?(:last_known_client_locale)
          @last_params_write_timestamp = args[:last_params_write_timestamp] if args.key?(:last_params_write_timestamp)
        end
      end
      
      # 
      class AssistantApiSettingsDeviceSupervisionSettings
        include Google::Apis::Core::Hashable
      
        # Specification of times when most features on a device are disabled for certain
        # users. During these periods, the device will respond to most interactions with
        # something like "sorry, I'm sleeping right now". Design: go/home-ft-settings-
        # storage PRD: go/home-family-tools-prd
        # Corresponds to the JSON property `downtimeSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceDowntimeSettings]
        attr_accessor :downtime_settings
      
        # Defines a set of restrictions on particular device features for a certain set
        # of users. Design: go/home-ft-settings-storage PRD: go/home-family-tools-prd
        # Corresponds to the JSON property `featureFilters`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceFeatureFilters]
        attr_accessor :feature_filters
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @downtime_settings = args[:downtime_settings] if args.key?(:downtime_settings)
          @feature_filters = args[:feature_filters] if args.key?(:feature_filters)
        end
      end
      
      # Specifies a period of up to 24 hours when downtime should be enabled, starting
      # at certain time on a certain day of the week, and ending at a later time on
      # either that day or the following day.
      class AssistantApiSettingsDowntimePeriod
        include Google::Apis::Core::Hashable
      
        # True if downtime should be enabled during this period.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # Represents a time of day. The date and time zone are either not significant or
        # are specified elsewhere. An API may choose to allow leap seconds. Related
        # types are google.type.Date and `google.protobuf.Timestamp`.
        # Corresponds to the JSON property `endTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeOfDay]
        attr_accessor :end_time
      
        # The day of the week when this downtime period starts. Required.
        # Corresponds to the JSON property `startDay`
        # @return [String]
        attr_accessor :start_day
      
        # Represents a time of day. The date and time zone are either not significant or
        # are specified elsewhere. An API may choose to allow leap seconds. Related
        # types are google.type.Date and `google.protobuf.Timestamp`.
        # Corresponds to the JSON property `startTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeOfDay]
        attr_accessor :start_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
          @end_time = args[:end_time] if args.key?(:end_time)
          @start_day = args[:start_day] if args.key?(:start_day)
          @start_time = args[:start_time] if args.key?(:start_time)
        end
      end
      
      # Specification of when downtime is enabled on different days of the week.
      # Contains up to 7 DowntimePeriod messages, up to one per day of the week.
      class AssistantApiSettingsDowntimeSchedule
        include Google::Apis::Core::Hashable
      
        # True if this downtime schedule should be enabled.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # Downtime entries for the days of the week, in no particular order. There can
        # be at most one period defined for each day of the week. Days of the week with
        # no explicit period defined are treated as disabled, so the device is available
        # all day (modulo an end time that may spill over from the previous day).
        # Corresponds to the JSON property `periods`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSettingsDowntimePeriod>]
        attr_accessor :periods
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
          @periods = args[:periods] if args.key?(:periods)
        end
      end
      
      # Duo related call settings on the device. Next ID: 5
      class AssistantApiSettingsDuoCallDeviceSettings
        include Google::Apis::Core::Hashable
      
        # True if Duo Knock Kncok feature is enabled on the device.
        # Corresponds to the JSON property `allowKnockKnock`
        # @return [Boolean]
        attr_accessor :allow_knock_knock
        alias_method :allow_knock_knock?, :allow_knock_knock
      
        # Boolean indicating if user has explicitly marked this device to be linked or
        # not. This bit is used in case where unexpected errors occur and we have to
        # check for account/device status and mark the device linked after verification.
        # Corresponds to the JSON property `shouldBeLinked`
        # @return [Boolean]
        attr_accessor :should_be_linked
        alias_method :should_be_linked?, :should_be_linked
      
        # The call state of the device (i.e. whether an Duo call account has been setup
        # on the device).
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # Client device settings: settings which are populated by client to give to
        # duocore. TalkBack is an accessibility service that helps blind and vision-
        # impaired users interact with their devices. Indicates whether talkback is
        # enabled for the device. Note: this is per device settings currently filled by
        # client for all users.
        # Corresponds to the JSON property `talkbackEnabled`
        # @return [Boolean]
        attr_accessor :talkback_enabled
        alias_method :talkback_enabled?, :talkback_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_knock_knock = args[:allow_knock_knock] if args.key?(:allow_knock_knock)
          @should_be_linked = args[:should_be_linked] if args.key?(:should_be_linked)
          @state = args[:state] if args.key?(:state)
          @talkback_enabled = args[:talkback_enabled] if args.key?(:talkback_enabled)
        end
      end
      
      # Specification of which assistant features are allowed for a particular device
      # or user account.
      class AssistantApiSettingsFeatureFilters
        include Google::Apis::Core::Hashable
      
        # Specification of which communication features can be used.
        # Corresponds to the JSON property `communicationsFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsCommunicationsFilter]
        attr_accessor :communications_filter
      
        # Specification of which music features can be used.
        # Corresponds to the JSON property `musicFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsMusicFilter]
        attr_accessor :music_filter
      
        # Specification of which news features can be used.
        # Corresponds to the JSON property `newsFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsNewsFilter]
        attr_accessor :news_filter
      
        # Specification of which podcast features can be used.
        # Corresponds to the JSON property `podcastFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsPodcastFilter]
        attr_accessor :podcast_filter
      
        # Specification of which search features can be used.
        # Corresponds to the JSON property `searchFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsSearchFilter]
        attr_accessor :search_filter
      
        # Specification of which third party apps can be used.
        # Corresponds to the JSON property `thirdPartyAppsFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsThirdPartyAppsFilter]
        attr_accessor :third_party_apps_filter
      
        # Specification of which video features can be used.
        # Corresponds to the JSON property `videoFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsVideoFilter]
        attr_accessor :video_filter
      
        # Specification of which webview features can be used.
        # Corresponds to the JSON property `webviewFilter`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsWebviewFilter]
        attr_accessor :webview_filter
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @communications_filter = args[:communications_filter] if args.key?(:communications_filter)
          @music_filter = args[:music_filter] if args.key?(:music_filter)
          @news_filter = args[:news_filter] if args.key?(:news_filter)
          @podcast_filter = args[:podcast_filter] if args.key?(:podcast_filter)
          @search_filter = args[:search_filter] if args.key?(:search_filter)
          @third_party_apps_filter = args[:third_party_apps_filter] if args.key?(:third_party_apps_filter)
          @video_filter = args[:video_filter] if args.key?(:video_filter)
          @webview_filter = args[:webview_filter] if args.key?(:webview_filter)
        end
      end
      
      # 
      class AssistantApiSettingsGcmSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `gcmId`
        # @return [String]
        attr_accessor :gcm_id
      
        # 
        # Corresponds to the JSON property `gcmPackage`
        # @return [String]
        attr_accessor :gcm_package
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcm_id = args[:gcm_id] if args.key?(:gcm_id)
          @gcm_package = args[:gcm_package] if args.key?(:gcm_package)
        end
      end
      
      # Next ID: 8
      class AssistantApiSettingsHomeGraphData
        include Google::Apis::Core::Hashable
      
        # Agent ID, aka project ID. Used as the AgentDeviceId.agent_id of device when
        # calling Home Graph Service.
        # Corresponds to the JSON property `agentId`
        # @return [String]
        attr_accessor :agent_id
      
        # See go/ha-dev-guide and HomeGraphItem.attribute in //assistant/verticals/
        # homeautomation/proto/home_graph.proto
        # Corresponds to the JSON property `attributes`
        # @return [Hash<String,Object>]
        attr_accessor :attributes
      
        # Device ID, used as AgentDeviceId.device_id of device when calling Home Graph
        # Service.
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        # HGS device type. See java/com/google/home/graph/service/config/protoconf.pi
        # for the exhaustive list of type strings.
        # Corresponds to the JSON property `deviceType`
        # @return [String]
        attr_accessor :device_type
      
        # Whether device data should be written to Home Graph via Assistant
        # device_settings. Assistant SDK and Google Home write their devices into Home
        # Graph through AssistantSettingsService, while Home Automation Partner devices (
        # e.g. SmartThings, Philips Hue, Nest, TP-Link, etc.) don't need to be written
        # to Home Graph through AssistantSettingsService. This field decides whether
        # AssistantSettingsService writes devices to Home Graph or not.
        # Corresponds to the JSON property `shouldWriteToHomeGraph`
        # @return [Boolean]
        attr_accessor :should_write_to_home_graph
        alias_method :should_write_to_home_graph?, :should_write_to_home_graph
      
        # Supported traits of the device. See java/com/google/home/graph/service/config/
        # protoconf.pi for the exhaustive list of trait-strings.
        # Corresponds to the JSON property `supportedTraits`
        # @return [Array<String>]
        attr_accessor :supported_traits
      
        # Whether the device supports direct response. See HomeGraphItem.
        # supports_direct_response in //assistant/verticals/homeautomation/proto/
        # home_graph.proto
        # Corresponds to the JSON property `supportsDirectResponse`
        # @return [Boolean]
        attr_accessor :supports_direct_response
        alias_method :supports_direct_response?, :supports_direct_response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_id = args[:agent_id] if args.key?(:agent_id)
          @attributes = args[:attributes] if args.key?(:attributes)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_type = args[:device_type] if args.key?(:device_type)
          @should_write_to_home_graph = args[:should_write_to_home_graph] if args.key?(:should_write_to_home_graph)
          @supported_traits = args[:supported_traits] if args.key?(:supported_traits)
          @supports_direct_response = args[:supports_direct_response] if args.key?(:supports_direct_response)
        end
      end
      
      # 
      class AssistantApiSettingsHospitalityCardSettings
        include Google::Apis::Core::Hashable
      
        # Config for Hospitality UI modules.
        # Corresponds to the JSON property `cardConfig`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSettingsHospitalityCardSettingsCardConfig>]
        attr_accessor :card_config
      
        # Toggle media tap gesture tutorial card.
        # Corresponds to the JSON property `showMediaTapGestureTutorial`
        # @return [Boolean]
        attr_accessor :show_media_tap_gesture_tutorial
        alias_method :show_media_tap_gesture_tutorial?, :show_media_tap_gesture_tutorial
      
        # Toggle photo swipe gesture tutorial card.
        # Corresponds to the JSON property `showPhotoSwipeGestureTutorial`
        # @return [Boolean]
        attr_accessor :show_photo_swipe_gesture_tutorial
        alias_method :show_photo_swipe_gesture_tutorial?, :show_photo_swipe_gesture_tutorial
      
        # Config for YouTube video cards.
        # Corresponds to the JSON property `youtubeCardConfig`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSettingsHospitalityCardSettingsYouTubeCardConfig>]
        attr_accessor :youtube_card_config
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @card_config = args[:card_config] if args.key?(:card_config)
          @show_media_tap_gesture_tutorial = args[:show_media_tap_gesture_tutorial] if args.key?(:show_media_tap_gesture_tutorial)
          @show_photo_swipe_gesture_tutorial = args[:show_photo_swipe_gesture_tutorial] if args.key?(:show_photo_swipe_gesture_tutorial)
          @youtube_card_config = args[:youtube_card_config] if args.key?(:youtube_card_config)
        end
      end
      
      # Configuration for hospitality card.
      class AssistantApiSettingsHospitalityCardSettingsCardConfig
        include Google::Apis::Core::Hashable
      
        # Whether the UI module requires user action. If true, the UI module can peek on
        # to the top of Ambient. See SmartDisplayModuleState::ACTIVE_ACTION_REQUIRED.
        # Corresponds to the JSON property `activeActionRequired`
        # @return [Boolean]
        attr_accessor :active_action_required
        alias_method :active_action_required?, :active_action_required
      
        # Whether the UI module is dismissable.
        # Corresponds to the JSON property `dismissable`
        # @return [Boolean]
        attr_accessor :dismissable
        alias_method :dismissable?, :dismissable
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `effectiveTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :effective_time
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `expiryTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :expiry_time
      
        # The image URL for the UI module.
        # Corresponds to the JSON property `imageUrl`
        # @return [String]
        attr_accessor :image_url
      
        # Module ID.
        # Corresponds to the JSON property `moduleId`
        # @return [String]
        attr_accessor :module_id
      
        # Payload query to the partner AoG action when user responds to UI Module, e.g. “
        # Tell the hotel how my stay is going”.
        # Corresponds to the JSON property `payloadQuery`
        # @return [String]
        attr_accessor :payload_query
      
        # Title of the message to be shown to user at the top of the UI Module.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @active_action_required = args[:active_action_required] if args.key?(:active_action_required)
          @dismissable = args[:dismissable] if args.key?(:dismissable)
          @effective_time = args[:effective_time] if args.key?(:effective_time)
          @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
          @image_url = args[:image_url] if args.key?(:image_url)
          @module_id = args[:module_id] if args.key?(:module_id)
          @payload_query = args[:payload_query] if args.key?(:payload_query)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Configuration for YouTube video card (Stargazer tile).
      class AssistantApiSettingsHospitalityCardSettingsYouTubeCardConfig
        include Google::Apis::Core::Hashable
      
        # URL of image to go on card. The URL must be a public link accessible from
        # ZeroState.
        # Corresponds to the JSON property `imageUrl`
        # @return [String]
        attr_accessor :image_url
      
        # ID of YouTube playlist to play on card tap. A playlist is used instead of a
        # single video id to avoid autoplaying related videos. The playlist and the
        # videos it contains must be public or unlisted to be accessible from ZeroState.
        # Corresponds to the JSON property `playlistId`
        # @return [String]
        attr_accessor :playlist_id
      
        # Text on card (i.e., video title).
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_url = args[:image_url] if args.key?(:image_url)
          @playlist_id = args[:playlist_id] if args.key?(:playlist_id)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Hospitality mode config for the current device. go/hospitality-mode-design.
      # Next ID: 17
      class AssistantApiSettingsHospitalityMode
        include Google::Apis::Core::Hashable
      
        # List of AOG app context ids that are linked to this device. These apps will
        # have access to the structure information for the device.
        # Corresponds to the JSON property `aogContextId`
        # @return [Array<String>]
        attr_accessor :aog_context_id
      
        # Invocation phrase for hotel's AoG action. Used for ZS promotion card and "talk
        # to my hotel" rewrites. Setting this to an empty value will mark it unset.
        # Corresponds to the JSON property `aogInvocationPhrase`
        # @return [String]
        attr_accessor :aog_invocation_phrase
      
        # TODO(b/169423976) Consider moving Branding out of user level settings into
        # enterprise level settings. Partner branding fields used to customize the ui.
        # Next ID: 7
        # Corresponds to the JSON property `branding`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsHospitalityModeBranding]
        attr_accessor :branding
      
        # 
        # Corresponds to the JSON property `cardSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsHospitalityCardSettings]
        attr_accessor :card_settings
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `deviceClearRequest`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :device_clear_request
      
        # Should the dialog have a shorter ttl. See go/ipp-consumer-prd#heading=h.
        # ibu9b1ysdl4t and go/interpreter-device-clear#bookmark=id.hw8ey1bzjadn for
        # context.
        # Corresponds to the JSON property `dialogTtlOverrideMicros`
        # @return [Fixnum]
        attr_accessor :dialog_ttl_override_micros
      
        # Identifier for the enterprise which owns the device. Setting this to an empty
        # value will mark it unset.
        # Corresponds to the JSON property `enterpriseId`
        # @return [String]
        attr_accessor :enterprise_id
      
        # Indicates whether this device is in the hospitality mode.
        # Corresponds to the JSON property `hospitalityModeEnabled`
        # @return [Boolean]
        attr_accessor :hospitality_mode_enabled
        alias_method :hospitality_mode_enabled?, :hospitality_mode_enabled
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastDeviceClear`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_device_clear
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastModifiedTimestamp`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_modified_timestamp
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastWelcomed`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_welcomed
      
        # Indicates whether or not the device must be reset manually (by voice or touch),
        # as opposed to being automatically reset. go/hospitality-manual-reset
        # Corresponds to the JSON property `manualResetRequired`
        # @return [Boolean]
        attr_accessor :manual_reset_required
        alias_method :manual_reset_required?, :manual_reset_required
      
        # In order promoted languages for interpreter devices. This represents languages
        # by BCP-47 language strings, such as "en", "en-US", "fr", "fr-CA", "sr-Latn", "
        # zh-Hans-CN", "zh-Hant-HK",etc.
        # Corresponds to the JSON property `promotedLanguages`
        # @return [Array<String>]
        attr_accessor :promoted_languages
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Whether we allow users to initiate clearing the device verbally. We generally
        # allow this for private devices and not for public ones.
        # Corresponds to the JSON property `verbalResetSupported`
        # @return [Boolean]
        attr_accessor :verbal_reset_supported
        alias_method :verbal_reset_supported?, :verbal_reset_supported
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `welcomeRequest`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :welcome_request
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aog_context_id = args[:aog_context_id] if args.key?(:aog_context_id)
          @aog_invocation_phrase = args[:aog_invocation_phrase] if args.key?(:aog_invocation_phrase)
          @branding = args[:branding] if args.key?(:branding)
          @card_settings = args[:card_settings] if args.key?(:card_settings)
          @device_clear_request = args[:device_clear_request] if args.key?(:device_clear_request)
          @dialog_ttl_override_micros = args[:dialog_ttl_override_micros] if args.key?(:dialog_ttl_override_micros)
          @enterprise_id = args[:enterprise_id] if args.key?(:enterprise_id)
          @hospitality_mode_enabled = args[:hospitality_mode_enabled] if args.key?(:hospitality_mode_enabled)
          @last_device_clear = args[:last_device_clear] if args.key?(:last_device_clear)
          @last_modified_timestamp = args[:last_modified_timestamp] if args.key?(:last_modified_timestamp)
          @last_welcomed = args[:last_welcomed] if args.key?(:last_welcomed)
          @manual_reset_required = args[:manual_reset_required] if args.key?(:manual_reset_required)
          @promoted_languages = args[:promoted_languages] if args.key?(:promoted_languages)
          @type = args[:type] if args.key?(:type)
          @verbal_reset_supported = args[:verbal_reset_supported] if args.key?(:verbal_reset_supported)
          @welcome_request = args[:welcome_request] if args.key?(:welcome_request)
        end
      end
      
      # TODO(b/169423976) Consider moving Branding out of user level settings into
      # enterprise level settings. Partner branding fields used to customize the ui.
      # Next ID: 7
      class AssistantApiSettingsHospitalityModeBranding
        include Google::Apis::Core::Hashable
      
        # Brand display in the UI
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Brand display in the UI for languages that the enterprise has a localized name
        # that is different from its global branding name. For example, Hilton is 'ヒルトン'
        # in Japanese and '希爾頓' in Chinese. The keys are hospitality supported display
        # locales, e.g. en, ja-JP, etc, defined in experiment parameter
        # Hospitality__hospitality_display_supported_locales.
        # Corresponds to the JSON property `displayNameForLanguage`
        # @return [Hash<String,String>]
        attr_accessor :display_name_for_language
      
        # 
        # Corresponds to the JSON property `largeLogoUrl`
        # @return [String]
        attr_accessor :large_logo_url
      
        # 
        # Corresponds to the JSON property `smallLogoUrl`
        # @return [String]
        attr_accessor :small_logo_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @display_name_for_language = args[:display_name_for_language] if args.key?(:display_name_for_language)
          @large_logo_url = args[:large_logo_url] if args.key?(:large_logo_url)
          @small_logo_url = args[:small_logo_url] if args.key?(:small_logo_url)
        end
      end
      
      # HotwordThresholdAdjustmentFactor contains threshold_adjustment_factor, and it'
      # s validity. value should only be considered when is_valid = true.
      class AssistantApiSettingsHotwordThresholdAdjustmentFactor
        include Google::Apis::Core::Hashable
      
        # Currently, is_valid is set to false whenever the TAF is not an Autotune aware
        # value. This includes hotword sensitivity users, or devices not eligible for
        # autotune.
        # Corresponds to the JSON property `isValid`
        # @return [Boolean]
        attr_accessor :is_valid
        alias_method :is_valid?, :is_valid
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_valid = args[:is_valid] if args.key?(:is_valid)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Represents supporting device ids.
      class AssistantApiSettingsInternalAncillaryDeviceId
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
        end
      end
      
      # Represents a version of a specifit setting, e.g. DeviceSettings.
      class AssistantApiSettingsInternalVersion
        include Google::Apis::Core::Hashable
      
        # Contains the timestamp when this version was generated.
        # Corresponds to the JSON property `generationTime`
        # @return [String]
        attr_accessor :generation_time
      
        # Integer value of the version, it is a monotonically increasing number and
        # starts at 0. On every update it is incremented by 1.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @generation_time = args[:generation_time] if args.key?(:generation_time)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # Kids mode config for the current device. go/aff-parentalsupervision-dd
      class AssistantApiSettingsKidsMode
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `kidsModeEnabled`
        # @return [Boolean]
        attr_accessor :kids_mode_enabled
        alias_method :kids_mode_enabled?, :kids_mode_enabled
      
        # Identifier of the account currently specified to be used with kids mode.
        # Corresponds to the JSON property `obfuscatedGaiaId`
        # @return [String]
        attr_accessor :obfuscated_gaia_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @kids_mode_enabled = args[:kids_mode_enabled] if args.key?(:kids_mode_enabled)
          @obfuscated_gaia_id = args[:obfuscated_gaia_id] if args.key?(:obfuscated_gaia_id)
        end
      end
      
      # 
      class AssistantApiSettingsLabeledDowntimeSchedule
        include Google::Apis::Core::Hashable
      
        # User-provided name for this schedule.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Specification of when downtime is enabled on different days of the week.
        # Contains up to 7 DowntimePeriod messages, up to one per day of the week.
        # Corresponds to the JSON property `schedule`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDowntimeSchedule]
        attr_accessor :schedule
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @schedule = args[:schedule] if args.key?(:schedule)
        end
      end
      
      # Represents the profile of the user who has signed in onto this device. Next id:
      # 5
      class AssistantApiSettingsLinkedUser
        include Google::Apis::Core::Hashable
      
        # Time of linking of the device with the user provided by Cast.
        # Corresponds to the JSON property `castLinkingTime`
        # @return [String]
        attr_accessor :cast_linking_time
      
        # Primary email address of the user.
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # Supports features which depend on profile name, when no matching contact is
        # found.
        # Corresponds to the JSON property `names`
        # @return [Array<Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiName>]
        attr_accessor :names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cast_linking_time = args[:cast_linking_time] if args.key?(:cast_linking_time)
          @email = args[:email] if args.key?(:email)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @names = args[:names] if args.key?(:names)
        end
      end
      
      # 
      class AssistantApiSettingsMarketplaceDisclosure
        include Google::Apis::Core::Hashable
      
        # True if the user has confirmed the marketplace disclosure.
        # Corresponds to the JSON property `confirmed`
        # @return [Boolean]
        attr_accessor :confirmed
        alias_method :confirmed?, :confirmed
      
        # The time user confirmed the marketplace disclosure.
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confirmed = args[:confirmed] if args.key?(:confirmed)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
        end
      end
      
      # Guest mode for the current device. go/assistant-guest-mode-summary
      class AssistantApiSettingsMasqueradeMode
        include Google::Apis::Core::Hashable
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastEnterGuestModeTimestamp`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_enter_guest_mode_timestamp
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastExitGuestModeTimestamp`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_exit_guest_mode_timestamp
      
        # 
        # Corresponds to the JSON property `masqueradeModeEnabled`
        # @return [Boolean]
        attr_accessor :masquerade_mode_enabled
        alias_method :masquerade_mode_enabled?, :masquerade_mode_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_enter_guest_mode_timestamp = args[:last_enter_guest_mode_timestamp] if args.key?(:last_enter_guest_mode_timestamp)
          @last_exit_guest_mode_timestamp = args[:last_exit_guest_mode_timestamp] if args.key?(:last_exit_guest_mode_timestamp)
          @masquerade_mode_enabled = args[:masquerade_mode_enabled] if args.key?(:masquerade_mode_enabled)
        end
      end
      
      # Specification of which music features can be used.
      class AssistantApiSettingsMusicFilter
        include Google::Apis::Core::Hashable
      
        # Providers available at the time user updated settings.
        # Corresponds to the JSON property `availableProviders`
        # @return [Array<String>]
        attr_accessor :available_providers
      
        # Represents the state for the music provider filter.
        # Corresponds to the JSON property `providerFilterState`
        # @return [String]
        attr_accessor :provider_filter_state
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # Contains the list of whitelisted music providers.
        # Corresponds to the JSON property `whitelistedProviders`
        # @return [Array<String>]
        attr_accessor :whitelisted_providers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @available_providers = args[:available_providers] if args.key?(:available_providers)
          @provider_filter_state = args[:provider_filter_state] if args.key?(:provider_filter_state)
          @state = args[:state] if args.key?(:state)
          @whitelisted_providers = args[:whitelisted_providers] if args.key?(:whitelisted_providers)
        end
      end
      
      # Specification of which news features can be used.
      class AssistantApiSettingsNewsFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # 
      class AssistantApiSettingsNotificationProfile
        include Google::Apis::Core::Hashable
      
        # Each device can have only one type of notification profile.
        # Corresponds to the JSON property `alloNotificationProfile`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsNotificationProfileAlloNotificationProfile]
        attr_accessor :allo_notification_profile
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allo_notification_profile = args[:allo_notification_profile] if args.key?(:allo_notification_profile)
        end
      end
      
      # 
      class AssistantApiSettingsNotificationProfileAlloNotificationProfile
        include Google::Apis::Core::Hashable
      
        # Token to be exposed and stored by the bot
        # Corresponds to the JSON property `botSendToken`
        # @return [Google::Apis::ContentwarehouseV1::ChatBotPlatformBotSendToken]
        attr_accessor :bot_send_token
      
        # The fireball id of this user.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::ChatBotPlatformFireballId]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bot_send_token = args[:bot_send_token] if args.key?(:bot_send_token)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # 
      class AssistantApiSettingsOnDeviceAppSettings
        include Google::Apis::Core::Hashable
      
        # Carrier related call settings on the device.
        # Corresponds to the JSON property `carrierCallDeviceSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsCarrierCallDeviceSettings]
        attr_accessor :carrier_call_device_settings
      
        # Duo related call settings on the device. Next ID: 5
        # Corresponds to the JSON property `duoCallDeviceSettings`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDuoCallDeviceSettings]
        attr_accessor :duo_call_device_settings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @carrier_call_device_settings = args[:carrier_call_device_settings] if args.key?(:carrier_call_device_settings)
          @duo_call_device_settings = args[:duo_call_device_settings] if args.key?(:duo_call_device_settings)
        end
      end
      
      # 
      class AssistantApiSettingsPersonalizationMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `faceMatch`
        # @return [String]
        attr_accessor :face_match
      
        # 
        # Corresponds to the JSON property `personalResults`
        # @return [String]
        attr_accessor :personal_results
      
        # 
        # Corresponds to the JSON property `voiceMatch`
        # @return [String]
        attr_accessor :voice_match
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @face_match = args[:face_match] if args.key?(:face_match)
          @personal_results = args[:personal_results] if args.key?(:personal_results)
          @voice_match = args[:voice_match] if args.key?(:voice_match)
        end
      end
      
      # Specification of which podcast features can be used.
      class AssistantApiSettingsPodcastFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Polite mode config for the current device. go/polite-mode-dd
      class AssistantApiSettingsPoliteMode
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `politeModeEnabled`
        # @return [Boolean]
        attr_accessor :polite_mode_enabled
        alias_method :polite_mode_enabled?, :polite_mode_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @polite_mode_enabled = args[:polite_mode_enabled] if args.key?(:polite_mode_enabled)
        end
      end
      
      # Settings related to Assistant reauth. go/assistant-reauth-verify-skip Next id:
      # 2
      class AssistantApiSettingsReauthTrustedDeviceSettings
        include Google::Apis::Core::Hashable
      
        # Mapping from integrator client id to device's trust settings. Id from
        # assistant/agent_platform/transactions/reauth/reauth_client.proto.
        # Corresponds to the JSON property `trustSettingsForClient`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantApiSettingsReauthTrustedDeviceSettingsTrustSettings>]
        attr_accessor :trust_settings_for_client
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @trust_settings_for_client = args[:trust_settings_for_client] if args.key?(:trust_settings_for_client)
        end
      end
      
      # Next id: 6
      class AssistantApiSettingsReauthTrustedDeviceSettingsTrustSettings
        include Google::Apis::Core::Hashable
      
        # If true, don't ask user to trust this device again.
        # Corresponds to the JSON property `neverAskAgain`
        # @return [Boolean]
        attr_accessor :never_ask_again
        alias_method :never_ask_again?, :never_ask_again
      
        # DEPRECATED: Use never_ask_again instead. Expiration timestamp of "never ask
        # again" status. If this field is set and is later than current timestamp, we
        # should NOT ask the user whether they'd like to trust this device.
        # Corresponds to the JSON property `neverAskExpirationTimestamp`
        # @return [String]
        attr_accessor :never_ask_expiration_timestamp
      
        # Expiration timestamp of "trusted" status. If this field is set and is later
        # than current timestamp, we can consider this device to be trusted.
        # Corresponds to the JSON property `trustDeviceExpirationTimestamp`
        # @return [String]
        attr_accessor :trust_device_expiration_timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @never_ask_again = args[:never_ask_again] if args.key?(:never_ask_again)
          @never_ask_expiration_timestamp = args[:never_ask_expiration_timestamp] if args.key?(:never_ask_expiration_timestamp)
          @trust_device_expiration_timestamp = args[:trust_device_expiration_timestamp] if args.key?(:trust_device_expiration_timestamp)
        end
      end
      
      # Specification of which search features can be used.
      class AssistantApiSettingsSearchFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Settings related to TTS output.
      class AssistantApiSettingsSpeechOutputSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `speechOutput`
        # @return [String]
        attr_accessor :speech_output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @speech_output = args[:speech_output] if args.key?(:speech_output)
        end
      end
      
      # Settings related to speech detection. See go/hotword-settings-on-cloud for
      # more info. Next ID: 16
      class AssistantApiSettingsSpeechSettings
        include Google::Apis::Core::Hashable
      
        # Indicates whether Continued Conversation is enabled for this device.
        # Corresponds to the JSON property `continuedConversationEnabled`
        # @return [Boolean]
        attr_accessor :continued_conversation_enabled
        alias_method :continued_conversation_enabled?, :continued_conversation_enabled
      
        # Stores the device model type e.g Pixel.
        # Corresponds to the JSON property `deviceModelType`
        # @return [String]
        attr_accessor :device_model_type
      
        # Whether the device has DSP chip to enable always on hotword detection.
        # Corresponds to the JSON property `dspAvailable`
        # @return [Boolean]
        attr_accessor :dsp_available
        alias_method :dsp_available?, :dsp_available
      
        # Whether hotword has been enabled by the user during navigation.
        # Corresponds to the JSON property `hotwordInNavigationEnabled`
        # @return [String]
        attr_accessor :hotword_in_navigation_enabled
      
        # Stores hotword setting status for the locales which don't support voice match.
        # Corresponds to the JSON property `hotwordSetting`
        # @return [String]
        attr_accessor :hotword_setting
      
        # Whether pin/pattern lockscreen has been enabled by the user.
        # Corresponds to the JSON property `lockscreenEnabled`
        # @return [Boolean]
        attr_accessor :lockscreen_enabled
        alias_method :lockscreen_enabled?, :lockscreen_enabled
      
        # Stores if Assistant is available for the user's device/locale, where Enabled
        # means it is available and disabled means it is not.
        # Corresponds to the JSON property `opaEligibilityState`
        # @return [String]
        attr_accessor :opa_eligibility_state
      
        # Stores if Assistant is available for the user's device/locale. Deprecated as
        # bools do not give accurate true/false ratios due to old clients reporting the
        # default value.
        # Corresponds to the JSON property `opaEligible`
        # @return [Boolean]
        attr_accessor :opa_eligible
        alias_method :opa_eligible?, :opa_eligible
      
        # Stores the Android SDK version. This comes from android.os.Build.VERSION.
        # SDK_INT.
        # Corresponds to the JSON property `sdkVersion`
        # @return [Fixnum]
        attr_accessor :sdk_version
      
        # Whether speaker ID model is present for the user.
        # Corresponds to the JSON property `speakerIdModelPresent`
        # @return [Boolean]
        attr_accessor :speaker_id_model_present
        alias_method :speaker_id_model_present?, :speaker_id_model_present
      
        # Indicates whether the user has enabled speaker-id (fromAnyScreen/alwaysOn) for
        # this device. Deprecated - use voice_match_setting instead
        # Corresponds to the JSON property `speakerIdRecognitionEnabled`
        # @return [Boolean]
        attr_accessor :speaker_id_recognition_enabled
        alias_method :speaker_id_recognition_enabled?, :speaker_id_recognition_enabled
      
        # Indicates whether the user has enabled trusted voice for this device.
        # Corresponds to the JSON property `trustedVoiceEnabled`
        # @return [Boolean]
        attr_accessor :trusted_voice_enabled
        alias_method :trusted_voice_enabled?, :trusted_voice_enabled
      
        # A bool indicating whether device supports unlocking device with hotword.
        # Corresponds to the JSON property `unlockWithHotwordAvailable`
        # @return [Boolean]
        attr_accessor :unlock_with_hotword_available
        alias_method :unlock_with_hotword_available?, :unlock_with_hotword_available
      
        # Stores if user was migrated from undecided to declined as apart of Mariko
        # project. Used for potential growth targeting.
        # Corresponds to the JSON property `userMigratedToDeclined`
        # @return [Boolean]
        attr_accessor :user_migrated_to_declined
        alias_method :user_migrated_to_declined?, :user_migrated_to_declined
      
        # Stores the hotword/voice match setting status for the locales which support
        # voice match.
        # Corresponds to the JSON property `voiceMatchSetting`
        # @return [String]
        attr_accessor :voice_match_setting
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @continued_conversation_enabled = args[:continued_conversation_enabled] if args.key?(:continued_conversation_enabled)
          @device_model_type = args[:device_model_type] if args.key?(:device_model_type)
          @dsp_available = args[:dsp_available] if args.key?(:dsp_available)
          @hotword_in_navigation_enabled = args[:hotword_in_navigation_enabled] if args.key?(:hotword_in_navigation_enabled)
          @hotword_setting = args[:hotword_setting] if args.key?(:hotword_setting)
          @lockscreen_enabled = args[:lockscreen_enabled] if args.key?(:lockscreen_enabled)
          @opa_eligibility_state = args[:opa_eligibility_state] if args.key?(:opa_eligibility_state)
          @opa_eligible = args[:opa_eligible] if args.key?(:opa_eligible)
          @sdk_version = args[:sdk_version] if args.key?(:sdk_version)
          @speaker_id_model_present = args[:speaker_id_model_present] if args.key?(:speaker_id_model_present)
          @speaker_id_recognition_enabled = args[:speaker_id_recognition_enabled] if args.key?(:speaker_id_recognition_enabled)
          @trusted_voice_enabled = args[:trusted_voice_enabled] if args.key?(:trusted_voice_enabled)
          @unlock_with_hotword_available = args[:unlock_with_hotword_available] if args.key?(:unlock_with_hotword_available)
          @user_migrated_to_declined = args[:user_migrated_to_declined] if args.key?(:user_migrated_to_declined)
          @voice_match_setting = args[:voice_match_setting] if args.key?(:voice_match_setting)
        end
      end
      
      # 
      class AssistantApiSettingsTetheredInfo
        include Google::Apis::Core::Hashable
      
        # The host this wearable is tethered to (e.g. phone). When host is AGSA then
        # this is agsa_client_instance_id. When host is IOPA then this is
        # opa_ios_device_id.
        # Corresponds to the JSON property `primaryHostDeviceId`
        # @return [String]
        attr_accessor :primary_host_device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @primary_host_device_id = args[:primary_host_device_id] if args.key?(:primary_host_device_id)
        end
      end
      
      # Specification of which third party apps can be used.
      class AssistantApiSettingsThirdPartyAppsFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Specification of which video features can be used.
      class AssistantApiSettingsVideoFilter
        include Google::Apis::Core::Hashable
      
        # State that indicates whether autoplay is enabled for youtube videos.
        # Corresponds to the JSON property `autoplayToggleState`
        # @return [String]
        attr_accessor :autoplay_toggle_state
      
        # Providers available at the time user updated settings.
        # Corresponds to the JSON property `availableProviders`
        # @return [Array<String>]
        attr_accessor :available_providers
      
        # Represents the state for the video provider filter.
        # Corresponds to the JSON property `providerFilterState`
        # @return [String]
        attr_accessor :provider_filter_state
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # Contains the list of whitelisted video providers.
        # Corresponds to the JSON property `whitelistedProviders`
        # @return [Array<String>]
        attr_accessor :whitelisted_providers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @autoplay_toggle_state = args[:autoplay_toggle_state] if args.key?(:autoplay_toggle_state)
          @available_providers = args[:available_providers] if args.key?(:available_providers)
          @provider_filter_state = args[:provider_filter_state] if args.key?(:provider_filter_state)
          @state = args[:state] if args.key?(:state)
          @whitelisted_providers = args[:whitelisted_providers] if args.key?(:whitelisted_providers)
        end
      end
      
      # Specification of which webview features can be used.
      class AssistantApiSettingsWebviewFilter
        include Google::Apis::Core::Hashable
      
        # Indicates if user has consented Jasper warning message.
        # Corresponds to the JSON property `jasperWebviewConsent`
        # @return [Boolean]
        attr_accessor :jasper_webview_consent
        alias_method :jasper_webview_consent?, :jasper_webview_consent
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @jasper_webview_consent = args[:jasper_webview_consent] if args.key?(:jasper_webview_consent)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # The method of sign in which the client supports.
      class AssistantApiSignInMethod
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `method`
        # @return [String]
        attr_accessor :method_prop
      
        # Make Google sign-in mandatory for using Google Assistant on the device.
        # Corresponds to the JSON property `signInRequired`
        # @return [Boolean]
        attr_accessor :sign_in_required
        alias_method :sign_in_required?, :sign_in_required
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @method_prop = args[:method_prop] if args.key?(:method_prop)
          @sign_in_required = args[:sign_in_required] if args.key?(:sign_in_required)
        end
      end
      
      # Capabilities related to SODA (Speech On-Device API). Next ID: 5
      class AssistantApiSodaCapabilities
        include Google::Apis::Core::Hashable
      
        # Whether the device supports different levels of hotword sensitivity. go/
        # hotword-sensitivity-prd
        # Corresponds to the JSON property `supportsHotwordSensitivity`
        # @return [Boolean]
        attr_accessor :supports_hotword_sensitivity
        alias_method :supports_hotword_sensitivity?, :supports_hotword_sensitivity
      
        # Whether Simple Stop (go/simple-stop) is enabled on the device. Simple stop
        # allows users to stop firing alarms and timers by just saying "stop" without
        # first saying the hotword.
        # Corresponds to the JSON property `supportsSimpleStop`
        # @return [Boolean]
        attr_accessor :supports_simple_stop
        alias_method :supports_simple_stop?, :supports_simple_stop
      
        # Whether the device supports speaker-id (speaker identification based on
        # hotword and/or spoken query - go/speaker-id). Note: there are existing devices
        # that support speaker-id but does not have this capability set. Not having this
        # field populated doesn't necessarily mean the device doesn't support speaker-id.
        # Corresponds to the JSON property `supportsSpeakerId`
        # @return [Boolean]
        attr_accessor :supports_speaker_id
        alias_method :supports_speaker_id?, :supports_speaker_id
      
        # Whether the device supports WarmWords (go/warm-words-framework).
        # Corresponds to the JSON property `supportsWarmWords`
        # @return [Boolean]
        attr_accessor :supports_warm_words
        alias_method :supports_warm_words?, :supports_warm_words
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supports_hotword_sensitivity = args[:supports_hotword_sensitivity] if args.key?(:supports_hotword_sensitivity)
          @supports_simple_stop = args[:supports_simple_stop] if args.key?(:supports_simple_stop)
          @supports_speaker_id = args[:supports_speaker_id] if args.key?(:supports_speaker_id)
          @supports_warm_words = args[:supports_warm_words] if args.key?(:supports_warm_words)
        end
      end
      
      # These capabilities represent what software features the client supports. This
      # should be determined based on the client's various software versions (OS, GSA
      # version, etc). Next ID: 26
      class AssistantApiSoftwareCapabilities
        include Google::Apis::Core::Hashable
      
        # IMPORTANT: Only one of AppCapabilities and AppCapabilitiesDelta should be in
        # the SoftwareCapabilities. In the edge case if the client sends up both
        # AppCapabilities and AppCapabilitiesDelta, AppCapabilitiesDelta is ignored.
        # Complete list of app capabilities.
        # Corresponds to the JSON property `appCapabilities`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiAppCapabilities>]
        attr_accessor :app_capabilities
      
        # Incremental update for app capabilities.
        # Corresponds to the JSON property `appCapabilitiesDelta`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiAppCapabilitiesDelta>]
        attr_accessor :app_capabilities_delta
      
        # App integrations settings for each packge name.
        # Corresponds to the JSON property `appIntegrationsSettings`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantApiAppIntegrationsSettings>]
        attr_accessor :app_integrations_settings
      
        # Capabilities that are associated with Assistants on auto surfaces. This is
        # different from other capabilities such as CarSettingsCapabilities,
        # CloudCarCapabilities since they are specific to settings and 3P cloud
        # information. All the auto/car Assistant specific capabilities should live here.
        # Corresponds to the JSON property `carAssistantCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCarAssistantCapabilities]
        attr_accessor :car_assistant_capabilities
      
        # Used to describe clock capabilities of the device (for example, capabilities
        # related to maximum number of supported alarms and timers that can be created
        # on the device). Fields may be populated by clients or be backfilled by SAL (in
        # case of Timon, for example).
        # Corresponds to the JSON property `clockCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiClockCapabilities]
        attr_accessor :clock_capabilities
      
        # The overall Conversation Protocol version. As we make fundamental changes to
        # Conversation protocol that are non-backwards compatible, we will increment the
        # protocol version. By default, all clients will support version 0. All versions
        # are documented at go/conversation-versions.
        # Corresponds to the JSON property `conversationVersion`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSupportedConversationVersion]
        attr_accessor :conversation_version
      
        # For torus x-device execution support
        # Corresponds to the JSON property `crossDeviceExecutionCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCrossDeviceExecutionCapability]
        attr_accessor :cross_device_execution_capabilities
      
        # Capabilities of Google assistant conversation service(GACS) devices. These
        # capabilites including supported GACS actions and response size limitations.
        # Corresponds to the JSON property `gacsCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiGacsCapabilities]
        attr_accessor :gacs_capabilities
      
        # Capabilities related to GCM.
        # Corresponds to the JSON property `gcmCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiGcmCapabilities]
        attr_accessor :gcm_capabilities
      
        # Capabilities related to live TV channels.
        # Corresponds to the JSON property `liveTvChannelCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiLiveTvChannelCapabilities]
        attr_accessor :live_tv_channel_capabilities
      
        # Encapsulates the action capabilities of the OEM device. This data is merged
        # from Device Model lookup, per-device registration, and per-request context.
        # This data is sent to NLU layer for query understanding.
        # Corresponds to the JSON property `oemCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiOemCapabilities]
        attr_accessor :oem_capabilities
      
        # Definitions of on-device assistant capabilities.
        # Corresponds to the JSON property `onDeviceAssistantCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiOnDeviceAssistantCapabilities]
        attr_accessor :on_device_assistant_capabilities
      
        # Definitions of on-device Smart Home capabilities. Next ID: 2
        # Corresponds to the JSON property `onDeviceSmartHomeCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiOnDeviceSmartHomeCapabilities]
        attr_accessor :on_device_smart_home_capabilities
      
        # The on-device storage capabilities found on the device.
        # Corresponds to the JSON property `onDeviceStorageCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiOnDeviceStorageCapabilities]
        attr_accessor :on_device_storage_capabilities
      
        # The operating system of the device.
        # Corresponds to the JSON property `operatingSystem`
        # @return [String]
        attr_accessor :operating_system
      
        # An ordered list containing the live tv providers available in the client. The
        # order of the providers reflects the ranking in the client and will be
        # respected by server as well.
        # Corresponds to the JSON property `orderedLiveTvProviders`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiLiveTvProvider>]
        attr_accessor :ordered_live_tv_providers
      
        # The Soli capabilities on Elaine, including gestures and sleep sensing. go/
        # dingo-dc-software Next ID: 4
        # Corresponds to the JSON property `selinaCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSelinaCapabilites]
        attr_accessor :selina_capabilities
      
        # These capabilties are associated with Assistant Settings on devices.
        # Corresponds to the JSON property `settingsAppCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsAppCapabilities]
        attr_accessor :settings_app_capabilities
      
        # 
        # Corresponds to the JSON property `supportedClientOp`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSupportedClientOp>]
        attr_accessor :supported_client_op
      
        # These are the set of features that are supported by the device. It's a part of
        # the SoftwareCapabilities of the device. Next ID: 62
        # Corresponds to the JSON property `supportedFeatures`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSupportedFeatures]
        attr_accessor :supported_features
      
        # Contains versions of protocol buffer messages. This is the equivalence of a
        # proto3 map, keyed by a protocol buffer message’s name, and the value is the
        # version of this message. e.g. `"assistant.api.core_types.Timer": 2, "assistant.
        # api.core_types.Alarm": 1` See go/assistant-protocol-versioning for more
        # details.
        # Corresponds to the JSON property `supportedMsgVersion`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSupportedProtocolVersion]
        attr_accessor :supported_msg_version
      
        # Types of providers that are supported by the client. For example, ChromeOS
        # support both web app and Android app (for eligible devices).
        # Corresponds to the JSON property `supportedProviderTypes`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSupportedProviderTypes]
        attr_accessor :supported_provider_types
      
        # Properties of the surface that are not hardware related or feature specific.
        # Corresponds to the JSON property `surfaceProperties`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSurfaceProperties]
        attr_accessor :surface_properties
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_capabilities = args[:app_capabilities] if args.key?(:app_capabilities)
          @app_capabilities_delta = args[:app_capabilities_delta] if args.key?(:app_capabilities_delta)
          @app_integrations_settings = args[:app_integrations_settings] if args.key?(:app_integrations_settings)
          @car_assistant_capabilities = args[:car_assistant_capabilities] if args.key?(:car_assistant_capabilities)
          @clock_capabilities = args[:clock_capabilities] if args.key?(:clock_capabilities)
          @conversation_version = args[:conversation_version] if args.key?(:conversation_version)
          @cross_device_execution_capabilities = args[:cross_device_execution_capabilities] if args.key?(:cross_device_execution_capabilities)
          @gacs_capabilities = args[:gacs_capabilities] if args.key?(:gacs_capabilities)
          @gcm_capabilities = args[:gcm_capabilities] if args.key?(:gcm_capabilities)
          @live_tv_channel_capabilities = args[:live_tv_channel_capabilities] if args.key?(:live_tv_channel_capabilities)
          @oem_capabilities = args[:oem_capabilities] if args.key?(:oem_capabilities)
          @on_device_assistant_capabilities = args[:on_device_assistant_capabilities] if args.key?(:on_device_assistant_capabilities)
          @on_device_smart_home_capabilities = args[:on_device_smart_home_capabilities] if args.key?(:on_device_smart_home_capabilities)
          @on_device_storage_capabilities = args[:on_device_storage_capabilities] if args.key?(:on_device_storage_capabilities)
          @operating_system = args[:operating_system] if args.key?(:operating_system)
          @ordered_live_tv_providers = args[:ordered_live_tv_providers] if args.key?(:ordered_live_tv_providers)
          @selina_capabilities = args[:selina_capabilities] if args.key?(:selina_capabilities)
          @settings_app_capabilities = args[:settings_app_capabilities] if args.key?(:settings_app_capabilities)
          @supported_client_op = args[:supported_client_op] if args.key?(:supported_client_op)
          @supported_features = args[:supported_features] if args.key?(:supported_features)
          @supported_msg_version = args[:supported_msg_version] if args.key?(:supported_msg_version)
          @supported_provider_types = args[:supported_provider_types] if args.key?(:supported_provider_types)
          @surface_properties = args[:surface_properties] if args.key?(:surface_properties)
        end
      end
      
      # DEPRECATED These capabilties are associated with speech detection on devices.
      class AssistantApiSpeechCapabilities
        include Google::Apis::Core::Hashable
      
        # A bool indicating whether device supports dsp based hotword detection.
        # Corresponds to the JSON property `dspAvailable`
        # @return [Boolean]
        attr_accessor :dsp_available
        alias_method :dsp_available?, :dsp_available
      
        # A bool indicating whether device supports unlocking device with hotword.
        # Corresponds to the JSON property `unlockWithHotwordAvailable`
        # @return [Boolean]
        attr_accessor :unlock_with_hotword_available
        alias_method :unlock_with_hotword_available?, :unlock_with_hotword_available
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dsp_available = args[:dsp_available] if args.key?(:dsp_available)
          @unlock_with_hotword_available = args[:unlock_with_hotword_available] if args.key?(:unlock_with_hotword_available)
        end
      end
      
      # Next ID: 17
      class AssistantApiSuggestionsSupport
        include Google::Apis::Core::Hashable
      
        # Whether client supports user impersonation on suggestion chip click. go/
        # suggestion-click-impersonation
        # Corresponds to the JSON property `clickImpersonationSupported`
        # @return [Boolean]
        attr_accessor :click_impersonation_supported
        alias_method :click_impersonation_supported?, :click_impersonation_supported
      
        # Whether client supports suggestion chips with colored background/border.
        # Corresponds to the JSON property `coloredChipBackgroundBorderSupported`
        # @return [Boolean]
        attr_accessor :colored_chip_background_border_supported
        alias_method :colored_chip_background_border_supported?, :colored_chip_background_border_supported
      
        # Whether client supports suggestion chips with colored text. See design doc:
        # http://go/opa-suggestions-ux-eng-design.
        # Corresponds to the JSON property `coloredChipTextSupported`
        # @return [Boolean]
        attr_accessor :colored_chip_text_supported
        alias_method :colored_chip_text_supported?, :colored_chip_text_supported
      
        # Whether client supports suggestions debug data to be displayed.
        # Corresponds to the JSON property `debugDataSupported`
        # @return [Boolean]
        attr_accessor :debug_data_supported
        alias_method :debug_data_supported?, :debug_data_supported
      
        # Whether DRL history chip is supported. Related bug: http://b/241837879, http://
        # b/171854732 Design doc: http://go/panthera-history-chip-dd DRL history chip
        # was originally rolled out to Panthera in http://google3/googledata/experiments/
        # mobile/agsa/studies/agsa_nga/opa_panthera_one_input_ui_launch.gcl?l=55&rcl=
        # 384682900. We plan to roll it out to NGA and TNG. drl_history_chip_supported
        # bit specifies whether the client support (and should have) DRL history chip.
        # Corresponds to the JSON property `drlHistoryChipSupported`
        # @return [Boolean]
        attr_accessor :drl_history_chip_supported
        alias_method :drl_history_chip_supported?, :drl_history_chip_supported
      
        # Whether client supports escape hatches aka post execution suggestions go/nga-
        # escape-hatch-prd
        # Corresponds to the JSON property `escapeHatchSupported`
        # @return [String]
        attr_accessor :escape_hatch_supported
      
        # Whether the client can rewrite suggestion query text into executed text, if
        # the latter is present. If this feature is disabled, the rewrite happens in
        # Assistant Server.
        # Corresponds to the JSON property `executedTextSupported`
        # @return [Boolean]
        attr_accessor :executed_text_supported
        alias_method :executed_text_supported?, :executed_text_supported
      
        # Whether the client supports passing back `execution_context` from |assistant.
        # api.client_op.SuggestionProcessingParams| when the suggestion is clicked or
        # spoken.
        # Corresponds to the JSON property `executionContextSupported`
        # @return [Boolean]
        attr_accessor :execution_context_supported
        alias_method :execution_context_supported?, :execution_context_supported
      
        # Whether the client supports features in |SuggestionFeatureSpecificAction|.
        # Corresponds to the JSON property `featureSpecificActionSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiFeatureSpecificActionSupport]
        attr_accessor :feature_specific_action_support
      
        # Whether the client supports handling App Actions' notification when the
        # suggestion is clicked. This will allow the server to populate the `
        # app_actions_notification_data` extension field from |
        # SuggestionFeatureSpecificAction| proto message.
        # Corresponds to the JSON property `featureSpecificAppActionsNotificationSupported`
        # @return [Boolean]
        attr_accessor :feature_specific_app_actions_notification_supported
        alias_method :feature_specific_app_actions_notification_supported?, :feature_specific_app_actions_notification_supported
      
        # Whether the rule_id field in the execution_context is supported. This is a
        # temporary workaround to be able to identify clicks on Person entity
        # suggestions on Sabrina and is expected to be eventually deprecated. TODO(b/
        # 185517153) : Deprecate (but do not delete) once click tracking is correctly
        # sent up from the Katniss client.
        # Corresponds to the JSON property `ruleIdInExecutionContextSupported`
        # @return [Boolean]
        attr_accessor :rule_id_in_execution_context_supported
        alias_method :rule_id_in_execution_context_supported?, :rule_id_in_execution_context_supported
      
        # Whether the client can show executed_text after the click on the suggestion
        # chip. Must be set to false on TNG. TNG disregards |SuggestionProcessingParams.
        # show_executed_text| field and always treats it as if |show_executed_text=true|.
        # Corresponds to the JSON property `showExecutedTextSupported`
        # @return [Boolean]
        attr_accessor :show_executed_text_supported
        alias_method :show_executed_text_supported?, :show_executed_text_supported
      
        # Whether the client can show chip as (text | translation). go/lang-partner-doc
        # Corresponds to the JSON property `showTranslationSupported`
        # @return [Boolean]
        attr_accessor :show_translation_supported
        alias_method :show_translation_supported?, :show_translation_supported
      
        # A list of suggestions display targets supported by this client. If unset only
        # DEFAULT SuggestionDisplayTarget is supported.
        # Corresponds to the JSON property `supportedDisplayTargets`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSuggestionsSupportDisplayTargetSupport>]
        attr_accessor :supported_display_targets
      
        # Whether client supports widget suggestion chip to be displayed.
        # Corresponds to the JSON property `widgetDataSupported`
        # @return [Boolean]
        attr_accessor :widget_data_supported
        alias_method :widget_data_supported?, :widget_data_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @click_impersonation_supported = args[:click_impersonation_supported] if args.key?(:click_impersonation_supported)
          @colored_chip_background_border_supported = args[:colored_chip_background_border_supported] if args.key?(:colored_chip_background_border_supported)
          @colored_chip_text_supported = args[:colored_chip_text_supported] if args.key?(:colored_chip_text_supported)
          @debug_data_supported = args[:debug_data_supported] if args.key?(:debug_data_supported)
          @drl_history_chip_supported = args[:drl_history_chip_supported] if args.key?(:drl_history_chip_supported)
          @escape_hatch_supported = args[:escape_hatch_supported] if args.key?(:escape_hatch_supported)
          @executed_text_supported = args[:executed_text_supported] if args.key?(:executed_text_supported)
          @execution_context_supported = args[:execution_context_supported] if args.key?(:execution_context_supported)
          @feature_specific_action_support = args[:feature_specific_action_support] if args.key?(:feature_specific_action_support)
          @feature_specific_app_actions_notification_supported = args[:feature_specific_app_actions_notification_supported] if args.key?(:feature_specific_app_actions_notification_supported)
          @rule_id_in_execution_context_supported = args[:rule_id_in_execution_context_supported] if args.key?(:rule_id_in_execution_context_supported)
          @show_executed_text_supported = args[:show_executed_text_supported] if args.key?(:show_executed_text_supported)
          @show_translation_supported = args[:show_translation_supported] if args.key?(:show_translation_supported)
          @supported_display_targets = args[:supported_display_targets] if args.key?(:supported_display_targets)
          @widget_data_supported = args[:widget_data_supported] if args.key?(:widget_data_supported)
        end
      end
      
      # 
      class AssistantApiSuggestionsSupportDisplayTargetSupport
        include Google::Apis::Core::Hashable
      
        # Whether the client can rewrite suggestion query text into executed text, if
        # the latter is present for the display target.
        # Corresponds to the JSON property `executedTextSupported`
        # @return [Boolean]
        attr_accessor :executed_text_supported
        alias_method :executed_text_supported?, :executed_text_supported
      
        # Whether PresentationParams.header_text is supported for the display target.
        # Corresponds to the JSON property `headerTextSupported`
        # @return [Boolean]
        attr_accessor :header_text_supported
        alias_method :header_text_supported?, :header_text_supported
      
        # Whether Suggestion.repress_impression is supported. If not repressed
        # suggestions are not returned.
        # Corresponds to the JSON property `repressImpressionSupported`
        # @return [Boolean]
        attr_accessor :repress_impression_supported
        alias_method :repress_impression_supported?, :repress_impression_supported
      
        # Display target that is supported.
        # Corresponds to the JSON property `target`
        # @return [String]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @executed_text_supported = args[:executed_text_supported] if args.key?(:executed_text_supported)
          @header_text_supported = args[:header_text_supported] if args.key?(:header_text_supported)
          @repress_impression_supported = args[:repress_impression_supported] if args.key?(:repress_impression_supported)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # 
      class AssistantApiSunriseFeaturesSupport
        include Google::Apis::Core::Hashable
      
        # If true, the device can slowly brighten the screen and simulate sunrise
        # experience. Alarms with sunrise field enabled can be set on this device.
        # Corresponds to the JSON property `sunriseSimulationSupported`
        # @return [Boolean]
        attr_accessor :sunrise_simulation_supported
        alias_method :sunrise_simulation_supported?, :sunrise_simulation_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @sunrise_simulation_supported = args[:sunrise_simulation_supported] if args.key?(:sunrise_simulation_supported)
        end
      end
      
      # These are the set of ClientOps that are supported by the device.
      class AssistantApiSupportedClientOp
        include Google::Apis::Core::Hashable
      
        # This should be the same as the name of the SemanticClientOp that is supported.
        # Corresponds to the JSON property `clientOpName`
        # @return [String]
        attr_accessor :client_op_name
      
        # Also known as "Extensions Without Extensions" or "The Poor Man's Any", this
        # simple proto is used to transmit arbitrary protocol buffers over the wire.
        # Unlike extensions: - It does not require the proto type to be compiled into
        # the binary. (Useful so that the proto declaration can be inside the
        # conversation package) - It is compatible with all versions of proto, including
        # proto3 and the wack-tastic version used on ChromecastOS. Server libraries for
        # dealing with it live in google3/assistant/protocol/protobuf_lib.h.
        # Corresponds to the JSON property `clientOpProperties`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiProtobuf]
        attr_accessor :client_op_properties
      
        # Additional properties that client can support for executing the client op.
        # Corresponds to the JSON property `supportedExecution`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSupportedClientOpSupportedExecution]
        attr_accessor :supported_execution
      
        # A version of 0 is the equivalent to not having support for that client_op type.
        # Note that a client_op is also unsupported if it is not included at all in the
        # list of supported client_ops.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_op_name = args[:client_op_name] if args.key?(:client_op_name)
          @client_op_properties = args[:client_op_properties] if args.key?(:client_op_properties)
          @supported_execution = args[:supported_execution] if args.key?(:supported_execution)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Additional properties that client can support for executing the client op.
      class AssistantApiSupportedClientOpSupportedExecution
        include Google::Apis::Core::Hashable
      
        # Client can support synchronous execution of the client op. For tts.OUTPUT
        # client op it means that client would honor |synchronous_playback_args|
        # argument. Please see more at go/synchronous-sounds-design.
        # Corresponds to the JSON property `supportsSynchronousExecution`
        # @return [Boolean]
        attr_accessor :supports_synchronous_execution
        alias_method :supports_synchronous_execution?, :supports_synchronous_execution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supports_synchronous_execution = args[:supports_synchronous_execution] if args.key?(:supports_synchronous_execution)
        end
      end
      
      # The overall Conversation Protocol version. As we make fundamental changes to
      # Conversation protocol that are non-backwards compatible, we will increment the
      # protocol version. By default, all clients will support version 0. All versions
      # are documented at go/conversation-versions.
      class AssistantApiSupportedConversationVersion
        include Google::Apis::Core::Hashable
      
        # Whether conversation protocol is supported explicitly. If true,
        # SingleDeviceCapabilityChecker::SupportsConversationProtocol will always return
        # true.
        # Corresponds to the JSON property `supportsConversationProtocol`
        # @return [Boolean]
        attr_accessor :supports_conversation_protocol
        alias_method :supports_conversation_protocol?, :supports_conversation_protocol
      
        # The supported version number.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supports_conversation_protocol = args[:supports_conversation_protocol] if args.key?(:supports_conversation_protocol)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # These are the set of features that are supported by the device. It's a part of
      # the SoftwareCapabilities of the device. Next ID: 62
      class AssistantApiSupportedFeatures
        include Google::Apis::Core::Hashable
      
        # Whether the client supports the alternative message notification sources on
        # AAE, in which case notification-related operations can access it.
        # Corresponds to the JSON property `aaeNotificationSourceSupported`
        # @return [Boolean]
        attr_accessor :aae_notification_source_supported
        alias_method :aae_notification_source_supported?, :aae_notification_source_supported
      
        # In what way is assistant continued presence supported. (go/opa-acp-prd)
        # Corresponds to the JSON property `acpSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAssistantContinuedPresenceSupport]
        attr_accessor :acp_support
      
        # The features supported by the ActionV2 protocol. Note that after we move on to
        # ConversationProto for all surfaces we can remove this message.
        # Corresponds to the JSON property `actionV2SupportedFeatures`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiActionV2SupportedFeatures]
        attr_accessor :action_v2_supported_features
      
        # Whether the client supports AlarmTimerManager API (go/alarm-timer-manager-api).
        # Corresponds to the JSON property `alarmTimerManagerApiSupported`
        # @return [Boolean]
        attr_accessor :alarm_timer_manager_api_supported
        alias_method :alarm_timer_manager_api_supported?, :alarm_timer_manager_api_supported
      
        # The client information for app control support. More details in: go/acaia.
        # Corresponds to the JSON property `appControlSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiAppControlSupport]
        attr_accessor :app_control_support
      
        # Whether the client supports the assistant explore section. This field will be
        # active only when the Explore section is available to the user. This means that
        # the user is (a) signed-in, (b) a IOPA / AGSA user, and (c) in a locale where
        # explore is available.
        # Corresponds to the JSON property `assistantExploreSupported`
        # @return [Boolean]
        attr_accessor :assistant_explore_supported
        alias_method :assistant_explore_supported?, :assistant_explore_supported
      
        # Whether Assistant for Kids (a.k.a. Designed for Family) features are supported.
        # Corresponds to the JSON property `assistantForKidsSupported`
        # @return [Boolean]
        attr_accessor :assistant_for_kids_supported
        alias_method :assistant_for_kids_supported?, :assistant_for_kids_supported
      
        # Whether communications flows for the client can bypass the DI/DC check. The
        # client will enforce some other equivalent permission as necessary concerning
        # access to device contacts and apps.
        # Corresponds to the JSON property `bypassDiDcCheckForComms`
        # @return [Boolean]
        attr_accessor :bypass_di_dc_check_for_comms
        alias_method :bypass_di_dc_check_for_comms?, :bypass_di_dc_check_for_comms
      
        # Whether or not Assistant should enforce the dismissal of communication
        # notifications associated with messages.
        # Corresponds to the JSON property `bypassMsgNotificationDismissal`
        # @return [Boolean]
        attr_accessor :bypass_msg_notification_dismissal
        alias_method :bypass_msg_notification_dismissal?, :bypass_msg_notification_dismissal
      
        # Whether the client supports 1m providers (go/1m-partner-expansion).
        # Corresponds to the JSON property `client1mProvidersSupported`
        # @return [Boolean]
        attr_accessor :client1m_providers_supported
        alias_method :client1m_providers_supported?, :client1m_providers_supported
      
        # Whether the client can batch client op results before sending them to the
        # server.
        # Corresponds to the JSON property `clientOpResultBatchingSupported`
        # @return [Boolean]
        attr_accessor :client_op_result_batching_supported
        alias_method :client_op_result_batching_supported?, :client_op_result_batching_supported
      
        # Whether the client supports cross-device broadcast (i.e. on Torus).
        # Corresponds to the JSON property `crossDeviceBroadcastSupported`
        # @return [Boolean]
        attr_accessor :cross_device_broadcast_supported
        alias_method :cross_device_broadcast_supported?, :cross_device_broadcast_supported
      
        # The version of cross device broadcast (ie; broadcast on torus) which the
        # client supports.
        # Corresponds to the JSON property `crossDeviceBroadcastVersion`
        # @return [String]
        attr_accessor :cross_device_broadcast_version
      
        # Whether the client supports csat visual overlay. (go/sd-od-csat)
        # Corresponds to the JSON property `csatVisualOverlaySupported`
        # @return [Boolean]
        attr_accessor :csat_visual_overlay_supported
        alias_method :csat_visual_overlay_supported?, :csat_visual_overlay_supported
      
        # The features set which duo client on the device supports. This should be
        # serialized from proto `@code duo_client_api.DuoClientApiFeatures`.
        # Corresponds to the JSON property `duoClientApiFeatures`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :duo_client_api_features
      
        # Whether the client supports Duo group calling.
        # Corresponds to the JSON property `duoGroupCallingSupported`
        # @return [Boolean]
        attr_accessor :duo_group_calling_supported
        alias_method :duo_group_calling_supported?, :duo_group_calling_supported
      
        # Information about what support this device has for fitness.
        # Corresponds to the JSON property `fitnessFeatureSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiFitnessFeatureSupport]
        attr_accessor :fitness_feature_support
      
        # Fluid Actions features supported by the client. If this field is not set in
        # the incoming request, it could mean that the client does not support Fluid
        # Actions. Alternatively, it could mean that the client supports Fluid Actions,
        # but syncs state with server using the old protocol, namely
        # ConversationStateParams. When b/140733618 is resolved, Surface Adaptation
        # Layer will add this field for old clients that support Fluid Actions framework.
        # Corresponds to the JSON property `fluidActionsSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiFluidActionsSupport]
        attr_accessor :fluid_actions_support
      
        # Whether the surface client op performer supports Funtime alarms and timers. go/
        # funtime-engdesign
        # Corresponds to the JSON property `funtimeSupported`
        # @return [Boolean]
        attr_accessor :funtime_supported
        alias_method :funtime_supported?, :funtime_supported
      
        # Whether account linking via Google Deep Integrations (GDI) is supported. go/
        # opa-gdi-design
        # Corresponds to the JSON property `gdiSupported`
        # @return [Boolean]
        attr_accessor :gdi_supported
        alias_method :gdi_supported?, :gdi_supported
      
        # Whether the client supports the Gearhead message notification source, in which
        # case notification-related operations can access it.
        # Corresponds to the JSON property `gearheadNotificationSourceSupported`
        # @return [Boolean]
        attr_accessor :gearhead_notification_source_supported
        alias_method :gearhead_notification_source_supported?, :gearhead_notification_source_supported
      
        # Whether the client has a physical radio installed.
        # Corresponds to the JSON property `hasPhysicalRadio`
        # @return [Boolean]
        attr_accessor :has_physical_radio
        alias_method :has_physical_radio?, :has_physical_radio
      
        # Whether the client supports confirmation messages in Immersive Canvas actions.
        # Deprecated: use the filed in immersive_canvas_support.
        # Corresponds to the JSON property `immersiveCanvasConfirmationMessageSupported`
        # @return [Boolean]
        attr_accessor :immersive_canvas_confirmation_message_supported
        alias_method :immersive_canvas_confirmation_message_supported?, :immersive_canvas_confirmation_message_supported
      
        # 
        # Corresponds to the JSON property `immersiveCanvasSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiImmersiveCanvasSupport]
        attr_accessor :immersive_canvas_support
      
        # Whether the client supports account linking in-dialog (askForSignIn). This is
        # used before this feature is moved to conversation protocol. To support this,
        # the client needs to: - Integrate with Google Deep Integrations. - Have logic
        # to send the result of account linking back to AS.
        # Corresponds to the JSON property `inDialogAccountLinkingSupported`
        # @return [Boolean]
        attr_accessor :in_dialog_account_linking_supported
        alias_method :in_dialog_account_linking_supported?, :in_dialog_account_linking_supported
      
        # Whether paired-phone contact upload is needed for communications queries to
        # work (e.g. on AAE).
        # Corresponds to the JSON property `isPairedPhoneContactUploadNeededForComms`
        # @return [Boolean]
        attr_accessor :is_paired_phone_contact_upload_needed_for_comms
        alias_method :is_paired_phone_contact_upload_needed_for_comms?, :is_paired_phone_contact_upload_needed_for_comms
      
        # Whether a Bluetooth-paired phone is a core component of communications flows
        # on the client.
        # Corresponds to the JSON property `isPairedPhoneNeededForComms`
        # @return [Boolean]
        attr_accessor :is_paired_phone_needed_for_comms
        alias_method :is_paired_phone_needed_for_comms?, :is_paired_phone_needed_for_comms
      
        # Which way of launching the keyboard the client supports.
        # Corresponds to the JSON property `launchKeyboardSupported`
        # @return [String]
        attr_accessor :launch_keyboard_supported
      
        # Whether the client has Google Lens (Assistant Eyes).
        # Corresponds to the JSON property `lensSupported`
        # @return [Boolean]
        attr_accessor :lens_supported
        alias_method :lens_supported?, :lens_supported
      
        # Whether the surface supports LiveCards. In cases where the user intent flow
        # cannot be completed within the Assistant, LiveCards are used to take the user
        # to an external app or website. These cards will be pushed to the Google Home
        # app via the PushMessage ClientOp.
        # Corresponds to the JSON property `liveCardsSupported`
        # @return [Boolean]
        attr_accessor :live_cards_supported
        alias_method :live_cards_supported?, :live_cards_supported
      
        # Whether the client supports Assistant dialogs within Maps. This field will be
        # set only when the Maps on the surface supports Assistant dialogs embedded
        # within Maps. go/gsa-gmm.
        # Corresponds to the JSON property `mapsDialogsSupported`
        # @return [Boolean]
        attr_accessor :maps_dialogs_supported
        alias_method :maps_dialogs_supported?, :maps_dialogs_supported
      
        # Whether the device supports masquerade mode (go/masquerade).
        # Corresponds to the JSON property `masqueradeModeSupported`
        # @return [Boolean]
        attr_accessor :masquerade_mode_supported
        alias_method :masquerade_mode_supported?, :masquerade_mode_supported
      
        # Information about how client handles media controls (play, pause, skip ...)
        # Corresponds to the JSON property `mediaControlSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiMediaControlSupport]
        attr_accessor :media_control_support
      
        # The ability of the client to detect media sessions on the device.
        # Corresponds to the JSON property `mediaSessionDetection`
        # @return [String]
        attr_accessor :media_session_detection
      
        # Whether the client supports joining a Google Meet meeting.
        # Corresponds to the JSON property `meetSupported`
        # @return [Boolean]
        attr_accessor :meet_supported
        alias_method :meet_supported?, :meet_supported
      
        # Whether the client can render no input response or just ignore it. No input
        # response is returned when client has a no speech input interaction, eg. user
        # tapped mic but didn't say anything.
        # Corresponds to the JSON property `noInputResponseSupported`
        # @return [Boolean]
        attr_accessor :no_input_response_supported
        alias_method :no_input_response_supported?, :no_input_response_supported
      
        # When the entry source is search, whether the client supports rendering a
        # similar response as OPA one does. Entry source is defined at http://cs/symbol:
        # assistant.api.params.DeviceProperties.EntrySource
        # Corresponds to the JSON property `opaOnSearchSupported`
        # @return [Boolean]
        attr_accessor :opa_on_search_supported
        alias_method :opa_on_search_supported?, :opa_on_search_supported
      
        # Whether or not the client supports enabling parental controls. When a device
        # to supports parental controls, it has the software necessary to store the
        # relevant information required for parental controls to work. This information
        # includes a boolean "enabled bit" as well as the obfuscated gaia ID of the kid
        # account selected for use with parental controls. Devices supportings kids mode
        # send this information to S3 via S3ClientInfo in every request. See go/aff-
        # kidsproduct for details.
        # Corresponds to the JSON property `parentalControlsSupported`
        # @return [Boolean]
        attr_accessor :parental_controls_supported
        alias_method :parental_controls_supported?, :parental_controls_supported
      
        # Whether the client supports persistent display. The new feature allows
        # Assistant devices with screen to display a continuously updating permanent
        # display, such as ambient weather, without the need for a user to ask the
        # Assistant. Design doc: go/assistant-persistent-display.
        # Corresponds to the JSON property `persistentDisplaySupported`
        # @return [Boolean]
        attr_accessor :persistent_display_supported
        alias_method :persistent_display_supported?, :persistent_display_supported
      
        # Whether the client supports the privacy-aware lockscreen protocol (go/
        # assistant-lockscreen-spec).
        # Corresponds to the JSON property `privacyAwareLockscreenSupported`
        # @return [Boolean]
        attr_accessor :privacy_aware_lockscreen_supported
        alias_method :privacy_aware_lockscreen_supported?, :privacy_aware_lockscreen_supported
      
        # Whether the client has remote casting enabled. For ex: we want to disable this
        # for clients like Auto.
        # Corresponds to the JSON property `remoteCloudCastingEnabled`
        # @return [Boolean]
        attr_accessor :remote_cloud_casting_enabled
        alias_method :remote_cloud_casting_enabled?, :remote_cloud_casting_enabled
      
        # Whether the Assistant Server should generate feedback suggestion chips.
        # Corresponds to the JSON property `serverGeneratedFeedbackChipsEnabled`
        # @return [Boolean]
        attr_accessor :server_generated_feedback_chips_enabled
        alias_method :server_generated_feedback_chips_enabled?, :server_generated_feedback_chips_enabled
      
        # Whether the client supports SmartHome lock screen logic (i.e. on Tangor).
        # Corresponds to the JSON property `shLockScreenSupported`
        # @return [Boolean]
        attr_accessor :sh_lock_screen_supported
        alias_method :sh_lock_screen_supported?, :sh_lock_screen_supported
      
        # The method of sign in which the client supports.
        # Corresponds to the JSON property `signInMethod`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSignInMethod]
        attr_accessor :sign_in_method
      
        # Whether the client can monitor sleep. This allows us to show sleep CUJ realted
        # information: go/TwilightDesign Use for development only, see the same field in
        # DeviceCapabilities.SoftwareCapabilities.SelinaCapabilities.
        # Corresponds to the JSON property `sleepSensingSupported`
        # @return [Boolean]
        attr_accessor :sleep_sensing_supported
        alias_method :sleep_sensing_supported?, :sleep_sensing_supported
      
        # Whether the client supports smart space cross-device timers. (go/ss-x-device-
        # timer)
        # Corresponds to the JSON property `smartspaceCrossDeviceTimerSupported`
        # @return [Boolean]
        attr_accessor :smartspace_cross_device_timer_supported
        alias_method :smartspace_cross_device_timer_supported?, :smartspace_cross_device_timer_supported
      
        # Whether or not the client supports gesture detection via soli chips. The
        # reason to prepend the name with soli is to distinguish it from computer vision
        # based methods, e.g. Newman devices.
        # Corresponds to the JSON property `soliGestureDetectionSupported`
        # @return [Boolean]
        attr_accessor :soli_gesture_detection_supported
        alias_method :soli_gesture_detection_supported?, :soli_gesture_detection_supported
      
        # Next ID: 17
        # Corresponds to the JSON property `suggestionsSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSuggestionsSupport]
        attr_accessor :suggestions_support
      
        # Whether the client supports the sunrise screen brightening feature before the
        # alarm fires. This is used to indicate whether sunrise alarms can be set on the
        # device. http://cs/symbol:assistant.api.core_types.governed.
        # RingtoneTaskMetadata.GentleWakeInfo
        # Corresponds to the JSON property `sunriseFeaturesSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSunriseFeaturesSupport]
        attr_accessor :sunrise_features_support
      
        # Whether the client supports faster optimization for tap_to_read feature.
        # Corresponds to the JSON property `tapToReadOptimizationSupported`
        # @return [Boolean]
        attr_accessor :tap_to_read_optimization_supported
        alias_method :tap_to_read_optimization_supported?, :tap_to_read_optimization_supported
      
        # Whether the device supports the 3p GUI framework, which allows third parties
        # to enter the conversation with the user, showing their logo next to their chat
        # bubbles, etc. go/3p-phone
        # Corresponds to the JSON property `thirdPartyGuiSupported`
        # @return [Boolean]
        attr_accessor :third_party_gui_supported
        alias_method :third_party_gui_supported?, :third_party_gui_supported
      
        # Transactions features, supported by the client. Transactions feature may
        # includes how Transactions team want to populate additional information from
        # the device to the server.
        # Corresponds to the JSON property `transactionFeaturesSupport`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTransactionFeaturesSupport]
        attr_accessor :transaction_features_support
      
        # The version of transactions which the client supports.
        # Corresponds to the JSON property `transactionsVersion`
        # @return [String]
        attr_accessor :transactions_version
      
        # If set, it indicates that the client can open a separate HTML browser/
        # webviewer (full viewer) to display certain visual results. These visual
        # results usually require more memory to render (e.g. high resolution photos).
        # Compared to the regular viewer that display all other Assistant result, the
        # full viewer does not have memory limit. The field is copied from the device
        # model. See http://google3/assistant/devices_platform/proto/
        # device_model_capabilities.proto?l=225&rcl=312576471 Also see go/webassistant-
        # full-card-viewer.
        # Corresponds to the JSON property `usesSeparateFullViewer`
        # @return [Boolean]
        attr_accessor :uses_separate_full_viewer
        alias_method :uses_separate_full_viewer?, :uses_separate_full_viewer
      
        # Whether the client supports viewing of reminder hub page or not. Default is
        # supported. Set to true to disable returning reminder hub page url in reminder
        # responses.
        # Corresponds to the JSON property `viewReminderHubPageNotSupported`
        # @return [Boolean]
        attr_accessor :view_reminder_hub_page_not_supported
        alias_method :view_reminder_hub_page_not_supported?, :view_reminder_hub_page_not_supported
      
        # Whether the client supports the programmatic warm welcome tutorial. Design doc:
        # go/opal-pww-design.
        # Corresponds to the JSON property `warmWelcomeTutorialSupported`
        # @return [Boolean]
        attr_accessor :warm_welcome_tutorial_supported
        alias_method :warm_welcome_tutorial_supported?, :warm_welcome_tutorial_supported
      
        # Whether the supports opening a URL in a web browser. For example, we want to
        # disable this for clients like Chirp.
        # Corresponds to the JSON property `webBrowserSupported`
        # @return [Boolean]
        attr_accessor :web_browser_supported
        alias_method :web_browser_supported?, :web_browser_supported
      
        # Whether or not the client supports WhatsNext in the protocol.
        # Corresponds to the JSON property `whatsNextSupported`
        # @return [Boolean]
        attr_accessor :whats_next_supported
        alias_method :whats_next_supported?, :whats_next_supported
      
        # Whether the client supports joining a Zoom meeting.
        # Corresponds to the JSON property `zoomSupported`
        # @return [Boolean]
        attr_accessor :zoom_supported
        alias_method :zoom_supported?, :zoom_supported
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aae_notification_source_supported = args[:aae_notification_source_supported] if args.key?(:aae_notification_source_supported)
          @acp_support = args[:acp_support] if args.key?(:acp_support)
          @action_v2_supported_features = args[:action_v2_supported_features] if args.key?(:action_v2_supported_features)
          @alarm_timer_manager_api_supported = args[:alarm_timer_manager_api_supported] if args.key?(:alarm_timer_manager_api_supported)
          @app_control_support = args[:app_control_support] if args.key?(:app_control_support)
          @assistant_explore_supported = args[:assistant_explore_supported] if args.key?(:assistant_explore_supported)
          @assistant_for_kids_supported = args[:assistant_for_kids_supported] if args.key?(:assistant_for_kids_supported)
          @bypass_di_dc_check_for_comms = args[:bypass_di_dc_check_for_comms] if args.key?(:bypass_di_dc_check_for_comms)
          @bypass_msg_notification_dismissal = args[:bypass_msg_notification_dismissal] if args.key?(:bypass_msg_notification_dismissal)
          @client1m_providers_supported = args[:client1m_providers_supported] if args.key?(:client1m_providers_supported)
          @client_op_result_batching_supported = args[:client_op_result_batching_supported] if args.key?(:client_op_result_batching_supported)
          @cross_device_broadcast_supported = args[:cross_device_broadcast_supported] if args.key?(:cross_device_broadcast_supported)
          @cross_device_broadcast_version = args[:cross_device_broadcast_version] if args.key?(:cross_device_broadcast_version)
          @csat_visual_overlay_supported = args[:csat_visual_overlay_supported] if args.key?(:csat_visual_overlay_supported)
          @duo_client_api_features = args[:duo_client_api_features] if args.key?(:duo_client_api_features)
          @duo_group_calling_supported = args[:duo_group_calling_supported] if args.key?(:duo_group_calling_supported)
          @fitness_feature_support = args[:fitness_feature_support] if args.key?(:fitness_feature_support)
          @fluid_actions_support = args[:fluid_actions_support] if args.key?(:fluid_actions_support)
          @funtime_supported = args[:funtime_supported] if args.key?(:funtime_supported)
          @gdi_supported = args[:gdi_supported] if args.key?(:gdi_supported)
          @gearhead_notification_source_supported = args[:gearhead_notification_source_supported] if args.key?(:gearhead_notification_source_supported)
          @has_physical_radio = args[:has_physical_radio] if args.key?(:has_physical_radio)
          @immersive_canvas_confirmation_message_supported = args[:immersive_canvas_confirmation_message_supported] if args.key?(:immersive_canvas_confirmation_message_supported)
          @immersive_canvas_support = args[:immersive_canvas_support] if args.key?(:immersive_canvas_support)
          @in_dialog_account_linking_supported = args[:in_dialog_account_linking_supported] if args.key?(:in_dialog_account_linking_supported)
          @is_paired_phone_contact_upload_needed_for_comms = args[:is_paired_phone_contact_upload_needed_for_comms] if args.key?(:is_paired_phone_contact_upload_needed_for_comms)
          @is_paired_phone_needed_for_comms = args[:is_paired_phone_needed_for_comms] if args.key?(:is_paired_phone_needed_for_comms)
          @launch_keyboard_supported = args[:launch_keyboard_supported] if args.key?(:launch_keyboard_supported)
          @lens_supported = args[:lens_supported] if args.key?(:lens_supported)
          @live_cards_supported = args[:live_cards_supported] if args.key?(:live_cards_supported)
          @maps_dialogs_supported = args[:maps_dialogs_supported] if args.key?(:maps_dialogs_supported)
          @masquerade_mode_supported = args[:masquerade_mode_supported] if args.key?(:masquerade_mode_supported)
          @media_control_support = args[:media_control_support] if args.key?(:media_control_support)
          @media_session_detection = args[:media_session_detection] if args.key?(:media_session_detection)
          @meet_supported = args[:meet_supported] if args.key?(:meet_supported)
          @no_input_response_supported = args[:no_input_response_supported] if args.key?(:no_input_response_supported)
          @opa_on_search_supported = args[:opa_on_search_supported] if args.key?(:opa_on_search_supported)
          @parental_controls_supported = args[:parental_controls_supported] if args.key?(:parental_controls_supported)
          @persistent_display_supported = args[:persistent_display_supported] if args.key?(:persistent_display_supported)
          @privacy_aware_lockscreen_supported = args[:privacy_aware_lockscreen_supported] if args.key?(:privacy_aware_lockscreen_supported)
          @remote_cloud_casting_enabled = args[:remote_cloud_casting_enabled] if args.key?(:remote_cloud_casting_enabled)
          @server_generated_feedback_chips_enabled = args[:server_generated_feedback_chips_enabled] if args.key?(:server_generated_feedback_chips_enabled)
          @sh_lock_screen_supported = args[:sh_lock_screen_supported] if args.key?(:sh_lock_screen_supported)
          @sign_in_method = args[:sign_in_method] if args.key?(:sign_in_method)
          @sleep_sensing_supported = args[:sleep_sensing_supported] if args.key?(:sleep_sensing_supported)
          @smartspace_cross_device_timer_supported = args[:smartspace_cross_device_timer_supported] if args.key?(:smartspace_cross_device_timer_supported)
          @soli_gesture_detection_supported = args[:soli_gesture_detection_supported] if args.key?(:soli_gesture_detection_supported)
          @suggestions_support = args[:suggestions_support] if args.key?(:suggestions_support)
          @sunrise_features_support = args[:sunrise_features_support] if args.key?(:sunrise_features_support)
          @tap_to_read_optimization_supported = args[:tap_to_read_optimization_supported] if args.key?(:tap_to_read_optimization_supported)
          @third_party_gui_supported = args[:third_party_gui_supported] if args.key?(:third_party_gui_supported)
          @transaction_features_support = args[:transaction_features_support] if args.key?(:transaction_features_support)
          @transactions_version = args[:transactions_version] if args.key?(:transactions_version)
          @uses_separate_full_viewer = args[:uses_separate_full_viewer] if args.key?(:uses_separate_full_viewer)
          @view_reminder_hub_page_not_supported = args[:view_reminder_hub_page_not_supported] if args.key?(:view_reminder_hub_page_not_supported)
          @warm_welcome_tutorial_supported = args[:warm_welcome_tutorial_supported] if args.key?(:warm_welcome_tutorial_supported)
          @web_browser_supported = args[:web_browser_supported] if args.key?(:web_browser_supported)
          @whats_next_supported = args[:whats_next_supported] if args.key?(:whats_next_supported)
          @zoom_supported = args[:zoom_supported] if args.key?(:zoom_supported)
        end
      end
      
      # Contains versions of protocol buffer messages. This is the equivalence of a
      # proto3 map, keyed by a protocol buffer message’s name, and the value is the
      # version of this message. e.g. `"assistant.api.core_types.Timer": 2, "assistant.
      # api.core_types.Alarm": 1` See go/assistant-protocol-versioning for more
      # details.
      class AssistantApiSupportedProtocolVersion
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `messageVersion`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSupportedProtocolVersionMessageVersionPair>]
        attr_accessor :message_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message_version = args[:message_version] if args.key?(:message_version)
        end
      end
      
      # 
      class AssistantApiSupportedProtocolVersionMessageVersionPair
        include Google::Apis::Core::Hashable
      
        # The full path of a message which should start from the package name. e.g. "
        # assistant.api.core_types.Timer".
        # Corresponds to the JSON property `messageName`
        # @return [String]
        attr_accessor :message_name
      
        # The supported version number.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message_name = args[:message_name] if args.key?(:message_name)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Types of providers that are supported by the client. For example, ChromeOS
      # support both web app and Android app (for eligible devices).
      class AssistantApiSupportedProviderTypes
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `supportedTypes`
        # @return [Array<String>]
        attr_accessor :supported_types
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supported_types = args[:supported_types] if args.key?(:supported_types)
        end
      end
      
      # Properties of the surface that are not hardware related or feature specific.
      class AssistantApiSurfaceProperties
        include Google::Apis::Core::Hashable
      
        # Describes the capabilities that are related to the execution of client ops on
        # the device.
        # Corresponds to the JSON property `executionCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSurfacePropertiesExecutionCapabilities]
        attr_accessor :execution_capabilities
      
        # If this field is unset, the response format is unknown
        # Corresponds to the JSON property `responseDisplayFormat`
        # @return [String]
        attr_accessor :response_display_format
      
        # If true, the client supports receiving multiple responses. See go/multiple-
        # response-in-media-use-cases for more details.
        # Corresponds to the JSON property `supportsMultiResponse`
        # @return [Boolean]
        attr_accessor :supports_multi_response
        alias_method :supports_multi_response?, :supports_multi_response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @execution_capabilities = args[:execution_capabilities] if args.key?(:execution_capabilities)
          @response_display_format = args[:response_display_format] if args.key?(:response_display_format)
          @supports_multi_response = args[:supports_multi_response] if args.key?(:supports_multi_response)
        end
      end
      
      # Describes the capabilities that are related to the execution of client ops on
      # the device.
      class AssistantApiSurfacePropertiesExecutionCapabilities
        include Google::Apis::Core::Hashable
      
        # Completes the preloading ie., sets up the stage for the execution of client
        # ops on the device while the previous conv delta is being executed. Refer to go/
        # preload-convdelta for more information.
        # Corresponds to the JSON property `supportsClientOpPreloading`
        # @return [Boolean]
        attr_accessor :supports_client_op_preloading
        alias_method :supports_client_op_preloading?, :supports_client_op_preloading
      
        # A value of true indicates that the client supports streaming of non-finalized
        # responses by use of ClientExecutionParams.response_stream_id. and
        # ClientExecutionParams.to_be_finalized.
        # Corresponds to the JSON property `supportsNonFinalizedResponses`
        # @return [Boolean]
        attr_accessor :supports_non_finalized_responses
        alias_method :supports_non_finalized_responses?, :supports_non_finalized_responses
      
        # If true, the client supports receiving non-materialized interactions (go/as-
        # streaming-protocol-nm).
        # Corresponds to the JSON property `supportsNonMaterializedInteractions`
        # @return [Boolean]
        attr_accessor :supports_non_materialized_interactions
        alias_method :supports_non_materialized_interactions?, :supports_non_materialized_interactions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supports_client_op_preloading = args[:supports_client_op_preloading] if args.key?(:supports_client_op_preloading)
          @supports_non_finalized_responses = args[:supports_non_finalized_responses] if args.key?(:supports_non_finalized_responses)
          @supports_non_materialized_interactions = args[:supports_non_materialized_interactions] if args.key?(:supports_non_materialized_interactions)
        end
      end
      
      # Restrictions related to system-level notifications.
      class AssistantApiSystemNotificationRestrictions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `categoryState`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSystemNotificationRestrictionsNotificationCategoryState>]
        attr_accessor :category_state
      
        # 
        # Corresponds to the JSON property `channelState`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiSystemNotificationRestrictionsNotificationChannelState>]
        attr_accessor :channel_state
      
        # Specifies whether the surface is able to display notifications.
        # Corresponds to the JSON property `notificationCapabilities`
        # @return [String]
        attr_accessor :notification_capabilities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_state = args[:category_state] if args.key?(:category_state)
          @channel_state = args[:channel_state] if args.key?(:channel_state)
          @notification_capabilities = args[:notification_capabilities] if args.key?(:notification_capabilities)
        end
      end
      
      # Notification channels state for the new server driven channels.
      class AssistantApiSystemNotificationRestrictionsNotificationCategoryState
        include Google::Apis::Core::Hashable
      
        # Notification channel type.
        # Corresponds to the JSON property `categoryId`
        # @return [Fixnum]
        attr_accessor :category_id
      
        # Weather the notifications on this channel are disabled.
        # Corresponds to the JSON property `disabled`
        # @return [Boolean]
        attr_accessor :disabled
        alias_method :disabled?, :disabled
      
        # 
        # Corresponds to the JSON property `disabledReason`
        # @return [String]
        attr_accessor :disabled_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_id = args[:category_id] if args.key?(:category_id)
          @disabled = args[:disabled] if args.key?(:disabled)
          @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason)
        end
      end
      
      # Notification channels state.
      class AssistantApiSystemNotificationRestrictionsNotificationChannelState
        include Google::Apis::Core::Hashable
      
        # Notification channel type.
        # Corresponds to the JSON property `channelType`
        # @return [String]
        attr_accessor :channel_type
      
        # Whether the notifications on this channel are enabled.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel_type = args[:channel_type] if args.key?(:channel_type)
          @enabled = args[:enabled] if args.key?(:enabled)
        end
      end
      
      # 3P Action Metadata. Next ID: 3
      class AssistantApiThirdPartyActionConfig
        include Google::Apis::Core::Hashable
      
        # This capability represents device action needed capability. Next ID: 10
        # Corresponds to the JSON property `deviceActionCapability`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoDeviceActionCapability]
        attr_accessor :device_action_capability
      
        # List of Action project capabilities.
        # Corresponds to the JSON property `projectConfigs`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiThirdPartyActionConfigProjectConfig>]
        attr_accessor :project_configs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_action_capability = args[:device_action_capability] if args.key?(:device_action_capability)
          @project_configs = args[:project_configs] if args.key?(:project_configs)
        end
      end
      
      # Metadata for ActionPackage. Device Actions are disabled by default unless
      # explicitly enabled for the device here, see go/3p-device-actions-v2-design.
      class AssistantApiThirdPartyActionConfigProjectConfig
        include Google::Apis::Core::Hashable
      
        # Google cloud project id for which the Action Package or Device Model is
        # registered.
        # Corresponds to the JSON property `projectId`
        # @return [String]
        attr_accessor :project_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @project_id = args[:project_id] if args.key?(:project_id)
        end
      end
      
      # 
      class AssistantApiThirdPartyCapabilities
        include Google::Apis::Core::Hashable
      
        # Restrictions for the device to share any data with third party apps. See
        # details in go/atv-dsc.
        # Corresponds to the JSON property `dataSharingRestrictions`
        # @return [String]
        attr_accessor :data_sharing_restrictions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_sharing_restrictions = args[:data_sharing_restrictions] if args.key?(:data_sharing_restrictions)
        end
      end
      
      # A civil time relative to a timezone. IMPORTANT: The definition of TimeOfDay
      # proto is being moved to //assistant/api/core_types/governed/datetime_type.
      # proto. All existing references will be updated to point to the new location.
      # If you are adding a reference, use the new one instead.
      class AssistantApiTimeOfDay
        include Google::Apis::Core::Hashable
      
        # The hour, in 0...23.
        # Corresponds to the JSON property `hour`
        # @return [Fixnum]
        attr_accessor :hour
      
        # The minute, in 0...59.
        # Corresponds to the JSON property `minute`
        # @return [Fixnum]
        attr_accessor :minute
      
        # The fraction of seconds in nanoseconds, in 0..999999999.
        # Corresponds to the JSON property `nanosecond`
        # @return [Fixnum]
        attr_accessor :nanosecond
      
        # The second, in 0...59. Leap seconds are not supported.
        # Corresponds to the JSON property `second`
        # @return [Fixnum]
        attr_accessor :second
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hour = args[:hour] if args.key?(:hour)
          @minute = args[:minute] if args.key?(:minute)
          @nanosecond = args[:nanosecond] if args.key?(:nanosecond)
          @second = args[:second] if args.key?(:second)
        end
      end
      
      # A time zone. Conceptually, a time zone is a set of rules associated with a
      # location that describes a UTC offset and how it changes over time (e.g.
      # Daylight Saving Time). The offset is used to compute the local date and time.
      # IMPORTANT: The definition of TimeZone enum is being moved to //assistant/api/
      # core_types/governed/datetime_type.proto. All existing references will be
      # updated to point to the new location. If you are adding a reference, use the
      # new one instead.
      class AssistantApiTimeZone
        include Google::Apis::Core::Hashable
      
        # Time zone in IANA format, e.g. America/Los_Angeles for USA Pacific Time.
        # Corresponds to the JSON property `ianaId`
        # @return [String]
        attr_accessor :iana_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @iana_id = args[:iana_id] if args.key?(:iana_id)
        end
      end
      
      # An absolute point in time independent of timezone or calendar, based on the
      # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
      # definition of Timestamp proto is being moved to //assistant/api/core_types/
      # governed/datetime_type.proto. All existing references will be updated to point
      # to the new location. If you are adding a reference, use the new one instead.
      # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
      # separately from google.protobuf.Timestamp due to incompatibility with proto2
      # syntax. The incompatibility issues have since been resolved and so the Google-
      # wide standard representation of google.protobuf.Timestamp should be preferred.
      # In fact, google.protobuf.* protos in general are now recommended to be used in
      # new APIs.
      class AssistantApiTimestamp
        include Google::Apis::Core::Hashable
      
        # Non-negative fractions of a second at nanosecond resolution.
        # Corresponds to the JSON property `nanos`
        # @return [Fixnum]
        attr_accessor :nanos
      
        # Seconds of UTC time since the Unix epoch.
        # Corresponds to the JSON property `seconds`
        # @return [Fixnum]
        attr_accessor :seconds
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @nanos = args[:nanos] if args.key?(:nanos)
          @seconds = args[:seconds] if args.key?(:seconds)
        end
      end
      
      # 
      class AssistantApiTransactionFeaturesSupport
        include Google::Apis::Core::Hashable
      
        # If true, setting this boolean means the device should not support voice PIN.
        # For example, although the phone supports both voice and PIN pad, but we don't
        # want users using voice. https://docs.google.com/document/d/
        # 1M8iJQX3GuxGZGeidS8Gl4KJt3LuBWAIlolPlW10DkxU/edit#heading=h.8ovvdd3i2thv
        # Corresponds to the JSON property `voicePinSuppressed`
        # @return [Boolean]
        attr_accessor :voice_pin_suppressed
        alias_method :voice_pin_suppressed?, :voice_pin_suppressed
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @voice_pin_suppressed = args[:voice_pin_suppressed] if args.key?(:voice_pin_suppressed)
        end
      end
      
      # 
      class AssistantApiVolumeProperties
        include Google::Apis::Core::Hashable
      
        # The volume percentages for spelled out values.
        # Corresponds to the JSON property `defaultVolumePercentage`
        # @return [Fixnum]
        attr_accessor :default_volume_percentage
      
        # 
        # Corresponds to the JSON property `highVolumePercentage`
        # @return [Fixnum]
        attr_accessor :high_volume_percentage
      
        # The number of levels to move for a step.
        # Corresponds to the JSON property `levelStepSize`
        # @return [Float]
        attr_accessor :level_step_size
      
        # 
        # Corresponds to the JSON property `lowVolumePercentage`
        # @return [Fixnum]
        attr_accessor :low_volume_percentage
      
        # The max number of volume levels the client supports.
        # Corresponds to the JSON property `maximumVolumeLevel`
        # @return [Fixnum]
        attr_accessor :maximum_volume_level
      
        # 
        # Corresponds to the JSON property `mediumVolumePercentage`
        # @return [Fixnum]
        attr_accessor :medium_volume_percentage
      
        # 
        # Corresponds to the JSON property `veryHighVolumePercentage`
        # @return [Fixnum]
        attr_accessor :very_high_volume_percentage
      
        # 
        # Corresponds to the JSON property `veryLowVolumePercentage`
        # @return [Fixnum]
        attr_accessor :very_low_volume_percentage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @default_volume_percentage = args[:default_volume_percentage] if args.key?(:default_volume_percentage)
          @high_volume_percentage = args[:high_volume_percentage] if args.key?(:high_volume_percentage)
          @level_step_size = args[:level_step_size] if args.key?(:level_step_size)
          @low_volume_percentage = args[:low_volume_percentage] if args.key?(:low_volume_percentage)
          @maximum_volume_level = args[:maximum_volume_level] if args.key?(:maximum_volume_level)
          @medium_volume_percentage = args[:medium_volume_percentage] if args.key?(:medium_volume_percentage)
          @very_high_volume_percentage = args[:very_high_volume_percentage] if args.key?(:very_high_volume_percentage)
          @very_low_volume_percentage = args[:very_low_volume_percentage] if args.key?(:very_low_volume_percentage)
        end
      end
      
      # The information associated with an error while selecting the target device.
      # Next ID: 2
      class AssistantDeviceTargetingDeviceTargetingError
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Capability with regard to support of alarms by the client.
      class AssistantDevicesPlatformProtoAlarmCapability
        include Google::Apis::Core::Hashable
      
        # Maximum number of alarms that can be created on the client. Zero or unset
        # indicates no maximum limit.
        # Corresponds to the JSON property `maxSupportedAlarms`
        # @return [Fixnum]
        attr_accessor :max_supported_alarms
      
        # Whether the client restricts alarms to ring within the next 24 hours.
        # Corresponds to the JSON property `restrictAlarmsToNextDay`
        # @return [Boolean]
        attr_accessor :restrict_alarms_to_next_day
        alias_method :restrict_alarms_to_next_day?, :restrict_alarms_to_next_day
      
        # Whether the client supports the STOP alarm action. If this is false, stop
        # actions will be represented by the MUTATE action, and the device may need to
        # check alarm state to determine if there's a firing alarm that needs to be
        # dismissed.
        # Corresponds to the JSON property `supportsStopAction`
        # @return [Boolean]
        attr_accessor :supports_stop_action
        alias_method :supports_stop_action?, :supports_stop_action
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_supported_alarms = args[:max_supported_alarms] if args.key?(:max_supported_alarms)
          @restrict_alarms_to_next_day = args[:restrict_alarms_to_next_day] if args.key?(:restrict_alarms_to_next_day)
          @supports_stop_action = args[:supports_stop_action] if args.key?(:supports_stop_action)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoArgSpec
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `intValueSpec`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoIntValueSpec]
        attr_accessor :int_value_spec
      
        # 
        # Corresponds to the JSON property `optionValueSpec`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoOptionValueSpec]
        attr_accessor :option_value_spec
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @int_value_spec = args[:int_value_spec] if args.key?(:int_value_spec)
          @option_value_spec = args[:option_value_spec] if args.key?(:option_value_spec)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoCallCallCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoClientReconnectCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # States the cloud capabilities of the device, i.e. the endpoint(s) to use for
      # cloud execution of Actions or Registration.
      class AssistantDevicesPlatformProtoCloudCapability
        include Google::Apis::Core::Hashable
      
        # The list of CloudEndpoints supported by this Device Model. Note that each
        # should have a unique |name|. If any cloud endpoints are provided here, then
        # the first one in the list will be used by default for all Cloud Execution. An
        # Intent may override the default by providing an |execution_config|.
        # Corresponds to the JSON property `cloudEndpoints`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoCloudEndpoint>]
        attr_accessor :cloud_endpoints
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_endpoints = args[:cloud_endpoints] if args.key?(:cloud_endpoints)
        end
      end
      
      # A cloud endpoints associates with this device, it can be used for query
      # parsing, or cloud execution.
      class AssistantDevicesPlatformProtoCloudEndpoint
        include Google::Apis::Core::Hashable
      
        # The name for this cloud endpoint. It's unique per Locale. This is not an API
        # resource name. Ex: sample-nlu-endpoint
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The list of scopes to be provided in the OAuth2 token. They must be a subset
        # of the scopes registered in the Account Linking flow, or the request will fail.
        # If the client itself provides the token, then this field is ignored.
        # Corresponds to the JSON property `scopes`
        # @return [Array<String>]
        attr_accessor :scopes
      
        # The URL for this endpoint, it must start with https.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @scopes = args[:scopes] if args.key?(:scopes)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # This capability represents device action needed capability. Next ID: 10
      class AssistantDevicesPlatformProtoDeviceActionCapability
        include Google::Apis::Core::Hashable
      
        # Integrate your device with Google's Smart Home solution by putting your device
        # into Google's Home Graph, a database that stores and provides contextual data
        # about the home and its devices. For example, Home Graph can store the concept
        # of a living room that contains multiple types of devices, when you say "turn
        # on the light" to a device, if you have light in the living room, that light
        # will be turned on.
        # Corresponds to the JSON property `assistantDeviceInRoomOptOut`
        # @return [Boolean]
        attr_accessor :assistant_device_in_room_opt_out
        alias_method :assistant_device_in_room_opt_out?, :assistant_device_in_room_opt_out
      
        # Specifies behavior for built-in device actions for this device model. If not
        # specified, defaults to ENABLE_CONFIGURED_INTENTS_ONLY.
        # Corresponds to the JSON property `builtInIntentMode`
        # @return [String]
        attr_accessor :built_in_intent_mode
      
        # Specifies which custom device actions should be enabled for this device model.
        # This will only affect the behavior of intents corresponding to those from the
        # Action Package of this project. If not specified, defaults to ENABLE_ALL.
        # Corresponds to the JSON property `customIntentMode`
        # @return [String]
        attr_accessor :custom_intent_mode
      
        # Specifies the routing capabilities of the Intent. It will apply only when the
        # Intent is triggered. Next ID: 8
        # Corresponds to the JSON property `defaultExecutionConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoExecutionConfig]
        attr_accessor :default_execution_config
      
        # Specifies capabilities for device actions that are inlined in the google.
        # assistant.embedded.v1.DeviceAction message.
        # Corresponds to the JSON property `inlinedActionCapability`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoInlinedActionCapability]
        attr_accessor :inlined_action_capability
      
        # Intent configurations. Built-in and custom intents may be configured here.
        # Note that built-in intents will always behave with IntentMode of
        # ENABLE_CONFIGURED_INTENTS_ONLY. The IntentMode for custom intents can be
        # changed using the custom_intent_mode. To configure an intent, list it here
        # with its intent name, e.g. "MY_CUSTOM_INTENT", "google.assistant.car.model.
        # capabilities.AC_TEMPERATURE".
        # Corresponds to the JSON property `intents`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoIntent>]
        attr_accessor :intents
      
        # Provided data which augments the device action capabilities. Some built-in
        # intents may require additional configuration to be provided. One example could
        # be the list of channels available for the `action.intent.SelectChannel` intent.
        # Corresponds to the JSON property `providedData`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoProvidedData>]
        attr_accessor :provided_data
      
        # List of built-in traits such as "action.devices.traits.OnOff" See java/com/
        # google/home/graph/service/config/protoconf.pi As of Nov. 2017, we also support
        # custom traits for EAP users. We'll eventually disable custom traits once
        # custom actions are in place.
        # Corresponds to the JSON property `traits`
        # @return [Array<String>]
        attr_accessor :traits
      
        # Specifies the NLU level that Google performs, which determines the request
        # format sent to the 3P cloud.
        # Corresponds to the JSON property `understandingConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoUnderstandingConfig]
        attr_accessor :understanding_config
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @assistant_device_in_room_opt_out = args[:assistant_device_in_room_opt_out] if args.key?(:assistant_device_in_room_opt_out)
          @built_in_intent_mode = args[:built_in_intent_mode] if args.key?(:built_in_intent_mode)
          @custom_intent_mode = args[:custom_intent_mode] if args.key?(:custom_intent_mode)
          @default_execution_config = args[:default_execution_config] if args.key?(:default_execution_config)
          @inlined_action_capability = args[:inlined_action_capability] if args.key?(:inlined_action_capability)
          @intents = args[:intents] if args.key?(:intents)
          @provided_data = args[:provided_data] if args.key?(:provided_data)
          @traits = args[:traits] if args.key?(:traits)
          @understanding_config = args[:understanding_config] if args.key?(:understanding_config)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoDeviceModifySettingCapability
        include Google::Apis::Core::Hashable
      
        # The properties of the client op device.MODIFY_SETTING. This proto is stored in
        # the SupportedClientOp proto.
        # Corresponds to the JSON property `clientOpProperty`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiClientOpPropertiesDeviceModifySettingClientOpProperty]
        attr_accessor :client_op_property
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_op_property = args[:client_op_property] if args.key?(:client_op_property)
        end
      end
      
      # Specifies the routing capabilities of the Intent. It will apply only when the
      # Intent is triggered. Next ID: 8
      class AssistantDevicesPlatformProtoExecutionConfig
        include Google::Apis::Core::Hashable
      
        # Instructions for performing a cloud execution request for the Intent when the
        # execution_type is set to CLOUD. If non-empty, then the device execution would
        # be routed to the CloudEndpoint specified by this name. The Account Linking
        # exchange may be performed to fetch the OAuth access token, and the access
        # token will be included in the HTTP header.
        # Corresponds to the JSON property `cloudEndpointName`
        # @return [String]
        attr_accessor :cloud_endpoint_name
      
        # If this field is set, then the Syndication cloud call will be disabled for
        # this intent. Note this only applies if any Syndication cloud endpoint is
        # associated with the Device Model, otherwise setting this field does nothing.
        # By default, all Intents that are enabled and supported by the Syndication API
        # will be routed through the Syndication cloud endpoint if it's provided.
        # Corresponds to the JSON property `cloudIntentTranslationDisabled`
        # @return [Boolean]
        attr_accessor :cloud_intent_translation_disabled
        alias_method :cloud_intent_translation_disabled?, :cloud_intent_translation_disabled
      
        # Specifies the intent command format for this Action. For example, in order to
        # launch an Android intent instead of receiving the device action payload on the
        # client, then this field can be set with "intent:/#Intent;...;my_extra=`$.
        # params.channels[0].channelCode`;end" The parameter "`$.params.channels[0].
        # channelCode`" is in JSON path format, and will be replaced with the content
        # from the original device action payload. Thus, with # JSON "execution": [ ` "
        # command": "action.devices.commands.SelectChannel", "params": ` "channels": [` "
        # channelName": "exampleChannel", "channelCode": "1-1" `] ` ` ] as the original
        # action result, then the final result would look like "intent:/#Intent;...;
        # my_extra=\"1-1\";end"
        # Corresponds to the JSON property `intentCommandFormat`
        # @return [String]
        attr_accessor :intent_command_format
      
        # If this field is set, then local execution capability is disabled for all
        # matching intents.
        # Corresponds to the JSON property `localDisabled`
        # @return [Boolean]
        attr_accessor :local_disabled
        alias_method :local_disabled?, :local_disabled
      
        # Specifies how to execute this Action when it is invoked locally (from the same
        # device.)
        # Corresponds to the JSON property `localExecutionType`
        # @return [String]
        attr_accessor :local_execution_type
      
        # If this field is set, then remote execution capability is disabled for all
        # matching intents.
        # Corresponds to the JSON property `remoteDisabled`
        # @return [Boolean]
        attr_accessor :remote_disabled
        alias_method :remote_disabled?, :remote_disabled
      
        # Specifies how to execute this Action when it is invoked remotely (from a
        # different device.)
        # Corresponds to the JSON property `remoteExecutionType`
        # @return [String]
        attr_accessor :remote_execution_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_endpoint_name = args[:cloud_endpoint_name] if args.key?(:cloud_endpoint_name)
          @cloud_intent_translation_disabled = args[:cloud_intent_translation_disabled] if args.key?(:cloud_intent_translation_disabled)
          @intent_command_format = args[:intent_command_format] if args.key?(:intent_command_format)
          @local_disabled = args[:local_disabled] if args.key?(:local_disabled)
          @local_execution_type = args[:local_execution_type] if args.key?(:local_execution_type)
          @remote_disabled = args[:remote_disabled] if args.key?(:remote_disabled)
          @remote_execution_type = args[:remote_execution_type] if args.key?(:remote_execution_type)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoInlinedActionCapability
        include Google::Apis::Core::Hashable
      
        # Capability with regard to support of alarms by the client.
        # Corresponds to the JSON property `alarm`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoAlarmCapability]
        attr_accessor :alarm
      
        # Specifies the size limits on responses receivable by the client.
        # Corresponds to the JSON property `responseLimits`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoResponseLimits]
        attr_accessor :response_limits
      
        # Whether this device model package support sdk.EXECUTE client_op (a.k.a action.
        # devices.EXECUTE intent), which will be filled into google.assistant.embedded.
        # v1.DeviceAction.device_request_json. It is default to true (and not public),
        # since all 3P will depends on the device_request_json. Only internal projects
        # like Edoras will set this to false.
        # Corresponds to the JSON property `supportSdkExecute`
        # @return [Boolean]
        attr_accessor :support_sdk_execute
        alias_method :support_sdk_execute?, :support_sdk_execute
      
        # This message will specify supports for fields in |assistant.embedded.v1.
        # DeviceOp|, for a device model package. See go/easi-client-op2 for more info.
        # Corresponds to the JSON property `supportedDeviceOps`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoSupportedDeviceOps]
        attr_accessor :supported_device_ops
      
        # Specifies whether server can send a series of responses for a single query.
        # Example: Routines where multiple actions to be executed one after another.
        # Corresponds to the JSON property `supportsMultiResponse`
        # @return [Boolean]
        attr_accessor :supports_multi_response
        alias_method :supports_multi_response?, :supports_multi_response
      
        # Capability with regard to support of timers by the client.
        # Corresponds to the JSON property `timer`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoTimerCapability]
        attr_accessor :timer
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alarm = args[:alarm] if args.key?(:alarm)
          @response_limits = args[:response_limits] if args.key?(:response_limits)
          @support_sdk_execute = args[:support_sdk_execute] if args.key?(:support_sdk_execute)
          @supported_device_ops = args[:supported_device_ops] if args.key?(:supported_device_ops)
          @supports_multi_response = args[:supports_multi_response] if args.key?(:supports_multi_response)
          @timer = args[:timer] if args.key?(:timer)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoIntValueSpec
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `maxValue`
        # @return [Fixnum]
        attr_accessor :max_value
      
        # 
        # Corresponds to the JSON property `minValue`
        # @return [Fixnum]
        attr_accessor :min_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_value = args[:max_value] if args.key?(:max_value)
          @min_value = args[:min_value] if args.key?(:min_value)
        end
      end
      
      # An intent configures the behavior of a device action for this device. Next ID:
      # 7
      class AssistantDevicesPlatformProtoIntent
        include Google::Apis::Core::Hashable
      
        # List of arguments associated this intent. Each of which depends a template for
        # the expected argument.
        # Corresponds to the JSON property `argSpecs`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoArgSpec>]
        attr_accessor :arg_specs
      
        # Specifies the routing capabilities of the Intent. It will apply only when the
        # Intent is triggered. Next ID: 8
        # Corresponds to the JSON property `executionConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoExecutionConfig]
        attr_accessor :execution_config
      
        # The name of the intent.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # List of provided data names used by this intent. Note that some built-in
        # intents will not function properly without provided data, such as `action.
        # intent.SwitchChannel` or `action.intent.AppSelector`.
        # Corresponds to the JSON property `providedDataNames`
        # @return [Array<String>]
        attr_accessor :provided_data_names
      
        # Encapsulates security configuration for a single intent of a device model.
        # Corresponds to the JSON property `securityConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoSecurityConfig]
        attr_accessor :security_config
      
        # The conditions which must be met by the device before executing this Intent.
        # More than one can be provided, in which case the conditions operate with the "
        # AND" operator, i.e. the first condition which is failed will be used to
        # restrict the execution of this Intent.
        # Corresponds to the JSON property `triggerConditions`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoTriggerCondition>]
        attr_accessor :trigger_conditions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @arg_specs = args[:arg_specs] if args.key?(:arg_specs)
          @execution_config = args[:execution_config] if args.key?(:execution_config)
          @name = args[:name] if args.key?(:name)
          @provided_data_names = args[:provided_data_names] if args.key?(:provided_data_names)
          @security_config = args[:security_config] if args.key?(:security_config)
          @trigger_conditions = args[:trigger_conditions] if args.key?(:trigger_conditions)
        end
      end
      
      # Capabilities that may only be set internally. Only internal callers (i.e.
      # Googlers or Google owned projects) will be able to set these, thanks to go/
      # assistant-device-model-package-ownership.
      class AssistantDevicesPlatformProtoInternalCapability
        include Google::Apis::Core::Hashable
      
        # When using the Assistant SDK (Embedded Assistant API), the project id used to
        # authenticate the gRPC request is checked and must match against the project id
        # of the Device Model. We will additionally allow the project ids listed in the
        # device model here to be let through. See https://docs.google.com/document/d/
        # 1InAczpQJs6LCH1l--2yy67JM9hsBJbiL57fusnL3A8A
        # Corresponds to the JSON property `allowedAssistantSdkAuthProjectIds`
        # @return [Array<String>]
        attr_accessor :allowed_assistant_sdk_auth_project_ids
      
        # Load the assistant.api.AppCapabilities from DEVICE_INSTALLED_APP footprint
        # corpus. See go/edoras-geller.
        # Corresponds to the JSON property `appCapabilitiesFromDeviceInstallApps`
        # @return [Boolean]
        attr_accessor :app_capabilities_from_device_install_apps
        alias_method :app_capabilities_from_device_install_apps?, :app_capabilities_from_device_install_apps
      
        # A cloud endpoints associates with this device, it can be used for query
        # parsing, or cloud execution.
        # Corresponds to the JSON property `cloudDeviceActionEndpoint`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoCloudEndpoint]
        attr_accessor :cloud_device_action_endpoint
      
        # Signals that the model will have updated ranking behavior as described in
        # https://docs.google.com/document/d/1SN_AgadRr_cdIrFe-
        # qgRbIX2J1sOE7lcRXAvM1GUPoU.
        # Corresponds to the JSON property `deviceActionsEligibleForHighConfidence`
        # @return [Boolean]
        attr_accessor :device_actions_eligible_for_high_confidence
        alias_method :device_actions_eligible_for_high_confidence?, :device_actions_eligible_for_high_confidence
      
        # Make Google sign-in mandatory for using Google Assistant on the device. (This
        # bit is initially added for Samsung TV.)
        # Corresponds to the JSON property `forceSignIn`
        # @return [Boolean]
        attr_accessor :force_sign_in
        alias_method :force_sign_in?, :force_sign_in
      
        # When looking up device (for example for disclosure consent check), then always
        # use the third party device id for lookup instead of any other device id which
        # would normally have higher precedence, such as cast_device_id.
        # Corresponds to the JSON property `forceThirdPartyDeviceIdForDeviceLookup`
        # @return [Boolean]
        attr_accessor :force_third_party_device_id_for_device_lookup
        alias_method :force_third_party_device_id_for_device_lookup?, :force_third_party_device_id_for_device_lookup
      
        # Adds "transactions.AUTHENTICATION" for car automation probers. Since the
        # probers run as Assistant SDK requests, voice match always fails for car
        # automation requests, so we add this client op as a hack to allow probers to
        # appear as personal devices and bypass voice match. See b/137221645.
        # Corresponds to the JSON property `forceTransactionsAuthentication`
        # @return [Boolean]
        attr_accessor :force_transactions_authentication
        alias_method :force_transactions_authentication?, :force_transactions_authentication
      
        # Signals that this device can "render" raw search results even with no screen (
        # e.g., using a text reader). If this is true, fallback search results can be
        # returned as a custom device action in a SearchResults message. http://google3/
        # assistant/embedded/proto_translation/utils/proto/search_results.proto
        # Corresponds to the JSON property `hasCustomSearchResultsRendering`
        # @return [Boolean]
        attr_accessor :has_custom_search_results_rendering
        alias_method :has_custom_search_results_rendering?, :has_custom_search_results_rendering
      
        # When looking up device (for example for disclosure consent check), use this
        # project id as part of the primary key for the device lookup (i.e. instead of
        # the device_config.agent_id.) The precedence is as follows: 1) this field, if
        # set for the device's device model 2) device_config.agent_id 3) device_model.
        # project_id
        # Corresponds to the JSON property `overrideProjectIdForDeviceLookup`
        # @return [String]
        attr_accessor :override_project_id_for_device_lookup
      
        # The StadiaAssistantConfig. This field should only be set if the device model
        # is a Stadia.
        # Corresponds to the JSON property `stadiaAssistantConfig`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoInternalCapabilityStadiaAssistantConfig]
        attr_accessor :stadia_assistant_config
      
        # Telephone server is able to send attribution to user feature phone. See go/
        # telephone-attribution.
        # Corresponds to the JSON property `telephoneAttribution`
        # @return [Boolean]
        attr_accessor :telephone_attribution
        alias_method :telephone_attribution?, :telephone_attribution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowed_assistant_sdk_auth_project_ids = args[:allowed_assistant_sdk_auth_project_ids] if args.key?(:allowed_assistant_sdk_auth_project_ids)
          @app_capabilities_from_device_install_apps = args[:app_capabilities_from_device_install_apps] if args.key?(:app_capabilities_from_device_install_apps)
          @cloud_device_action_endpoint = args[:cloud_device_action_endpoint] if args.key?(:cloud_device_action_endpoint)
          @device_actions_eligible_for_high_confidence = args[:device_actions_eligible_for_high_confidence] if args.key?(:device_actions_eligible_for_high_confidence)
          @force_sign_in = args[:force_sign_in] if args.key?(:force_sign_in)
          @force_third_party_device_id_for_device_lookup = args[:force_third_party_device_id_for_device_lookup] if args.key?(:force_third_party_device_id_for_device_lookup)
          @force_transactions_authentication = args[:force_transactions_authentication] if args.key?(:force_transactions_authentication)
          @has_custom_search_results_rendering = args[:has_custom_search_results_rendering] if args.key?(:has_custom_search_results_rendering)
          @override_project_id_for_device_lookup = args[:override_project_id_for_device_lookup] if args.key?(:override_project_id_for_device_lookup)
          @stadia_assistant_config = args[:stadia_assistant_config] if args.key?(:stadia_assistant_config)
          @telephone_attribution = args[:telephone_attribution] if args.key?(:telephone_attribution)
        end
      end
      
      # The StadiaAssistantConfig. This field should only be set if the device model
      # is a Stadia.
      class AssistantDevicesPlatformProtoInternalCapabilityStadiaAssistantConfig
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `stadiaPlatform`
        # @return [String]
        attr_accessor :stadia_platform
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @stadia_platform = args[:stadia_platform] if args.key?(:stadia_platform)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaNextCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaPauseCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaPlayMediaCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaPreviousCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaResumeCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoMediaStopCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoOptionValueSpec
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `values`
        # @return [Array<String>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Provided data which augments the device action capabilities. Some built-in
      # intents may require additional configuration to be provided. One example could
      # be the list of channels available for the `action.intent.SelectChannel` intent.
      class AssistantDevicesPlatformProtoProvidedData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoProviderOpenCapability
        include Google::Apis::Core::Hashable
      
        # The properties of the provider.OPEN ClientOp. This proto is stored in the
        # SupportedClientOp proto with the key provider.OPEN.
        # Corresponds to the JSON property `clientOpProperty`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiClientOpPropertiesProviderOpenClientOpProperty]
        attr_accessor :client_op_property
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_op_property = args[:client_op_property] if args.key?(:client_op_property)
        end
      end
      
      # Specifies the size limits on responses receivable by the client.
      class AssistantDevicesPlatformProtoResponseLimits
        include Google::Apis::Core::Hashable
      
        # Max size in bytes of the total serialized AssistResponse receivable by the
        # client. If response exceeds this max, response may be modified by the server.
        # Corresponds to the JSON property `maxAssistResponseSizeBytes`
        # @return [Fixnum]
        attr_accessor :max_assist_response_size_bytes
      
        # Maximum size in bytes (not characters) of text the display can handle (which
        # may be different from how much the display can show at a time due to scrolling)
        # .
        # Corresponds to the JSON property `maxDisplayLinesBytes`
        # @return [Fixnum]
        attr_accessor :max_display_lines_bytes
      
        # Maximum size in bytes (not characters) for each suggestion chip.
        # Corresponds to the JSON property `maxSuggestionChipBytes`
        # @return [Fixnum]
        attr_accessor :max_suggestion_chip_bytes
      
        # Maximum number of suggestion chips the device can handle to display.
        # Corresponds to the JSON property `maxSuggestionChips`
        # @return [Fixnum]
        attr_accessor :max_suggestion_chips
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_assist_response_size_bytes = args[:max_assist_response_size_bytes] if args.key?(:max_assist_response_size_bytes)
          @max_display_lines_bytes = args[:max_display_lines_bytes] if args.key?(:max_display_lines_bytes)
          @max_suggestion_chip_bytes = args[:max_suggestion_chip_bytes] if args.key?(:max_suggestion_chip_bytes)
          @max_suggestion_chips = args[:max_suggestion_chips] if args.key?(:max_suggestion_chips)
        end
      end
      
      # Encapsulates security configuration for a single intent of a device model.
      class AssistantDevicesPlatformProtoSecurityConfig
        include Google::Apis::Core::Hashable
      
        # Specifies auth mechanism to be used upon remote request for device action.
        # Corresponds to the JSON property `authMechanismForRemoteRequests`
        # @return [String]
        attr_accessor :auth_mechanism_for_remote_requests
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @auth_mechanism_for_remote_requests = args[:auth_mechanism_for_remote_requests] if args.key?(:auth_mechanism_for_remote_requests)
        end
      end
      
      # 
      class AssistantDevicesPlatformProtoSendChatMessageCapability
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # This message will specify supports for fields in |assistant.embedded.v1.
      # DeviceOp|, for a device model package. See go/easi-client-op2 for more info.
      class AssistantDevicesPlatformProtoSupportedDeviceOps
        include Google::Apis::Core::Hashable
      
        # |call_call| specifies the support for the call.CALL clientop, and the
        # corresponding call_call field in assistant.embedded.v1.DeviceOp.
        # Corresponds to the JSON property `callCall`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoCallCallCapability]
        attr_accessor :call_call
      
        # |client_reconnect| indicates support for client.RECONNECT using assistant.
        # embedded.v1.DeviceOp. There is an alternative API/capability for client.
        # RECONNECT specified in RoutineCapability.supports_reconnect. Client should
        # choose between this and RoutineCapability but not both.
        # Corresponds to the JSON property `clientReconnect`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoClientReconnectCapability]
        attr_accessor :client_reconnect
      
        # |device_modify_setting| specifies the support for device.MODIFY_SETTING
        # client_op, and the corresponding device_modify_setting field in assistant.
        # embedded.v1.DeviceOp.
        # Corresponds to the JSON property `deviceModifySetting`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoDeviceModifySettingCapability]
        attr_accessor :device_modify_setting
      
        # 
        # Corresponds to the JSON property `mediaNext`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaNextCapability]
        attr_accessor :media_next
      
        # 
        # Corresponds to the JSON property `mediaPause`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaPauseCapability]
        attr_accessor :media_pause
      
        # 
        # Corresponds to the JSON property `mediaPlayMedia`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaPlayMediaCapability]
        attr_accessor :media_play_media
      
        # 
        # Corresponds to the JSON property `mediaPrevious`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaPreviousCapability]
        attr_accessor :media_previous
      
        # 
        # Corresponds to the JSON property `mediaResume`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaResumeCapability]
        attr_accessor :media_resume
      
        # 
        # Corresponds to the JSON property `mediaStop`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoMediaStopCapability]
        attr_accessor :media_stop
      
        # |provider_open| specifies the support for provider.OPEN client_op, and the
        # corresponding provider_open field in assistant.embedded.v1.DeviceOp.
        # Corresponds to the JSON property `providerOpen`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoProviderOpenCapability]
        attr_accessor :provider_open
      
        # |send_chat_message| specifies the support for the chat_message.SEND clientop,
        # and the corresponding send_chat_message field in assistant.embedded.v1.
        # DeviceOp.
        # Corresponds to the JSON property `sendChatMessage`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoSendChatMessageCapability]
        attr_accessor :send_chat_message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @call_call = args[:call_call] if args.key?(:call_call)
          @client_reconnect = args[:client_reconnect] if args.key?(:client_reconnect)
          @device_modify_setting = args[:device_modify_setting] if args.key?(:device_modify_setting)
          @media_next = args[:media_next] if args.key?(:media_next)
          @media_pause = args[:media_pause] if args.key?(:media_pause)
          @media_play_media = args[:media_play_media] if args.key?(:media_play_media)
          @media_previous = args[:media_previous] if args.key?(:media_previous)
          @media_resume = args[:media_resume] if args.key?(:media_resume)
          @media_stop = args[:media_stop] if args.key?(:media_stop)
          @provider_open = args[:provider_open] if args.key?(:provider_open)
          @send_chat_message = args[:send_chat_message] if args.key?(:send_chat_message)
        end
      end
      
      # Capability with regard to support of timers by the client.
      class AssistantDevicesPlatformProtoTimerCapability
        include Google::Apis::Core::Hashable
      
        # A Duration represents a signed, fixed-length span of time represented as a
        # count of seconds and fractions of seconds at nanosecond resolution. It is
        # independent of any calendar and concepts like "day" or "month". It is related
        # to Timestamp in that the difference between two Timestamp values is a Duration
        # and it can be added or subtracted from a Timestamp. Range is approximately +-
        # 10,000 years.
        # Corresponds to the JSON property `maxSupportedExtendedTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDuration]
        attr_accessor :max_supported_extended_timer_duration
      
        # A Duration represents a signed, fixed-length span of time represented as a
        # count of seconds and fractions of seconds at nanosecond resolution. It is
        # independent of any calendar and concepts like "day" or "month". It is related
        # to Timestamp in that the difference between two Timestamp values is a Duration
        # and it can be added or subtracted from a Timestamp. Range is approximately +-
        # 10,000 years.
        # Corresponds to the JSON property `maxSupportedTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDuration]
        attr_accessor :max_supported_timer_duration
      
        # Maximum number of timers that can be created on the client. Zero or unset
        # indicates no maximum limit.
        # Corresponds to the JSON property `maxSupportedTimers`
        # @return [Fixnum]
        attr_accessor :max_supported_timers
      
        # Whether the client supports the MUTATE timer action. If this is false, mutate
        # operations may be handled by sending a pair of REMOVE and CREATE timer actions
        # to replace the existing timer instead of mutating it.
        # Corresponds to the JSON property `supportsMutateAction`
        # @return [Boolean]
        attr_accessor :supports_mutate_action
        alias_method :supports_mutate_action?, :supports_mutate_action
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_supported_extended_timer_duration = args[:max_supported_extended_timer_duration] if args.key?(:max_supported_extended_timer_duration)
          @max_supported_timer_duration = args[:max_supported_timer_duration] if args.key?(:max_supported_timer_duration)
          @max_supported_timers = args[:max_supported_timers] if args.key?(:max_supported_timers)
          @supports_mutate_action = args[:supports_mutate_action] if args.key?(:supports_mutate_action)
        end
      end
      
      # A TriggerCondition is described as a set of states which must be met by the
      # device. It also includes instructions to the Assistant on what kind of
      # response to execute when the condition is not met.
      class AssistantDevicesPlatformProtoTriggerCondition
        include Google::Apis::Core::Hashable
      
        # The map of state keys along with their values which must be returned by the
        # device, for example to start the dishwasher you may require states: `"door": "
        # CLOSED", "detergent_status": "READY"`.
        # Corresponds to the JSON property `requiredStateValues`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantDevicesPlatformProtoArgSpec>]
        attr_accessor :required_state_values
      
        # A simple TTS to play.
        # Corresponds to the JSON property `simpleTts`
        # @return [String]
        attr_accessor :simple_tts
      
        # Refers to a defined ConditionalResult keyed by its status. It could be a built-
        # in or custom ConditionalResult for this Intent. Note: the states provided by
        # the device MUST contain all of the states required by the ConditionalResult.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @required_state_values = args[:required_state_values] if args.key?(:required_state_values)
          @simple_tts = args[:simple_tts] if args.key?(:simple_tts)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Specifies the NLU level that Google performs, which determines the request
      # format sent to the 3P cloud.
      class AssistantDevicesPlatformProtoUnderstandingConfig
        include Google::Apis::Core::Hashable
      
        # Specifies the NLU level for the intent.
        # Corresponds to the JSON property `nluLevel`
        # @return [String]
        attr_accessor :nlu_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @nlu_level = args[:nlu_level] if args.key?(:nlu_level)
        end
      end
      
      # 
      class AssistantLogsAllMediaStreamLog
        include Google::Apis::Core::Hashable
      
        # All active media streams while the user issues the query.
        # Corresponds to the JSON property `streams`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsMediaStreamLog>]
        attr_accessor :streams
      
        # Media stream is composed of a media session and one or more devices which are
        # hosting (playing) the session. Usually, a session is only hosted by one devcie.
        # However, with cast group or stream transfer/expansion, a session could be
        # hosted by multiple devices, which are playing the same session simultaneously.
        # Corresponds to the JSON property `targetStream`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaStreamLog]
        attr_accessor :target_stream
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @streams = args[:streams] if args.key?(:streams)
          @target_stream = args[:target_stream] if args.key?(:target_stream)
        end
      end
      
      # This message logs details on ambiguous device targeting logic. 1. It first
      # takes a list of ambiguous devices 2. Then applies two filters: structure
      # filter and playability filter. 3. If more than one device remains, it tiggers
      # DeviceSelectionDialog to let the user pick one device.
      class AssistantLogsAmbiguousTargetDeviceLog
        include Google::Apis::Core::Hashable
      
        # Device index of the initial ambiguous devices. The device index in this
        # message is consistent with the device index in DeviceInfoLog. It would be used
        # to track more detailed information of a device if needed.
        # Corresponds to the JSON property `ambiguousDeviceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :ambiguous_device_index
      
        # The information related to the device.
        # Corresponds to the JSON property `finalTargetDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :final_target_device
      
        # Device index of the devices after playability filter
        # Corresponds to the JSON property `playabilityFilteredDevicesIndex`
        # @return [Array<Fixnum>]
        attr_accessor :playability_filtered_devices_index
      
        # When there is no qualified devices after playability check, it would populate
        # punt_info below. If all devices are filtered out for the same reason, there
        # would only be one item. Otherwise, there will be multiple items.
        # Corresponds to the JSON property `puntInfoLog`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsAmbiguousTargetDeviceLogPuntInfoLog>]
        attr_accessor :punt_info_log
      
        # Device index of the devices after structure filter
        # Corresponds to the JSON property `structureFilteredDeviceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :structure_filtered_device_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ambiguous_device_index = args[:ambiguous_device_index] if args.key?(:ambiguous_device_index)
          @final_target_device = args[:final_target_device] if args.key?(:final_target_device)
          @playability_filtered_devices_index = args[:playability_filtered_devices_index] if args.key?(:playability_filtered_devices_index)
          @punt_info_log = args[:punt_info_log] if args.key?(:punt_info_log)
          @structure_filtered_device_index = args[:structure_filtered_device_index] if args.key?(:structure_filtered_device_index)
        end
      end
      
      # PuntInfoLog is used to log why devices get filtered out during media content
      # playability check. It contains media excuse, provider mid and also index of
      # devices filtered by them.
      class AssistantLogsAmbiguousTargetDeviceLogPuntInfoLog
        include Google::Apis::Core::Hashable
      
        # Index of devices that have the same punt info during playability check, i.e.
        # same media_excuse and provider_mid.
        # Corresponds to the JSON property `deviceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :device_index
      
        # Excuse for media action triggering. See: assistant/verticals/media/proto/
        # media_excuse.proto.
        # Corresponds to the JSON property `mediaExcuse`
        # @return [Fixnum]
        attr_accessor :media_excuse
      
        # Provider id that the excuse belongs to. This is the KG MID of the provider, e.
        # g., "/m/09jcvs" for Youtube.
        # Corresponds to the JSON property `providerMid`
        # @return [String]
        attr_accessor :provider_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_index = args[:device_index] if args.key?(:device_index)
          @media_excuse = args[:media_excuse] if args.key?(:media_excuse)
          @provider_mid = args[:provider_mid] if args.key?(:provider_mid)
        end
      end
      
      # This is the log version of apps.people.oz.external.mergedpeopleapi.
      # DeviceContactInfo Next ID: 2
      class AssistantLogsCommunicationDeviceContactInfoLog
        include Google::Apis::Core::Hashable
      
        # This list provides account information from the raw contact which is the
        # source of this field.
        # Corresponds to the JSON property `rawContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationRawDeviceContactInfoLog>]
        attr_accessor :raw_contact_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_contact_info = args[:raw_contact_info] if args.key?(:raw_contact_info)
        end
      end
      
      # This is the log version of fuzzy ngram match results that's used for
      # generating the best fuzzy match. Next ID: 3
      class AssistantLogsCommunicationFuzzyNgramMatchLog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `relativeCost`
        # @return [Float]
        attr_accessor :relative_cost
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @relative_cost = args[:relative_cost] if args.key?(:relative_cost)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # From google3/quality/qrewrite/proto/account_provenance.proto;l=14 We need to
      # copy this as the above proto has Enum field which is not compatible between
      # proto2 and proto3. go/proto2-versus-proto3#enums
      class AssistantLogsCommunicationGoogleAccountProvenance
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # 
        # Corresponds to the JSON property `isDasherAccount`
        # @return [Boolean]
        attr_accessor :is_dasher_account
        alias_method :is_dasher_account?, :is_dasher_account
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @is_dasher_account = args[:is_dasher_account] if args.key?(:is_dasher_account)
        end
      end
      
      # This is the log version of apps.people.oz.external.mergedpeopleapi.
      # PersonMetadata Next ID: 2
      class AssistantLogsCommunicationPersonMetadataLog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `deviceContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationDeviceContactInfoLog>]
        attr_accessor :device_contact_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_contact_info = args[:device_contact_info] if args.key?(:device_contact_info)
        end
      end
      
      # Contact meta data. Next ID: 30
      class AssistantLogsCommunicationPersonalContactDataLog
        include Google::Apis::Core::Hashable
      
        # From google3/quality/qrewrite/proto/account_provenance.proto;l=14 We need to
        # copy this as the above proto has Enum field which is not compatible between
        # proto2 and proto3. go/proto2-versus-proto3#enums
        # Corresponds to the JSON property `accountProvenance`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationGoogleAccountProvenance]
        attr_accessor :account_provenance
      
        # Populated if matched_name_type is GIVEN_NAME_ALIAS or FULL_NAME_ALIAS.
        # Corresponds to the JSON property `commonNameAliasConfidence`
        # @return [Float]
        attr_accessor :common_name_alias_confidence
      
        # Concept id for relationships in English, e.g. "Mother" for all non-English
        # locales. It's only populated for source = RELATIONSHIP.
        # Corresponds to the JSON property `conceptId`
        # @return [String]
        attr_accessor :concept_id
      
        # Integer value corresponding to DeviceContactExtraMetadata.Attribute enum. http:
        # //google3/social/graph/wire/proto/merged_person.proto?l=933&rcl=320308954
        # Corresponds to the JSON property `deviceContactAttributes`
        # @return [Array<Fixnum>]
        attr_accessor :device_contact_attributes
      
        # # emails stored for the contact.
        # Corresponds to the JSON property `emailIdCount`
        # @return [Fixnum]
        attr_accessor :email_id_count
      
        # Populate only if ContactRecognitionAlternate.Source is 'FUZZY_CONTACT_MATCH'.
        # Corresponds to the JSON property `fuzzyNgramMatch`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationFuzzyNgramMatchLog>]
        attr_accessor :fuzzy_ngram_match
      
        # Contact owner's gaia id from cs/symbol::symbol:quality_qrewrite.
        # PersonalContactData.shared_contact_owner_gaia_id. Only populated for is_shared
        # = true and non sign-out mode and user is not the owner of the contact(shared
        # contact from other user).
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # Boolean value indicating whether selected contact is from different account
        # than the logged in account.
        # Corresponds to the JSON property `isContactFromSecondaryAccount`
        # @return [Boolean]
        attr_accessor :is_contact_from_secondary_account
        alias_method :is_contact_from_secondary_account?, :is_contact_from_secondary_account
      
        # If this is a shared contact. This is true in 2 cases: - User is calling their
        # own contacts that have been marked as shared. - User is calling shared
        # contacts from some other user's contact list.
        # Corresponds to the JSON property `isShared`
        # @return [Boolean]
        attr_accessor :is_shared
        alias_method :is_shared?, :is_shared
      
        # Indicate the contact matches the transliterated query.
        # Corresponds to the JSON property `isTransliteratedMatch`
        # @return [Boolean]
        attr_accessor :is_transliterated_match
        alias_method :is_transliterated_match?, :is_transliterated_match
      
        # True if the contact is a vanity contact(has email = user's email address).
        # Corresponds to the JSON property `isVanityContact`
        # @return [Boolean]
        attr_accessor :is_vanity_contact
        alias_method :is_vanity_contact?, :is_vanity_contact
      
        # If the lookup was done using relationship which is visible to guests. This
        # value will only be set if lookup was done using relationship. E.g. user has a
        # guest relationship (doctor) -> (John) And user says "call doctor", then this
        # value will be true.
        # Corresponds to the JSON property `isVisibleToGuestsRelationship`
        # @return [Boolean]
        attr_accessor :is_visible_to_guests_relationship
        alias_method :is_visible_to_guests_relationship?, :is_visible_to_guests_relationship
      
        # The matched name type of a contact candidate.
        # Corresponds to the JSON property `matchedNameType`
        # @return [String]
        attr_accessor :matched_name_type
      
        # Alternate recognition term which was used to match this contact.
        # Corresponds to the JSON property `matchedRecognitionAlternateName`
        # @return [String]
        attr_accessor :matched_recognition_alternate_name
      
        # Ngram matched by starlight lookup for fuzzy matching in fulfillment. We need
        # this to analyze how many contacts are returned by starlight lookup that is not
        # matched by fuzzy matching. For example, "Komal Dear" is matched to "Komal Dr"
        # by fuzzy match. When doing starlight lookup, "Komal" and "Dr" will be looked
        # up separately. So "Dr xxx" will also be returned. We want to see how often
        # this happens.
        # Corresponds to the JSON property `matchedStarlightLookupName`
        # @return [Array<String>]
        attr_accessor :matched_starlight_lookup_name
      
        # This is the log version of apps.people.oz.external.mergedpeopleapi.
        # PersonMetadata Next ID: 2
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationPersonMetadataLog]
        attr_accessor :metadata
      
        # The indices of the contact in |candidate_contact| whose name matches the |
        # selected_contact_data|. |candidate_contact|: http://google3/logs/proto/
        # assistant/contact.proto?l=111&rcl=306283376 |selected_contact_data|: http://
        # google3/logs/proto/assistant/contact.proto?l=108&rcl=306283376
        # Corresponds to the JSON property `nameMatchedContactIndex`
        # @return [Array<Fixnum>]
        attr_accessor :name_matched_contact_index
      
        # The original name in the query as transcribed by ASR.
        # Corresponds to the JSON property `originalQueryName`
        # @return [String]
        attr_accessor :original_query_name
      
        # Information regarding the phone endpoints of the selected contact. Currently
        # it is only logged for selected candidate.
        # Corresponds to the JSON property `phone`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationPhoneLog>]
        attr_accessor :phone
      
        # # phone_numbers stored for the contact.
        # Corresponds to the JSON property `phoneNumberCount`
        # @return [Fixnum]
        attr_accessor :phone_number_count
      
        # Encodes if pkg_person was resolved via a name or relationship reference.
        # Corresponds to the JSON property `pkgReferenceType`
        # @return [String]
        attr_accessor :pkg_reference_type
      
        # Populate only if ContactRecognitionAlternate.Source is not NONE.
        # Corresponds to the JSON property `recognitionAlternateScore`
        # @return [Float]
        attr_accessor :recognition_alternate_score
      
        # Recognition alternative source type. If not none, then it indicates the
        # personal contact data is alternative and how the alternative is fulfilled.
        # Corresponds to the JSON property `recognitionAlternateSource`
        # @return [String]
        attr_accessor :recognition_alternate_source
      
        # The number of resolved relationship names and contact pointers from Assistant
        # Memory.
        # Corresponds to the JSON property `relationshipMemoryCount`
        # @return [Fixnum]
        attr_accessor :relationship_memory_count
      
        # This is the log version of apps.people.oz.external.mergedpeopleapi.Phone proto.
        # Next ID: 3
        # Corresponds to the JSON property `selectedPhone`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationPhoneLog]
        attr_accessor :selected_phone
      
        # The information on whether the contact is related to an app shortcut. Next ID:
        # 2
        # Corresponds to the JSON property `shortcutContactInfo`
        # @return [Google::Apis::ContentwarehouseV1::MajelContactInformationShortcutInformation]
        attr_accessor :shortcut_contact_info
      
        # The contact source of a contact candidate.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # Integer value corresponding to SystemContactGroup enum. http://google3/social/
        # graph/wire/proto/merged_person.proto?l=3151&rcl=320308954
        # Corresponds to the JSON property `systemContactGroupId`
        # @return [Array<Fixnum>]
        attr_accessor :system_contact_group_id
      
        # DEPRECATED. Use phone instead. Used before 2020-01-13. Number of phone numbers
        # annotated with Whatsapp.
        # Corresponds to the JSON property `whatsappPhoneNumberCount`
        # @return [Fixnum]
        attr_accessor :whatsapp_phone_number_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_provenance = args[:account_provenance] if args.key?(:account_provenance)
          @common_name_alias_confidence = args[:common_name_alias_confidence] if args.key?(:common_name_alias_confidence)
          @concept_id = args[:concept_id] if args.key?(:concept_id)
          @device_contact_attributes = args[:device_contact_attributes] if args.key?(:device_contact_attributes)
          @email_id_count = args[:email_id_count] if args.key?(:email_id_count)
          @fuzzy_ngram_match = args[:fuzzy_ngram_match] if args.key?(:fuzzy_ngram_match)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @is_contact_from_secondary_account = args[:is_contact_from_secondary_account] if args.key?(:is_contact_from_secondary_account)
          @is_shared = args[:is_shared] if args.key?(:is_shared)
          @is_transliterated_match = args[:is_transliterated_match] if args.key?(:is_transliterated_match)
          @is_vanity_contact = args[:is_vanity_contact] if args.key?(:is_vanity_contact)
          @is_visible_to_guests_relationship = args[:is_visible_to_guests_relationship] if args.key?(:is_visible_to_guests_relationship)
          @matched_name_type = args[:matched_name_type] if args.key?(:matched_name_type)
          @matched_recognition_alternate_name = args[:matched_recognition_alternate_name] if args.key?(:matched_recognition_alternate_name)
          @matched_starlight_lookup_name = args[:matched_starlight_lookup_name] if args.key?(:matched_starlight_lookup_name)
          @metadata = args[:metadata] if args.key?(:metadata)
          @name_matched_contact_index = args[:name_matched_contact_index] if args.key?(:name_matched_contact_index)
          @original_query_name = args[:original_query_name] if args.key?(:original_query_name)
          @phone = args[:phone] if args.key?(:phone)
          @phone_number_count = args[:phone_number_count] if args.key?(:phone_number_count)
          @pkg_reference_type = args[:pkg_reference_type] if args.key?(:pkg_reference_type)
          @recognition_alternate_score = args[:recognition_alternate_score] if args.key?(:recognition_alternate_score)
          @recognition_alternate_source = args[:recognition_alternate_source] if args.key?(:recognition_alternate_source)
          @relationship_memory_count = args[:relationship_memory_count] if args.key?(:relationship_memory_count)
          @selected_phone = args[:selected_phone] if args.key?(:selected_phone)
          @shortcut_contact_info = args[:shortcut_contact_info] if args.key?(:shortcut_contact_info)
          @source = args[:source] if args.key?(:source)
          @system_contact_group_id = args[:system_contact_group_id] if args.key?(:system_contact_group_id)
          @whatsapp_phone_number_count = args[:whatsapp_phone_number_count] if args.key?(:whatsapp_phone_number_count)
        end
      end
      
      # This is the log version of apps.people.oz.external.mergedpeopleapi.Phone proto.
      # Next ID: 3
      class AssistantLogsCommunicationPhoneLog
        include Google::Apis::Core::Hashable
      
        # This list provides account information from the raw contact which is the
        # source of this field.
        # Corresponds to the JSON property `rawDeviceContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationRawDeviceContactInfoLog>]
        attr_accessor :raw_device_contact_info
      
        # Label for phone number in the Contacts app. It can have standard values
        # provided by the app e.g. MOBILE, HOME, WORK etc, but users are allowed to
        # modify. So essentially it becomes user content.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_device_contact_info = args[:raw_device_contact_info] if args.key?(:raw_device_contact_info)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This is the log version of apps.people.oz.external.mergedpeopleapi.
      # RawDeviceContactInfo proto. Next ID: 3
      class AssistantLogsCommunicationRawDeviceContactInfoLog
        include Google::Apis::Core::Hashable
      
        # Account type of raw contact, e.g. "com.google" or "com.linkedin.android".
        # Corresponds to the JSON property `accountType`
        # @return [String]
        attr_accessor :account_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_type = args[:account_type] if args.key?(:account_type)
        end
      end
      
      # Log device info of default speaker and tv
      class AssistantLogsDefaultDeviceLog
        include Google::Apis::Core::Hashable
      
        # The information related to the device.
        # Corresponds to the JSON property `defaultSpeaker`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :default_speaker
      
        # The information related to the device.
        # Corresponds to the JSON property `defaultTv`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :default_tv
      
        # 
        # Corresponds to the JSON property `sourceDeviceId`
        # @return [String]
        attr_accessor :source_device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @default_speaker = args[:default_speaker] if args.key?(:default_speaker)
          @default_tv = args[:default_tv] if args.key?(:default_tv)
          @source_device_id = args[:source_device_id] if args.key?(:source_device_id)
        end
      end
      
      # 
      class AssistantLogsDefaultDevicesLog
        include Google::Apis::Core::Hashable
      
        # Log device info of default speaker and tv
        # Corresponds to the JSON property `localDefaultDevices`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDefaultDeviceLog]
        attr_accessor :local_default_devices
      
        # Default settings of nearby devices.
        # Corresponds to the JSON property `nearbyDefaultDevices`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDefaultDeviceLog>]
        attr_accessor :nearby_default_devices
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @local_default_devices = args[:local_default_devices] if args.key?(:local_default_devices)
          @nearby_default_devices = args[:nearby_default_devices] if args.key?(:nearby_default_devices)
        end
      end
      
      # Device annotation mention from query
      class AssistantLogsDeviceAnnotationLog
        include Google::Apis::Core::Hashable
      
        # The raw text mentioning a device from the query, such as "any tv".
        # Corresponds to the JSON property `rawTextFromQuery`
        # @return [String]
        attr_accessor :raw_text_from_query
      
        # The annotation type mentioned in the query.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The matched device name set by the user, such as "big screen tv".
        # Corresponds to the JSON property `userDefinedName`
        # @return [String]
        attr_accessor :user_defined_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_text_from_query = args[:raw_text_from_query] if args.key?(:raw_text_from_query)
          @type = args[:type] if args.key?(:type)
          @user_defined_name = args[:user_defined_name] if args.key?(:user_defined_name)
        end
      end
      
      # The information related to the device.
      class AssistantLogsDeviceInfoLog
        include Google::Apis::Core::Hashable
      
        # Device identifier string for the current device used in the arbitration
        # service.
        # Corresponds to the JSON property `arbitrationDeviceId`
        # @return [String]
        attr_accessor :arbitration_device_id
      
        # 
        # Corresponds to the JSON property `connectivity`
        # @return [String]
        attr_accessor :connectivity
      
        # The identification of the device. DeviceId (go/as-device-id) has multiple
        # fields. To consloidate it to a single to make dremel easier, we use the string
        # obtained by calling go/get-device-id.
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        # We index linked devices and log these index to avoid logging device_id.
        # device_index should always be a positive number or -1. -1 means this device is
        # not in homegraph.
        # Corresponds to the JSON property `deviceIndex`
        # @return [Fixnum]
        attr_accessor :device_index
      
        # This is the device_model_id field in device_settings proto. It has the same
        # value for the same type of devices. e.g. Sonos.Sonos One.S13
        # Corresponds to the JSON property `deviceModelId`
        # @return [String]
        attr_accessor :device_model_id
      
        # LINT.ThenChange(//depot/google3/assistant/context/proto/device_arbitration.
        # proto:EstimatedRelativeDistance)
        # Corresponds to the JSON property `distance`
        # @return [String]
        attr_accessor :distance
      
        # The lumos processor which eliminated this device, if applicable
        # Corresponds to the JSON property `eliminatingLumosProcessor`
        # @return [String]
        attr_accessor :eliminating_lumos_processor
      
        # 
        # Corresponds to the JSON property `isRemote`
        # @return [Boolean]
        attr_accessor :is_remote
        alias_method :is_remote?, :is_remote
      
        # This flag indicates this is a non-local device that is tethered to local/
        # originating device. Tethered device is a special case of is_remote and
        # typically used in wearable scenarios. This is always false for local device
        # and when it is true, it implies is_remote is also true.
        # Corresponds to the JSON property `isTethered`
        # @return [Boolean]
        attr_accessor :is_tethered
        alias_method :is_tethered?, :is_tethered
      
        # 
        # Corresponds to the JSON property `mediaCapabilities`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaCapabilities]
        attr_accessor :media_capabilities
      
        # 
        # Corresponds to the JSON property `mediaDeviceType`
        # @return [String]
        attr_accessor :media_device_type
      
        # User defined device name
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # This field should be populated only when there is at least one session on this
        # device.
        # Corresponds to the JSON property `sessions`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDeviceMediaSessionLog>]
        attr_accessor :sessions
      
        # This field should be populated only when the device is an Assistant device.
        # Corresponds to the JSON property `surfaceType`
        # @return [String]
        attr_accessor :surface_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @arbitration_device_id = args[:arbitration_device_id] if args.key?(:arbitration_device_id)
          @connectivity = args[:connectivity] if args.key?(:connectivity)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_index = args[:device_index] if args.key?(:device_index)
          @device_model_id = args[:device_model_id] if args.key?(:device_model_id)
          @distance = args[:distance] if args.key?(:distance)
          @eliminating_lumos_processor = args[:eliminating_lumos_processor] if args.key?(:eliminating_lumos_processor)
          @is_remote = args[:is_remote] if args.key?(:is_remote)
          @is_tethered = args[:is_tethered] if args.key?(:is_tethered)
          @media_capabilities = args[:media_capabilities] if args.key?(:media_capabilities)
          @media_device_type = args[:media_device_type] if args.key?(:media_device_type)
          @name = args[:name] if args.key?(:name)
          @sessions = args[:sessions] if args.key?(:sessions)
          @surface_type = args[:surface_type] if args.key?(:surface_type)
        end
      end
      
      # Log about the media session on a device.
      class AssistantLogsDeviceMediaSessionLog
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # 
        # Corresponds to the JSON property `mediaSessionType`
        # @return [String]
        attr_accessor :media_session_type
      
        # The type of the media session. If provider does not report this field, we ##
        # compute it by mapping provider type to media type. Here is the mapping: |
        # ProviderType |MediaItemMetadata.Type| |-------------------------------------- |
        # MUSIC |TRACK | |VIDEO |VIDEO | |LIVE_TV |TV_CHANNEL | |AUDIOBOOK |AUDIO_BOOK |
        # |PODCAST |PODCAST_EPISODE | ## |LIVE_STREAMING|VIDEO |
        # Corresponds to the JSON property `mediaType`
        # @return [String]
        attr_accessor :media_type
      
        # The playback states of the session.
        # Corresponds to the JSON property `playbackState`
        # @return [String]
        attr_accessor :playback_state
      
        # The KG mid of the media provider.
        # Corresponds to the JSON property `providerMid`
        # @return [String]
        attr_accessor :provider_mid
      
        # 
        # Corresponds to the JSON property `supportedTransportControl`
        # @return [Array<String>]
        attr_accessor :supported_transport_control
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @media_session_type = args[:media_session_type] if args.key?(:media_session_type)
          @media_type = args[:media_type] if args.key?(:media_type)
          @playback_state = args[:playback_state] if args.key?(:playback_state)
          @provider_mid = args[:provider_mid] if args.key?(:provider_mid)
          @supported_transport_control = args[:supported_transport_control] if args.key?(:supported_transport_control)
        end
      end
      
      # Contains information logged in target device selection. See go/improve-device-
      # targeting-logging for details. Next Id: 22
      class AssistantLogsDeviceSelectionLog
        include Google::Apis::Core::Hashable
      
        # Default settings of all nearby devices Deprecated, use default_devices_log
        # instead.
        # Corresponds to the JSON property `allDefaultDevices`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDefaultDeviceLog>]
        attr_accessor :all_default_devices
      
        # Logs all active media sessions.
        # Corresponds to the JSON property `allMediaStreamLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsAllMediaStreamLog]
        attr_accessor :all_media_stream_log
      
        # Contains information logged in target device selection. See go/improve-device-
        # targeting-logging for details. Next Id: 22
        # Corresponds to the JSON property `counterfactualDeviceSelectionLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceSelectionLog]
        attr_accessor :counterfactual_device_selection_log
      
        # Log device info of default speaker and tv
        # Corresponds to the JSON property `defaultDevices`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDefaultDeviceLog]
        attr_accessor :default_devices
      
        # 
        # Corresponds to the JSON property `defaultDevicesLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDefaultDevicesLog]
        attr_accessor :default_devices_log
      
        # Temporaray field for debugging ANDROID_AUTO multi_target_devices punt. This
        # will be removed once we identify the root cause.
        # Corresponds to the JSON property `devicesStr`
        # @return [Array<String>]
        attr_accessor :devices_str
      
        # 
        # Corresponds to the JSON property `inputErrorLog`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsInputErrorLog>]
        attr_accessor :input_error_log
      
        # The information related to the device.
        # Corresponds to the JSON property `localDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :local_device
      
        # Indicates which library populated the device_selection_log for this query.
        # Corresponds to the JSON property `logDataSource`
        # @return [String]
        attr_accessor :log_data_source
      
        # The information related to Media Focus. TODO(b/138952173) Deprecate
        # MediaFocusState in logs/proto/majel_gws/media_action_triggering_info.proto and
        # assistant/verticals/media/proto/target_device_info.proto
        # Corresponds to the JSON property `mediaFocus`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaFocusInfoLog]
        attr_accessor :media_focus
      
        # Following are the MDA compatible loggings for media focus, default settings
        # and nearby devices.
        # Corresponds to the JSON property `mediaFocusesLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaFocusesLog]
        attr_accessor :media_focuses_log
      
        # All nearby devices and local device.
        # Corresponds to the JSON property `nearbyDevicesLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsNearbyDevicesLog]
        attr_accessor :nearby_devices_log
      
        # Log about the query requirements
        # Corresponds to the JSON property `queryAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsQueryAnnotationLog]
        attr_accessor :query_annotation
      
        # Log the selection result. Next ID: 11
        # Corresponds to the JSON property `selectionResult`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceSelectionResultLog]
        attr_accessor :selection_result
      
        # 
        # Corresponds to the JSON property `testCodes`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDeviceTargetingTestCode>]
        attr_accessor :test_codes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_default_devices = args[:all_default_devices] if args.key?(:all_default_devices)
          @all_media_stream_log = args[:all_media_stream_log] if args.key?(:all_media_stream_log)
          @counterfactual_device_selection_log = args[:counterfactual_device_selection_log] if args.key?(:counterfactual_device_selection_log)
          @default_devices = args[:default_devices] if args.key?(:default_devices)
          @default_devices_log = args[:default_devices_log] if args.key?(:default_devices_log)
          @devices_str = args[:devices_str] if args.key?(:devices_str)
          @input_error_log = args[:input_error_log] if args.key?(:input_error_log)
          @local_device = args[:local_device] if args.key?(:local_device)
          @log_data_source = args[:log_data_source] if args.key?(:log_data_source)
          @media_focus = args[:media_focus] if args.key?(:media_focus)
          @media_focuses_log = args[:media_focuses_log] if args.key?(:media_focuses_log)
          @nearby_devices_log = args[:nearby_devices_log] if args.key?(:nearby_devices_log)
          @query_annotation = args[:query_annotation] if args.key?(:query_annotation)
          @selection_result = args[:selection_result] if args.key?(:selection_result)
          @test_codes = args[:test_codes] if args.key?(:test_codes)
        end
      end
      
      # Log the selection result. Next ID: 11
      class AssistantLogsDeviceSelectionResultLog
        include Google::Apis::Core::Hashable
      
        # This message logs details on ambiguous device targeting logic. 1. It first
        # takes a list of ambiguous devices 2. Then applies two filters: structure
        # filter and playability filter. 3. If more than one device remains, it tiggers
        # DeviceSelectionDialog to let the user pick one device.
        # Corresponds to the JSON property `ambiguousTargetDevices`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsAmbiguousTargetDeviceLog]
        attr_accessor :ambiguous_target_devices
      
        # A summary of the reasons that we chose a certain target device.
        # Corresponds to the JSON property `deviceSelectionDecisionSummary`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaDeviceSelectionDecisionSummary]
        attr_accessor :device_selection_decision_summary
      
        # 
        # Corresponds to the JSON property `deviceTargetingErrorType`
        # @return [String]
        attr_accessor :device_targeting_error_type
      
        # The class name for the final filter/promoter used by Lumos for device
        # targeting. This filter or promoter runs for all users, and contains no data
        # specific to the individual user.
        # Corresponds to the JSON property `finalLumosStage`
        # @return [String]
        attr_accessor :final_lumos_stage
      
        # Represents the case where there is a target device with low confidence so that
        # the library didn't directly target it. Instead, the library returns the low
        # confidence target device and the fallback device for the client to decide to
        # either trigger a dialog to disambiguate or select one of them based on extra
        # business logic. Next ID: 3
        # Corresponds to the JSON property `lowConfidenceTargetDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsLowConfidenceTargetDeviceLog]
        attr_accessor :low_confidence_target_device
      
        # //////////////////////////////////////////////////////////////////////////
        # This field log the error while selecting target device in media_focus_selector.
        # Corresponds to the JSON property `mediaFocusSelectionErrorType`
        # @return [String]
        attr_accessor :media_focus_selection_error_type
      
        # The log for each stage of Lumos, showing the number of eliminated devices from
        # each processor.
        # Corresponds to the JSON property `processorInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsLumosProcessorInfo>]
        attr_accessor :processor_info
      
        # This message logs details on ambiguous device targeting logic. 1. It first
        # takes a list of ambiguous devices 2. Then applies two filters: structure
        # filter and playability filter. 3. If more than one device remains, it tiggers
        # DeviceSelectionDialog to let the user pick one device.
        # Corresponds to the JSON property `qualifiedDevices`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsAmbiguousTargetDeviceLog]
        attr_accessor :qualified_devices
      
        # The information related to the device.
        # Corresponds to the JSON property `singleTargetDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :single_target_device
      
        # Represents the case where the library successfully selects the target device.
        # It could be one or multiple devices. Next ID: 3
        # Corresponds to the JSON property `targetDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsTargetDeviceLog]
        attr_accessor :target_device
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ambiguous_target_devices = args[:ambiguous_target_devices] if args.key?(:ambiguous_target_devices)
          @device_selection_decision_summary = args[:device_selection_decision_summary] if args.key?(:device_selection_decision_summary)
          @device_targeting_error_type = args[:device_targeting_error_type] if args.key?(:device_targeting_error_type)
          @final_lumos_stage = args[:final_lumos_stage] if args.key?(:final_lumos_stage)
          @low_confidence_target_device = args[:low_confidence_target_device] if args.key?(:low_confidence_target_device)
          @media_focus_selection_error_type = args[:media_focus_selection_error_type] if args.key?(:media_focus_selection_error_type)
          @processor_info = args[:processor_info] if args.key?(:processor_info)
          @qualified_devices = args[:qualified_devices] if args.key?(:qualified_devices)
          @single_target_device = args[:single_target_device] if args.key?(:single_target_device)
          @target_device = args[:target_device] if args.key?(:target_device)
        end
      end
      
      # Test code is used to track special events happening in Device Targeting
      # Library. Next Id: 2
      class AssistantLogsDeviceTargetingTestCode
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class AssistantLogsInputErrorLog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `errorCode`
        # @return [Fixnum]
        attr_accessor :error_code
      
        # 
        # Corresponds to the JSON property `errorType`
        # @return [String]
        attr_accessor :error_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @error_code = args[:error_code] if args.key?(:error_code)
          @error_type = args[:error_type] if args.key?(:error_type)
        end
      end
      
      # Represents the case where there is a target device with low confidence so that
      # the library didn't directly target it. Instead, the library returns the low
      # confidence target device and the fallback device for the client to decide to
      # either trigger a dialog to disambiguate or select one of them based on extra
      # business logic. Next ID: 3
      class AssistantLogsLowConfidenceTargetDeviceLog
        include Google::Apis::Core::Hashable
      
        # The information related to the device.
        # Corresponds to the JSON property `fallbackDeviceLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :fallback_device_log
      
        # The information related to the device.
        # Corresponds to the JSON property `lowConfTargetDeviceLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :low_conf_target_device_log
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fallback_device_log = args[:fallback_device_log] if args.key?(:fallback_device_log)
          @low_conf_target_device_log = args[:low_conf_target_device_log] if args.key?(:low_conf_target_device_log)
        end
      end
      
      # 
      class AssistantLogsLumosProcessorInfo
        include Google::Apis::Core::Hashable
      
        # Number of candidate devices after this stage is run.
        # Corresponds to the JSON property `devicesAfterRun`
        # @return [Fixnum]
        attr_accessor :devices_after_run
      
        # Number of candidate devices before this stage is run.
        # Corresponds to the JSON property `devicesBeforeRun`
        # @return [Fixnum]
        attr_accessor :devices_before_run
      
        # Name of the processor for this stage.
        # Corresponds to the JSON property `processorName`
        # @return [String]
        attr_accessor :processor_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @devices_after_run = args[:devices_after_run] if args.key?(:devices_after_run)
          @devices_before_run = args[:devices_before_run] if args.key?(:devices_before_run)
          @processor_name = args[:processor_name] if args.key?(:processor_name)
        end
      end
      
      # 
      class AssistantLogsMediaCapabilities
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `canReceiveRemoteAction`
        # @return [Boolean]
        attr_accessor :can_receive_remote_action
        alias_method :can_receive_remote_action?, :can_receive_remote_action
      
        # 
        # Corresponds to the JSON property `hasScreen`
        # @return [Boolean]
        attr_accessor :has_screen
        alias_method :has_screen?, :has_screen
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @can_receive_remote_action = args[:can_receive_remote_action] if args.key?(:can_receive_remote_action)
          @has_screen = args[:has_screen] if args.key?(:has_screen)
        end
      end
      
      # A summary of the reasons that we chose a certain target device.
      class AssistantLogsMediaDeviceSelectionDecisionSummary
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `deviceSelectionPreferenceUsed`
        # @return [String]
        attr_accessor :device_selection_preference_used
      
        # 
        # Corresponds to the JSON property `deviceSelectionReason`
        # @return [String]
        attr_accessor :device_selection_reason
      
        # 
        # Corresponds to the JSON property `miscSelectionSignal`
        # @return [Array<String>]
        attr_accessor :misc_selection_signal
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_selection_preference_used = args[:device_selection_preference_used] if args.key?(:device_selection_preference_used)
          @device_selection_reason = args[:device_selection_reason] if args.key?(:device_selection_reason)
          @misc_selection_signal = args[:misc_selection_signal] if args.key?(:misc_selection_signal)
        end
      end
      
      # The information related to Media Focus. TODO(b/138952173) Deprecate
      # MediaFocusState in logs/proto/majel_gws/media_action_triggering_info.proto and
      # assistant/verticals/media/proto/target_device_info.proto
      class AssistantLogsMediaFocusInfoLog
        include Google::Apis::Core::Hashable
      
        # How long the device is in focus so far
        # Corresponds to the JSON property `currentFocusDurationSec`
        # @return [Fixnum]
        attr_accessor :current_focus_duration_sec
      
        # TODO(b/134944092) Log MediaFocusDialogTrigger Enum in focus_status.
        # Corresponds to the JSON property `dialogTriggered`
        # @return [Boolean]
        attr_accessor :dialog_triggered
        alias_method :dialog_triggered?, :dialog_triggered
      
        # The information related to the device.
        # Corresponds to the JSON property `focusDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :focus_device
      
        # The media focus state at the time of the request.
        # Corresponds to the JSON property `mediaFocusState`
        # @return [String]
        attr_accessor :media_focus_state
      
        # The source device of media focus.
        # Corresponds to the JSON property `sourceDeviceId`
        # @return [String]
        attr_accessor :source_device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @current_focus_duration_sec = args[:current_focus_duration_sec] if args.key?(:current_focus_duration_sec)
          @dialog_triggered = args[:dialog_triggered] if args.key?(:dialog_triggered)
          @focus_device = args[:focus_device] if args.key?(:focus_device)
          @media_focus_state = args[:media_focus_state] if args.key?(:media_focus_state)
          @source_device_id = args[:source_device_id] if args.key?(:source_device_id)
        end
      end
      
      # Following are the MDA compatible loggings for media focus, default settings
      # and nearby devices.
      class AssistantLogsMediaFocusesLog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dialogTriggered`
        # @return [Boolean]
        attr_accessor :dialog_triggered
        alias_method :dialog_triggered?, :dialog_triggered
      
        # The information related to Media Focus. TODO(b/138952173) Deprecate
        # MediaFocusState in logs/proto/majel_gws/media_action_triggering_info.proto and
        # assistant/verticals/media/proto/target_device_info.proto
        # Corresponds to the JSON property `localMediaFocus`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsMediaFocusInfoLog]
        attr_accessor :local_media_focus
      
        # Deprecated, use nearby_media_focuses instead.
        # Corresponds to the JSON property `mediaFocuses`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsMediaFocusInfoLog>]
        attr_accessor :media_focuses
      
        # MediaFouces found on nearby devices.
        # Corresponds to the JSON property `nearbyMediaFocuses`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsMediaFocusInfoLog>]
        attr_accessor :nearby_media_focuses
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dialog_triggered = args[:dialog_triggered] if args.key?(:dialog_triggered)
          @local_media_focus = args[:local_media_focus] if args.key?(:local_media_focus)
          @media_focuses = args[:media_focuses] if args.key?(:media_focuses)
          @nearby_media_focuses = args[:nearby_media_focuses] if args.key?(:nearby_media_focuses)
        end
      end
      
      # Media stream is composed of a media session and one or more devices which are
      # hosting (playing) the session. Usually, a session is only hosted by one devcie.
      # However, with cast group or stream transfer/expansion, a session could be
      # hosted by multiple devices, which are playing the same session simultaneously.
      class AssistantLogsMediaStreamLog
        include Google::Apis::Core::Hashable
      
        # The device index in this message is consistent with the device index in
        # DeviceInfoLog. This field refers to the devices that hosting the session.
        # Corresponds to the JSON property `deviceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :device_index
      
        # Log about the media session on a device.
        # Corresponds to the JSON property `session`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceMediaSessionLog]
        attr_accessor :session
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_index = args[:device_index] if args.key?(:device_index)
          @session = args[:session] if args.key?(:session)
        end
      end
      
      # 
      class AssistantLogsNearbyDevicesLog
        include Google::Apis::Core::Hashable
      
        # The timestamp that DeviceArbitration is created in milliseconds.
        # Corresponds to the JSON property `deviceArbitrationCreationTimestampMs`
        # @return [Fixnum]
        attr_accessor :device_arbitration_creation_timestamp_ms
      
        # 
        # Corresponds to the JSON property `eliminatedByFurtherDistance`
        # @return [Fixnum]
        attr_accessor :eliminated_by_further_distance
      
        # 
        # Corresponds to the JSON property `eliminatedByLocalClosest`
        # @return [Fixnum]
        attr_accessor :eliminated_by_local_closest
      
        # 
        # Corresponds to the JSON property `eliminatedByUnknownDifferentRoom`
        # @return [Fixnum]
        attr_accessor :eliminated_by_unknown_different_room
      
        # 
        # Corresponds to the JSON property `eliminatedByUnregisteredDevice`
        # @return [Fixnum]
        attr_accessor :eliminated_by_unregistered_device
      
        # The information related to the device.
        # Corresponds to the JSON property `localDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog]
        attr_accessor :local_device
      
        # 
        # Corresponds to the JSON property `nearbyDevices`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog>]
        attr_accessor :nearby_devices
      
        # 
        # Corresponds to the JSON property `numClosestDevices`
        # @return [Fixnum]
        attr_accessor :num_closest_devices
      
        # 
        # Corresponds to the JSON property `numEquallyCloseDevices`
        # @return [Fixnum]
        attr_accessor :num_equally_close_devices
      
        # 
        # Corresponds to the JSON property `numFurtherDevices`
        # @return [Fixnum]
        attr_accessor :num_further_devices
      
        # 
        # Corresponds to the JSON property `numHearingDevices`
        # @return [Fixnum]
        attr_accessor :num_hearing_devices
      
        # 
        # Corresponds to the JSON property `numUnknownDistanceDevices`
        # @return [Fixnum]
        attr_accessor :num_unknown_distance_devices
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_arbitration_creation_timestamp_ms = args[:device_arbitration_creation_timestamp_ms] if args.key?(:device_arbitration_creation_timestamp_ms)
          @eliminated_by_further_distance = args[:eliminated_by_further_distance] if args.key?(:eliminated_by_further_distance)
          @eliminated_by_local_closest = args[:eliminated_by_local_closest] if args.key?(:eliminated_by_local_closest)
          @eliminated_by_unknown_different_room = args[:eliminated_by_unknown_different_room] if args.key?(:eliminated_by_unknown_different_room)
          @eliminated_by_unregistered_device = args[:eliminated_by_unregistered_device] if args.key?(:eliminated_by_unregistered_device)
          @local_device = args[:local_device] if args.key?(:local_device)
          @nearby_devices = args[:nearby_devices] if args.key?(:nearby_devices)
          @num_closest_devices = args[:num_closest_devices] if args.key?(:num_closest_devices)
          @num_equally_close_devices = args[:num_equally_close_devices] if args.key?(:num_equally_close_devices)
          @num_further_devices = args[:num_further_devices] if args.key?(:num_further_devices)
          @num_hearing_devices = args[:num_hearing_devices] if args.key?(:num_hearing_devices)
          @num_unknown_distance_devices = args[:num_unknown_distance_devices] if args.key?(:num_unknown_distance_devices)
        end
      end
      
      # Log about the query requirements
      class AssistantLogsQueryAnnotationLog
        include Google::Apis::Core::Hashable
      
        # Device annotation mention from query
        # Corresponds to the JSON property `deviceAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceAnnotationLog]
        attr_accessor :device_annotation
      
        # Log the device annotations mentioned in the query.
        # Corresponds to the JSON property `deviceAnnotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDeviceAnnotationLog>]
        attr_accessor :device_annotations
      
        # Room annotation mentioned in query.
        # Corresponds to the JSON property `roomAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsRoomAnnotationLog]
        attr_accessor :room_annotation
      
        # Log the room annotations mentioned in the query.
        # Corresponds to the JSON property `roomAnnotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsRoomAnnotationLog>]
        attr_accessor :room_annotations
      
        # Log the structure annotations mentioned in the query.
        # Corresponds to the JSON property `structureAnnotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsStructureAnnotationLog>]
        attr_accessor :structure_annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_annotation = args[:device_annotation] if args.key?(:device_annotation)
          @device_annotations = args[:device_annotations] if args.key?(:device_annotations)
          @room_annotation = args[:room_annotation] if args.key?(:room_annotation)
          @room_annotations = args[:room_annotations] if args.key?(:room_annotations)
          @structure_annotations = args[:structure_annotations] if args.key?(:structure_annotations)
        end
      end
      
      # Annotate a single reminder instance.
      class AssistantLogsReminderLog
        include Google::Apis::Core::Hashable
      
        # The reminder is created N seconds ago. This helps tracking how the user issues
        # follow-up actions after reminder is created. For example, whether the user
        # likes to issues another [show reminders] query right after reminder is created?
        # Corresponds to the JSON property `createdSecondsAgo`
        # @return [Fixnum]
        attr_accessor :created_seconds_ago
      
        # If the reminder is retrieved by a ranking class (see go/opa-reminders-ranker),
        # this will be populated with the class info. Refer to assistant.productivity.
        # ReminderRankingClass.RankingType. Since that proto is in proto2 format, we can
        # only wire by int type.
        # Corresponds to the JSON property `retrievedRankingClass`
        # @return [Fixnum]
        attr_accessor :retrieved_ranking_class
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @created_seconds_ago = args[:created_seconds_ago] if args.key?(:created_seconds_ago)
          @retrieved_ranking_class = args[:retrieved_ranking_class] if args.key?(:retrieved_ranking_class)
        end
      end
      
      # Room annotation mentioned in query.
      class AssistantLogsRoomAnnotationLog
        include Google::Apis::Core::Hashable
      
        # The raw text mentioning a room from the query, such as "my living room".
        # Corresponds to the JSON property `rawTextFromQuery`
        # @return [String]
        attr_accessor :raw_text_from_query
      
        # The number of rooms annotated, if there are multiple structures. They are
        # guaranteed to have the same text_from_query and name due to exact matching.
        # Corresponds to the JSON property `roomCount`
        # @return [Fixnum]
        attr_accessor :room_count
      
        # The annotation type mentioned in the query.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `userDefinedName`
        # @return [String]
        attr_accessor :user_defined_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_text_from_query = args[:raw_text_from_query] if args.key?(:raw_text_from_query)
          @room_count = args[:room_count] if args.key?(:room_count)
          @type = args[:type] if args.key?(:type)
          @user_defined_name = args[:user_defined_name] if args.key?(:user_defined_name)
        end
      end
      
      # Structure annotation mentioned in query.
      class AssistantLogsStructureAnnotationLog
        include Google::Apis::Core::Hashable
      
        # The raw text mentioning a structure from the query, such as "my house".
        # Corresponds to the JSON property `rawTextFromQuery`
        # @return [String]
        attr_accessor :raw_text_from_query
      
        # The annotation type mentioned in the query.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `userDefinedName`
        # @return [String]
        attr_accessor :user_defined_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_text_from_query = args[:raw_text_from_query] if args.key?(:raw_text_from_query)
          @type = args[:type] if args.key?(:type)
          @user_defined_name = args[:user_defined_name] if args.key?(:user_defined_name)
        end
      end
      
      # Represents the case where the library successfully selects the target device.
      # It could be one or multiple devices. Next ID: 3
      class AssistantLogsTargetDeviceLog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `devices`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantLogsDeviceInfoLog>]
        attr_accessor :devices
      
        # 
        # Corresponds to the JSON property `resultConfidenceLevel`
        # @return [String]
        attr_accessor :result_confidence_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @devices = args[:devices] if args.key?(:devices)
          @result_confidence_level = args[:result_confidence_level] if args.key?(:result_confidence_level)
        end
      end
      
      # Signals to be used by the Prefulfillment Ranker. Derived from the
      # ParsingSignals and GroundingSignals carried by the FunctionCall. LINT.IfChange
      # Next ID: 25
      class AssistantPrefulfillmentRankerPrefulfillmentSignals
        include Google::Apis::Core::Hashable
      
        # A parsing score that is independently calibrated by each parser/IG.
        # Corresponds to the JSON property `calibratedParsingScore`
        # @return [Float]
        attr_accessor :calibrated_parsing_score
      
        # Same semantics as 'calibrated_parsing_score' but in float form. Some RL models
        # (such as decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `calibratedParsingScoreFloat`
        # @return [Float]
        attr_accessor :calibrated_parsing_score_float
      
        # Indicates interpretation dominance predicted by KScorer
        # Corresponds to the JSON property `dominant`
        # @return [Boolean]
        attr_accessor :dominant
        alias_method :dominant?, :dominant
      
        # The total effective length of the spans for the arguments used to construct
        # the parse. May include vertical specific adjustments. Eg: For the query [
        # delete my 7 p.m. alarm called chicken] and intent Delete_alarm(alarm_object=RD(
        # category=AlarmObject( label="chicken", trigger_time_datetime=<< 7 PM >>))),
        # the effective argument span is "7 p.m." + "chicken" (total length of 13).
        # Corresponds to the JSON property `effectiveArgSpanLength`
        # @return [Float]
        attr_accessor :effective_arg_span_length
      
        # Grounding Signals. Score indicating how grounded the intent is, populated by
        # the Grounding Box.
        # Corresponds to the JSON property `groundabilityScore`
        # @return [Float]
        attr_accessor :groundability_score
      
        # This is a cross-intent feature which is calculated by iterating all intent
        # candidates. This feature should be populated in post-IG stage (before GB).
        # Corresponds to the JSON property `inQueryMaxEffectiveArgSpanLength`
        # @return [Float]
        attr_accessor :in_query_max_effective_arg_span_length
      
        # intent_name is used by PFR ensemble model. See go/pfr_ha_launch_doc
        # Corresponds to the JSON property `intentName`
        # @return [String]
        attr_accessor :intent_name
      
        # QUS intent-based ranking signals. Assistant User Interaction Score which is
        # aggregated using intent name.
        # Corresponds to the JSON property `intentNameAuisScore`
        # @return [Float]
        attr_accessor :intent_name_auis_score
      
        # Assistant User Interaction Score which is aggregated using intent name from
        # exp laelaps.
        # Corresponds to the JSON property `intentNameAuisScoreExp`
        # @return [Float]
        attr_accessor :intent_name_auis_score_exp
      
        # This feature is always false / no-op in serving time. In training time, this
        # feature may be set true on specific examples for weighted training where when
        # this signal is true, only cross-intent level features are used for training
        # and other candidate level features are masked (set as missing).
        # Corresponds to the JSON property `maskCandidateLevelFeatures`
        # @return [Boolean]
        attr_accessor :mask_candidate_level_features
        alias_method :mask_candidate_level_features?, :mask_candidate_level_features
      
        # Sum of the number of constraints used by the Grounding Box to ground each
        # variable.
        # Corresponds to the JSON property `numConstraints`
        # @return [Float]
        attr_accessor :num_constraints
      
        # Same semantics as 'num_constraints' but in float form. Some RL models (such as
        # decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numConstraintsFloat`
        # @return [Float]
        attr_accessor :num_constraints_float
      
        # Sum of the number of constraints satisfied for each variable. Depending on the
        # match score for a constraint, this number can be fractional and is in the
        # range [0, num_constraints]. Populated by the Grounding Box.
        # Corresponds to the JSON property `numConstraintsSatisfied`
        # @return [Float]
        attr_accessor :num_constraints_satisfied
      
        # Same semantics as 'num_constraints_satisfied' but in float form. Some RL
        # models (such as decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numConstraintsSatisfiedFloat`
        # @return [Float]
        attr_accessor :num_constraints_satisfied_float
      
        # Number of groundable arguments the intent has, populated by the Grounding Box.
        # Corresponds to the JSON property `numGroundableArgs`
        # @return [Float]
        attr_accessor :num_groundable_args
      
        # Same semantics as 'num_groundable_args' but in float form. Some RL models (
        # such as decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numGroundableArgsFloat`
        # @return [Float]
        attr_accessor :num_groundable_args_float
      
        # Number of grounded arguments the intent has, populated by the Grounding Box.
        # Corresponds to the JSON property `numGroundedArgs`
        # @return [Float]
        attr_accessor :num_grounded_args
      
        # Same semantics as 'num_grounded_args' but in float form. Some RL models (such
        # as decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numGroundedArgsFloat`
        # @return [Float]
        attr_accessor :num_grounded_args_float
      
        # Signals as proposed in go/improved-grounding-signals. Number of arguments,
        # possibly nested, that the Grounding Box tried to ground.
        # Corresponds to the JSON property `numVariables`
        # @return [Float]
        attr_accessor :num_variables
      
        # Same semantics as 'num_variables' but in float form. Some RL models (such as
        # decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numVariablesFloat`
        # @return [Float]
        attr_accessor :num_variables_float
      
        # Number of arguments, possibly nested, that the Grounding Box was able to
        # ground. This includes ambiguously grounded arguments.
        # Corresponds to the JSON property `numVariablesGrounded`
        # @return [Float]
        attr_accessor :num_variables_grounded
      
        # Same semantics as 'num_variables_grounded' but in float form. Some RL models (
        # such as decision tree) doesn't consume double input well.
        # Corresponds to the JSON property `numVariablesGroundedFloat`
        # @return [Float]
        attr_accessor :num_variables_grounded_float
      
        # Cosine similarity between predicted query-to-term model and assistant intent-
        # type-based salient terms. This is intended to be only used for ACE ranking and
        # only populated for assistant traffic.
        # Corresponds to the JSON property `pq2tVsAssistantIbstCosine`
        # @return [Float]
        attr_accessor :pq2t_vs_assistant_ibst_cosine
      
        # Cosine similarity between predicted query-to-term model and intent-type-based
        # salient terms. This is intended to be used as a backoff to
        # pq2t_vs_qibst_cosine if it is missing.
        # Corresponds to the JSON property `pq2tVsIbstCosine`
        # @return [Float]
        attr_accessor :pq2t_vs_ibst_cosine
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calibrated_parsing_score = args[:calibrated_parsing_score] if args.key?(:calibrated_parsing_score)
          @calibrated_parsing_score_float = args[:calibrated_parsing_score_float] if args.key?(:calibrated_parsing_score_float)
          @dominant = args[:dominant] if args.key?(:dominant)
          @effective_arg_span_length = args[:effective_arg_span_length] if args.key?(:effective_arg_span_length)
          @groundability_score = args[:groundability_score] if args.key?(:groundability_score)
          @in_query_max_effective_arg_span_length = args[:in_query_max_effective_arg_span_length] if args.key?(:in_query_max_effective_arg_span_length)
          @intent_name = args[:intent_name] if args.key?(:intent_name)
          @intent_name_auis_score = args[:intent_name_auis_score] if args.key?(:intent_name_auis_score)
          @intent_name_auis_score_exp = args[:intent_name_auis_score_exp] if args.key?(:intent_name_auis_score_exp)
          @mask_candidate_level_features = args[:mask_candidate_level_features] if args.key?(:mask_candidate_level_features)
          @num_constraints = args[:num_constraints] if args.key?(:num_constraints)
          @num_constraints_float = args[:num_constraints_float] if args.key?(:num_constraints_float)
          @num_constraints_satisfied = args[:num_constraints_satisfied] if args.key?(:num_constraints_satisfied)
          @num_constraints_satisfied_float = args[:num_constraints_satisfied_float] if args.key?(:num_constraints_satisfied_float)
          @num_groundable_args = args[:num_groundable_args] if args.key?(:num_groundable_args)
          @num_groundable_args_float = args[:num_groundable_args_float] if args.key?(:num_groundable_args_float)
          @num_grounded_args = args[:num_grounded_args] if args.key?(:num_grounded_args)
          @num_grounded_args_float = args[:num_grounded_args_float] if args.key?(:num_grounded_args_float)
          @num_variables = args[:num_variables] if args.key?(:num_variables)
          @num_variables_float = args[:num_variables_float] if args.key?(:num_variables_float)
          @num_variables_grounded = args[:num_variables_grounded] if args.key?(:num_variables_grounded)
          @num_variables_grounded_float = args[:num_variables_grounded_float] if args.key?(:num_variables_grounded_float)
          @pq2t_vs_assistant_ibst_cosine = args[:pq2t_vs_assistant_ibst_cosine] if args.key?(:pq2t_vs_assistant_ibst_cosine)
          @pq2t_vs_ibst_cosine = args[:pq2t_vs_ibst_cosine] if args.key?(:pq2t_vs_ibst_cosine)
        end
      end
      
      # A message to represent an item in a list. Just a basic string for now, but
      # extensible for the future.
      class AssistantProductivityListItem
        include Google::Apis::Core::Hashable
      
        # [REQUIRED] The name of the list item.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Proto descrbing an attachment to an Assistant Reminder. If the attachment has
      # different behavior on different surfaces (e.g., deeplinks), there will be
      # multiple attachments attach to the Reminder. Each of them will specify the
      # surface type and the corresponding deeplink.
      class AssistantRemindersAttachment
        include Google::Apis::Core::Hashable
      
        # REQUIRED. An unique identifier for the attachment. We have a plan to index
        # this field, so it's marked as REQUIRED. Chat with opa-reminders-eng@ if you
        # have a use case without an attachment ID.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `link`
        # @return [Google::Apis::ContentwarehouseV1::AssistantRemindersAttachmentLink]
        attr_accessor :link
      
        # REQUIRED. Surface types this attachment should be shown.
        # Corresponds to the JSON property `surfaceType`
        # @return [Array<String>]
        attr_accessor :surface_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @link = args[:link] if args.key?(:link)
          @surface_type = args[:surface_type] if args.key?(:surface_type)
        end
      end
      
      # 
      class AssistantRemindersAttachmentLink
        include Google::Apis::Core::Hashable
      
        # REQUIRED. The link to surface to frontends (e.g., Hubpage, notifications.)
        # This could also be a surface-specific deeplink (be sure to set `surface_type`
        # accordingly.)
        # Corresponds to the JSON property `linkUrl`
        # @return [String]
        attr_accessor :link_url
      
        # Equivalent to nlp_generation.TemplateKey. We cannot use nlp_generation.
        # TemplateKey message directly becasue that proto is defined in a relatively
        # large proto and has other dependencies, which will increase the size
        # unnecessary and might hit many limitations (e.g., 5MiB limitation for Spanner
        # type environment.).
        # Corresponds to the JSON property `notificationText`
        # @return [Google::Apis::ContentwarehouseV1::AssistantRemindersNlgTemplateKey]
        attr_accessor :notification_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @link_url = args[:link_url] if args.key?(:link_url)
          @notification_text = args[:notification_text] if args.key?(:notification_text)
        end
      end
      
      # Since this is stored in BE, any update on this proto needs LGTM by ARIS
      # storage owner
      class AssistantRemindersMemoryPayload
        include Google::Apis::Core::Hashable
      
        # Whether the reminder created has a referenced_entity attached to it or not(go/
        # hub-memory-payload). Since we plan to set this in Assistant reminder creation
        # path flow, in case later the referenced_entity is removed from the reminder,
        # then this bit might still remain true. Also in case referenced_entity is later
        # added to reminder(for example when referenced_entity is attached by Server),
        # then also this bit might remain false. This bit will be used to *guess* if the
        # user has a memory-enabled AGSA, thus we'll surface the "open memory" button on
        # hubpage. This check is not perfect, as the user might have other phones with
        # older AGSA, so this is just a *best guess*. This field won't be stored in
        # Memory backend, and will not be populated back when retrieving reminders.
        # Corresponds to the JSON property `hasReferencedEntityAtCreation`
        # @return [Boolean]
        attr_accessor :has_referenced_entity_at_creation
        alias_method :has_referenced_entity_at_creation?, :has_referenced_entity_at_creation
      
        # Id of record that is associated with Reminder. This will be set for all
        # Assistant reminders created after the first launch of the Reminder Memory
        # integration, see go/reminders-memory for more details. Also, this might apply
        # to all other types of reminders.
        # Corresponds to the JSON property `recordId`
        # @return [String]
        attr_accessor :record_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_referenced_entity_at_creation = args[:has_referenced_entity_at_creation] if args.key?(:has_referenced_entity_at_creation)
          @record_id = args[:record_id] if args.key?(:record_id)
        end
      end
      
      # Equivalent to nlp_generation.TemplateKey. We cannot use nlp_generation.
      # TemplateKey message directly becasue that proto is defined in a relatively
      # large proto and has other dependencies, which will increase the size
      # unnecessary and might hit many limitations (e.g., 5MiB limitation for Spanner
      # type environment.).
      class AssistantRemindersNlgTemplateKey
        include Google::Apis::Core::Hashable
      
        # REQUIRED.
        # Corresponds to the JSON property `messageSet`
        # @return [String]
        attr_accessor :message_set
      
        # REQUIRED.
        # Corresponds to the JSON property `templateName`
        # @return [String]
        attr_accessor :template_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message_set = args[:message_set] if args.key?(:message_set)
          @template_name = args[:template_name] if args.key?(:template_name)
        end
      end
      
      # 
      class AssistantTeleportTeleportNicknameSignals
        include Google::Apis::Core::Hashable
      
        # Whether the nickname could also refer to a location. For example, "walmart", "
        # starbucks".
        # Corresponds to the JSON property `hasLocationInterpretation`
        # @return [Boolean]
        attr_accessor :has_location_interpretation
        alias_method :has_location_interpretation?, :has_location_interpretation
      
        # Indicates whether the user has the app installed.
        # Corresponds to the JSON property `installInfo`
        # @return [String]
        attr_accessor :install_info
      
        # True when the name is generic, i.e when it could refer to multiple packages
        # from different developrs. For example, "mail" is considered a generic name (
        # since it can refer to "gmail", "yahoo mail" etc.) but "facebook" although
        # could refer to both "facebook" and "facebook lite" is not considered generic (
        # both packages are from the same third party).
        # Corresponds to the JSON property `isGeneric`
        # @return [Boolean]
        attr_accessor :is_generic
        alias_method :is_generic?, :is_generic
      
        # The tier of the nickname.
        # Corresponds to the JSON property `nicknameTier`
        # @return [String]
        attr_accessor :nickname_tier
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_location_interpretation = args[:has_location_interpretation] if args.key?(:has_location_interpretation)
          @install_info = args[:install_info] if args.key?(:install_info)
          @is_generic = args[:is_generic] if args.key?(:is_generic)
          @nickname_tier = args[:nickname_tier] if args.key?(:nickname_tier)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Neural contact match signals.
      class AssistantVerticalsCommonContactMatchSignal
        include Google::Apis::Core::Hashable
      
        # Neural contact match similarity score.
        # Corresponds to the JSON property `matchScore`
        # @return [Float]
        attr_accessor :match_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @match_score = args[:match_score] if args.key?(:match_score)
        end
      end
      
      # Metadata for Actions-on-Google configuration.
      class AssistantVerticalsHomeautomationProtoActionProjectConfig
        include Google::Apis::Core::Hashable
      
        # Actions-on-Google action context ID. See go/sdm-hospitality-design.
        # Corresponds to the JSON property `contextId`
        # @return [String]
        attr_accessor :context_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @context_id = args[:context_id] if args.key?(:context_id)
        end
      end
      
      # An agent + device pair that uniquely identifies a device.
      class AssistantVerticalsHomeautomationProtoAgentDeviceId
        include Google::Apis::Core::Hashable
      
        # The agent's ID. Generally it is the agent's Google pantheon project id.
        # Corresponds to the JSON property `agentId`
        # @return [String]
        attr_accessor :agent_id
      
        # Device ID defined by the agent.
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_id = args[:agent_id] if args.key?(:agent_id)
          @device_id = args[:device_id] if args.key?(:device_id)
        end
      end
      
      # AgentInformation represents the details needed to support both 1P and 3P
      # partnerships for Home Automation. Next ID: 7
      class AssistantVerticalsHomeautomationProtoAgentInformation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `authType`
        # @return [String]
        attr_accessor :auth_type
      
        # 
        # Corresponds to the JSON property `deviceSource`
        # @return [String]
        attr_accessor :device_source
      
        # 
        # Corresponds to the JSON property `executionPath`
        # @return [String]
        attr_accessor :execution_path
      
        # Unique Agent ID which maps to a specific Agent. Not using Agent Name here as
        # it may change over time.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Agent's foreign key that uniquely identifies a user's device.
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @auth_type = args[:auth_type] if args.key?(:auth_type)
          @device_source = args[:device_source] if args.key?(:device_source)
          @execution_path = args[:execution_path] if args.key?(:execution_path)
          @id = args[:id] if args.key?(:id)
          @key = args[:key] if args.key?(:key)
        end
      end
      
      # Protos representing device or structure attributes. See go/hgs-attributes-
      # protos. Only protos approved and formalized by assistant/HG team should be
      # added here.
      class AssistantVerticalsHomeautomationProtoAttribute
        include Google::Apis::Core::Hashable
      
        # Routines team stores the core Structure Based Routine data as the payload. We
        # will add specific metadata on a per-need basis. LINT.IfChange(
        # proto_structure_based_routine) Next id: 12 These two forms of payload are
        # equivalent data in different formats and both will be stored in Home Graph. 1.
        # The internal format will fan out to the DynamicEntity Footprints for read in
        # Settings flow and Execution. 2. The UI format will be stripped out upon
        # replication to DynamicEntity Footprints due to its redundancy and the
        # Footprints data size limit, i.e. DE Footprints will only contain the internal
        # format.
        # Corresponds to the JSON property `structureBasedRoutine`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoCommonStructureBasedRoutine]
        attr_accessor :structure_based_routine
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @structure_based_routine = args[:structure_based_routine] if args.key?(:structure_based_routine)
        end
      end
      
      # LINT.IfChange(proto_attributes)
      class AssistantVerticalsHomeautomationProtoAttributes
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attributeProtos`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoAttribute>]
        attr_accessor :attribute_protos
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_protos = args[:attribute_protos] if args.key?(:attribute_protos)
        end
      end
      
      # LINT.IfChange(proto_event_trigger) Next id: 5
      class AssistantVerticalsHomeautomationProtoCommonEventTrigger
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # Detailed settings for the event trigger; unset if not applicable.
        # Corresponds to the JSON property `eventTriggerPayload`
        # @return [Hash<String,Object>]
        attr_accessor :event_trigger_payload
      
        # Different event type may have different settings. For example: * SCHEDULED
        # will have event_trigger_payload of cs/symbol:assistant.verticals.
        # voice_shortcut.proto.Schedule * LOCATION will have event_trigger_payload of cs/
        # symbol:assistant.verticals.voice_shortcut.proto.LocationTriggerEvent
        # Corresponds to the JSON property `eventTriggerType`
        # @return [String]
        attr_accessor :event_trigger_type
      
        # Unique identifier for the EventTrigger, e.g. SCHEDULED_ROUTINES. See the enum
        # values of cs/symbol:WorkflowTriggerInput.TriggerSource
        # Corresponds to the JSON property `triggerSource`
        # @return [Fixnum]
        attr_accessor :trigger_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
          @event_trigger_payload = args[:event_trigger_payload] if args.key?(:event_trigger_payload)
          @event_trigger_type = args[:event_trigger_type] if args.key?(:event_trigger_type)
          @trigger_source = args[:trigger_source] if args.key?(:trigger_source)
        end
      end
      
      # Routines team stores the core Structure Based Routine data as the payload. We
      # will add specific metadata on a per-need basis. LINT.IfChange(
      # proto_structure_based_routine) Next id: 12 These two forms of payload are
      # equivalent data in different formats and both will be stored in Home Graph. 1.
      # The internal format will fan out to the DynamicEntity Footprints for read in
      # Settings flow and Execution. 2. The UI format will be stripped out upon
      # replication to DynamicEntity Footprints due to its redundancy and the
      # Footprints data size limit, i.e. DE Footprints will only contain the internal
      # format.
      class AssistantVerticalsHomeautomationProtoCommonStructureBasedRoutine
        include Google::Apis::Core::Hashable
      
        # Whether this Routine is enabled or not. If false, then this Routine can't be
        # triggered by Voice.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # The unique identifier for a class of workflows. For example: * "sbr_001" =>
        # Away * "sbr_002" => Home * "category_template" => CUSTOM
        # Corresponds to the JSON property `googlePreconfigWorkflowId`
        # @return [String]
        attr_accessor :google_preconfig_workflow_id
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Internal format payload primarily for Routines team use.
        # Corresponds to the JSON property `payload`
        # @return [Hash<String,Object>]
        attr_accessor :payload
      
        # The security level of the Structure Based Routine as determined by the most
        # security-sensitive task.
        # Corresponds to the JSON property `securityLevel`
        # @return [String]
        attr_accessor :security_level
      
        # 
        # Corresponds to the JSON property `shared`
        # @return [Boolean]
        attr_accessor :shared
        alias_method :shared?, :shared
      
        # 
        # Corresponds to the JSON property `storagePayload`
        # @return [Hash<String,Object>]
        attr_accessor :storage_payload
      
        # 
        # Corresponds to the JSON property `structureId`
        # @return [String]
        attr_accessor :structure_id
      
        # Voice or event triggers.
        # Corresponds to the JSON property `triggers`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoCommonStructureBasedRoutineTrigger>]
        attr_accessor :triggers
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # UI format payload primarily for external team use.
        # Corresponds to the JSON property `uiPayload`
        # @return [Hash<String,Object>]
        attr_accessor :ui_payload
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enabled = args[:enabled] if args.key?(:enabled)
          @google_preconfig_workflow_id = args[:google_preconfig_workflow_id] if args.key?(:google_preconfig_workflow_id)
          @language = args[:language] if args.key?(:language)
          @payload = args[:payload] if args.key?(:payload)
          @security_level = args[:security_level] if args.key?(:security_level)
          @shared = args[:shared] if args.key?(:shared)
          @storage_payload = args[:storage_payload] if args.key?(:storage_payload)
          @structure_id = args[:structure_id] if args.key?(:structure_id)
          @triggers = args[:triggers] if args.key?(:triggers)
          @type = args[:type] if args.key?(:type)
          @ui_payload = args[:ui_payload] if args.key?(:ui_payload)
        end
      end
      
      # Next id: 3
      class AssistantVerticalsHomeautomationProtoCommonStructureBasedRoutineTrigger
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(proto_event_trigger) Next id: 5
        # Corresponds to the JSON property `eventTrigger`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoCommonEventTrigger]
        attr_accessor :event_trigger
      
        # LINT.IfChange(proto_voice_trigger) Next id: 2
        # Corresponds to the JSON property `voiceTrigger`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoCommonVoiceTrigger]
        attr_accessor :voice_trigger
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event_trigger = args[:event_trigger] if args.key?(:event_trigger)
          @voice_trigger = args[:voice_trigger] if args.key?(:voice_trigger)
        end
      end
      
      # LINT.IfChange(proto_voice_trigger) Next id: 2
      class AssistantVerticalsHomeautomationProtoCommonVoiceTrigger
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @query = args[:query] if args.key?(:query)
        end
      end
      
      # The Concierge features a structure is eligible for. See `@link home.graph.
      # common.ConciergeFeatures`.
      class AssistantVerticalsHomeautomationProtoConciergeFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `conciergeProductFeatures`
        # @return [Array<String>]
        attr_accessor :concierge_product_features
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @concierge_product_features = args[:concierge_product_features] if args.key?(:concierge_product_features)
        end
      end
      
      # Next ID: 5
      class AssistantVerticalsHomeautomationProtoDeviceTargetingOutputQueryInfo
        include Google::Apis::Core::Hashable
      
        # The query span for device mention.
        # Corresponds to the JSON property `annotatedSpanDevice`
        # @return [String]
        attr_accessor :annotated_span_device
      
        # The query span for room mention.
        # Corresponds to the JSON property `annotatedSpanRoom`
        # @return [String]
        attr_accessor :annotated_span_room
      
        # The query span for structure mention.
        # Corresponds to the JSON property `annotatedSpanStructure`
        # @return [String]
        attr_accessor :annotated_span_structure
      
        # This field is from query_info.processed_mentioned_span in DTO.
        # Corresponds to the JSON property `processedMentionedSpan`
        # @return [String]
        attr_accessor :processed_mentioned_span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotated_span_device = args[:annotated_span_device] if args.key?(:annotated_span_device)
          @annotated_span_room = args[:annotated_span_room] if args.key?(:annotated_span_room)
          @annotated_span_structure = args[:annotated_span_structure] if args.key?(:annotated_span_structure)
          @processed_mentioned_span = args[:processed_mentioned_span] if args.key?(:processed_mentioned_span)
        end
      end
      
      # Next ID: 9
      class AssistantVerticalsHomeautomationProtoHomeAutomationDevice
        include Google::Apis::Core::Hashable
      
        # Contains information logged in target device selection. See go/improve-device-
        # targeting-logging for details. Next Id: 22
        # Corresponds to the JSON property `deviceSelectionLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsDeviceSelectionLog]
        attr_accessor :device_selection_log
      
        # The information associated with an error while selecting the target device.
        # Next ID: 2
        # Corresponds to the JSON property `dtoError`
        # @return [Google::Apis::ContentwarehouseV1::AssistantDeviceTargetingDeviceTargetingError]
        attr_accessor :dto_error
      
        # Next ID: 5
        # Corresponds to the JSON property `dtoQueryInfo`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoDeviceTargetingOutputQueryInfo]
        attr_accessor :dto_query_info
      
        # Next ID: 40
        # Corresponds to the JSON property `homeautomationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoHomeAutomationMetaData]
        attr_accessor :homeautomation_metadata
      
        # list of HomeAutomationDeviceItem. After migration completes, we will mark the
        # above 4 field as deprecated and only use this field.
        # Corresponds to the JSON property `list`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoHomeAutomationDeviceItem>]
        attr_accessor :list
      
        # Corresponding to casse matched_item CustomTypeItem key.
        # Corresponds to the JSON property `matchedItemKey`
        # @return [String]
        attr_accessor :matched_item_key
      
        # Corresponding to casse Argument raw_value.
        # Corresponds to the JSON property `matchedItemRawvalue`
        # @return [String]
        attr_accessor :matched_item_rawvalue
      
        # Corresponding to casse matched_item CustomTypeItem value.
        # Corresponds to the JSON property `matchedItemValue`
        # @return [Array<String>]
        attr_accessor :matched_item_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_selection_log = args[:device_selection_log] if args.key?(:device_selection_log)
          @dto_error = args[:dto_error] if args.key?(:dto_error)
          @dto_query_info = args[:dto_query_info] if args.key?(:dto_query_info)
          @homeautomation_metadata = args[:homeautomation_metadata] if args.key?(:homeautomation_metadata)
          @list = args[:list] if args.key?(:list)
          @matched_item_key = args[:matched_item_key] if args.key?(:matched_item_key)
          @matched_item_rawvalue = args[:matched_item_rawvalue] if args.key?(:matched_item_rawvalue)
          @matched_item_value = args[:matched_item_value] if args.key?(:matched_item_value)
        end
      end
      
      # 
      class AssistantVerticalsHomeautomationProtoHomeAutomationDeviceItem
        include Google::Apis::Core::Hashable
      
        # Next ID: 40
        # Corresponds to the JSON property `homeautomationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoHomeAutomationMetaData]
        attr_accessor :homeautomation_metadata
      
        # Corresponding to casse matched_item CustomTypeItem key.
        # Corresponds to the JSON property `matchedItemKey`
        # @return [String]
        attr_accessor :matched_item_key
      
        # Corresponding to casse Argument raw_value.
        # Corresponds to the JSON property `matchedItemRawvalue`
        # @return [String]
        attr_accessor :matched_item_rawvalue
      
        # Corresponding to casse matched_item CustomTypeItem value.
        # Corresponds to the JSON property `matchedItemValue`
        # @return [Array<String>]
        attr_accessor :matched_item_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @homeautomation_metadata = args[:homeautomation_metadata] if args.key?(:homeautomation_metadata)
          @matched_item_key = args[:matched_item_key] if args.key?(:matched_item_key)
          @matched_item_rawvalue = args[:matched_item_rawvalue] if args.key?(:matched_item_rawvalue)
          @matched_item_value = args[:matched_item_value] if args.key?(:matched_item_value)
        end
      end
      
      # Next ID: 40
      class AssistantVerticalsHomeautomationProtoHomeAutomationMetaData
        include Google::Apis::Core::Hashable
      
        # Custom actions that this item supports.
        # Corresponds to the JSON property `actionProjectConfigs`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoActionProjectConfig>]
        attr_accessor :action_project_configs
      
        # AgentInformation represents the details needed to support both 1P and 3P
        # partnerships for Home Automation. Next ID: 7
        # Corresponds to the JSON property `agentInformation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoAgentInformation]
        attr_accessor :agent_information
      
        # Device ID that matches the ID passed from the device to discourse_context when
        # a user issues a query to an Assistant-enabled device that is registered with
        # Cast (via CCS (see go/castservers)), or some other service.
        # Corresponds to the JSON property `assistantDeviceId`
        # @return [String]
        attr_accessor :assistant_device_id
      
        # Attributes data as provided from SYNC. This gets used in mutation and
        # execution and in some potential cases, in biasing.
        # Corresponds to the JSON property `attributes`
        # @return [Hash<String,Object>]
        attr_accessor :attributes
      
        # See Device.creator_gaia_ids in //home/graph/proto/service/types.proto. If
        # empty, the GAIA ID from the request EUC is assumed to be the creator. We only
        # need at most one creator_gaia_id.
        # Corresponds to the JSON property `creatorGaiaId`
        # @return [Fixnum]
        attr_accessor :creator_gaia_id
      
        # Any types that are not the given item type, but derived later. For example, if
        # an item has type action.devices.types.OUTLET but is named "floor lamp" we can
        # derive that it also has type action.devices.types.LIGHT. Also considered along
        # with |type| when triggering type-based actions.
        # Corresponds to the JSON property `derivedType`
        # @return [Array<String>]
        attr_accessor :derived_type
      
        # See note in home_graph.proto; loaded into DE now to avoid having to double-
        # read assistant settings records as per go/smarthome-removing-assistant-
        # settings
        # Corresponds to the JSON property `deviceModelId`
        # @return [String]
        attr_accessor :device_model_id
      
        # GCM address for cloud execution across google cloud messaging rather than 3p
        # cloud; for future use.
        # Corresponds to the JSON property `gcmExecutionAddress`
        # @return [String]
        attr_accessor :gcm_execution_address
      
        # The hash value from go/de-consistency-check
        # Corresponds to the JSON property `hashValue`
        # @return [String]
        attr_accessor :hash_value
      
        # Whether local home platform should discover new devices via LAN for the
        # structure.
        # Corresponds to the JSON property `lanscanOptedIn`
        # @return [Boolean]
        attr_accessor :lanscan_opted_in
        alias_method :lanscan_opted_in?, :lanscan_opted_in
      
        # Model name from HomeGraph, populated from model_manifest.model_name. See b/
        # 200087451.
        # Corresponds to the JSON property `modelName`
        # @return [String]
        attr_accessor :model_name
      
        # Indicates whether notifications have been enabled by a user and will be
        # announced for this device. This is set by the user within the Google app
        # settings, and Google will announce the device notification only if both
        # notification_supported_by_agent and notification_enabled_by_user are true.
        # Corresponds to the JSON property `notificationEnabledByUser`
        # @return [Boolean]
        attr_accessor :notification_enabled_by_user
        alias_method :notification_enabled_by_user?, :notification_enabled_by_user
      
        # Indicates whether the device is capable of sending notifications. This field
        # will be set by the agent (partner) on an incoming SYNC. If a device is not
        # capable of generating notifications, the partner should set this flag to false.
        # If a partner is not capable of calling ReportStateAndNotification to send
        # notifications to Google, the partner should set this flag to false. If there
        # is a user setting in the partner app to enable notifications and it is turned
        # off, the partner should set this flag to false.
        # Corresponds to the JSON property `notificationSupportedByAgent`
        # @return [Boolean]
        attr_accessor :notification_supported_by_agent
        alias_method :notification_supported_by_agent?, :notification_supported_by_agent
      
        # Store custom data for agent calls here. This will likely be short-lived -- we
        # will replace this with calls to HGS. (Note: This may end up not temporary if
        # we only need it for a couple partners -- more efficient to have it on a few
        # users than require HGS reads for all users.
        # Corresponds to the JSON property `opaqueCustomData`
        # @return [String]
        attr_accessor :opaque_custom_data
      
        # Operational CHIP Node ID that combines the fabric ID and node id in format of .
        # (Hex format without 0x prefix, for example, 0F001234FA67AA39.1234ABCD1111DDDD)
        # .
        # Corresponds to the JSON property `operationalNodeId`
        # @return [String]
        attr_accessor :operational_node_id
      
        # Other agent id + foreign id pairs associated with the device. This can be used
        # to represent a group of devices (e.g. Sonos' bonded zone) as a single device,
        # or a device that comes in through different sync flows (e.g. Newman with a
        # Nest camera).
        # Corresponds to the JSON property `otherDeviceIds`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoAgentDeviceId>]
        attr_accessor :other_device_ids
      
        # LINT.IfChange(home_graph_single_parent) At the moment, we just have a single
        # string. In future this will expand with additional metadata from client or
        # cloud execution data store. In today's 'tree' HomeGraph each object has a
        # single parent. In the future this may have a mesh for complex cases -- zones,
        # doors, etc -- so we make this a repeated element today. LINT.ThenChange(//
        # depot/google3/assistant/assistant_server/settings/user_defined_actions/
        # footprints/footprint_accessor.cc:home_graph_single_parent)
        # Corresponds to the JSON property `parentNode`
        # @return [Array<String>]
        attr_accessor :parent_node
      
        # The type of the parent. Currently only set for devices, to distinguish between
        # structure and room parents. Items currently have only one parent, and entries
        # after the first parent_type are ignored.
        # Corresponds to the JSON property `parentType`
        # @return [Array<String>]
        attr_accessor :parent_type
      
        # User-given nicknames for an entity (e.g. "My house"). These nicknames are
        # unique to the gaia user. Nickname in DeviceInfo is per-entity level nickname,
        # while personalized_nicknames is per-user per-entity.
        # Corresponds to the JSON property `personalizedNicknames`
        # @return [Array<String>]
        attr_accessor :personalized_nicknames
      
        # Stores the location for the STRUCTURE type.
        # Corresponds to the JSON property `physicalLocation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoPhysicalLocation]
        attr_accessor :physical_location
      
        # We use this to determine if the synonyms matched in the aqua interpretation is
        # plural. Then we will return disambiguate dialog or execute commands with all
        # the targets.
        # Corresponds to the JSON property `plural`
        # @return [Array<String>]
        attr_accessor :plural
      
        # Which of the values was the original, user-provided name -- or our
        # disambiguated, cleaned-up version of it. This is what we use in TTS when we
        # need to identify an object that wasn't just spoken uniquely by the user -- in
        # disambiguation dialogue, or in response to a collective interrogative (e.g. "
        # what lights are on in the kitchen?")
        # Corresponds to the JSON property `primaryName`
        # @return [String]
        attr_accessor :primary_name
      
        # Represents the user’s role such as assistant only or manager for a device.
        # Design doc: https://docs.google.com/document/d/
        # 1c1hnauEbBfDkywO3GZkI8ejHP765l2tLspmPgckEe2Y/
        # Corresponds to the JSON property `roleInformation`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoRoleInformation]
        attr_accessor :role_information
      
        # Only present for a target device. Indicates this target device is reachable by
        # a local (AoGH) path via an AoGH device.
        # Corresponds to the JSON property `routableViaGcm`
        # @return [Boolean]
        attr_accessor :routable_via_gcm
        alias_method :routable_via_gcm?, :routable_via_gcm
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `saftDocument`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :saft_document
      
        # Data needed for SDM (fleet management). See go/enterprise-id-in-assistant.
        # Corresponds to the JSON property `smartDeviceManagementData`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoSmartDeviceManagementData]
        attr_accessor :smart_device_management_data
      
        # SmartHome feature flags that may be enabled per-item. LINT.IfChange
        # Corresponds to the JSON property `smartHomeFeatures`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoSmartHomeFeatures]
        attr_accessor :smart_home_features
      
        # The features a structure supports.
        # Corresponds to the JSON property `supportedStructureFeatures`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoSupportedStructureFeatures]
        attr_accessor :supported_structure_features
      
        # Map from agent ID to supported traits. Some devices (e.g. Newman) have
        # multiple agents, with each agent being associated with a specific set of
        # traits. This could alternatively have been formatted as map as `trait, agent`
        # pairs instead of the `agent, list of trait` pairs, but we retain this format
        # to be consistent with HomeGraph's representation. In practice, a trait should
        # only be paired with a single agent (i.e. we should not have two agents with
        # the same trait in their value list). This field is optional and should only be
        # provided if the item has multiple agents.
        # Corresponds to the JSON property `supportedTraitsByAgent`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoHomeAutomationMetaDataSupportedTraits>]
        attr_accessor :supported_traits_by_agent
      
        # This device supports direct response -- if the device itself is issuing the
        # query (which means it's also an assistant surface) we can return its payload
        # directly rather than via cloud.
        # Corresponds to the JSON property `supportsDirectResponse`
        # @return [Boolean]
        attr_accessor :supports_direct_response
        alias_method :supports_direct_response?, :supports_direct_response
      
        # Only present for an AoGH device. HGS Device ID of a target device and the
        # signal strength (RSSI in dB, higher is better) between that target device and
        # the AoGH device. If this map is empty, there are no target devices reachable
        # by this AoGH device.
        # Corresponds to the JSON property `targetDeviceSignalStrengths`
        # @return [Hash<String,Fixnum>]
        attr_accessor :target_device_signal_strengths
      
        # For SHED devices, some traits can only be executed on 3P cloud, e.g. "action.
        # devices.traits.MediaInitiation", "action.devices.traits.Channel" go/shed-per-
        # trait-routing
        # Corresponds to the JSON property `traitRoutingHints`
        # @return [Array<Google::Apis::ContentwarehouseV1::HomeGraphCommonTraitRoutingHints>]
        attr_accessor :trait_routing_hints
      
        # Map from traits to routing table. Metadata includes preferred execution path
        # per trait and, when Matter is preferred, which endpoint should be used for the
        # trait.
        # Corresponds to the JSON property `traitRoutingTable`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::HomeGraphCommonRoutingTable>]
        attr_accessor :trait_routing_table
      
        # Map of trait to a proto representing the attribute. This is different from the
        # attributes field above which is represented as a struct. The attributes here
        # are represented as protos and will require specific support per trait.
        # Corresponds to the JSON property `traitToAttributeProtos`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoAttributes>]
        attr_accessor :trait_to_attribute_protos
      
        # The item type, such as "action.devices.types.VACUUM" - to be used in
        # triggering type-based actions, e.g. "start vacuuming": go/smarthome-type-based-
        # actions.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The priority order of speech targeting: 1. user_defined_device_type 2.
        # derived_device_type 3. device_type
        # Corresponds to the JSON property `userDefinedDeviceType`
        # @return [String]
        attr_accessor :user_defined_device_type
      
        # Set to which level of voice match is needed. Enum based on string input from
        # the partner in json sync. Values accepted: "none" (but in this case partners
        # won't set it), "owner" [requires matching one of the creator gaia IDs], or "
        # member" [any recognized voice 'enrolled' on the device]. This may expand; only
        # "owner" is in use for first partner, Tile.
        # Corresponds to the JSON property `voiceMatchRequired`
        # @return [String]
        attr_accessor :voice_match_required
      
        # This device will report state; we can query realtime state from local HGS
        # rather than slow QUERY intent to the 3p cloud.
        # Corresponds to the JSON property `willReportState`
        # @return [Boolean]
        attr_accessor :will_report_state
        alias_method :will_report_state?, :will_report_state
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `zoneNameSaftDocument`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :zone_name_saft_document
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_project_configs = args[:action_project_configs] if args.key?(:action_project_configs)
          @agent_information = args[:agent_information] if args.key?(:agent_information)
          @assistant_device_id = args[:assistant_device_id] if args.key?(:assistant_device_id)
          @attributes = args[:attributes] if args.key?(:attributes)
          @creator_gaia_id = args[:creator_gaia_id] if args.key?(:creator_gaia_id)
          @derived_type = args[:derived_type] if args.key?(:derived_type)
          @device_model_id = args[:device_model_id] if args.key?(:device_model_id)
          @gcm_execution_address = args[:gcm_execution_address] if args.key?(:gcm_execution_address)
          @hash_value = args[:hash_value] if args.key?(:hash_value)
          @lanscan_opted_in = args[:lanscan_opted_in] if args.key?(:lanscan_opted_in)
          @model_name = args[:model_name] if args.key?(:model_name)
          @notification_enabled_by_user = args[:notification_enabled_by_user] if args.key?(:notification_enabled_by_user)
          @notification_supported_by_agent = args[:notification_supported_by_agent] if args.key?(:notification_supported_by_agent)
          @opaque_custom_data = args[:opaque_custom_data] if args.key?(:opaque_custom_data)
          @operational_node_id = args[:operational_node_id] if args.key?(:operational_node_id)
          @other_device_ids = args[:other_device_ids] if args.key?(:other_device_ids)
          @parent_node = args[:parent_node] if args.key?(:parent_node)
          @parent_type = args[:parent_type] if args.key?(:parent_type)
          @personalized_nicknames = args[:personalized_nicknames] if args.key?(:personalized_nicknames)
          @physical_location = args[:physical_location] if args.key?(:physical_location)
          @plural = args[:plural] if args.key?(:plural)
          @primary_name = args[:primary_name] if args.key?(:primary_name)
          @role_information = args[:role_information] if args.key?(:role_information)
          @routable_via_gcm = args[:routable_via_gcm] if args.key?(:routable_via_gcm)
          @saft_document = args[:saft_document] if args.key?(:saft_document)
          @smart_device_management_data = args[:smart_device_management_data] if args.key?(:smart_device_management_data)
          @smart_home_features = args[:smart_home_features] if args.key?(:smart_home_features)
          @supported_structure_features = args[:supported_structure_features] if args.key?(:supported_structure_features)
          @supported_traits_by_agent = args[:supported_traits_by_agent] if args.key?(:supported_traits_by_agent)
          @supports_direct_response = args[:supports_direct_response] if args.key?(:supports_direct_response)
          @target_device_signal_strengths = args[:target_device_signal_strengths] if args.key?(:target_device_signal_strengths)
          @trait_routing_hints = args[:trait_routing_hints] if args.key?(:trait_routing_hints)
          @trait_routing_table = args[:trait_routing_table] if args.key?(:trait_routing_table)
          @trait_to_attribute_protos = args[:trait_to_attribute_protos] if args.key?(:trait_to_attribute_protos)
          @type = args[:type] if args.key?(:type)
          @user_defined_device_type = args[:user_defined_device_type] if args.key?(:user_defined_device_type)
          @voice_match_required = args[:voice_match_required] if args.key?(:voice_match_required)
          @will_report_state = args[:will_report_state] if args.key?(:will_report_state)
          @zone_name_saft_document = args[:zone_name_saft_document] if args.key?(:zone_name_saft_document)
        end
      end
      
      # 
      class AssistantVerticalsHomeautomationProtoHomeAutomationMetaDataSupportedTraits
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `traits`
        # @return [Array<String>]
        attr_accessor :traits
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @traits = args[:traits] if args.key?(:traits)
        end
      end
      
      # 
      class AssistantVerticalsHomeautomationProtoPhysicalLocation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `address`
        # @return [String]
        attr_accessor :address
      
        # An object that represents a latitude/longitude pair. This is expressed as a
        # pair of doubles to represent degrees latitude and degrees longitude. Unless
        # specified otherwise, this object must conform to the WGS84 standard. Values
        # must be within normalized ranges.
        # Corresponds to the JSON property `geoLocation`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeLatLng]
        attr_accessor :geo_location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address = args[:address] if args.key?(:address)
          @geo_location = args[:geo_location] if args.key?(:geo_location)
        end
      end
      
      # Represents the user’s role such as assistant only or manager for a device.
      # Design doc: https://docs.google.com/document/d/
      # 1c1hnauEbBfDkywO3GZkI8ejHP765l2tLspmPgckEe2Y/
      class AssistantVerticalsHomeautomationProtoRoleInformation
        include Google::Apis::Core::Hashable
      
        # When true, role_type will be ignored, Nest IAM RPC will called to check
        # authority.
        # Corresponds to the JSON property `iamCheckRequired`
        # @return [Boolean]
        attr_accessor :iam_check_required
        alias_method :iam_check_required?, :iam_check_required
      
        # 
        # Corresponds to the JSON property `roleType`
        # @return [String]
        attr_accessor :role_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @iam_check_required = args[:iam_check_required] if args.key?(:iam_check_required)
          @role_type = args[:role_type] if args.key?(:role_type)
        end
      end
      
      # 
      class AssistantVerticalsHomeautomationProtoSmartDeviceManagementData
        include Google::Apis::Core::Hashable
      
        # The enterprise that owns the structure. E.g. Disney, Dream Hotel, etc. This is
        # used for log/analytics purpose. For privacy reasons, we log at enterprise
        # level instead of structure level.
        # Corresponds to the JSON property `enterpriseId`
        # @return [String]
        attr_accessor :enterprise_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enterprise_id = args[:enterprise_id] if args.key?(:enterprise_id)
        end
      end
      
      # SmartHome feature flags that may be enabled per-item. LINT.IfChange
      class AssistantVerticalsHomeautomationProtoSmartHomeFeatures
        include Google::Apis::Core::Hashable
      
        # Flag indicating whether the background Circadian Lighting effect is enabled
        # for a particular light (go/circadian-lighting-e2e).
        # Corresponds to the JSON property `circadianLightingEnabled`
        # @return [Boolean]
        attr_accessor :circadian_lighting_enabled
        alias_method :circadian_lighting_enabled?, :circadian_lighting_enabled
      
        # Flag indicating whether automatic Energy Savings are enabled for this item.
        # Corresponds to the JSON property `energySavingsEnabled`
        # @return [Boolean]
        attr_accessor :energy_savings_enabled
        alias_method :energy_savings_enabled?, :energy_savings_enabled
      
        # Flag indicating whether Gentle Wake Up is enabled for this item (go/sleep-wake-
        # design).
        # Corresponds to the JSON property `gentleWakeupEnabled`
        # @return [Boolean]
        attr_accessor :gentle_wakeup_enabled
        alias_method :gentle_wakeup_enabled?, :gentle_wakeup_enabled
      
        # Flag indicating whether the user has enabled / disabled sending Home/Away
        # status updates to the device through the Google custom IntelligenceEvents
        # Matter cluster. (go/google-clusters-design)
        # Corresponds to the JSON property `homeAwayOverMatterEnabled`
        # @return [Boolean]
        attr_accessor :home_away_over_matter_enabled
        alias_method :home_away_over_matter_enabled?, :home_away_over_matter_enabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circadian_lighting_enabled = args[:circadian_lighting_enabled] if args.key?(:circadian_lighting_enabled)
          @energy_savings_enabled = args[:energy_savings_enabled] if args.key?(:energy_savings_enabled)
          @gentle_wakeup_enabled = args[:gentle_wakeup_enabled] if args.key?(:gentle_wakeup_enabled)
          @home_away_over_matter_enabled = args[:home_away_over_matter_enabled] if args.key?(:home_away_over_matter_enabled)
        end
      end
      
      # The features a structure supports.
      class AssistantVerticalsHomeautomationProtoSupportedStructureFeatures
        include Google::Apis::Core::Hashable
      
        # The Concierge features a structure is eligible for. See `@link home.graph.
        # common.ConciergeFeatures`.
        # Corresponds to the JSON property `conciergeFeatures`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoConciergeFeatures]
        attr_accessor :concierge_features
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @concierge_features = args[:concierge_features] if args.key?(:concierge_features)
        end
      end
      
      # Represents the properties of a mention. Next ID: 13
      class AttentionalEntitiesMentionProperties
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # An EventId is a 128 bit identifier that uniquely identifies an event, such as
        # a query. The event time recorded to the nearest microsecond, along with
        # information about the process generating the event, ensures that all EventIds
        # are unique. Details of this EventId are described in a design document: http://
        # www/eng/designdocs/sawmill/adlogs.html
        # Corresponds to the JSON property `eventId`
        # @return [Google::Apis::ContentwarehouseV1::EventIdMessage]
        attr_accessor :event_id
      
        # If this mention corresponds to a WebAnswer, then this defines the score
        # associated with that answer.
        # Corresponds to the JSON property `factoidScore`
        # @return [Float]
        attr_accessor :factoid_score
      
        # Contains information about how an entity was presented as part of a list.
        # Corresponds to the JSON property `listEntryInfo`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionPropertiesListEntryInfo]
        attr_accessor :list_entry_info
      
        # Estimates the recency of the mention. This is internally computed at runtime
        # on a turn-by-turn basis.
        # Corresponds to the JSON property `recency`
        # @return [String]
        attr_accessor :recency
      
        # Uniquely identifies a semantic role. When this role corresponds to a slot in a
        # registered user intent (see go/assistant-intent-catalog), then the
        # SemanticRoleId maps precisely onto that slot in the intent catalog. However,
        # not all semantic roles corresponds to such user intent slots.
        # Corresponds to the JSON property `role`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesSemanticRoleId]
        attr_accessor :role
      
        # How salient this mention is. This field will only be set if the mention is
        # derived from a SearchAnswerValue. See go/webresultsdata-as-aes for more
        # details.
        # Corresponds to the JSON property `salience`
        # @return [String]
        attr_accessor :salience
      
        # The agent or system from which the mention was derived. Each mention
        # corresponds to a single source.
        # Corresponds to the JSON property `source`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionPropertiesSource]
        attr_accessor :source
      
        # Properties of visual mentions (e.g., how they are displayed to the user,
        # visibility, etc.).
        # Corresponds to the JSON property `spatialProperties`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesSpatialProperties]
        attr_accessor :spatial_properties
      
        # How the entity was presented in this mention at a surface level. For example, "
        # President Barack Obama" or "Barack Obama" or "he" might all be reasonable
        # surface forms for the MID /m/02mjmr.
        # Corresponds to the JSON property `surfaceForm`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesSurfaceForm]
        attr_accessor :surface_form
      
        # Unix timestamp noting (approximately) when this mention occurred. We do not
        # guarantee that the time will correspond precisely to when the user uttered/
        # heard a response. If mentions within a single turn have *different* timestamps,
        # they should accurately reflect the order in which the mentions occurred. If
        # that order is unknown, they should all have the same timestamp.
        # Corresponds to the JSON property `timestamp`
        # @return [String]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @event_id = args[:event_id] if args.key?(:event_id)
          @factoid_score = args[:factoid_score] if args.key?(:factoid_score)
          @list_entry_info = args[:list_entry_info] if args.key?(:list_entry_info)
          @recency = args[:recency] if args.key?(:recency)
          @role = args[:role] if args.key?(:role)
          @salience = args[:salience] if args.key?(:salience)
          @source = args[:source] if args.key?(:source)
          @spatial_properties = args[:spatial_properties] if args.key?(:spatial_properties)
          @surface_form = args[:surface_form] if args.key?(:surface_form)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # Contains information about how an entity was presented as part of a list.
      class AttentionalEntitiesMentionPropertiesListEntryInfo
        include Google::Apis::Core::Hashable
      
        # The index of the entity presented to the user. NOTE: Indexing starts from 0.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # A string which uniquely identifies the list item this entity represents in the
        # list. For example, consider the "OrderPizza" intent with the "size" slot: U: I
        # want to order a pizza A: Sure. What size do you want: large, medium, or small?
        # U: Gigantic The lexical_groundings_id can be "large" to identify the large
        # item in the list. This lexical_groundings_id together with the semantic role
        # fields (i.e., role.intent_id & role.role_id) can be used to match the
        # nlp_semantic_parsing::LexicalGroundings::ValueTermType to utilize lexical
        # grounding for i18n of static list selection items. Note that this field only
        # needs to be populated when developers expect to provide lexical groundings for
        # the list item this entity represents. Effectively, this field will be
        # populated when this entity is published by ListPresentationFrame and the ::
        # quality::dialog_manager::IntentStageSignals::FieldCandidate.
        # lexical_groundings_id field is populated. See go/lpf-i18nv2 & go/taskstate-ae-
        # sync for more details.
        # Corresponds to the JSON property `lexicalGroundingsId`
        # @return [String]
        attr_accessor :lexical_groundings_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
          @lexical_groundings_id = args[:lexical_groundings_id] if args.key?(:lexical_groundings_id)
        end
      end
      
      # The agent or system from which the mention was derived. Each mention
      # corresponds to a single source.
      class AttentionalEntitiesMentionPropertiesSource
        include Google::Apis::Core::Hashable
      
        # The client provided this entity. Currently, this exclusively corresponds to an
        # entity that was circulated by the client. See go/on-device-aes for more
        # details.
        # Corresponds to the JSON property `client`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionPropertiesSourceClient]
        attr_accessor :client
      
        # The Assistant mentioned this entity. This corresponds to entities annotated
        # during fulfillment. More specifically, these entities are typically provided
        # by developers either via a Monastery frame or an InteractionBuilder.
        # Corresponds to the JSON property `system`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionPropertiesSourceSystem]
        attr_accessor :system
      
        # The user mentioned this entity. It was extracted from a previous winning
        # intent (IntentQuery or IntentUpdate). Such entities are computed at runtime
        # from the interpretation history without any developer intervention.
        # Corresponds to the JSON property `user`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionPropertiesSourceUser]
        attr_accessor :user
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client = args[:client] if args.key?(:client)
          @system = args[:system] if args.key?(:system)
          @user = args[:user] if args.key?(:user)
        end
      end
      
      # The client provided this entity. Currently, this exclusively corresponds to an
      # entity that was circulated by the client. See go/on-device-aes for more
      # details.
      class AttentionalEntitiesMentionPropertiesSourceClient
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The Assistant mentioned this entity. This corresponds to entities annotated
      # during fulfillment. More specifically, these entities are typically provided
      # by developers either via a Monastery frame or an InteractionBuilder.
      class AttentionalEntitiesMentionPropertiesSourceSystem
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The user mentioned this entity. It was extracted from a previous winning
      # intent (IntentQuery or IntentUpdate). Such entities are computed at runtime
      # from the interpretation history without any developer intervention.
      class AttentionalEntitiesMentionPropertiesSourceUser
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Uniquely identifies a semantic role. When this role corresponds to a slot in a
      # registered user intent (see go/assistant-intent-catalog), then the
      # SemanticRoleId maps precisely onto that slot in the intent catalog. However,
      # not all semantic roles corresponds to such user intent slots.
      class AttentionalEntitiesSemanticRoleId
        include Google::Apis::Core::Hashable
      
        # Semantic roles will be defined locally, within the context of a single task/
        # feature. The |intent_id| is a unique identifier for such a local cluster. In
        # most cases, this should be exactly the same as the name of the intent used for
        # TaskState (see go/assistant-intent-catalog). In cases where the intent isn't
        # well-defined, this can be an arbitrary, feature-defined identifier.
        # Corresponds to the JSON property `intentId`
        # @return [String]
        attr_accessor :intent_id
      
        # Identifier for a semantic role, unique within the namespace of |intent_id|.
        # When this role corresponds to a slot in the intent, the |role_id| should be
        # equal to the name of that argument. For example, consider an entry in the
        # intent catalog: core_intent ` id ` id: "BookARide" ` slot ` name: "provider"
        # type ` string_type ` ` ` ` slot ` name: "num_riders" type ` number_type ` ` ` `
        # ` Then, the |role_id| would be "provider" or "num_riders" when referring to
        # one of these slots. NOTE: when responding to the user, the Assistant may
        # actually make use of other roles such as "ETA" or "driver" that are not part
        # of the intent declaration. These should still be assigned consistent semantic
        # roles. For example, a dialog with the Shopping feature: User: Where can I buy
        # XYZ? Google: [Best Buy in Sunnyvale] has [XYZ] in stock. User: Great! Give me
        # directions. In this case, both "Best Buy" and "XYZ" would be pushed to
        # attentional entities. Best Buy, in this case, may not be an argument in the
        # ShoppingItemStockInquiry intent, but should still have a consistent |role_id|
        # such as "possessing_business".
        # Corresponds to the JSON property `roleId`
        # @return [String]
        attr_accessor :role_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent_id = args[:intent_id] if args.key?(:intent_id)
          @role_id = args[:role_id] if args.key?(:role_id)
        end
      end
      
      # Properties of visual mentions (e.g., how they are displayed to the user,
      # visibility, etc.).
      class AttentionalEntitiesSpatialProperties
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `visibility`
        # @return [String]
        attr_accessor :visibility
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @visibility = args[:visibility] if args.key?(:visibility)
        end
      end
      
      # How the entity was presented in this mention at a surface level. For example, "
      # President Barack Obama" or "Barack Obama" or "he" might all be reasonable
      # surface forms for the MID /m/02mjmr.
      class AttentionalEntitiesSurfaceForm
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # This data is expected to appear in approximately 2 out of every 1,000
      # documents with an average of 2 fields per document. Rough order of size is in
      # the hundreds of kilobytes per Mustang shard.
      class BiasingPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `biasingfield`
        # @return [Array<Google::Apis::ContentwarehouseV1::BiasingPerDocDataBiasingField>]
        attr_accessor :biasingfield
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @biasingfield = args[:biasingfield] if args.key?(:biasingfield)
        end
      end
      
      # A replacement for BiasingPerDocData that is more efficient wrt size in the
      # index.
      class BiasingPerDocData2
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `biasingField`
        # @return [Array<Google::Apis::ContentwarehouseV1::BiasingPerDocData2BiasingField>]
        attr_accessor :biasing_field
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @biasing_field = args[:biasing_field] if args.key?(:biasing_field)
        end
      end
      
      # 
      class BiasingPerDocData2BiasingField
        include Google::Apis::Core::Hashable
      
        # A fingerprint of the actual name of the field.
        # Corresponds to the JSON property `compressedName`
        # @return [Fixnum]
        attr_accessor :compressed_name
      
        # The value, under various representations to get maximum compression. Exactly
        # one of them is guaranteed to be filled. value as a double.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        # a floating value, represented as an integer by converting using floating_value
        # * 1000. Useable for all floating values that need 3 digits of precision, and
        # are small enough.
        # Corresponds to the JSON property `valueFloat`
        # @return [Fixnum]
        attr_accessor :value_float
      
        # value as an int32. When the value is encode-able as an integer.
        # Corresponds to the JSON property `valueInt`
        # @return [Fixnum]
        attr_accessor :value_int
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compressed_name = args[:compressed_name] if args.key?(:compressed_name)
          @value = args[:value] if args.key?(:value)
          @value_float = args[:value_float] if args.key?(:value_float)
          @value_int = args[:value_int] if args.key?(:value_int)
        end
      end
      
      # Metadata fields on which we can bias (sort) search results independently from
      # the normal ranking using a ScoreAdjuster
      class BiasingPerDocDataBiasingField
        include Google::Apis::Core::Hashable
      
        # Fingerprint of the attribute name (no need to keep long field names)
        # Corresponds to the JSON property `Name`
        # @return [Fixnum]
        attr_accessor :name
      
        # Biasing value translated into a double for uniform comparison
        # Corresponds to the JSON property `Value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A BlobRef is used to refer to a blob in BlobStore. Clients may only manipulate
      # blobs through BlobRefs. BlobRefs should not be sent in the clear outside of
      # Google (for example, encoded in URLs, stored in a client cookie, or referred
      # to in Javascript); for efficiency, the IDs expose internal details of the
      # blobstore (such as machine IPs or cluster names). If clients need to store
      # BlobRefs outside of Google, they must encrypt the BlobRef securely or use an
      # alternative insecure identifier with an id->BlobRef mapping inside our network.
      # 
      class BlobstoreBlobRef
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `BlobID`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :blob_id
      
        # 
        # Corresponds to the JSON property `Options`
        # @return [Fixnum]
        attr_accessor :options
      
        # 
        # Corresponds to the JSON property `RefID`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ref_id
      
        # 
        # Corresponds to the JSON property `ShardBin`
        # @return [Fixnum]
        attr_accessor :shard_bin
      
        # Size of the complete blob, in bytes.
        # Corresponds to the JSON property `Size`
        # @return [Fixnum]
        attr_accessor :size
      
        # The ID of the V2 blob this blob has
        # Corresponds to the JSON property `SourceV2BlobID`
        # @return [String]
        attr_accessor :source_v2_blob_id
      
        # Deprecated.
        # Corresponds to the JSON property `V2ReadBlobToken`
        # @return [String]
        attr_accessor :v2_read_blob_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blob_id = args[:blob_id] if args.key?(:blob_id)
          @options = args[:options] if args.key?(:options)
          @ref_id = args[:ref_id] if args.key?(:ref_id)
          @shard_bin = args[:shard_bin] if args.key?(:shard_bin)
          @size = args[:size] if args.key?(:size)
          @source_v2_blob_id = args[:source_v2_blob_id] if args.key?(:source_v2_blob_id)
          @v2_read_blob_token = args[:v2_read_blob_token] if args.key?(:v2_read_blob_token)
        end
      end
      
      # Additional data for Blog/Posts
      class BlogPerDocData
        include Google::Apis::Core::Hashable
      
        # used for blogurl crowding.
        # Corresponds to the JSON property `blogurlFp`
        # @return [Fixnum]
        attr_accessor :blogurl_fp
      
        # This score captures how spammy the client is that the micropost was created
        # with. The higher the score the worse.
        # Corresponds to the JSON property `clientSpamminess`
        # @return [Fixnum]
        attr_accessor :client_spamminess
      
        # For the threaded conversation view. Only populated in docs with provider type
        # SYNTHETIC_CONVERSATION_DOC.
        # Corresponds to the JSON property `convTree`
        # @return [Google::Apis::ContentwarehouseV1::BlogsearchConversationTree]
        attr_accessor :conv_tree
      
        # 
        # Corresponds to the JSON property `copycatScore`
        # @return [Fixnum]
        attr_accessor :copycat_score
      
        # 
        # Corresponds to the JSON property `docQualityScore`
        # @return [Fixnum]
        attr_accessor :doc_quality_score
      
        # A syntactic reshare is a document that is * created from an original and
        # shared with friends and * we detect this resharing property by syntactically
        # parsing the doc. . For example, a retweet is an example of a syntactic_reshare
        # because we can detect that it's a reshare by grepping for "RT @".
        # Corresponds to the JSON property `isSyntacticReshare`
        # @return [Boolean]
        attr_accessor :is_syntactic_reshare
        alias_method :is_syntactic_reshare?, :is_syntactic_reshare
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `microblogQualityExptData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :microblog_quality_expt_data
      
        # For replies/reshares. num_mentions = number of times the pattern @foo appears
        # in the document.
        # Corresponds to the JSON property `numMentions`
        # @return [Fixnum]
        attr_accessor :num_mentions
      
        # 
        # Corresponds to the JSON property `outlinks`
        # @return [Array<Google::Apis::ContentwarehouseV1::BlogPerDocDataOutlinks>]
        attr_accessor :outlinks
      
        # The fingerprint for the body text of the microblog post. It is copied from
        # MicroBlogPost.post_content_fingerprint.
        # Corresponds to the JSON property `postContentFingerprint`
        # @return [Fixnum]
        attr_accessor :post_content_fingerprint
      
        # 
        # Corresponds to the JSON property `qualityScore`
        # @return [Fixnum]
        attr_accessor :quality_score
      
        # Blog scoring signals.
        # Corresponds to the JSON property `spamScore`
        # @return [Fixnum]
        attr_accessor :spam_score
      
        # 
        # Corresponds to the JSON property `universalWhitelisted`
        # @return [Boolean]
        attr_accessor :universal_whitelisted
        alias_method :universal_whitelisted?, :universal_whitelisted
      
        # User and doc quality scores for updates (aka microposts).
        # Corresponds to the JSON property `userQualityScore`
        # @return [Fixnum]
        attr_accessor :user_quality_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blogurl_fp = args[:blogurl_fp] if args.key?(:blogurl_fp)
          @client_spamminess = args[:client_spamminess] if args.key?(:client_spamminess)
          @conv_tree = args[:conv_tree] if args.key?(:conv_tree)
          @copycat_score = args[:copycat_score] if args.key?(:copycat_score)
          @doc_quality_score = args[:doc_quality_score] if args.key?(:doc_quality_score)
          @is_syntactic_reshare = args[:is_syntactic_reshare] if args.key?(:is_syntactic_reshare)
          @microblog_quality_expt_data = args[:microblog_quality_expt_data] if args.key?(:microblog_quality_expt_data)
          @num_mentions = args[:num_mentions] if args.key?(:num_mentions)
          @outlinks = args[:outlinks] if args.key?(:outlinks)
          @post_content_fingerprint = args[:post_content_fingerprint] if args.key?(:post_content_fingerprint)
          @quality_score = args[:quality_score] if args.key?(:quality_score)
          @spam_score = args[:spam_score] if args.key?(:spam_score)
          @universal_whitelisted = args[:universal_whitelisted] if args.key?(:universal_whitelisted)
          @user_quality_score = args[:user_quality_score] if args.key?(:user_quality_score)
        end
      end
      
      # Resolved url and site spamscore for outlinks in updates (aka microposts).
      class BlogPerDocDataOutlinks
        include Google::Apis::Core::Hashable
      
        # Representative id for an equivalence class of URLs. E.g. http://youtube.com/
        # watch?v=12 and http://youtube.com/watch?v=12&feature=related have the same
        # aggregation id since they're effectively the same webpage
        # Corresponds to the JSON property `aggregationFp`
        # @return [Fixnum]
        attr_accessor :aggregation_fp
      
        # 
        # Corresponds to the JSON property `resolvedUrl`
        # @return [String]
        attr_accessor :resolved_url
      
        # 
        # Corresponds to the JSON property `siteSpamScore`
        # @return [Fixnum]
        attr_accessor :site_spam_score
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregation_fp = args[:aggregation_fp] if args.key?(:aggregation_fp)
          @resolved_url = args[:resolved_url] if args.key?(:resolved_url)
          @site_spam_score = args[:site_spam_score] if args.key?(:site_spam_score)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class BlogsearchConversationNode
        include Google::Apis::Core::Hashable
      
        # The username of the author of the microblog post represented by this node.
        # Corresponds to the JSON property `authorName`
        # @return [String]
        attr_accessor :author_name
      
        # A list of docids of child nodes.
        # Corresponds to the JSON property `children`
        # @return [Array<String>]
        attr_accessor :children
      
        # The creation date of the doc.
        # Corresponds to the JSON property `date`
        # @return [Fixnum]
        attr_accessor :date
      
        # Docid of the microblog post represented by this node.
        # Corresponds to the JSON property `docid`
        # @return [String]
        attr_accessor :docid
      
        # The docid of the parent node. The root of the tree will leave this empty.
        # Corresponds to the JSON property `parent`
        # @return [String]
        attr_accessor :parent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author_name = args[:author_name] if args.key?(:author_name)
          @children = args[:children] if args.key?(:children)
          @date = args[:date] if args.key?(:date)
          @docid = args[:docid] if args.key?(:docid)
          @parent = args[:parent] if args.key?(:parent)
        end
      end
      
      # 
      class BlogsearchConversationTree
        include Google::Apis::Core::Hashable
      
        # The id of this conversation.
        # Corresponds to the JSON property `convId`
        # @return [String]
        attr_accessor :conv_id
      
        # The nodes in this conversation. No particular order is assumed.
        # Corresponds to the JSON property `nodes`
        # @return [Array<Google::Apis::ContentwarehouseV1::BlogsearchConversationNode>]
        attr_accessor :nodes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conv_id = args[:conv_id] if args.key?(:conv_id)
          @nodes = args[:nodes] if args.key?(:nodes)
        end
      end
      
      # Information to indicate BG availability for businesses. This message is filled
      # from Topic Server and stored in the GSR in Superroot.
      class BlueGingerClientVisibleProtoBlueGingerSupportedServices
        include Google::Apis::Core::Hashable
      
        # List of supported modules for a business.
        # Corresponds to the JSON property `modules`
        # @return [Array<Google::Apis::ContentwarehouseV1::BlueGingerClientVisibleProtoBlueGingerSupportedServicesBlueGingerModule>]
        attr_accessor :modules
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @modules = args[:modules] if args.key?(:modules)
        end
      end
      
      # 
      class BlueGingerClientVisibleProtoBlueGingerSupportedServicesBlueGingerModule
        include Google::Apis::Core::Hashable
      
        # Module name, e.g. hairdresser_reservation. from quality/views/extraction/kcube/
        # bg/modules/modules.bzl.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Services of this module that are supported by the business, e.g. haircuts.
        # Corresponds to the JSON property `services`
        # @return [Array<String>]
        attr_accessor :services
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @services = args[:services] if args.key?(:services)
        end
      end
      
      # Per-doc data for the web page about the cited book Approximate size is on
      # average ~10bytes
      class BookCitationPerDocData
        include Google::Apis::Core::Hashable
      
        # the book id for the main citation
        # Corresponds to the JSON property `bookId`
        # @return [Fixnum]
        attr_accessor :book_id
      
        # the discretized citation score for the main book. we map the raw score 1.0-20.
        # 0 to 0 - 127
        # Corresponds to the JSON property `discretizedCitationScore`
        # @return [Fixnum]
        attr_accessor :discretized_citation_score
      
        # Is there a preview or excerpt of the book on this document?
        # Corresponds to the JSON property `previewable`
        # @return [Boolean]
        attr_accessor :previewable
        alias_method :previewable?, :previewable
      
        # book id for the second citation if we can't separate the two top citations (
        # they are too close).
        # Corresponds to the JSON property `secondBookId`
        # @return [Fixnum]
        attr_accessor :second_book_id
      
        # the discretized score for the second citation
        # Corresponds to the JSON property `secondDiscretizedCitationScore`
        # @return [Fixnum]
        attr_accessor :second_discretized_citation_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @book_id = args[:book_id] if args.key?(:book_id)
          @discretized_citation_score = args[:discretized_citation_score] if args.key?(:discretized_citation_score)
          @previewable = args[:previewable] if args.key?(:previewable)
          @second_book_id = args[:second_book_id] if args.key?(:second_book_id)
          @second_discretized_citation_score = args[:second_discretized_citation_score] if args.key?(:second_discretized_citation_score)
        end
      end
      
      # We divide up a week into individual open intervals. If any are present then
      # they must be arranged in strictly increasing order, with non-empty spaces
      # between successive intervals, and all times between 0 and 604800, the number
      # of seconds in a week.
      class BusinessHours
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dayopen`
        # @return [Fixnum]
        attr_accessor :dayopen
      
        # 
        # Corresponds to the JSON property `interval`
        # @return [Array<Google::Apis::ContentwarehouseV1::BusinessHoursInterval>]
        attr_accessor :interval
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dayopen = args[:dayopen] if args.key?(:dayopen)
          @interval = args[:interval] if args.key?(:interval)
        end
      end
      
      # 
      class BusinessHoursInterval
        include Google::Apis::Core::Hashable
      
        # The interval ends at the start of this second
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # Time in seconds since Midnight-Monday-Morn
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end = args[:end] if args.key?(:end)
          @start = args[:start] if args.key?(:start)
        end
      end
      
      # Token to be exposed and stored by the bot
      class ChatBotPlatformBotSendToken
        include Google::Apis::Core::Hashable
      
        # Time since epoch (micros) that this will expire
        # Corresponds to the JSON property `expiryTimeMicros`
        # @return [Fixnum]
        attr_accessor :expiry_time_micros
      
        # Encrypted InternalSendToken
        # Corresponds to the JSON property `sendToken`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :send_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiry_time_micros = args[:expiry_time_micros] if args.key?(:expiry_time_micros)
          @send_token = args[:send_token] if args.key?(:send_token)
        end
      end
      
      # 
      class ChatBotPlatformFireballId
        include Google::Apis::Core::Hashable
      
        # Id for message recipients, e.g. users, groups etc.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalCommunicationsInstantmessagingV1Id]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # Per-URL porn scores for the URLs associated with the corresponding image.
      class ClassifierPornAggregatedUrlPornScores
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `averageUrlPornScore`
        # @return [Float]
        attr_accessor :average_url_porn_score
      
        # 
        # Corresponds to the JSON property `urlCount`
        # @return [Fixnum]
        attr_accessor :url_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_url_porn_score = args[:average_url_porn_score] if args.key?(:average_url_porn_score)
          @url_count = args[:url_count] if args.key?(:url_count)
        end
      end
      
      # Next ID: 6
      class ClassifierPornClassifierData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `classification`
        # @return [Array<Google::Apis::ContentwarehouseV1::ClassifierPornClassifierDataClassification>]
        attr_accessor :classification
      
        # Records whether the image linker is run already. This is only used for
        # Alexandria but NOT for Segindexer.
        # Corresponds to the JSON property `imageBasedDetectionDone`
        # @return [Boolean]
        attr_accessor :image_based_detection_done
        alias_method :image_based_detection_done?, :image_based_detection_done
      
        # 
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @classification = args[:classification] if args.key?(:classification)
          @image_based_detection_done = args[:image_based_detection_done] if args.key?(:image_based_detection_done)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # 
      class ClassifierPornClassifierDataClassification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Next ID: 3
      class ClassifierPornDocumentData
        include Google::Apis::Core::Hashable
      
        # Next ID: 6
        # Corresponds to the JSON property `classifierdata`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornClassifierData]
        attr_accessor :classifierdata
      
        # Next ID: 51
        # Corresponds to the JSON property `sitedata`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornSiteData]
        attr_accessor :sitedata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @classifierdata = args[:classifierdata] if args.key?(:classifierdata)
          @sitedata = args[:sitedata] if args.key?(:sitedata)
        end
      end
      
      # Generic output for one vertical.
      class ClassifierPornQueryClassifierOutput
        include Google::Apis::Core::Hashable
      
        # This field is only filled for the CSAI vertical.
        # Corresponds to the JSON property `csaiClassification`
        # @return [String]
        attr_accessor :csai_classification
      
        # DO NOT USE: This field is temporary and should be used only for the CSAI
        # Onebox. This field is the result of the regular expression classifier alone as
        # opposed to a combination with Seti classifier as in csai_classification field.
        # Corresponds to the JSON property `csaiRegexpHighConfidenceClassification`
        # @return [String]
        attr_accessor :csai_regexp_high_confidence_classification
      
        # Human-readable debug information about the classification. This field is only
        # set if output_debug is set in the classification input.
        # Corresponds to the JSON property `debug`
        # @return [String]
        attr_accessor :debug
      
        # The bit that shows if this classifier outputs positive classification for the
        # input query. Set by thresholding with a recommended threshold.
        # Corresponds to the JSON property `isPositive`
        # @return [Boolean]
        attr_accessor :is_positive
        alias_method :is_positive?, :is_positive
      
        # The score that the classifier assigned to the input query. This is filled by
        # all verticals.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @csai_classification = args[:csai_classification] if args.key?(:csai_classification)
          @csai_regexp_high_confidence_classification = args[:csai_regexp_high_confidence_classification] if args.key?(:csai_regexp_high_confidence_classification)
          @debug = args[:debug] if args.key?(:debug)
          @is_positive = args[:is_positive] if args.key?(:is_positive)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Multi-label classification output. It contains the output for each vertical.
      # The output for some verticals can be empty, in case that vertical is not
      # supported by the classifier or if the set of verticals was restricted using
      # MultiLabelClassifierInput.verticals.
      class ClassifierPornQueryMultiLabelClassifierOutput
        include Google::Apis::Core::Hashable
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `csai`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :csai
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `fringe`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :fringe
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `medical`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :medical
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `offensive`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :offensive
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `porn`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :porn
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `spoof`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :spoof
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `violence`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :violence
      
        # Generic output for one vertical.
        # Corresponds to the JSON property `vulgar`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryClassifierOutput]
        attr_accessor :vulgar
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @csai = args[:csai] if args.key?(:csai)
          @fringe = args[:fringe] if args.key?(:fringe)
          @medical = args[:medical] if args.key?(:medical)
          @offensive = args[:offensive] if args.key?(:offensive)
          @porn = args[:porn] if args.key?(:porn)
          @spoof = args[:spoof] if args.key?(:spoof)
          @violence = args[:violence] if args.key?(:violence)
          @vulgar = args[:vulgar] if args.key?(:vulgar)
        end
      end
      
      # QuerySats contains the information about the queries that users typed to
      # search for this image.
      class ClassifierPornQueryStats
        include Google::Apis::Core::Hashable
      
        # A query text porn score for the queries which have clicks to the image:
        # query_text_porn_score := sum(clicks(query) * text_porn_score(query)) / sum(
        # clicks(query))
        # Corresponds to the JSON property `queryTextPornScore`
        # @return [Float]
        attr_accessor :query_text_porn_score
      
        # 
        # Corresponds to the JSON property `totalClicks`
        # @return [Float]
        attr_accessor :total_clicks
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @query_text_porn_score = args[:query_text_porn_score] if args.key?(:query_text_porn_score)
          @total_clicks = args[:total_clicks] if args.key?(:total_clicks)
        end
      end
      
      # ReferrerCounts stores how many referrers an images has and how many of them
      # were classified as porn and as adult/softporn respectively. Note that a
      # referrer is usually a landing page, but as of March 2011 this also includes
      # referrers which an image can 'inherit' by propagating counts from near
      # duplicate images.
      class ClassifierPornReferrerCounts
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `adult`
        # @return [Fixnum]
        attr_accessor :adult
      
        # Number of referrers which are classified as porn and as adult.
        # Corresponds to the JSON property `porn`
        # @return [Fixnum]
        attr_accessor :porn
      
        # Total number of referrers.
        # Corresponds to the JSON property `total`
        # @return [Fixnum]
        attr_accessor :total
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @adult = args[:adult] if args.key?(:adult)
          @porn = args[:porn] if args.key?(:porn)
          @total = args[:total] if args.key?(:total)
        end
      end
      
      # Next ID: 51
      class ClassifierPornSiteData
        include Google::Apis::Core::Hashable
      
        # The average pedo page score for the site.
        # Corresponds to the JSON property `avgPedoPageScore`
        # @return [Float]
        attr_accessor :avg_pedo_page_score
      
        # 
        # Corresponds to the JSON property `finalPedoSiteScore`
        # @return [Float]
        attr_accessor :final_pedo_site_score
      
        # The number of pages that were used to compute the scores and ratios.
        # Corresponds to the JSON property `numberOfPages`
        # @return [Fixnum]
        attr_accessor :number_of_pages
      
        # The number of pages with pedo restrict.
        # Corresponds to the JSON property `numberOfPedoPages`
        # @return [Fixnum]
        attr_accessor :number_of_pedo_pages
      
        # The ratio of porn/softporn of the site this page belongs to.
        # Corresponds to the JSON property `sitePornRatio`
        # @return [Float]
        attr_accessor :site_porn_ratio
      
        # 
        # Corresponds to the JSON property `siteSoftpornRatio`
        # @return [Float]
        attr_accessor :site_softporn_ratio
      
        # 
        # Corresponds to the JSON property `versionedscore`
        # @return [Array<Google::Apis::ContentwarehouseV1::ClassifierPornSiteDataVersionedScore>]
        attr_accessor :versionedscore
      
        # Next ID: 6
        # Corresponds to the JSON property `violenceStats`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornSiteViolenceStats]
        attr_accessor :violence_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @avg_pedo_page_score = args[:avg_pedo_page_score] if args.key?(:avg_pedo_page_score)
          @final_pedo_site_score = args[:final_pedo_site_score] if args.key?(:final_pedo_site_score)
          @number_of_pages = args[:number_of_pages] if args.key?(:number_of_pages)
          @number_of_pedo_pages = args[:number_of_pedo_pages] if args.key?(:number_of_pedo_pages)
          @site_porn_ratio = args[:site_porn_ratio] if args.key?(:site_porn_ratio)
          @site_softporn_ratio = args[:site_softporn_ratio] if args.key?(:site_softporn_ratio)
          @versionedscore = args[:versionedscore] if args.key?(:versionedscore)
          @violence_stats = args[:violence_stats] if args.key?(:violence_stats)
        end
      end
      
      # The site porn score of the site to which the page of interest belongs to.
      # Multiple versions are kept across large changes for some time. The Version-4
      # score is the average Universal Page Probability of all the site's pages, and
      # will come with populated verticals4_score and site_rule (if any rule fires)
      # fields. When using this score it is recommended to subscribe to the following
      # mailing list: g/safesearch-announce.
      class ClassifierPornSiteDataVersionedScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `siteRule`
        # @return [Array<String>]
        attr_accessor :site_rule
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        # Please talk to safesearch@ before relying on any of these internal fields:
        # Corresponds to the JSON property `verticals4Score`
        # @return [Float]
        attr_accessor :verticals4_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @site_rule = args[:site_rule] if args.key?(:site_rule)
          @version = args[:version] if args.key?(:version)
          @verticals4_score = args[:verticals4_score] if args.key?(:verticals4_score)
        end
      end
      
      # Next ID: 6
      class ClassifierPornSiteViolenceStats
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `meanFinalViolenceScore`
        # @return [Float]
        attr_accessor :mean_final_violence_score
      
        # 
        # Corresponds to the JSON property `numberOfImages`
        # @return [Fixnum]
        attr_accessor :number_of_images
      
        # 
        # Corresponds to the JSON property `numberOfVideos`
        # @return [Fixnum]
        attr_accessor :number_of_videos
      
        # 
        # Corresponds to the JSON property `videoViolenceScore`
        # @return [Float]
        attr_accessor :video_violence_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mean_final_violence_score = args[:mean_final_violence_score] if args.key?(:mean_final_violence_score)
          @number_of_images = args[:number_of_images] if args.key?(:number_of_images)
          @number_of_videos = args[:number_of_videos] if args.key?(:number_of_videos)
          @video_violence_score = args[:video_violence_score] if args.key?(:video_violence_score)
        end
      end
      
      # The basic message that contains a single decision output of go/deeptagger.
      class CommerceDatastoreDeepTag
        include Google::Apis::Core::Hashable
      
        # The confidence of the tag, encoded to 14 bits (range [0, 16383]). Due to
        # modeling details, a large number of tags become trustworthy with confidence
        # greater than 0.001, so two bytes of precision are required.
        # Corresponds to the JSON property `confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # A Deep Tag enum in uint32 form.
        # Corresponds to the JSON property `tag`
        # @return [Fixnum]
        attr_accessor :tag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @tag = args[:tag] if args.key?(:tag)
        end
      end
      
      # Image-level deep tags: essentially equivalent to the proto above but
      # containing tags that are computed at the image level. These image signals are
      # maintained by the Visual Shopping team (visual-shopping@). *** If you do use
      # the signals, please add an entry in go/ShoppingImageAttributeClients to be
      # notified for model upgrade. *** We recommend our clients against using the raw
      # confidence value directly. Instead, the clients should use the library, cs/ads/
      # shopping/visual/deeptags/public/single_tag.h and cs/ads/shopping/visual/
      # deeptags/public/single_scored_tag.h to specify an operating point in terms of
      # precision or recall. See the following code example: http://google3/shopping/
      # visual/explore_looks/looks_offline_pipeline.cc?l=268&rcl=304165166 *** `
      # model_outputs` is a repeated field. Please check `version` to get the model
      # you desire to use, instead of indexing the model_outputs directly e.g.
      # model_outputs(0). We will remove the old versions in the future and this will
      # lead to incorrect model. *** Models: As of Q2 2020, we have two models running
      # within Shopping: model one only has the overlay tag, which we are deprecating,
      # and model two has the tags specified in go/VisualShoppingImageAttributes.
      class CommerceDatastoreImageDeepTags
        include Google::Apis::Core::Hashable
      
        # The set of outputs for a series of model versions. The size of this field
        # should not extend beyond 4 at any time: two versions for slow-update track
        # dependencies, and two versions for fast-update track dependencies.
        # Corresponds to the JSON property `modelOutputs`
        # @return [Array<Google::Apis::ContentwarehouseV1::CommerceDatastoreImageDeepTagsModelOutput>]
        attr_accessor :model_outputs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @model_outputs = args[:model_outputs] if args.key?(:model_outputs)
        end
      end
      
      # 
      class CommerceDatastoreImageDeepTagsModelOutput
        include Google::Apis::Core::Hashable
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `backgroundType`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :background_type
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `collage`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :collage
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `cropping`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :cropping
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `modelType`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :model_type
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `nfs`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :nfs
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `objectCount`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :object_count
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `overlay`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :overlay
      
        # The basic message that contains a single decision output of go/deeptagger.
        # Corresponds to the JSON property `selfie`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag]
        attr_accessor :selfie
      
        # Tag corresponding to the text overlay classifier (watermarks, logos,
        # promotional elements, artifacts, etc).
        # Corresponds to the JSON property `textOverlay`
        # @return [Array<Google::Apis::ContentwarehouseV1::CommerceDatastoreDeepTag>]
        attr_accessor :text_overlay
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @background_type = args[:background_type] if args.key?(:background_type)
          @collage = args[:collage] if args.key?(:collage)
          @cropping = args[:cropping] if args.key?(:cropping)
          @model_type = args[:model_type] if args.key?(:model_type)
          @nfs = args[:nfs] if args.key?(:nfs)
          @object_count = args[:object_count] if args.key?(:object_count)
          @overlay = args[:overlay] if args.key?(:overlay)
          @selfie = args[:selfie] if args.key?(:selfie)
          @text_overlay = args[:text_overlay] if args.key?(:text_overlay)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Protocol record used for collecting together all information about a document.
      # Please consult go/dme for two basic questions about `CompositeDoc`: - Where
      # should I look up certain information (e.g: pagerank, language)? - What does
      # each field in CompositeDoc mean and who should I contact if I have questions?
      # To add a new field into CompositeDoc, or change existing field's size
      # significantly, please file a ticket at go/dj-new-field, fill in necessary
      # information and get approved by docjoin-access@ team. Next id: 190
      class CompositeDoc
        include Google::Apis::Core::Hashable
      
        # Visible content checksum as computed by repository::parsehandler::checksum::
        # Checksum96bitsParseHandler. The value is a Fprint96 in "key format" (i.e., by
        # Fprint96::AsKey()).
        # Corresponds to the JSON property `ContentChecksum96`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content_checksum96
      
        # Contains necessary information to enforce row level Docjoin access control.
        # Corresponds to the JSON property `accessRequirements`
        # @return [Google::Apis::ContentwarehouseV1::IndexingPrivacyAccessAccessRequirements]
        attr_accessor :access_requirements
      
        # Additional checksums of the document.
        # Corresponds to the JSON property `additionalchecksums`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocAdditionalChecksums]
        attr_accessor :additionalchecksums
      
        # 
        # Corresponds to the JSON property `alternatename`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocAlternateName>]
        attr_accessor :alternatename
      
        # Statistics of the anchors in a docjoin. Next available tag ID: 63.
        # Corresponds to the JSON property `anchorStats`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorStatistics]
        attr_accessor :anchor_stats
      
        # 
        # Corresponds to the JSON property `anchors`
        # @return [Google::Apis::ContentwarehouseV1::Anchors]
        attr_accessor :anchors
      
        # This protobuffer stores bad SSL certificate information for a canonical URL,
        # and meant to be included in DocJoins and push to serving time.
        # Corresponds to the JSON property `badSslCertificate`
        # @return [Google::Apis::ContentwarehouseV1::IndexingBadSslCertificate]
        attr_accessor :bad_ssl_certificate
      
        # 
        # Corresponds to the JSON property `cseId`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityProseCseUrlInfo>]
        attr_accessor :cse_id
      
        # URL should only be selected for CSE Index if it's pagerank is higher than
        # cse_pagerank_cutoff.
        # Corresponds to the JSON property `csePagerankCutoff`
        # @return [Fixnum]
        attr_accessor :cse_pagerank_cutoff
      
        # DataVersion tracks the version of data in CompositeDoc. The notion of "data"
        # here is loose and people can define the name of their own. For example, a
        # signal generated by Index Signals or an annotation generated by Goldmine (and
        # other components) can all be considered as data here. Each field in this proto
        # represents the human readable version string and the timestamp of one
        # particular data. We choose to explicitly list out all of the data here for
        # better understanding about which data are tracked. NOTE that
        # human_readable_version is not intended for comparison, use timestamp_micros.
        # In addition, we have an annotation about the field paths of each data. With
        # proto reflection (using google3/net/proto2/util/public/field_path.h),
        # downstream systems can take advantage of this annotation to automatically
        # handle newly introduced data without modifying their code. Please also see the
        # comment of FieldProjector above. There are also some fields in DataInfo that
        # annotate who generates the data, the Index Signals or Goldmine annotator name.
        # Corresponds to the JSON property `dataVersion`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersion]
        attr_accessor :data_version
      
        # Next id: 127
        # Corresponds to the JSON property `doc`
        # @return [Google::Apis::ContentwarehouseV1::GDocumentBase]
        attr_accessor :doc
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `docAttachments`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :doc_attachments
      
        # Info about "selected" images associated with the document for which we (
        # already) have ImageData. For each image URL, some fixed number of documents
        # are selected as web referrers for the image URL, and within those selected
        # documents, we say the image is "selected". Within the remaining documents, we
        # say the image is "rejected". Note that this distinction is slightly different
        # from selected for indexing. Only images within doc_images where
        # is_indexed_by_imagesearch is true will be selected for indexing. You can find
        # the rejected images at composite_doc.doc_attachments().get(). You can find
        # images that are selected, but for which we have no ImageData (yet) at
        # composite_doc.image_indexing_info().selected_not_indexed_image_link()
        # Corresponds to the JSON property `docImages`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageData>]
        attr_accessor :doc_images
      
        # Info about videos embedded in the document.
        # Corresponds to the JSON property `docVideos`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryVideoProperties>]
        attr_accessor :doc_videos
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `docinfoPassthroughAttachments`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :docinfo_passthrough_attachments
      
        # This protobuf is used (1) To pass data between EmbeddedExporter and the
        # publisher, and (2) As a member of CompositeDoc, to stick embedded content
        # output into the docjoins. Next tag available: 21
        # Corresponds to the JSON property `embeddedContentInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentEmbeddedContentInfo]
        attr_accessor :embedded_content_info
      
        # 
        # Corresponds to the JSON property `extradup`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocExtraDup>]
        attr_accessor :extradup
      
        # 
        # Corresponds to the JSON property `forwardingdup`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocForwardingDup>]
        attr_accessor :forwardingdup
      
        # 
        # Corresponds to the JSON property `includedcontent`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocIncludedContent>]
        attr_accessor :includedcontent
      
        # Contains information *mostly* used within indexing (e.g. not used for building
        # the production serving shards). Most of this data is generated only in
        # Alexandria, however there are exceptions.
        # Corresponds to the JSON property `indexinginfo`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocIndexingInfo]
        attr_accessor :indexinginfo
      
        # This field associates a document to particular labels and assigns confidence
        # values to them.
        # Corresponds to the JSON property `labelData`
        # @return [Google::Apis::ContentwarehouseV1::QualityLabelsGoogleLabelData]
        attr_accessor :label_data
      
        # Contains information needed for end-to-end live experiments. For a cdoc
        # generated by production pipeline, it includes experiment IDs that have
        # selected current document. For a cdoc generated by experiment pipeline, it
        # includes current experiment ID.
        # Corresponds to the JSON property `liveexperimentinfo`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocLiveExperimentInfo]
        attr_accessor :liveexperimentinfo
      
        # Next Id: 36
        # Corresponds to the JSON property `localinfo`
        # @return [Google::Apis::ContentwarehouseV1::LocalWwwInfo]
        attr_accessor :localinfo
      
        # Localized alternate names are similar to alternate names, except that it is
        # associated with a language different from its canonical. This is the subset of
        # webmaster-provided localized alternate names being in the dup cluster of this
        # document. Used during serving for swapping in the URL based on regional and
        # language preferences of the user.
        # Corresponds to the JSON property `localizedAlternateName`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingConverterLocalizedAlternateName>]
        attr_accessor :localized_alternate_name
      
        # 
        # Corresponds to the JSON property `localizedvariations`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocLocalizedVariations]
        attr_accessor :localizedvariations
      
        # Manybox container message
        # Corresponds to the JSON property `manyboxData`
        # @return [Google::Apis::ContentwarehouseV1::ManyboxData]
        attr_accessor :manybox_data
      
        # Contains information about the partial updates present in a partial
        # CompositeDoc.
        # Corresponds to the JSON property `partialUpdateInfo`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocPartialUpdateInfo]
        attr_accessor :partial_update_info
      
        # =========================================================================== #
        # Make sure you read the comments in the bottom before you add any new field. NB:
        # As noted in the comments, this protocol buffer is used in both indexing and
        # serving. In mustang serving implementations we only decode perdocdata during
        # the search phase, and so this protocol should only contain data used during
        # search. See mustang/repos_www/attachments.proto:`MustangBasicInfo,
        # MustangContentInfo` for protocols used during search and/or docinfo. Next
        # available tag deprecated, use this (and look for commented out fields): blaze-
        # bin/net/proto_compiler/protocol-compiler --freetags \ indexer/perdocdata/
        # perdocdata.proto Next tag: 217
        # Corresponds to the JSON property `perDocData`
        # @return [Google::Apis::ContentwarehouseV1::PerDocData]
        attr_accessor :per_doc_data
      
        # Next ID: 3
        # Corresponds to the JSON property `porninfo`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornDocumentData]
        attr_accessor :porninfo
      
        # NOTE: In segindexer, the docproperties of a document may be reused from a
        # previous cycle if its content is not changed. If you add a new field to
        # DocProperties, make sure it is taken care (i.e., gets copied from a previous
        # cycle to the current document) in CDocProperties::EndDocument().
        # Corresponds to the JSON property `properties`
        # @return [Google::Apis::ContentwarehouseV1::DocProperties]
        attr_accessor :properties
      
        # PToken expresses policy-relevant properties of the data objects being
        # processed and stored in Google's production systems. See go/ptoken to learn
        # more. Next ID: 8
        # Corresponds to the JSON property `ptoken`
        # @return [Google::Apis::ContentwarehouseV1::PtokenPToken]
        attr_accessor :ptoken
      
        # This field should hold all new quality online signals (after 02/05/10).
        # Quality offline signals, which are loaded by Signal API, should be stored in
        # doc_attachments.
        # Corresponds to the JSON property `qualitysignals`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocQualitySignals]
        attr_accessor :qualitysignals
      
        # Domain registration information for the document. NEXT ID TO USE: 3
        # Corresponds to the JSON property `registrationinfo`
        # @return [Google::Apis::ContentwarehouseV1::RegistrationInfo]
        attr_accessor :registrationinfo
      
        # Contains information about 3 versions of the content of a document: 1.
        # Original: the crawled content (possibly patched in ConversionFilters). 2.
        # Processed: the final version of the content indexed in Web search. 3.
        # Intermediate (no longer generated): intermediate version between the original
        # and the processed content. All 3 versions of the content consist of HTTP
        # headers (in unknown encoding) concatenated with the document body (in
        # interchange valid UTF-8 encoding).
        # Corresponds to the JSON property `richcontentData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRichContentData]
        attr_accessor :richcontent_data
      
        # rich snippet extracted from the content of a document.
        # Corresponds to the JSON property `richsnippet`
        # @return [Google::Apis::ContentwarehouseV1::RichsnippetsPageMap]
        attr_accessor :richsnippet
      
        # List of robots info parsed for the user-agents other than the default used to
        # crawl this page.
        # Corresponds to the JSON property `robotsinfolist`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDocRobotsInfoList]
        attr_accessor :robotsinfolist
      
        # to copy to per-doc
        # Corresponds to the JSON property `scaledIndyRank`
        # @return [Fixnum]
        attr_accessor :scaled_indy_rank
      
        # Note: If you are going to populate any new field in this proto, you probably
        # need to go through the go/dj-new-field and go/index-changes process.
        # Corresponds to the JSON property `sitemap`
        # @return [Google::Apis::ContentwarehouseV1::Sitemap]
        attr_accessor :sitemap
      
        # Row timestamp in CDoc storage.
        # Corresponds to the JSON property `storageRowTimestampMicros`
        # @return [Fixnum]
        attr_accessor :storage_row_timestamp_micros
      
        # 
        # Corresponds to the JSON property `subindexid`
        # @return [Array<String>]
        attr_accessor :subindexid
      
        # Next ID: 21
        # Corresponds to the JSON property `syntacticDate`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedSyntacticDate]
        attr_accessor :syntactic_date
      
        # WARNING!!! "url" field in CompositeDoc is optional, and is usually missing: e.
        # g., Docjoin CompositeDoc's don't have CompositeDoc::url. has_url() checking is
        # often useful. So don't rely on CompositeDoc::url unless you're sure otherwise.
        # Usually you want to use CompositeDoc::doc::url instead.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Date in the url extracted by quality/snippets/urldate/date-in-url.cc This is
        # given as midnight GMT on the date in question.
        # Corresponds to the JSON property `urldate`
        # @return [Fixnum]
        attr_accessor :urldate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_checksum96 = args[:content_checksum96] if args.key?(:content_checksum96)
          @access_requirements = args[:access_requirements] if args.key?(:access_requirements)
          @additionalchecksums = args[:additionalchecksums] if args.key?(:additionalchecksums)
          @alternatename = args[:alternatename] if args.key?(:alternatename)
          @anchor_stats = args[:anchor_stats] if args.key?(:anchor_stats)
          @anchors = args[:anchors] if args.key?(:anchors)
          @bad_ssl_certificate = args[:bad_ssl_certificate] if args.key?(:bad_ssl_certificate)
          @cse_id = args[:cse_id] if args.key?(:cse_id)
          @cse_pagerank_cutoff = args[:cse_pagerank_cutoff] if args.key?(:cse_pagerank_cutoff)
          @data_version = args[:data_version] if args.key?(:data_version)
          @doc = args[:doc] if args.key?(:doc)
          @doc_attachments = args[:doc_attachments] if args.key?(:doc_attachments)
          @doc_images = args[:doc_images] if args.key?(:doc_images)
          @doc_videos = args[:doc_videos] if args.key?(:doc_videos)
          @docinfo_passthrough_attachments = args[:docinfo_passthrough_attachments] if args.key?(:docinfo_passthrough_attachments)
          @embedded_content_info = args[:embedded_content_info] if args.key?(:embedded_content_info)
          @extradup = args[:extradup] if args.key?(:extradup)
          @forwardingdup = args[:forwardingdup] if args.key?(:forwardingdup)
          @includedcontent = args[:includedcontent] if args.key?(:includedcontent)
          @indexinginfo = args[:indexinginfo] if args.key?(:indexinginfo)
          @label_data = args[:label_data] if args.key?(:label_data)
          @liveexperimentinfo = args[:liveexperimentinfo] if args.key?(:liveexperimentinfo)
          @localinfo = args[:localinfo] if args.key?(:localinfo)
          @localized_alternate_name = args[:localized_alternate_name] if args.key?(:localized_alternate_name)
          @localizedvariations = args[:localizedvariations] if args.key?(:localizedvariations)
          @manybox_data = args[:manybox_data] if args.key?(:manybox_data)
          @partial_update_info = args[:partial_update_info] if args.key?(:partial_update_info)
          @per_doc_data = args[:per_doc_data] if args.key?(:per_doc_data)
          @porninfo = args[:porninfo] if args.key?(:porninfo)
          @properties = args[:properties] if args.key?(:properties)
          @ptoken = args[:ptoken] if args.key?(:ptoken)
          @qualitysignals = args[:qualitysignals] if args.key?(:qualitysignals)
          @registrationinfo = args[:registrationinfo] if args.key?(:registrationinfo)
          @richcontent_data = args[:richcontent_data] if args.key?(:richcontent_data)
          @richsnippet = args[:richsnippet] if args.key?(:richsnippet)
          @robotsinfolist = args[:robotsinfolist] if args.key?(:robotsinfolist)
          @scaled_indy_rank = args[:scaled_indy_rank] if args.key?(:scaled_indy_rank)
          @sitemap = args[:sitemap] if args.key?(:sitemap)
          @storage_row_timestamp_micros = args[:storage_row_timestamp_micros] if args.key?(:storage_row_timestamp_micros)
          @subindexid = args[:subindexid] if args.key?(:subindexid)
          @syntactic_date = args[:syntactic_date] if args.key?(:syntactic_date)
          @url = args[:url] if args.key?(:url)
          @urldate = args[:urldate] if args.key?(:urldate)
        end
      end
      
      # Additional checksums of the document.
      class CompositeDocAdditionalChecksums
        include Google::Apis::Core::Hashable
      
        # Same as ContentChecksum96 but without transient boilerplate.
        # Corresponds to the JSON property `NoTransientChecksum96`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :no_transient_checksum96
      
        # Deprecated. Use simhash_v2 and simhash_v2_significance instead.
        # Corresponds to the JSON property `SimHash`
        # @return [Fixnum]
        attr_accessor :sim_hash
      
        # 
        # Corresponds to the JSON property `SimHashIsTrusted`
        # @return [Boolean]
        attr_accessor :sim_hash_is_trusted
        alias_method :sim_hash_is_trusted?, :sim_hash_is_trusted
      
        # Simhash-v2 is generated by SimHashParseHandler, designed as a complete
        # replacement of simhash-v1 (a.k.a. the original simhash above) from
        # ApproxDupsParseHandler. Simhash-v2 uses a revised algorithm so that it is
        # expected to work better in most cases than simhash-v1. They coexist in current
        # transition period, then simhash-v1 will be retired.
        # Corresponds to the JSON property `simhashV2`
        # @return [Fixnum]
        attr_accessor :simhash_v2
      
        # Simhash-v2-significance is used to describe the confidence about the
        # corresponding simhash-v2 value. It is defined as the average absolute
        # difference from zero of all internal state components when finalizing a
        # simhash-v2 value in HashMultiSetDotCauchy. We used to compare the significance
        # against some pre-defined threshold (default: 20) to get a boolean value "
        # trusted_simhash_v2". However, it is possible that this field is missing while "
        # simhash_v2" is present, in such case (1) Use "SimHashIsTrusted" instead if it
        # is present, AND/OR (2) Assume "simhash_v2" is trusted if its value is non-zero.
        # Corresponds to the JSON property `simhashV2Significance`
        # @return [Float]
        attr_accessor :simhash_v2_significance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @no_transient_checksum96 = args[:no_transient_checksum96] if args.key?(:no_transient_checksum96)
          @sim_hash = args[:sim_hash] if args.key?(:sim_hash)
          @sim_hash_is_trusted = args[:sim_hash_is_trusted] if args.key?(:sim_hash_is_trusted)
          @simhash_v2 = args[:simhash_v2] if args.key?(:simhash_v2)
          @simhash_v2_significance = args[:simhash_v2_significance] if args.key?(:simhash_v2_significance)
        end
      end
      
      # Alternate names are some urls that we would like to associate with documents
      # in addition to canonicals. Sometimes we may want to serve these alternatenames
      # instead of canonicals. Alternames in CompositeDoc should come from WebMirror
      # pipeline.
      class CompositeDocAlternateName
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Url`
        # @return [String]
        attr_accessor :url
      
        # See webutil/urlencoding
        # Corresponds to the JSON property `UrlEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        # Fp96 of webmirror equivalence class as of last time this was exported.
        # Corresponds to the JSON property `ecnFp`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn_fp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url = args[:url] if args.key?(:url)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
          @ecn_fp = args[:ecn_fp] if args.key?(:ecn_fp)
        end
      end
      
      # The top non-forwarding dups of the canonical url.
      class CompositeDocExtraDup
        include Google::Apis::Core::Hashable
      
        # Fp96 of webmirror equivalence class as of last time this was exported.
        # Corresponds to the JSON property `ecnFp`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn_fp
      
        # The url of the non-forwarding dup.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ecn_fp = args[:ecn_fp] if args.key?(:ecn_fp)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # The top forwarding dups of the canonical url. (note: it may actually include
      # some dups that are NOT used for forwarding data but for making "info:"
      # complete)
      class CompositeDocForwardingDup
        include Google::Apis::Core::Hashable
      
        # The name of the url's webmirror equivalence class.
        # Corresponds to the JSON property `ecn`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn
      
        # 
        # Corresponds to the JSON property `ecnFp`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn_fp
      
        # The purpose(s) of the forwarding dup indicating if it is used for forwarding
        # signal/anchors generally, or only for forwarding some specific signal (e.g.
        # navboost), or for some other purposes (e.g., not for forwarding any data but
        # for making "info:" complete). See indexing/dups/public/dups.h for more details.
        # Corresponds to the JSON property `purposes`
        # @return [Fixnum]
        attr_accessor :purposes
      
        # Raw pagerank of the url.
        # Corresponds to the JSON property `rawPagerank`
        # @return [Fixnum]
        attr_accessor :raw_pagerank
      
        # The webmirror repid of the forwarding dup.
        # Corresponds to the JSON property `repid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :repid
      
        # The url of the forwarding dup.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # The encoding of the url (see webutil/urlencoding for details).
        # Corresponds to the JSON property `urlencoding`
        # @return [Fixnum]
        attr_accessor :urlencoding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ecn = args[:ecn] if args.key?(:ecn)
          @ecn_fp = args[:ecn_fp] if args.key?(:ecn_fp)
          @purposes = args[:purposes] if args.key?(:purposes)
          @raw_pagerank = args[:raw_pagerank] if args.key?(:raw_pagerank)
          @repid = args[:repid] if args.key?(:repid)
          @url = args[:url] if args.key?(:url)
          @urlencoding = args[:urlencoding] if args.key?(:urlencoding)
        end
      end
      
      # 
      class CompositeDocIncludedContent
        include Google::Apis::Core::Hashable
      
        # Indicate how this content came to be included. Legal values are constructed by
        # bitwise-OR-ing values from the included_content::SourceType enum. Default
        # SourceTypeBitfield = included_content::INCLUDED_FRAME
        # Corresponds to the JSON property `SourceTypeBitfield`
        # @return [Fixnum]
        attr_accessor :source_type_bitfield
      
        # Next id: 127
        # Corresponds to the JSON property `includedDoc`
        # @return [Google::Apis::ContentwarehouseV1::GDocumentBase]
        attr_accessor :included_doc
      
        # 
        # Corresponds to the JSON property `linkUrl`
        # @return [String]
        attr_accessor :link_url
      
        # =========================================================================== #
        # Make sure you read the comments in the bottom before you add any new field. NB:
        # As noted in the comments, this protocol buffer is used in both indexing and
        # serving. In mustang serving implementations we only decode perdocdata during
        # the search phase, and so this protocol should only contain data used during
        # search. See mustang/repos_www/attachments.proto:`MustangBasicInfo,
        # MustangContentInfo` for protocols used during search and/or docinfo. Next
        # available tag deprecated, use this (and look for commented out fields): blaze-
        # bin/net/proto_compiler/protocol-compiler --freetags \ indexer/perdocdata/
        # perdocdata.proto Next tag: 217
        # Corresponds to the JSON property `perDocData`
        # @return [Google::Apis::ContentwarehouseV1::PerDocData]
        attr_accessor :per_doc_data
      
        # NOTE: In segindexer, the docproperties of a document may be reused from a
        # previous cycle if its content is not changed. If you add a new field to
        # DocProperties, make sure it is taken care (i.e., gets copied from a previous
        # cycle to the current document) in CDocProperties::EndDocument().
        # Corresponds to the JSON property `properties`
        # @return [Google::Apis::ContentwarehouseV1::DocProperties]
        attr_accessor :properties
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_type_bitfield = args[:source_type_bitfield] if args.key?(:source_type_bitfield)
          @included_doc = args[:included_doc] if args.key?(:included_doc)
          @link_url = args[:link_url] if args.key?(:link_url)
          @per_doc_data = args[:per_doc_data] if args.key?(:per_doc_data)
          @properties = args[:properties] if args.key?(:properties)
        end
      end
      
      # Contains information *mostly* used within indexing (e.g. not used for building
      # the production serving shards). Most of this data is generated only in
      # Alexandria, however there are exceptions.
      class CompositeDocIndexingInfo
        include Google::Apis::Core::Hashable
      
        # Holds extra info except annotations and raw cdoc for buildint the final cdoc.
        # Corresponds to the JSON property `cdocBuildInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerCDocBuildInfo]
        attr_accessor :cdoc_build_info
      
        # Whether current page is under content protection, i.e. a page has been crawled
        # as an error page, but we preserve its last known good content and keep its
        # crawl_status as converter.CrawlStatus::CONTENT.
        # Corresponds to the JSON property `contentProtected`
        # @return [Boolean]
        attr_accessor :content_protected
        alias_method :content_protected?, :content_protected
      
        # If set, indicates that the crawl status was converted to ROBOTED for the
        # reason specified by the enum value in converter.RobotedReasons.
        # ConvertToRobotedReasons. See indexing/converter/proto/converter.proto for
        # details. If unset, then the document was not converted to roboted, and if the
        # document crawl status is ROBOTED, then the document is disallowed (at least to
        # Google) in robots.txt.
        # Corresponds to the JSON property `convertToRobotedReason`
        # @return [Fixnum]
        attr_accessor :convert_to_roboted_reason
      
        # One of the enum values in converter.CrawlStatus.State (see indexing/converter/
        # proto/converter.proto for details). Default is converter.CrawlStatus::CONTENT.
        # The document is roboted if the value is converter.CrawlStatus::ROBOTED.
        # Corresponds to the JSON property `crawlStatus`
        # @return [Fixnum]
        attr_accessor :crawl_status
      
        # 
        # Corresponds to the JSON property `demotionTags`
        # @return [Array<String>]
        attr_accessor :demotion_tags
      
        # One of the enum values in converter.ErrorPageType (see indexing/converter/
        # proto/error-page-detector-enum.proto for detail). Default is converter::
        # ERROR_PAGE_NONE.
        # Corresponds to the JSON property `errorType`
        # @return [Fixnum]
        attr_accessor :error_type
      
        # 
        # Corresponds to the JSON property `freshdocsCorpora`
        # @return [Array<String>]
        attr_accessor :freshdocs_corpora
      
        # The host id of the document. Used chiefly to determine whether the document is
        # part of a parked domain.
        # Corresponds to the JSON property `hostid`
        # @return [Fixnum]
        attr_accessor :hostid
      
        # A short descriptive string to help identify the IE application or setup where
        # this CDoc is generated. For example: websearch_m3 This field is for
        # debuggability purposes.
        # Corresponds to the JSON property `ieIdentifier`
        # @return [String]
        attr_accessor :ie_identifier
      
        # Indexing info about images (i.e. image links missing image data, etc).
        # Corresponds to the JSON property `imageIndexingInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageSearchImageIndexingInfo]
        attr_accessor :image_indexing_info
      
        # The timestamp (the time since the Epoch, in microseconds) when the docjoin is
        # exported from indexing. The main purpose of this field is to identify
        # different versions of the same document.
        # Corresponds to the JSON property `indexingTs`
        # @return [Fixnum]
        attr_accessor :indexing_ts
      
        # Page is deleted when indexing choice flips between different corpora (e.g.
        # desktop, mobile, archive, scholar, etc.) for the same URL. It's only set for
        # deletion cdocs. Downstreams using URL as key should ignore the current
        # deletion if the field is set.
        # Corresponds to the JSON property `isSiblingDeletion`
        # @return [Boolean]
        attr_accessor :is_sibling_deletion
        alias_method :is_sibling_deletion?, :is_sibling_deletion
      
        # If set, the timestamp in microseconds when the URL stopped being canonical.
        # This should never be set for exported canonical documents. This field is used
        # by dups during canonical flip, and by webmain when doc selection switched
        # between desktop and mobile. Union respects this timestamp to prevent old doc
        # being deleted until the new doc is picked up
        # Corresponds to the JSON property `noLongerCanonicalTimestamp`
        # @return [Fixnum]
        attr_accessor :no_longer_canonical_timestamp
      
        # This score is calculated by re-mapping the back onto the partition's score
        # distribution, such that the score represents the score of the equivalently
        # ranked organically-selected document.
        # Corresponds to the JSON property `normalizedClickScore`
        # @return [Float]
        attr_accessor :normalized_click_score
      
        # The raw navboost count for the canonical url without aggregating the navboost
        # from dup urls. This field is used when building forwarding map.
        # Corresponds to the JSON property `rawNavboost`
        # @return [Fixnum]
        attr_accessor :raw_navboost
      
        # The timestamp (the time since the Epoch, in microseconds) to represent doc
        # version, which is used in the downstream processing after Raffia. If it's not
        # set, indexing_ts will be used as row_timestamp. The timestamp is generally set
        # by reprocessing to set slightly newer indexing_ts such that the system can
        # respect the reprocessed version to overwrite old data in storage.
        # Corresponds to the JSON property `rowTimestamp`
        # @return [Fixnum]
        attr_accessor :row_timestamp
      
        # Selection tier rank is a language normalized score ranging from 0-1 over the
        # serving tier (Base, Zeppelins, Landfills) for this document.
        # Corresponds to the JSON property `selectionTierRank`
        # @return [Float]
        attr_accessor :selection_tier_rank
      
        # The tracing ids is to label the version of url for url status tracking. This
        # repeated field will carry at most 10 tracing id. See more details in go/rich-
        # tracing-design There will be less than 2% base+uz cdocs carrying this field.
        # The major sources of tracing ids include: * Indexing API pushed urls * Index
        # Metrics sampling urls The tracing ids will be written into cdocs by Webmain
        # Ramifier. The consumer of the tracing ids is Union serving notification
        # collector see more at go/serving-notification-from-union
        # Corresponds to the JSON property `tracingId`
        # @return [Array<String>]
        attr_accessor :tracing_id
      
        # The next available field number is 22. To access the best estimate of change
        # period, please use GetChangePeriod in predict-change-rate.h to select between
        # this and other change period estimates below.
        # Corresponds to the JSON property `urlChangerate`
        # @return [Google::Apis::ContentwarehouseV1::CrawlerChangerateUrlChangerate]
        attr_accessor :url_changerate
      
        # Url change history for this doc (see crawler/changerate/changerate.proto for
        # details). Note if a doc has more than 20 changes, we only keep the last 20
        # changes here to avoid adding to much data in its docjoin.
        # Corresponds to the JSON property `urlHistory`
        # @return [Google::Apis::ContentwarehouseV1::CrawlerChangerateUrlHistory]
        attr_accessor :url_history
      
        # Contains only the signals necessary to perform per-URL click prediction. Used
        # by Index Selection for scoring. NEXT ID TO USE: 7
        # Corresponds to the JSON property `urlPatternSignals`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlPatternSignals]
        attr_accessor :url_pattern_signals
      
        # Indexing info about videos.
        # Corresponds to the JSON property `videoIndexingInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryVideoIndexingInfo]
        attr_accessor :video_indexing_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cdoc_build_info = args[:cdoc_build_info] if args.key?(:cdoc_build_info)
          @content_protected = args[:content_protected] if args.key?(:content_protected)
          @convert_to_roboted_reason = args[:convert_to_roboted_reason] if args.key?(:convert_to_roboted_reason)
          @crawl_status = args[:crawl_status] if args.key?(:crawl_status)
          @demotion_tags = args[:demotion_tags] if args.key?(:demotion_tags)
          @error_type = args[:error_type] if args.key?(:error_type)
          @freshdocs_corpora = args[:freshdocs_corpora] if args.key?(:freshdocs_corpora)
          @hostid = args[:hostid] if args.key?(:hostid)
          @ie_identifier = args[:ie_identifier] if args.key?(:ie_identifier)
          @image_indexing_info = args[:image_indexing_info] if args.key?(:image_indexing_info)
          @indexing_ts = args[:indexing_ts] if args.key?(:indexing_ts)
          @is_sibling_deletion = args[:is_sibling_deletion] if args.key?(:is_sibling_deletion)
          @no_longer_canonical_timestamp = args[:no_longer_canonical_timestamp] if args.key?(:no_longer_canonical_timestamp)
          @normalized_click_score = args[:normalized_click_score] if args.key?(:normalized_click_score)
          @raw_navboost = args[:raw_navboost] if args.key?(:raw_navboost)
          @row_timestamp = args[:row_timestamp] if args.key?(:row_timestamp)
          @selection_tier_rank = args[:selection_tier_rank] if args.key?(:selection_tier_rank)
          @tracing_id = args[:tracing_id] if args.key?(:tracing_id)
          @url_changerate = args[:url_changerate] if args.key?(:url_changerate)
          @url_history = args[:url_history] if args.key?(:url_history)
          @url_pattern_signals = args[:url_pattern_signals] if args.key?(:url_pattern_signals)
          @video_indexing_info = args[:video_indexing_info] if args.key?(:video_indexing_info)
        end
      end
      
      # Contains information needed for end-to-end live experiments. For a cdoc
      # generated by production pipeline, it includes experiment IDs that have
      # selected current document. For a cdoc generated by experiment pipeline, it
      # includes current experiment ID.
      class CompositeDocLiveExperimentInfo
        include Google::Apis::Core::Hashable
      
        # List of necessary information for each live experiments.
        # Corresponds to the JSON property `perLiveExperimentInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocLiveExperimentInfoPerLiveExperimentInfo>]
        attr_accessor :per_live_experiment_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @per_live_experiment_info = args[:per_live_experiment_info] if args.key?(:per_live_experiment_info)
        end
      end
      
      # Contains information for a live experiment.
      class CompositeDocLiveExperimentInfoPerLiveExperimentInfo
        include Google::Apis::Core::Hashable
      
        # ID of a live experiment.
        # Corresponds to the JSON property `experimentId`
        # @return [String]
        attr_accessor :experiment_id
      
        # Protocol record used for collecting together all information about a document.
        # Please consult go/dme for two basic questions about `CompositeDoc`: - Where
        # should I look up certain information (e.g: pagerank, language)? - What does
        # each field in CompositeDoc mean and who should I contact if I have questions?
        # To add a new field into CompositeDoc, or change existing field's size
        # significantly, please file a ticket at go/dj-new-field, fill in necessary
        # information and get approved by docjoin-access@ team. Next id: 190
        # Corresponds to the JSON property `partialCdoc`
        # @return [Google::Apis::ContentwarehouseV1::CompositeDoc]
        attr_accessor :partial_cdoc
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experiment_id = args[:experiment_id] if args.key?(:experiment_id)
          @partial_cdoc = args[:partial_cdoc] if args.key?(:partial_cdoc)
        end
      end
      
      # 
      class CompositeDocLocalizedVariations
        include Google::Apis::Core::Hashable
      
        # A subset of computed variations, only the members which are dups to the main
        # url. Used during serving for swapping in the URL based on regional and
        # language preferences of the user.
        # Corresponds to the JSON property `dupsComputedAlternateNames`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsComputedLocalizedAlternateNamesLocaleEntry>]
        attr_accessor :dups_computed_alternate_names
      
        # All localized alternate names provided by the webmaster (canonical and dups,
        # indexed and not-indexed). Used on the ranking side for swapping out results
        # based on the webmaster preference.
        # Corresponds to the JSON property `webmasterAlternateNames`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingConverterLocalizedAlternateName>]
        attr_accessor :webmaster_alternate_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dups_computed_alternate_names = args[:dups_computed_alternate_names] if args.key?(:dups_computed_alternate_names)
          @webmaster_alternate_names = args[:webmaster_alternate_names] if args.key?(:webmaster_alternate_names)
        end
      end
      
      # Contains information about the partial updates present in a partial
      # CompositeDoc.
      class CompositeDocPartialUpdateInfo
        include Google::Apis::Core::Hashable
      
        # List of goldmine annotator updates present in the enclosing partial cdoc.
        # Corresponds to the JSON property `goldmineAnnotatorNames`
        # @return [Array<String>]
        attr_accessor :goldmine_annotator_names
      
        # List of images signal updates present in the enclosing partial cdoc. Images
        # signal name for a images signal is the unique name for the signal according to
        # SignalSpec.
        # Corresponds to the JSON property `imagesSignalNames`
        # @return [Array<String>]
        attr_accessor :images_signal_names
      
        # Contains last full indexing information for partial updates.
        # Corresponds to the JSON property `lastFullIndexingInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDocPartialUpdateInfoLastFullIndexingInfo>]
        attr_accessor :last_full_indexing_info
      
        # Which tier we should do cdoc lookup to merge partial cdocs. This uses the
        # integer value of indexing.selection.CorpusId. NOT intended for other usage.
        # Corresponds to the JSON property `shouldLookupDocjoinsTier`
        # @return [Fixnum]
        attr_accessor :should_lookup_docjoins_tier
      
        # List of signal updates present in the enclosing partial cdoc. Signal name for
        # a signal is unique name for the signal according to SignalSpec.
        # Corresponds to the JSON property `signalNames`
        # @return [Array<String>]
        attr_accessor :signal_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @goldmine_annotator_names = args[:goldmine_annotator_names] if args.key?(:goldmine_annotator_names)
          @images_signal_names = args[:images_signal_names] if args.key?(:images_signal_names)
          @last_full_indexing_info = args[:last_full_indexing_info] if args.key?(:last_full_indexing_info)
          @should_lookup_docjoins_tier = args[:should_lookup_docjoins_tier] if args.key?(:should_lookup_docjoins_tier)
          @signal_names = args[:signal_names] if args.key?(:signal_names)
        end
      end
      
      # Last full indexing information for the partial CDoc.
      class CompositeDocPartialUpdateInfoLastFullIndexingInfo
        include Google::Apis::Core::Hashable
      
        # The corpus of last full updates.
        # Corresponds to the JSON property `corpus`
        # @return [String]
        attr_accessor :corpus
      
        # Last full update indexing timestamp in microseconds.
        # Corresponds to the JSON property `lastFullIndexingTsMicros`
        # @return [Fixnum]
        attr_accessor :last_full_indexing_ts_micros
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @corpus = args[:corpus] if args.key?(:corpus)
          @last_full_indexing_ts_micros = args[:last_full_indexing_ts_micros] if args.key?(:last_full_indexing_ts_micros)
        end
      end
      
      # This field should hold all new quality online signals (after 02/05/10).
      # Quality offline signals, which are loaded by Signal API, should be stored in
      # doc_attachments.
      class CompositeDocQualitySignals
        include Google::Apis::Core::Hashable
      
        # Contains a date used for the "Date Last Modified" toolbelt restrict mode. Note:
        # this date is a combined date and is different from the pure shingle-based
        # signal stored in contentage.last_significant_update field.
        # Corresponds to the JSON property `lastSignificantUpdate`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedLastSignificantUpdate]
        attr_accessor :last_significant_update
      
        # 
        # Corresponds to the JSON property `oldnessInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedOldnessInfo]
        attr_accessor :oldness_info
      
        # 
        # Corresponds to the JSON property `pagetype`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedPageType]
        attr_accessor :pagetype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_significant_update = args[:last_significant_update] if args.key?(:last_significant_update)
          @oldness_info = args[:oldness_info] if args.key?(:oldness_info)
          @pagetype = args[:pagetype] if args.key?(:pagetype)
        end
      end
      
      # List of robots info parsed for the user-agents other than the default used to
      # crawl this page.
      class CompositeDocRobotsInfoList
        include Google::Apis::Core::Hashable
      
        # Robots Info encapsulates all robots.txt or related information that we know
        # about the Document collected from multiple sources such as HTTP headers, meta
        # robots tags etc.
        # Corresponds to the JSON property `newsRobotsInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRobotsInfo]
        attr_accessor :news_robots_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @news_robots_info = args[:news_robots_info] if args.key?(:news_robots_info)
        end
      end
      
      # A message containing per doc signals that are compressed and included in
      # Mustang and TeraGoogle. For TeraGoogle, this message is included in perdocdata
      # which means it can be used in preliminary scoring. CAREFUL: For TeraGoogle,
      # this data resides in very limited serving memory (Flash storage) for a huge
      # number of documents. Next id: 40
      class CompressedQualitySignals
        include Google::Apis::Core::Hashable
      
        # anchor_mismatch_demotion: converted from QualityBoost.mismatched.boost.
        # Corresponds to the JSON property `anchorMismatchDemotion`
        # @return [Fixnum]
        attr_accessor :anchor_mismatch_demotion
      
        # authority promotion: converted from QualityBoost.authority.boost
        # Corresponds to the JSON property `authorityPromotion`
        # @return [Fixnum]
        attr_accessor :authority_promotion
      
        # baby_panda_demotion: converted from QualityBoost.rendered.boost.
        # Corresponds to the JSON property `babyPandaDemotion`
        # @return [Fixnum]
        attr_accessor :baby_panda_demotion
      
        # New BabyPanda demotion, applied on top of Panda. This is meant to replace |
        # baby_panda_demotion|.
        # Corresponds to the JSON property `babyPandaV2Demotion`
        # @return [Fixnum]
        attr_accessor :baby_panda_v2_demotion
      
        # Impressions, unsquashed, host level, not to be used with compressed ratios.
        # Not to be used in Pattern Data.
        # Corresponds to the JSON property `crapsAbsoluteHostSignals`
        # @return [Fixnum]
        attr_accessor :craps_absolute_host_signals
      
        # 
        # Corresponds to the JSON property `crapsNewHostSignals`
        # @return [Fixnum]
        attr_accessor :craps_new_host_signals
      
        # 
        # Corresponds to the JSON property `crapsNewPatternSignals`
        # @return [Fixnum]
        attr_accessor :craps_new_pattern_signals
      
        # For craps_[url|pattern]_signals, please avoid accessing these fields directly,
        # even in minor ways like checking has_craps_*. Instead, please use methods from
        # quality/navboost/craps/craps-lossy-compression.h or talk to dice-team.
        # Corresponds to the JSON property `crapsNewUrlSignals`
        # @return [Fixnum]
        attr_accessor :craps_new_url_signals
      
        # 
        # Corresponds to the JSON property `crapsUnscaledIpPriorBadFraction`
        # @return [Fixnum]
        attr_accessor :craps_unscaled_ip_prior_bad_fraction
      
        # Page quality signals converted from fields in proto QualityBoost in quality/q2/
        # proto/quality-boost.proto. To save indexing space, we convert the float values
        # in [0, 1] to integers in range [0, 1023] (use 10 bits).
        # exact_match_domain_demotion: converted from QualityBoost.emd.boost.
        # Corresponds to the JSON property `exactMatchDomainDemotion`
        # @return [Fixnum]
        attr_accessor :exact_match_domain_demotion
      
        # Experimental NsrTeam data. This is a proto containing versioned signals which
        # can be used to run live experiments. This proto will not be propagated to MDU
        # shards, but it will be populated at query time by go/web-signal-joins inside
        # the CompressedQualitySignals subproto of PerDocData proto. See go/0DayLEs for
        # the design doc. Note how this is only meant to be used during LEs, it should *
        # not* be used for launches.
        # Corresponds to the JSON property `experimentalNsrTeamData`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrExperimentalNsrTeamData]
        attr_accessor :experimental_nsr_team_data
      
        # This field is *not* propagated to shards, but it's populated at serving time
        # by go/web-signal-joins (see b/207344056). See go/0DayLEs for details. This is
        # only meant to be used during LEs, it should *not* be used for launches.
        # Corresponds to the JSON property `experimentalNsrTeamWsjData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityNsrExperimentalNsrTeamWsjData>]
        attr_accessor :experimental_nsr_team_wsj_data
      
        # This field is *not* propagated to shards. It is meant to be populated at
        # serving time using one of the versions present in the `
        # experimental_nsr_team_wsj_data` field above (using the `
        # ExperimentalNsrTeamDataOverridesParams` opti to populate it; see http://source/
        # search?q=ExperimentalNsrTeamDataOverridesParams%20file:ascorer.proto). The
        # purpose of this field is to be read by an experimental Q* component, in order
        # to quickly run LEs with new delta components. See go/0DayLEs for details.
        # Corresponds to the JSON property `experimentalQstarDeltaSignal`
        # @return [Float]
        attr_accessor :experimental_qstar_delta_signal
      
        # This field is *not* propagated to shards. It is meant to be populated at
        # serving time using one of the versions present in the `
        # experimental_nsr_team_wsj_data` field above (using the `
        # ExperimentalNsrTeamDataOverridesParams` opti to populate it; see http://source/
        # search?q=ExperimentalNsrTeamDataOverridesParams%20file:ascorer.proto). The
        # purpose of this field is to be read by an experimental Q* component, in order
        # to quickly run LEs with new components. See go/0DayLEs for details.
        # Corresponds to the JSON property `experimentalQstarSignal`
        # @return [Float]
        attr_accessor :experimental_qstar_signal
      
        # This field is *not* propagated to shards. It is meant to be populated at
        # serving time using one of the versions present in the `
        # experimental_nsr_team_wsj_data` field above (using the `
        # ExperimentalNsrTeamDataOverridesParams` opti to populate it; see http://source/
        # search?q=ExperimentalNsrTeamDataOverridesParams%20file:ascorer.proto). The
        # purpose of this field is to be read by an experimental Q* component, in order
        # to quickly run LEs with new site components. See go/0DayLEs for details.
        # Corresponds to the JSON property `experimentalQstarSiteSignal`
        # @return [Float]
        attr_accessor :experimental_qstar_site_signal
      
        # S2V low quality score: converted from quality_nsr.NsrData, applied in Qstar.
        # See NsrUtil::ConvertNsrDataToLowQuality.
        # Corresponds to the JSON property `lowQuality`
        # @return [Fixnum]
        attr_accessor :low_quality
      
        # nav_demotion: converted from QualityBoost.nav_demoted.boost.
        # Corresponds to the JSON property `navDemotion`
        # @return [Fixnum]
        attr_accessor :nav_demotion
      
        # NSR confidence score: converted from quality_nsr.NsrData.
        # Corresponds to the JSON property `nsrConfidence`
        # @return [Fixnum]
        attr_accessor :nsr_confidence
      
        # NSR override bid, used in Q* for emergency overrides.
        # Corresponds to the JSON property `nsrOverrideBid`
        # @return [Float]
        attr_accessor :nsr_override_bid
      
        # Versioned NSR score to be used in continuous evaluation of the upcoming NSR
        # version and assess quality impact on various slices.
        # Corresponds to the JSON property `nsrVersionedData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NsrVersionedItem>]
        attr_accessor :nsr_versioned_data
      
        # PairwiseQ data for QTJ. This field is *not* propagated to shards, but is
        # populated at serving time by go/web-signal-joins. See b/175762140
        # Corresponds to the JSON property `pairwiseqScoringData`
        # @return [Google::Apis::ContentwarehouseV1::PairwiseQScoringData]
        attr_accessor :pairwiseq_scoring_data
      
        # Versioned PairwiseQ score to be used in continuous evaluation of the upcoming
        # PairwiseQ versions and assess quality impact on various slices.
        # Corresponds to the JSON property `pairwiseqVersionedData`
        # @return [Array<Google::Apis::ContentwarehouseV1::PairwiseQVersionedItem>]
        attr_accessor :pairwiseq_versioned_data
      
        # This is the encoding of Panda fields in the proto SiteQualityFeatures in
        # quality/q2/proto/site_quality_features.proto. The encoding/decoding is
        # performed using functions from quality_coati::coati_util.
        # Corresponds to the JSON property `pandaDemotion`
        # @return [Fixnum]
        attr_accessor :panda_demotion
      
        # Encoded page-level PQ signals.
        # Corresponds to the JSON property `pqData`
        # @return [Fixnum]
        attr_accessor :pq_data
      
        # Stripped page-level signals, not present in the encoded field 'pq_data'.
        # Corresponds to the JSON property `pqDataProto`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrPqData]
        attr_accessor :pq_data_proto
      
        # 
        # Corresponds to the JSON property `productReviewPDemotePage`
        # @return [Fixnum]
        attr_accessor :product_review_p_demote_page
      
        # Product review demotion/promotion confidences. (Times 1000 and floored)
        # Corresponds to the JSON property `productReviewPDemoteSite`
        # @return [Fixnum]
        attr_accessor :product_review_p_demote_site
      
        # 
        # Corresponds to the JSON property `productReviewPPromotePage`
        # @return [Fixnum]
        attr_accessor :product_review_p_promote_page
      
        # 
        # Corresponds to the JSON property `productReviewPPromoteSite`
        # @return [Fixnum]
        attr_accessor :product_review_p_promote_site
      
        # Scam model score. Used as one of the web page quality qstar signals. Value
        # range from 0 to 1023.
        # Corresponds to the JSON property `scamness`
        # @return [Fixnum]
        attr_accessor :scamness
      
        # serp demotion: applied in Qstar.
        # Corresponds to the JSON property `serpDemotion`
        # @return [Fixnum]
        attr_accessor :serp_demotion
      
        # site_authority: converted from quality_nsr.SiteAuthority, applied in Qstar.
        # Corresponds to the JSON property `siteAuthority`
        # @return [Fixnum]
        attr_accessor :site_authority
      
        # Versioned TopicEmbeddings data to be populated later into superroot / used
        # directly in scorers.
        # Corresponds to the JSON property `topicEmbeddingsVersionedData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityAuthorityTopicEmbeddingsVersionedItem>]
        attr_accessor :topic_embeddings_versioned_data
      
        # Unauthoritative score. Used as one of the web page quality qstar signals.
        # Corresponds to the JSON property `unauthoritativeScore`
        # @return [Fixnum]
        attr_accessor :unauthoritative_score
      
        # NSR for low-quality videos, converted from quality_nsr.NsrData.vlq_nsr.
        # Corresponds to the JSON property `vlqNsr`
        # @return [Fixnum]
        attr_accessor :vlq_nsr
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_mismatch_demotion = args[:anchor_mismatch_demotion] if args.key?(:anchor_mismatch_demotion)
          @authority_promotion = args[:authority_promotion] if args.key?(:authority_promotion)
          @baby_panda_demotion = args[:baby_panda_demotion] if args.key?(:baby_panda_demotion)
          @baby_panda_v2_demotion = args[:baby_panda_v2_demotion] if args.key?(:baby_panda_v2_demotion)
          @craps_absolute_host_signals = args[:craps_absolute_host_signals] if args.key?(:craps_absolute_host_signals)
          @craps_new_host_signals = args[:craps_new_host_signals] if args.key?(:craps_new_host_signals)
          @craps_new_pattern_signals = args[:craps_new_pattern_signals] if args.key?(:craps_new_pattern_signals)
          @craps_new_url_signals = args[:craps_new_url_signals] if args.key?(:craps_new_url_signals)
          @craps_unscaled_ip_prior_bad_fraction = args[:craps_unscaled_ip_prior_bad_fraction] if args.key?(:craps_unscaled_ip_prior_bad_fraction)
          @exact_match_domain_demotion = args[:exact_match_domain_demotion] if args.key?(:exact_match_domain_demotion)
          @experimental_nsr_team_data = args[:experimental_nsr_team_data] if args.key?(:experimental_nsr_team_data)
          @experimental_nsr_team_wsj_data = args[:experimental_nsr_team_wsj_data] if args.key?(:experimental_nsr_team_wsj_data)
          @experimental_qstar_delta_signal = args[:experimental_qstar_delta_signal] if args.key?(:experimental_qstar_delta_signal)
          @experimental_qstar_signal = args[:experimental_qstar_signal] if args.key?(:experimental_qstar_signal)
          @experimental_qstar_site_signal = args[:experimental_qstar_site_signal] if args.key?(:experimental_qstar_site_signal)
          @low_quality = args[:low_quality] if args.key?(:low_quality)
          @nav_demotion = args[:nav_demotion] if args.key?(:nav_demotion)
          @nsr_confidence = args[:nsr_confidence] if args.key?(:nsr_confidence)
          @nsr_override_bid = args[:nsr_override_bid] if args.key?(:nsr_override_bid)
          @nsr_versioned_data = args[:nsr_versioned_data] if args.key?(:nsr_versioned_data)
          @pairwiseq_scoring_data = args[:pairwiseq_scoring_data] if args.key?(:pairwiseq_scoring_data)
          @pairwiseq_versioned_data = args[:pairwiseq_versioned_data] if args.key?(:pairwiseq_versioned_data)
          @panda_demotion = args[:panda_demotion] if args.key?(:panda_demotion)
          @pq_data = args[:pq_data] if args.key?(:pq_data)
          @pq_data_proto = args[:pq_data_proto] if args.key?(:pq_data_proto)
          @product_review_p_demote_page = args[:product_review_p_demote_page] if args.key?(:product_review_p_demote_page)
          @product_review_p_demote_site = args[:product_review_p_demote_site] if args.key?(:product_review_p_demote_site)
          @product_review_p_promote_page = args[:product_review_p_promote_page] if args.key?(:product_review_p_promote_page)
          @product_review_p_promote_site = args[:product_review_p_promote_site] if args.key?(:product_review_p_promote_site)
          @scamness = args[:scamness] if args.key?(:scamness)
          @serp_demotion = args[:serp_demotion] if args.key?(:serp_demotion)
          @site_authority = args[:site_authority] if args.key?(:site_authority)
          @topic_embeddings_versioned_data = args[:topic_embeddings_versioned_data] if args.key?(:topic_embeddings_versioned_data)
          @unauthoritative_score = args[:unauthoritative_score] if args.key?(:unauthoritative_score)
          @vlq_nsr = args[:vlq_nsr] if args.key?(:vlq_nsr)
        end
      end
      
      # The following protobuf is used to store an attribution from one page to (
      # usually) one other page, giving credit for the content. This information is
      # used during ranking to promote the attributed page. This protobuf is copied
      # from a quality_contra::SelectedAttribution. See //quality/contra/authorship/
      # attribution and https://qwiki.corp.google.com/display/Q/
      # ContentTrackingContentAttribution.
      class ContentAttributions
        include Google::Apis::Core::Hashable
      
        # Selected outgoing attributions extracted on FreshDocs.
        # Corresponds to the JSON property `freshdocsOutgoing`
        # @return [Array<Google::Apis::ContentwarehouseV1::ContentAttributionsOutgoingAttribution>]
        attr_accessor :freshdocs_outgoing
      
        # Selected outgoing attributions extracted via offline MR jobs.
        # Corresponds to the JSON property `offlineOutgoing`
        # @return [Array<Google::Apis::ContentwarehouseV1::ContentAttributionsOutgoingAttribution>]
        attr_accessor :offline_outgoing
      
        # Selected outgoing attributions extracted online on Alexandria.
        # Corresponds to the JSON property `onlineOutgoing`
        # @return [Array<Google::Apis::ContentwarehouseV1::ContentAttributionsOutgoingAttribution>]
        attr_accessor :online_outgoing
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @freshdocs_outgoing = args[:freshdocs_outgoing] if args.key?(:freshdocs_outgoing)
          @offline_outgoing = args[:offline_outgoing] if args.key?(:offline_outgoing)
          @online_outgoing = args[:online_outgoing] if args.key?(:online_outgoing)
        end
      end
      
      # This is a copy of quality_contra::SelectedAttribution::SelectedInfo. The url
      # is converted to docid and other fields are copied directly.
      class ContentAttributionsOutgoingAttribution
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `bestEvidenceType`
        # @return [String]
        attr_accessor :best_evidence_type
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # 
        # Corresponds to the JSON property `properties`
        # @return [Fixnum]
        attr_accessor :properties
      
        # 
        # Corresponds to the JSON property `usableForClustering`
        # @return [Boolean]
        attr_accessor :usable_for_clustering
        alias_method :usable_for_clustering?, :usable_for_clustering
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @best_evidence_type = args[:best_evidence_type] if args.key?(:best_evidence_type)
          @docid = args[:docid] if args.key?(:docid)
          @properties = args[:properties] if args.key?(:properties)
          @usable_for_clustering = args[:usable_for_clustering] if args.key?(:usable_for_clustering)
        end
      end
      
      # 
      class ContentAwareCropsIndexing
        include Google::Apis::Core::Hashable
      
        # Compact representation for Mustang storage. See image/search/utils/
        # packed_crops.h for details on the packing format.
        # Corresponds to the JSON property `mustangBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :mustang_bytes
      
        # 
        # Corresponds to the JSON property `mustangBytesVersion`
        # @return [Fixnum]
        attr_accessor :mustang_bytes_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mustang_bytes = args[:mustang_bytes] if args.key?(:mustang_bytes)
          @mustang_bytes_version = args[:mustang_bytes_version] if args.key?(:mustang_bytes_version)
        end
      end
      
      # Contains lexical metadata for a given reference. For example, this proto will
      # be used to store locale-specific Lexical mids for contact relationships (e.g. /
      # g/11gv0vypg4 is the mid for mother in english and /g/11gmy_gv87 is for mother
      # in french) as an extension to QRefAnnotation::other_metadata, when available.
      class CopleyLexicalMetadata
        include Google::Apis::Core::Hashable
      
        # Mid for an entity that has lexical data (a LexiconEntry). See https://g3doc.
        # corp.google.com/nlp/generation/g3doc/lexical_data.md for for more information
        # about lexical data. This is the canonical mid for this entity (eg. it would be
        # for "mother" in EN even if user referred to "mom").
        # Corresponds to the JSON property `canonicalLexicalMid`
        # @return [String]
        attr_accessor :canonical_lexical_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_lexical_mid = args[:canonical_lexical_mid] if args.key?(:canonical_lexical_mid)
        end
      end
      
      # Represents a reference made by a user that refers to some personal entity.
      class CopleyPersonalReference
        include Google::Apis::Core::Hashable
      
        # The manner in which the entity was referenced (e.g. "my hotel", "the airport").
        # Corresponds to the JSON property `personalReferenceType`
        # @return [String]
        attr_accessor :personal_reference_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @personal_reference_type = args[:personal_reference_type] if args.key?(:personal_reference_type)
        end
      end
      
      # General message used to store metadata about references to personal entities,
      # even if those entities cannot be resolved.
      class CopleyPersonalReferenceMetadata
        include Google::Apis::Core::Hashable
      
        # The strength of the personal reference. For example "my flight" may receive a
        # high reference_score, whereas "the airport" may receive a low score.
        # Corresponds to the JSON property `referenceScore`
        # @return [Float]
        attr_accessor :reference_score
      
        # A list of all references made. Empty if no personal references exist. Multiple
        # references can be present when multiple references were made in a single query,
        # or the type of reference was ambiguous.
        # Corresponds to the JSON property `references`
        # @return [Array<Google::Apis::ContentwarehouseV1::CopleyPersonalReference>]
        attr_accessor :references
      
        # Represents the most compound resolved entities and most nested unresolved
        # references for a span. Useful for punting.
        # Corresponds to the JSON property `subreferenceMetadata`
        # @return [Google::Apis::ContentwarehouseV1::CopleySubreferenceMetadata]
        attr_accessor :subreference_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reference_score = args[:reference_score] if args.key?(:reference_score)
          @references = args[:references] if args.key?(:references)
          @subreference_metadata = args[:subreference_metadata] if args.key?(:subreference_metadata)
        end
      end
      
      # 
      class CopleySourceTypeList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `sourceTypeMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::CopleySourceTypeMetadata>]
        attr_accessor :source_type_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_type_metadata = args[:source_type_metadata] if args.key?(:source_type_metadata)
        end
      end
      
      # Contains the source and type information related to a personal entity, for
      # example if it's an hotel or a restaurant (type) and if it comes from gmail,
      # calendar, etc. (source). Next ID: 13
      class CopleySourceTypeMetadata
        include Google::Apis::Core::Hashable
      
        # Annotation ID of a contact annotation, e.g. a relationship set via Assistant.
        # This ID is generated by People Write Server. It is used to delete Contact
        # Annotations via People API.
        # Corresponds to the JSON property `contactAnnotationId`
        # @return [String]
        attr_accessor :contact_annotation_id
      
        # 
        # Corresponds to the JSON property `displayableName`
        # @return [String]
        attr_accessor :displayable_name
      
        # Only used if personal_data_provenance == PERSONAL_SOURCE_GMAIL. Used to create
        # a link to the source email in the form: mail.google.com/mail/u/0/?extsrc=sync&
        # client=h&plid=`email_identifier`
        # Corresponds to the JSON property `emailIdentifier`
        # @return [String]
        attr_accessor :email_identifier
      
        # An EventId is a 128 bit identifier that uniquely identifies an event, such as
        # a query. The event time recorded to the nearest microsecond, along with
        # information about the process generating the event, ensures that all EventIds
        # are unique. Details of this EventId are described in a design document: http://
        # www/eng/designdocs/sawmill/adlogs.html
        # Corresponds to the JSON property `eventId`
        # @return [Google::Apis::ContentwarehouseV1::EventIdMessage]
        attr_accessor :event_id
      
        # Metadata related to LocalDiscoverySettings,e.g., dietary_restriction, cuisine
        # and ingredient.
        # Corresponds to the JSON property `localDiscoverySettingsMetadata`
        # @return [Google::Apis::ContentwarehouseV1::PersonalizationSettingsApiProtoLocalDiscoveryLocalDiscoverySettingsMetadata]
        attr_accessor :local_discovery_settings_metadata
      
        # 
        # Corresponds to the JSON property `personalDataProvenance`
        # @return [String]
        attr_accessor :personal_data_provenance
      
        # 
        # Corresponds to the JSON property `personalDataType`
        # @return [String]
        attr_accessor :personal_data_type
      
        # 
        # Corresponds to the JSON property `provenanceCategory`
        # @return [Array<String>]
        attr_accessor :provenance_category
      
        # Canonical representation of query sensitivites. See go/sensitive-intents for
        # more details.
        # Corresponds to the JSON property `sensitivity`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivitySensitivity]
        attr_accessor :sensitivity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_annotation_id = args[:contact_annotation_id] if args.key?(:contact_annotation_id)
          @displayable_name = args[:displayable_name] if args.key?(:displayable_name)
          @email_identifier = args[:email_identifier] if args.key?(:email_identifier)
          @event_id = args[:event_id] if args.key?(:event_id)
          @local_discovery_settings_metadata = args[:local_discovery_settings_metadata] if args.key?(:local_discovery_settings_metadata)
          @personal_data_provenance = args[:personal_data_provenance] if args.key?(:personal_data_provenance)
          @personal_data_type = args[:personal_data_type] if args.key?(:personal_data_type)
          @provenance_category = args[:provenance_category] if args.key?(:provenance_category)
          @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
        end
      end
      
      # Represents the most compound resolved entities and most nested unresolved
      # references for a span. Useful for punting.
      class CopleySubreferenceMetadata
        include Google::Apis::Core::Hashable
      
        # Resolved entities are sorted from highest resolution score to lowest.
        # Corresponds to the JSON property `mostCompoundResolvedEntities`
        # @return [Array<Google::Apis::ContentwarehouseV1::CopleySubreferenceResolution>]
        attr_accessor :most_compound_resolved_entities
      
        # Represents a reference that may be part of a larger compound reference. For
        # example, "my brother's birthday" will have a subreference that may have
        # references for "my brother".
        # Corresponds to the JSON property `mostNestedUnresolvedReference`
        # @return [Google::Apis::ContentwarehouseV1::CopleySubreferenceReference]
        attr_accessor :most_nested_unresolved_reference
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @most_compound_resolved_entities = args[:most_compound_resolved_entities] if args.key?(:most_compound_resolved_entities)
          @most_nested_unresolved_reference = args[:most_nested_unresolved_reference] if args.key?(:most_nested_unresolved_reference)
        end
      end
      
      # Represents a reference that may be part of a larger compound reference. For
      # example, "my brother's birthday" will have a subreference that may have
      # references for "my brother".
      class CopleySubreferenceReference
        include Google::Apis::Core::Hashable
      
        # Type of reference. There may be multiple for a single reference (e.g.
        # relationship and contact).
        # Corresponds to the JSON property `personalReferenceTypes`
        # @return [Array<String>]
        attr_accessor :personal_reference_types
      
        # Highest reference score for any references merged in this span.
        # Corresponds to the JSON property `referenceScore`
        # @return [Float]
        attr_accessor :reference_score
      
        # Contains lexical metadata for a given reference. For example, this proto will
        # be used to store locale-specific Lexical mids for contact relationships (e.g. /
        # g/11gv0vypg4 is the mid for mother in english and /g/11gmy_gv87 is for mother
        # in french) as an extension to QRefAnnotation::other_metadata, when available.
        # Corresponds to the JSON property `relationshipLexicalInfo`
        # @return [Google::Apis::ContentwarehouseV1::CopleyLexicalMetadata]
        attr_accessor :relationship_lexical_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @personal_reference_types = args[:personal_reference_types] if args.key?(:personal_reference_types)
          @reference_score = args[:reference_score] if args.key?(:reference_score)
          @relationship_lexical_info = args[:relationship_lexical_info] if args.key?(:relationship_lexical_info)
        end
      end
      
      # Represents a resolution that may be part of a larger compound reference. For
      # example, "my brother's birthday" will have a subreference that may have
      # resolutions for "my brother".
      class CopleySubreferenceResolution
        include Google::Apis::Core::Hashable
      
        # Can be used with PKG Service for looking up metadata about this entity at
        # fulfillment/GenX time.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Name of the entity represented by this resolution.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # A resolution score of 0 indicates that it did not resolve to a real entity.
        # Corresponds to the JSON property `resolutionScore`
        # @return [Float]
        attr_accessor :resolution_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
          @resolution_score = args[:resolution_score] if args.key?(:resolution_score)
        end
      end
      
      # 
      class CorpusSelectionInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `corpus`
        # @return [String]
        attr_accessor :corpus
      
        # Corpus specific score for an image
        # Corresponds to the JSON property `corpusScore`
        # @return [Float]
        attr_accessor :corpus_score
      
        # Whether an image was selected for indexing.
        # Corresponds to the JSON property `isSelectedForIndexing`
        # @return [Boolean]
        attr_accessor :is_selected_for_indexing
        alias_method :is_selected_for_indexing?, :is_selected_for_indexing
      
        # Set of referrers indexed with the image.
        # Corresponds to the JSON property `referrerDocid`
        # @return [Array<Fixnum>]
        attr_accessor :referrer_docid
      
        # Set of referrer urls indexed with the image.
        # Corresponds to the JSON property `referrerUrls`
        # @return [Array<String>]
        attr_accessor :referrer_urls
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @corpus = args[:corpus] if args.key?(:corpus)
          @corpus_score = args[:corpus_score] if args.key?(:corpus_score)
          @is_selected_for_indexing = args[:is_selected_for_indexing] if args.key?(:is_selected_for_indexing)
          @referrer_docid = args[:referrer_docid] if args.key?(:referrer_docid)
          @referrer_urls = args[:referrer_urls] if args.key?(:referrer_urls)
        end
      end
      
      # 
      class CountryClickDistribution
        include Google::Apis::Core::Hashable
      
        # To store confidence in the distribution in cases when total is not set.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `item`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountryClickDistributionItem>]
        attr_accessor :item
      
        # To store total clicks on this page/domain.
        # Corresponds to the JSON property `total`
        # @return [Float]
        attr_accessor :total
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @item = args[:item] if args.key?(:item)
          @total = args[:total] if args.key?(:total)
        end
      end
      
      # 
      class CountryClickDistributionItem
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `doubleValue`
        # @return [Float]
        attr_accessor :double_value
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @double_value = args[:double_value] if args.key?(:double_value)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # If you add new fields to this message, do not use any tag value less than the "
      # Next free tag" below. The lower tag values might be missing in this file, but
      # they were used in past for some field, so cannot be used again. Next free tag:
      # 44
      class CountryCountryAttachment
        include Google::Apis::Core::Hashable
      
        # Store weighted click distribution for page level country-id classification.
        # Corresponds to the JSON property `clickDistribution`
        # @return [Google::Apis::ContentwarehouseV1::CountryClickDistribution]
        attr_accessor :click_distribution
      
        # Is true if the country attachment was computed through the UGC pipeline.
        # Corresponds to the JSON property `countryidFromUgc`
        # @return [Boolean]
        attr_accessor :countryid_from_ugc
        alias_method :countryid_from_ugc?, :countryid_from_ugc
      
        # A non critical field to store debug info for a country attachment. Used in
        # experiments and for debugging.
        # Corresponds to the JSON property `debug`
        # @return [String]
        attr_accessor :debug
      
        # Set to the signal source URLs when merging country signals in Alexandria
        # during sitemoves. Essentially if sites A and B move to C, and we merge A and B'
        # s signal to C, in the countryattachment signal C will have URL A and B as
        # source_url. Only used for debugging and it doesn't show up in docjoins.
        # Corresponds to the JSON property `debugSourceUrl`
        # @return [Array<String>]
        attr_accessor :debug_source_url
      
        # Specifies the origin of `geo_locations`. Right now, it can either come from
        # deprecated Docloc system or the new Brainloc system when Docloc doesn't have
        # sufficient evidence.
        # Corresponds to the JSON property `documentLocationSource`
        # @return [String]
        attr_accessor :document_location_source
      
        # 
        # Corresponds to the JSON property `existNextLevel`
        # @return [Boolean]
        attr_accessor :exist_next_level
        alias_method :exist_next_level?, :exist_next_level
      
        # Booleans to keep track of where the country-id of the page came from. These
        # are used for debugging and/or unittests, and cleared in production.
        # Corresponds to the JSON property `fromLanguageFallback`
        # @return [Boolean]
        attr_accessor :from_language_fallback
        alias_method :from_language_fallback?, :from_language_fallback
      
        # 
        # Corresponds to the JSON property `fromRestricts`
        # @return [Boolean]
        attr_accessor :from_restricts
        alias_method :from_restricts?, :from_restricts
      
        # 
        # Corresponds to the JSON property `fromSgDomains`
        # @return [Boolean]
        attr_accessor :from_sg_domains
        alias_method :from_sg_domains?, :from_sg_domains
      
        # 
        # Corresponds to the JSON property `fromTld`
        # @return [Boolean]
        attr_accessor :from_tld
        alias_method :from_tld?, :from_tld
      
        # 
        # Corresponds to the JSON property `fromUgc`
        # @return [Boolean]
        attr_accessor :from_ugc
        alias_method :from_ugc?, :from_ugc
      
        # 
        # Corresponds to the JSON property `fromUrlPattern`
        # @return [Boolean]
        attr_accessor :from_url_pattern
        alias_method :from_url_pattern?, :from_url_pattern
      
        # 
        # Corresponds to the JSON property `fromWmx`
        # @return [Boolean]
        attr_accessor :from_wmx
        alias_method :from_wmx?, :from_wmx
      
        # List of locations assigned to a document.
        # Corresponds to the JSON property `geoLocations`
        # @return [Google::Apis::ContentwarehouseV1::CountryGeoLocations]
        attr_accessor :geo_locations
      
        # 
        # Corresponds to the JSON property `global`
        # @return [Boolean]
        attr_accessor :global
        alias_method :global?, :global
      
        # Set to true if the local_countries field can be used for country restricts as
        # well.
        # Corresponds to the JSON property `isValidForCountryRestrict`
        # @return [Boolean]
        attr_accessor :is_valid_for_country_restrict
        alias_method :is_valid_for_country_restrict?, :is_valid_for_country_restrict
      
        # two-letter(lower-case) countrycode, e.g. us countries that is local to
        # Corresponds to the JSON property `localCountries`
        # @return [Array<String>]
        attr_accessor :local_countries
      
        # Fields that actually store the country id in docjoins. The format of this data
        # is defined in //i18n/identifiers/stableinternalregionconverter.cc. Converter
        # defined there can be used to convert it to RegionCode format.
        # Corresponds to the JSON property `localCountryCodes`
        # @return [Array<Fixnum>]
        attr_accessor :local_country_codes
      
        # Metro locations: list of NavBoost feature V2 associated with a doc, along with
        # the enclosing province. Metro locations with new tags.
        # Corresponds to the JSON property `metroIdList`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountryMetroNbFeature>]
        attr_accessor :metro_id_list
      
        # Metro level data. metro_location_id stores geotokens for metro restricts.
        # Corresponds to the JSON property `metroLocationId`
        # @return [Array<String>]
        attr_accessor :metro_location_id
      
        # Metro navboost: list of (NavBoost feature V2, navboost float) pairs.
        # Corresponds to the JSON property `metroNavboost`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountryMetroNbFeature>]
        attr_accessor :metro_navboost
      
        # 
        # Corresponds to the JSON property `provinceGeotokenList`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountryProvinceGeotoken>]
        attr_accessor :province_geotoken_list
      
        # two-letter(lower-case) countrycode, e.g. us countries that is related to, but
        # not local to
        # Corresponds to the JSON property `relatedCountries`
        # @return [Array<String>]
        attr_accessor :related_countries
      
        # 
        # Corresponds to the JSON property `relatedCountryCodes`
        # @return [Array<Fixnum>]
        attr_accessor :related_country_codes
      
        # List of two-letter(lower-case) countrycodes(e.g. us) valid for restricts.
        # Typically cloned out of local_countries if is_valid_for_country_restrict is
        # set to true.
        # Corresponds to the JSON property `restrictCountries`
        # @return [Array<String>]
        attr_accessor :restrict_countries
      
        # [Experimental]: Top salient countries for a doc. If a country can not be found
        # on this field it can be considered that this doc is not relevant to it.
        # Corresponds to the JSON property `salientCountries`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountrySalientCountry>]
        attr_accessor :salient_countries
      
        # Set of SalientCountry for a document.
        # Corresponds to the JSON property `salientCountrySet`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientCountriesSalientCountrySet]
        attr_accessor :salient_country_set
      
        # Domain name of keys in filtering metro reducer class, used only by the
        # intermediate mapreduces to produce filtered data.
        # Corresponds to the JSON property `sitename`
        # @return [String]
        attr_accessor :sitename
      
        # Super global pages get lesser demotion than global pages. A document can only
        # be either global or super_global but not both.
        # Corresponds to the JSON property `superGlobal`
        # @return [Boolean]
        attr_accessor :super_global
        alias_method :super_global?, :super_global
      
        # 
        # Corresponds to the JSON property `urlPatternBasedCountry`
        # @return [Fixnum]
        attr_accessor :url_pattern_based_country
      
        # Language and country extracted using the URL pattern map.
        # Corresponds to the JSON property `urlPatternBasedLanguage`
        # @return [Fixnum]
        attr_accessor :url_pattern_based_language
      
        # This is used to store the visible country id computed from logs data
        # Corresponds to the JSON property `userVisibleCountryFromLogs`
        # @return [String]
        attr_accessor :user_visible_country_from_logs
      
        # This is the country id we show to users on the result page. This is kept
        # different from country demotion country id because we dont want to expose our
        # backoff and url based detection algorithm - also we want to be ultra
        # conservative in showing this.
        # Corresponds to the JSON property `userVisibleLocalCountry`
        # @return [Fixnum]
        attr_accessor :user_visible_local_country
      
        # If result is global, store weight above ideal, as a confidence signal. Used in
        # query localness, cleared in production CountryAttachment.
        # Corresponds to the JSON property `weightAboveIdealForLocalness`
        # @return [Float]
        attr_accessor :weight_above_ideal_for_localness
      
        # Country specified for a web-site through webmaster console.
        # Corresponds to the JSON property `wmxCountry`
        # @return [String]
        attr_accessor :wmx_country
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @click_distribution = args[:click_distribution] if args.key?(:click_distribution)
          @countryid_from_ugc = args[:countryid_from_ugc] if args.key?(:countryid_from_ugc)
          @debug = args[:debug] if args.key?(:debug)
          @debug_source_url = args[:debug_source_url] if args.key?(:debug_source_url)
          @document_location_source = args[:document_location_source] if args.key?(:document_location_source)
          @exist_next_level = args[:exist_next_level] if args.key?(:exist_next_level)
          @from_language_fallback = args[:from_language_fallback] if args.key?(:from_language_fallback)
          @from_restricts = args[:from_restricts] if args.key?(:from_restricts)
          @from_sg_domains = args[:from_sg_domains] if args.key?(:from_sg_domains)
          @from_tld = args[:from_tld] if args.key?(:from_tld)
          @from_ugc = args[:from_ugc] if args.key?(:from_ugc)
          @from_url_pattern = args[:from_url_pattern] if args.key?(:from_url_pattern)
          @from_wmx = args[:from_wmx] if args.key?(:from_wmx)
          @geo_locations = args[:geo_locations] if args.key?(:geo_locations)
          @global = args[:global] if args.key?(:global)
          @is_valid_for_country_restrict = args[:is_valid_for_country_restrict] if args.key?(:is_valid_for_country_restrict)
          @local_countries = args[:local_countries] if args.key?(:local_countries)
          @local_country_codes = args[:local_country_codes] if args.key?(:local_country_codes)
          @metro_id_list = args[:metro_id_list] if args.key?(:metro_id_list)
          @metro_location_id = args[:metro_location_id] if args.key?(:metro_location_id)
          @metro_navboost = args[:metro_navboost] if args.key?(:metro_navboost)
          @province_geotoken_list = args[:province_geotoken_list] if args.key?(:province_geotoken_list)
          @related_countries = args[:related_countries] if args.key?(:related_countries)
          @related_country_codes = args[:related_country_codes] if args.key?(:related_country_codes)
          @restrict_countries = args[:restrict_countries] if args.key?(:restrict_countries)
          @salient_countries = args[:salient_countries] if args.key?(:salient_countries)
          @salient_country_set = args[:salient_country_set] if args.key?(:salient_country_set)
          @sitename = args[:sitename] if args.key?(:sitename)
          @super_global = args[:super_global] if args.key?(:super_global)
          @url_pattern_based_country = args[:url_pattern_based_country] if args.key?(:url_pattern_based_country)
          @url_pattern_based_language = args[:url_pattern_based_language] if args.key?(:url_pattern_based_language)
          @user_visible_country_from_logs = args[:user_visible_country_from_logs] if args.key?(:user_visible_country_from_logs)
          @user_visible_local_country = args[:user_visible_local_country] if args.key?(:user_visible_local_country)
          @weight_above_ideal_for_localness = args[:weight_above_ideal_for_localness] if args.key?(:weight_above_ideal_for_localness)
          @wmx_country = args[:wmx_country] if args.key?(:wmx_country)
        end
      end
      
      # Stores one location and all meta-data associated with that location.
      class CountryGeoLocation
        include Google::Apis::Core::Hashable
      
        # The radius (in miles) around the assigned location that the document gets 50%
        # of its clicks.
        # Corresponds to the JSON property `clickRadius50Percent`
        # @return [Fixnum]
        attr_accessor :click_radius50_percent
      
        # Confidence on the location. Ranges in [0.0, 1.0]. Cleared during index
        # creation.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Confidence mapped to [0, 100]. Converted to integer for efficient storage.
        # Populated during index creation.
        # Corresponds to the JSON property `confidencePercent`
        # @return [Fixnum]
        attr_accessor :confidence_percent
      
        # Used for compressed docloc data. In compressed data, instead of location_info,
        # only an integer ID for that LocationInfo is stored. A separate lookup table is
        # used to get full LocationInfo from the internal ID.
        # Corresponds to the JSON property `internalId`
        # @return [Fixnum]
        attr_accessor :internal_id
      
        # This represents one location.
        # Corresponds to the JSON property `locationInfo`
        # @return [Google::Apis::ContentwarehouseV1::CountryLocationInfo]
        attr_accessor :location_info
      
        # True if this location is assigned to one of the subpages, and not to the page
        # itself. If the total number of locations assigned to all the subpages of a
        # page is small (usually up to 5), then that page also gets assigned those
        # locations, and this flag is set for those locations.
        # Corresponds to the JSON property `propagatedFromASubpage`
        # @return [Boolean]
        attr_accessor :propagated_from_a_subpage
        alias_method :propagated_from_a_subpage?, :propagated_from_a_subpage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @click_radius50_percent = args[:click_radius50_percent] if args.key?(:click_radius50_percent)
          @confidence = args[:confidence] if args.key?(:confidence)
          @confidence_percent = args[:confidence_percent] if args.key?(:confidence_percent)
          @internal_id = args[:internal_id] if args.key?(:internal_id)
          @location_info = args[:location_info] if args.key?(:location_info)
          @propagated_from_a_subpage = args[:propagated_from_a_subpage] if args.key?(:propagated_from_a_subpage)
        end
      end
      
      # List of locations assigned to a document.
      class CountryGeoLocations
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `geoLocation`
        # @return [Array<Google::Apis::ContentwarehouseV1::CountryGeoLocation>]
        attr_accessor :geo_location
      
        # This will be set to true for documents which receive several clicks but are
        # not assigned any location because the click distribution is flat. Typical
        # examples are global sites like facebook.com, chains like walmart.com,
        # informational sites like wikipedia.org etc. This flag is not propagated to
        # deeper pages since this signal is meant to indicate that a website or a part
        # of website is conclusively non-local, so propagating this information to
        # deeper pages does not make sense. If this flag is set, then the only possible
        # geo_location will be the ones which are propagated_from_a_subpage.
        # Corresponds to the JSON property `isNonLocationSpecific`
        # @return [Boolean]
        attr_accessor :is_non_location_specific
        alias_method :is_non_location_specific?, :is_non_location_specific
      
        # Depth of the URL from it's nearest parent in GeoLocation data. Webpages
        # inherhit locations from their parent pages. For example, if foo.com/a is
        # assigned location L1, and foo.com/a/b is not assigned any location, then http:/
        # /www.foo.com/a/b inherits location L1 from it's nearest parent foo.com/a in
        # GeoLocation data. This attribute is the distance from the nearest parent which
        # is present in GeoLocation data. In this particular case, it will be 1.
        # Corresponds to the JSON property `propagationDepthFromParent`
        # @return [Fixnum]
        attr_accessor :propagation_depth_from_parent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @geo_location = args[:geo_location] if args.key?(:geo_location)
          @is_non_location_specific = args[:is_non_location_specific] if args.key?(:is_non_location_specific)
          @propagation_depth_from_parent = args[:propagation_depth_from_parent] if args.key?(:propagation_depth_from_parent)
        end
      end
      
      # This represents one location.
      class CountryLocationInfo
        include Google::Apis::Core::Hashable
      
        # The latitude and longitude of the conceptual center of the location. For
        # cities, this would be the center of the downtown, or maybe the location of
        # city hall. For states and countries it might be the capital city. But there
        # are no guarantees and this may be any random point inside the location.
        # Corresponds to the JSON property `center`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :center
      
        # 
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # Human readable name hierarchy. Only the relevant fields will be present. For
        # example for city GeoLocations, sub_locality field will not be present. Cleared
        # during index creation.
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `county`
        # @return [String]
        attr_accessor :county
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `enclosingStateFeatureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :enclosing_state_feature_id
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # 32 bit fingerprint of the feature id of the state of this location. For cities
        # and sub-localities it will be the enclosing state. For state locations, it
        # will be fingerprint of the feture-id of the location itself. Populated during
        # index creation.
        # Corresponds to the JSON property `stateIdFprint`
        # @return [Fixnum]
        attr_accessor :state_id_fprint
      
        # 
        # Corresponds to the JSON property `subLocality`
        # @return [String]
        attr_accessor :sub_locality
      
        # Type of the location (sub-locality, city, state etc).
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @center = args[:center] if args.key?(:center)
          @city = args[:city] if args.key?(:city)
          @country = args[:country] if args.key?(:country)
          @county = args[:county] if args.key?(:county)
          @enclosing_state_feature_id = args[:enclosing_state_feature_id] if args.key?(:enclosing_state_feature_id)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @state = args[:state] if args.key?(:state)
          @state_id_fprint = args[:state_id_fprint] if args.key?(:state_id_fprint)
          @sub_locality = args[:sub_locality] if args.key?(:sub_locality)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A metro feature, keyed by NavBoost feature id V2. This can be a metro id, a
      # boost, or extended in the future to add probabilities or weights.
      class CountryMetroNbFeature
        include Google::Apis::Core::Hashable
      
        # The enclosing_province_geotoken is a 32 bit fingerprint of the state encosing
        # the (metro) id. MetroId's can span multiple states. Enclosing geotoken is
        # filled in with the state name for disambiguation. ProvinceGeotoken field is
        # different as it indicates an "interest". Format: 32 bit fingerprint(
        # __state__country).
        # Corresponds to the JSON property `enclosingProvinceGeotoken`
        # @return [Fixnum]
        attr_accessor :enclosing_province_geotoken
      
        # A 32 bit navboost v2 feature id encoding (country, language, metro).
        # NavBoosterUtils class (google3/quality/navboost/nav_booster_utils.h) provides
        # functions to decode this feature.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # This is the multiplier to apply to the result for this locale & query. NOTE:
        # This is for serving purposes only and should not be populated in the index.
        # Corresponds to the JSON property `navboost`
        # @return [Float]
        attr_accessor :navboost
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enclosing_province_geotoken = args[:enclosing_province_geotoken] if args.key?(:enclosing_province_geotoken)
          @id = args[:id] if args.key?(:id)
          @navboost = args[:navboost] if args.key?(:navboost)
        end
      end
      
      # A 32 bit fingerprint of a state level geotoken. The geotoken is in the
      # following format: __state__country. These indicate a page is of interest to
      # these states/regions of a country. The use of message is to enable easy
      # additions of probabilities or weights per metro id in the future.
      class CountryProvinceGeotoken
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `geotoken`
        # @return [Fixnum]
        attr_accessor :geotoken
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @geotoken = args[:geotoken] if args.key?(:geotoken)
        end
      end
      
      # Salient Countries is an estimated probability (salience) of a doc to be
      # relevant to a country. On this message, countries are represented as int32 (
      # the format of this data is defined in i18n/identifiers/
      # stableinternalregionconverter.cc). Salience is a value in range [0.0 - 1.0] in
      # which 1.0 represents a high likelihood to be relevant to the country
      class CountrySalientCountry
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `compressedSalience`
        # @return [Fixnum]
        attr_accessor :compressed_salience
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [Fixnum]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compressed_salience = args[:compressed_salience] if args.key?(:compressed_salience)
          @country_code = args[:country_code] if args.key?(:country_code)
          @salience = args[:salience] if args.key?(:salience)
        end
      end
      
      # Proto contains parameters for a multiple component distributions, where each
      # component has non-negative weight and the sum of component weights is 1.
      class CrawlerChangerateMultipleComponentDistribution
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `components`
        # @return [Array<Google::Apis::ContentwarehouseV1::CrawlerChangerateSingleComponentDistribution>]
        attr_accessor :components
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @components = args[:components] if args.key?(:components)
        end
      end
      
      # Proto contains parameters of a single component distribution.
      class CrawlerChangerateSingleComponentDistribution
        include Google::Apis::Core::Hashable
      
        # Scaling factor to ensure the approximated posterior to have the same scale as
        # the product of prior and likelihood. This value is used to compute posterior
        # weights. Uses log scale to provide a wider range. This field is for internal
        # use only.
        # Corresponds to the JSON property `logScaling`
        # @return [Float]
        attr_accessor :log_scaling
      
        # The type indicates the type of the distribution.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The weight is only used in multiple component scenarios.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @log_scaling = args[:log_scaling] if args.key?(:log_scaling)
          @type = args[:type] if args.key?(:type)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # NEXT_TAG: 13
      class CrawlerChangerateUrlChange
        include Google::Apis::Core::Hashable
      
        # Duplicate UrlChanges crawled within a specified time range will be merged
        # together. UrlChanges are considered duplicates if the simhash,
        # simhash_is_trusted, simhash_v2, simhash_v2_is_trusted, and shingle_simhash are
        # the same. additional_changes_merged indiciates the number of duplicate
        # UrlChanges merged into this UrlChange.
        # Corresponds to the JSON property `additionalChangesMerged`
        # @return [Fixnum]
        attr_accessor :additional_changes_merged
      
        # Deprecated fields. The fraction of tiles (0 to 1) that changed.
        # Corresponds to the JSON property `fractionalTileChange`
        # @return [Float]
        attr_accessor :fractional_tile_change
      
        # The length in seconds of the change.
        # Corresponds to the JSON property `interval`
        # @return [Fixnum]
        attr_accessor :interval
      
        # Whether the content of the off-domain links changed.
        # Corresponds to the JSON property `offDomainLinksChange`
        # @return [Boolean]
        attr_accessor :off_domain_links_change
        alias_method :off_domain_links_change?, :off_domain_links_change
      
        # The new count of off-domain links, if they changed.
        # Corresponds to the JSON property `offDomainLinksCount`
        # @return [Fixnum]
        attr_accessor :off_domain_links_count
      
        # The new count of on-domain links, if the count changed.
        # Corresponds to the JSON property `onDomainLinksCount`
        # @return [Fixnum]
        attr_accessor :on_domain_links_count
      
        # Whether the number of on-domain links changed.
        # Corresponds to the JSON property `onDomainLinksCountChange`
        # @return [Boolean]
        attr_accessor :on_domain_links_count_change
        alias_method :on_domain_links_count_change?, :on_domain_links_count_change
      
        # Used for storing fingerprints, along with meta-data that expresses how the
        # fingerprint was computed. The metadata can be anything that fits in an uint64.
        # Corresponds to the JSON property `shingleSimhash`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterShingleFingerprint]
        attr_accessor :shingle_simhash
      
        # The simhash-v1 value. Use of simhash-v1 is deprecated, and newer UrlChange
        # should only contain simhash-v2. During this transition period, UrlChange can
        # contain either simhash or simhash_v2. It is possible that previous UrlChange
        # only contain simhash-v1 and the next UrlChange only contain simhash-v2. In
        # this case, we skip that interval in our changerate computation. [go/changerate-
        # simhash-v2-migration]
        # Corresponds to the JSON property `simhash`
        # @return [Fixnum]
        attr_accessor :simhash
      
        # Whether the simhash-v1 should be trusted.
        # Corresponds to the JSON property `simhashIsTrusted`
        # @return [Boolean]
        attr_accessor :simhash_is_trusted
        alias_method :simhash_is_trusted?, :simhash_is_trusted
      
        # The simhash-v2 value.
        # Corresponds to the JSON property `simhashV2`
        # @return [Fixnum]
        attr_accessor :simhash_v2
      
        # Whether the simhash-v2 value should be trusted.
        # Corresponds to the JSON property `simhashV2IsTrusted`
        # @return [Boolean]
        attr_accessor :simhash_v2_is_trusted
        alias_method :simhash_v2_is_trusted?, :simhash_v2_is_trusted
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_changes_merged = args[:additional_changes_merged] if args.key?(:additional_changes_merged)
          @fractional_tile_change = args[:fractional_tile_change] if args.key?(:fractional_tile_change)
          @interval = args[:interval] if args.key?(:interval)
          @off_domain_links_change = args[:off_domain_links_change] if args.key?(:off_domain_links_change)
          @off_domain_links_count = args[:off_domain_links_count] if args.key?(:off_domain_links_count)
          @on_domain_links_count = args[:on_domain_links_count] if args.key?(:on_domain_links_count)
          @on_domain_links_count_change = args[:on_domain_links_count_change] if args.key?(:on_domain_links_count_change)
          @shingle_simhash = args[:shingle_simhash] if args.key?(:shingle_simhash)
          @simhash = args[:simhash] if args.key?(:simhash)
          @simhash_is_trusted = args[:simhash_is_trusted] if args.key?(:simhash_is_trusted)
          @simhash_v2 = args[:simhash_v2] if args.key?(:simhash_v2)
          @simhash_v2_is_trusted = args[:simhash_v2_is_trusted] if args.key?(:simhash_v2_is_trusted)
        end
      end
      
      # The next available field number is 22. To access the best estimate of change
      # period, please use GetChangePeriod in predict-change-rate.h to select between
      # this and other change period estimates below.
      class CrawlerChangerateUrlChangerate
        include Google::Apis::Core::Hashable
      
        # Proto contains parameters for a multiple component distributions, where each
        # component has non-negative weight and the sum of component weights is 1.
        # Corresponds to the JSON property `approximatedPosterior`
        # @return [Google::Apis::ContentwarehouseV1::CrawlerChangerateMultipleComponentDistribution]
        attr_accessor :approximated_posterior
      
        # The "significance" of the average change we saw of this document (from 0 to 1).
        # Influenced by content changes. This can be used for prioritizing the crawl (
        # higher significance first).
        # Corresponds to the JSON property `averageChangeSignificance`
        # @return [Float]
        attr_accessor :average_change_significance
      
        # ////////////////////////////////////////////////////////////////////////////
        # The classic changerate estimation. ////////////////////////////////////////////
        # //////////////////////////////// The classic estimate of change period (in
        # seconds). It is computed by inserted a "fake" change and no-change interval as
        # a prior distribution. This field is generally not used and should NOT be
        # accessed directly. See above for correct method for determining the change
        # period estimate.
        # Corresponds to the JSON property `changeperiod`
        # @return [Fixnum]
        attr_accessor :changeperiod
      
        # The confidence (between 0 and 1) in the changeperiod guess.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # ////////////////////////////////////////////////////////////////////////////
        # The changerate estimation based on the global prior. //////////////////////////
        # ////////////////////////////////////////////////// The global-based
        # changeperiod. This is our estimate (in seconds) for the average time between
        # changes. It is computed using the new prior method based on
        # global_based_prior_period and the global_based_prior_strength specified below.
        # This is used for computing pattern priors. Use pattern_based_change_period or
        # changeperiod fields for all other purposes.
        # Corresponds to the JSON property `globalBasedChangePeriod`
        # @return [Fixnum]
        attr_accessor :global_based_change_period
      
        # The 'confidence' of the global-based changeperiod. This is the n-th root of
        # the posterior evaluated at MAP point, where n is the number of history
        # intervals. For now, it is hard to interpret the meaning of the absolute values
        # of 'average' posterior cross different sets of data.
        # Corresponds to the JSON property `globalBasedChangePeriodConfidence`
        # @return [Float]
        attr_accessor :global_based_change_period_confidence
      
        # The 2 parameters below specify the prior employed in calculating the
        # global_based_change_period. These values are precomputed through an offline
        # analysis and specified via flags.
        # Corresponds to the JSON property `globalBasedPriorPeriod`
        # @return [Float]
        attr_accessor :global_based_prior_period
      
        # 
        # Corresponds to the JSON property `globalBasedPriorStrength`
        # @return [Float]
        attr_accessor :global_based_prior_strength
      
        # The "significance" of the last change we saw of this document (from 0 to 1).
        # Influenced by content changes, etc. This can be used for prioritizing the
        # crawl (higher significance first).
        # Corresponds to the JSON property `lastChangeSignificance`
        # @return [Float]
        attr_accessor :last_change_significance
      
        # The last time (unix timestamp) we saw a changed copy of the document. Provided
        # iff we have seen the page change.
        # Corresponds to the JSON property `lastChanged`
        # @return [Fixnum]
        attr_accessor :last_changed
      
        # The last time (unix timestamp) we saw a fetched copy of the document.
        # Corresponds to the JSON property `lastFetched`
        # @return [Fixnum]
        attr_accessor :last_fetched
      
        # The number of intervals we've seen for this document (where an interval is two
        # different versions).
        # Corresponds to the JSON property `numIntervals`
        # @return [Fixnum]
        attr_accessor :num_intervals
      
        # ////////////////////////////////////////////////////////////////////////////
        # The changerate estimation based on the pattern prior. /////////////////////////
        # /////////////////////////////////////////////////// The pattern-based
        # changeperiod. This is our estimate (in seconds) for the average time between
        # changes. It is calculated based on the pattern_based_prior_period and
        # pattern_based_prior_strength below. This quantity will eventually replace the
        # old changeperiod calculation.
        # Corresponds to the JSON property `patternBasedChangePeriod`
        # @return [Fixnum]
        attr_accessor :pattern_based_change_period
      
        # The same as global_based_change_period_confidence, except it is computed using
        # pattern based priors.
        # Corresponds to the JSON property `patternBasedChangePeriodConfidence`
        # @return [Float]
        attr_accessor :pattern_based_change_period_confidence
      
        # The lower edge of a confidence interval for the pattern-based change period.
        # Corresponds to the JSON property `patternBasedLowerChangePeriod`
        # @return [Fixnum]
        attr_accessor :pattern_based_lower_change_period
      
        # The 2 parameters below specify the prior employed in calculating the
        # pattern_based_change_period. These values are calculated in a separate process
        # and looked up based on the URL pattern.
        # Corresponds to the JSON property `patternBasedPriorPeriod`
        # @return [Float]
        attr_accessor :pattern_based_prior_period
      
        # 
        # Corresponds to the JSON property `patternBasedPriorStrength`
        # @return [Float]
        attr_accessor :pattern_based_prior_strength
      
        # The version number of the algorithm, refer to ChangePeriodVersion for more
        # information.
        # Corresponds to the JSON property `patternChangePeriodVersion`
        # @return [Fixnum]
        attr_accessor :pattern_change_period_version
      
        # ////////////////////////////////////////////////////////////////////////////
        # Basic information of a document. //////////////////////////////////////////////
        # ////////////////////////////// The type of the document determined by crawl
        # histories, refer to TYPE for more information.
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        # ////////////////////////////////////////////////////////////////////////////
        # The UGC changerate estimation. ////////////////////////////////////////////////
        # //////////////////////////// Information on change period generated from user
        # generated content (UGC) change history.
        # Corresponds to the JSON property `ugcChangePeriod`
        # @return [Fixnum]
        attr_accessor :ugc_change_period
      
        # 
        # Corresponds to the JSON property `ugcChangePeriodConfidence`
        # @return [Float]
        attr_accessor :ugc_change_period_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @approximated_posterior = args[:approximated_posterior] if args.key?(:approximated_posterior)
          @average_change_significance = args[:average_change_significance] if args.key?(:average_change_significance)
          @changeperiod = args[:changeperiod] if args.key?(:changeperiod)
          @confidence = args[:confidence] if args.key?(:confidence)
          @global_based_change_period = args[:global_based_change_period] if args.key?(:global_based_change_period)
          @global_based_change_period_confidence = args[:global_based_change_period_confidence] if args.key?(:global_based_change_period_confidence)
          @global_based_prior_period = args[:global_based_prior_period] if args.key?(:global_based_prior_period)
          @global_based_prior_strength = args[:global_based_prior_strength] if args.key?(:global_based_prior_strength)
          @last_change_significance = args[:last_change_significance] if args.key?(:last_change_significance)
          @last_changed = args[:last_changed] if args.key?(:last_changed)
          @last_fetched = args[:last_fetched] if args.key?(:last_fetched)
          @num_intervals = args[:num_intervals] if args.key?(:num_intervals)
          @pattern_based_change_period = args[:pattern_based_change_period] if args.key?(:pattern_based_change_period)
          @pattern_based_change_period_confidence = args[:pattern_based_change_period_confidence] if args.key?(:pattern_based_change_period_confidence)
          @pattern_based_lower_change_period = args[:pattern_based_lower_change_period] if args.key?(:pattern_based_lower_change_period)
          @pattern_based_prior_period = args[:pattern_based_prior_period] if args.key?(:pattern_based_prior_period)
          @pattern_based_prior_strength = args[:pattern_based_prior_strength] if args.key?(:pattern_based_prior_strength)
          @pattern_change_period_version = args[:pattern_change_period_version] if args.key?(:pattern_change_period_version)
          @type = args[:type] if args.key?(:type)
          @ugc_change_period = args[:ugc_change_period] if args.key?(:ugc_change_period)
          @ugc_change_period_confidence = args[:ugc_change_period_confidence] if args.key?(:ugc_change_period_confidence)
        end
      end
      
      # 
      class CrawlerChangerateUrlHistory
        include Google::Apis::Core::Hashable
      
        # All the changes we've seen for this URL.
        # Corresponds to the JSON property `change`
        # @return [Array<Google::Apis::ContentwarehouseV1::CrawlerChangerateUrlChange>]
        attr_accessor :change
      
        # NEXT_TAG: 15
        # Corresponds to the JSON property `latestVersion`
        # @return [Google::Apis::ContentwarehouseV1::CrawlerChangerateUrlVersion]
        attr_accessor :latest_version
      
        # This field in only set in 'url_history' column of Union repository to avoid
        # having to read CompositeDocs.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @change = args[:change] if args.key?(:change)
          @latest_version = args[:latest_version] if args.key?(:latest_version)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # NEXT_TAG: 15
      class CrawlerChangerateUrlVersion
        include Google::Apis::Core::Hashable
      
        # Same as the field in UrlChange. This allows us to merge identical UrlVersions
        # into a single UrlVersion.
        # Corresponds to the JSON property `additionalChangesMerged`
        # @return [Fixnum]
        attr_accessor :additional_changes_merged
      
        # The content type of the page.
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # Whether this is an IMS response (a 304, not modified).
        # Corresponds to the JSON property `isImsNotModified`
        # @return [Boolean]
        attr_accessor :is_ims_not_modified
        alias_method :is_ims_not_modified?, :is_ims_not_modified
      
        # The date from the LastModified header, if present.
        # Corresponds to the JSON property `lastModified`
        # @return [Fixnum]
        attr_accessor :last_modified
      
        # The checksum of all the off-domain links on the page.
        # Corresponds to the JSON property `offDomainLinksChecksum`
        # @return [Fixnum]
        attr_accessor :off_domain_links_checksum
      
        # The count of all the off-domain links on the page.
        # Corresponds to the JSON property `offDomainLinksCount`
        # @return [Fixnum]
        attr_accessor :off_domain_links_count
      
        # The count of all the on-domain links on the page. We aren't worried about the
        # contents themselves, since they might often change (e.g., session ids). We
        # assume that a change in the number of links is significant, however.
        # Corresponds to the JSON property `onDomainLinksCount`
        # @return [Fixnum]
        attr_accessor :on_domain_links_count
      
        # Used for storing fingerprints, along with meta-data that expresses how the
        # fingerprint was computed. The metadata can be anything that fits in an uint64.
        # Corresponds to the JSON property `shingleSimhash`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterShingleFingerprint]
        attr_accessor :shingle_simhash
      
        # The simhash-v1 value. The simhash-v1 is now deprecated and new UrlVersions
        # should only populate simhash-v2. During migration phase from using simhash-v1
        # to simhash-v2, it is possible that previous UrlChange only contain simhash-v1
        # and the next UrlChange / UrlVersion could only contain simhash-v2. In this
        # case, we skip that interval in our changerate computation. [go/changerate-
        # simhash-v2-migration]
        # Corresponds to the JSON property `simhash`
        # @return [Fixnum]
        attr_accessor :simhash
      
        # Whether the simhash-v1 should be trusted.
        # Corresponds to the JSON property `simhashIsTrusted`
        # @return [Boolean]
        attr_accessor :simhash_is_trusted
        alias_method :simhash_is_trusted?, :simhash_is_trusted
      
        # The simhash-v2 value.
        # Corresponds to the JSON property `simhashV2`
        # @return [Fixnum]
        attr_accessor :simhash_v2
      
        # Whether the simhash-v2 value should be trusted.
        # Corresponds to the JSON property `simhashV2IsTrusted`
        # @return [Boolean]
        attr_accessor :simhash_v2_is_trusted
        alias_method :simhash_v2_is_trusted?, :simhash_v2_is_trusted
      
        # The tiles of the document body. We use int32s instead of int64s (the norm) in
        # order to save space. Since rare inaccuracy doesn't really matter, we've
        # decided this is an okay tradeoff.
        # Corresponds to the JSON property `tile`
        # @return [Array<Fixnum>]
        attr_accessor :tile
      
        # The timestamp we crawled the page.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_changes_merged = args[:additional_changes_merged] if args.key?(:additional_changes_merged)
          @content_type = args[:content_type] if args.key?(:content_type)
          @is_ims_not_modified = args[:is_ims_not_modified] if args.key?(:is_ims_not_modified)
          @last_modified = args[:last_modified] if args.key?(:last_modified)
          @off_domain_links_checksum = args[:off_domain_links_checksum] if args.key?(:off_domain_links_checksum)
          @off_domain_links_count = args[:off_domain_links_count] if args.key?(:off_domain_links_count)
          @on_domain_links_count = args[:on_domain_links_count] if args.key?(:on_domain_links_count)
          @shingle_simhash = args[:shingle_simhash] if args.key?(:shingle_simhash)
          @simhash = args[:simhash] if args.key?(:simhash)
          @simhash_is_trusted = args[:simhash_is_trusted] if args.key?(:simhash_is_trusted)
          @simhash_v2 = args[:simhash_v2] if args.key?(:simhash_v2)
          @simhash_v2_is_trusted = args[:simhash_v2_is_trusted] if args.key?(:simhash_v2_is_trusted)
          @tile = args[:tile] if args.key?(:tile)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # 
      class CrowdingPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `newscluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::CrowdingPerDocDataNewsCluster>]
        attr_accessor :newscluster
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @newscluster = args[:newscluster] if args.key?(:newscluster)
        end
      end
      
      # For crowding in news we need to keep data about the last X clustering
      # iterations around.
      class CrowdingPerDocDataNewsCluster
        include Google::Apis::Core::Hashable
      
        # Fingerprint combination of all urls in a cluster
        # Corresponds to the JSON property `ClusterId`
        # @return [Fixnum]
        attr_accessor :cluster_id
      
        # This is the X in the "and X related >>" link on headlines and search results
        # Corresponds to the JSON property `ClusterSize`
        # @return [Fixnum]
        attr_accessor :cluster_size
      
        # When was this clustered (needed for keeping last X iterations around and
        # discarding earlier ones)
        # Corresponds to the JSON property `ClusterTimeStamp`
        # @return [Fixnum]
        attr_accessor :cluster_time_stamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_size = args[:cluster_size] if args.key?(:cluster_size)
          @cluster_time_stamp = args[:cluster_time_stamp] if args.key?(:cluster_time_stamp)
        end
      end
      
      # 
      class DeepCropIndexing
        include Google::Apis::Core::Hashable
      
        # Compact representation for indexing, see creatism::CropBitmap for details on
        # the packing format.
        # Corresponds to the JSON property `cropBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :crop_bytes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crop_bytes = args[:crop_bytes] if args.key?(:crop_bytes)
        end
      end
      
      # 
      class DeepCropPixels
        include Google::Apis::Core::Hashable
      
        # Pixels version of the DeepCropIndexing bytes, this corresponds to the crop box
        # for a given image (based input image size and desired aspect ratio).
        # Corresponds to the JSON property `x0`
        # @return [Fixnum]
        attr_accessor :x0
      
        # 
        # Corresponds to the JSON property `x1`
        # @return [Fixnum]
        attr_accessor :x1
      
        # 
        # Corresponds to the JSON property `y0`
        # @return [Fixnum]
        attr_accessor :y0
      
        # 
        # Corresponds to the JSON property `y1`
        # @return [Fixnum]
        attr_accessor :y1
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x0 = args[:x0] if args.key?(:x0)
          @x1 = args[:x1] if args.key?(:x1)
          @y0 = args[:y0] if args.key?(:y0)
          @y1 = args[:y1] if args.key?(:y1)
        end
      end
      
      # NOTE: In segindexer, the docproperties of a document may be reused from a
      # previous cycle if its content is not changed. If you add a new field to
      # DocProperties, make sure it is taken care (i.e., gets copied from a previous
      # cycle to the current document) in CDocProperties::EndDocument().
      class DocProperties
        include Google::Apis::Core::Hashable
      
        # The average weighted font size of a term in the doc body
        # Corresponds to the JSON property `avgTermWeight`
        # @return [Fixnum]
        attr_accessor :avg_term_weight
      
        # Missing or meaningless title
        # Corresponds to the JSON property `badTitle`
        # @return [Boolean]
        attr_accessor :bad_title
        alias_method :bad_title?, :bad_title
      
        # 
        # Corresponds to the JSON property `badtitleinfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::DocPropertiesBadTitleInfo>]
        attr_accessor :badtitleinfo
      
        # A Language enum value. See: go/language-enum
        # Corresponds to the JSON property `languages`
        # @return [Array<Fixnum>]
        attr_accessor :languages
      
        # Leading text information generated by google3/quality/snippets/leadingtext/
        # leadingtext-detector.cc
        # Corresponds to the JSON property `leadingtext`
        # @return [Google::Apis::ContentwarehouseV1::SnippetsLeadingtextLeadingTextInfo]
        attr_accessor :leadingtext
      
        # 
        # Corresponds to the JSON property `numPunctuations`
        # @return [Fixnum]
        attr_accessor :num_punctuations
      
        # 
        # Corresponds to the JSON property `numTags`
        # @return [Fixnum]
        attr_accessor :num_tags
      
        # The number of tokens, tags and punctuations in the tokenized contents. This is
        # an approximation of the number of tokens, tags and punctuations we end up with
        # in mustang, but is inexact since we drop some tokens in mustang and also
        # truncate docs at a max cap.
        # Corresponds to the JSON property `numTokens`
        # @return [Fixnum]
        attr_accessor :num_tokens
      
        # The restricts for CSE structured search.
        # Corresponds to the JSON property `proseRestrict`
        # @return [Array<String>]
        attr_accessor :prose_restrict
      
        # 
        # Corresponds to the JSON property `restricts`
        # @return [Array<String>]
        attr_accessor :restricts
      
        # The time CDocProperties::StartDocument() is called, encoded as seconds past
        # the epoch (Jan 1, 1970). This value is always refreshed and not reused.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # Extracted from the title tag of the content. This is typically extracted by
        # TitleMetaCollector defined at google3/segindexer/title-meta-collector.h.
        # Please see its documentation for the format and other caveats.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @avg_term_weight = args[:avg_term_weight] if args.key?(:avg_term_weight)
          @bad_title = args[:bad_title] if args.key?(:bad_title)
          @badtitleinfo = args[:badtitleinfo] if args.key?(:badtitleinfo)
          @languages = args[:languages] if args.key?(:languages)
          @leadingtext = args[:leadingtext] if args.key?(:leadingtext)
          @num_punctuations = args[:num_punctuations] if args.key?(:num_punctuations)
          @num_tags = args[:num_tags] if args.key?(:num_tags)
          @num_tokens = args[:num_tokens] if args.key?(:num_tokens)
          @prose_restrict = args[:prose_restrict] if args.key?(:prose_restrict)
          @restricts = args[:restricts] if args.key?(:restricts)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Bad title information.
      class DocPropertiesBadTitleInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class DrishtiDenseFeatureData
        include Google::Apis::Core::Hashable
      
        # If extra is present it must be of the same length as value.
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # 
        # Corresponds to the JSON property `generalExtra`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :general_extra
      
        # Dense data.
        # Corresponds to the JSON property `value`
        # @return [Array<Float>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @general_extra = args[:general_extra] if args.key?(:general_extra)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class DrishtiFeatureExtra
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class DrishtiFeatureSetData
        include Google::Apis::Core::Hashable
      
        # Extra information for this particular FeatureSetData (example timestamp of
        # this frame in the video). (Almost never used).
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # The following can have multiple FeatureSetElement(s) Each of these
        # FeatureSetElement correspond to the various feature groups. One concrete
        # example is the way these features are generated - example audio, video or OCR.
        # Corresponds to the JSON property `feature`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureSetDataFeatureSetElement>]
        attr_accessor :feature
      
        # Labels for this particular FeatureSetData. (Almost never used). Only
        # interesting when you have (for example) frame level labels.
        # Corresponds to the JSON property `label`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiLabelSetElement>]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @feature = args[:feature] if args.key?(:feature)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # A FeatureSetElement stores the features coming from a single group.
      class DrishtiFeatureSetDataFeatureSetElement
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dense`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiDenseFeatureData]
        attr_accessor :dense
      
        # 
        # Corresponds to the JSON property `indexed`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiIndexedFeatureData]
        attr_accessor :indexed
      
        # A name for the feature group: example "AUDIO", "VIDEO", "OCR", etc.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `quantized`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiQuantizedDenseFeatureData]
        attr_accessor :quantized
      
        # 
        # Corresponds to the JSON property `sparse`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiSparseFeatureData]
        attr_accessor :sparse
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dense = args[:dense] if args.key?(:dense)
          @indexed = args[:indexed] if args.key?(:indexed)
          @name = args[:name] if args.key?(:name)
          @quantized = args[:quantized] if args.key?(:quantized)
          @sparse = args[:sparse] if args.key?(:sparse)
        end
      end
      
      # This represents a sequence (ordered) of FeatureSetData elements.
      class DrishtiFeatureSetDataSequence
        include Google::Apis::Core::Hashable
      
        # FeatureSetData contains the features. In most scenarios, you only have one
        # element. However, multiple elements are appropriate in case of videos where
        # each element may correspond to a frame in the video.
        # Corresponds to the JSON property `element`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureSetData>]
        attr_accessor :element
      
        # Some extra information about this FeatureSetDataSequence. (Almost never used).
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # Global (video-level) labels. In most cases, you only have one LabelSetElement.
        # All the labels will be stored in this single LabelSetElement. Scenarios where
        # you may have multiple LabelSetElement(s) is (for example) when you want to
        # differentiate the labels into various sub-groups - eg, central vs relevant, kg-
        # ids vs queries, etc.
        # Corresponds to the JSON property `label`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiLabelSetElement>]
        attr_accessor :label
      
        # If set, must be same length as element. Each entry is the timestamp in
        # microseconds where the FeatureSetData element was extracted.
        # Corresponds to the JSON property `timestamp`
        # @return [Array<Fixnum>]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @element = args[:element] if args.key?(:element)
          @extra = args[:extra] if args.key?(:extra)
          @label = args[:label] if args.key?(:label)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # 
      class DrishtiIndexedFeatureData
        include Google::Apis::Core::Hashable
      
        # If extra is present it must be of the same length as index and value.
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # 
        # Corresponds to the JSON property `generalExtra`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :general_extra
      
        # Indexed data. index and value must be of the same length.
        # Corresponds to the JSON property `index`
        # @return [Array<Fixnum>]
        attr_accessor :index
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<Float>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @general_extra = args[:general_extra] if args.key?(:general_extra)
          @index = args[:index] if args.key?(:index)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class DrishtiLabelSetData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # 
        # Corresponds to the JSON property `generalExtra`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :general_extra
      
        # 
        # Corresponds to the JSON property `targetClass`
        # @return [Array<Fixnum>]
        attr_accessor :target_class
      
        # 
        # Corresponds to the JSON property `targetClassName`
        # @return [Array<String>]
        attr_accessor :target_class_name
      
        # 
        # Corresponds to the JSON property `targetValue`
        # @return [Array<Float>]
        attr_accessor :target_value
      
        # 
        # Corresponds to the JSON property `targetWeight`
        # @return [Array<Float>]
        attr_accessor :target_weight
      
        # Weight assigned to this set of labels.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @general_extra = args[:general_extra] if args.key?(:general_extra)
          @target_class = args[:target_class] if args.key?(:target_class)
          @target_class_name = args[:target_class_name] if args.key?(:target_class_name)
          @target_value = args[:target_value] if args.key?(:target_value)
          @target_weight = args[:target_weight] if args.key?(:target_weight)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # 
      class DrishtiLabelSetElement
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `label`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiLabelSetData]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class DrishtiQuantizedDenseFeatureData
        include Google::Apis::Core::Hashable
      
        # If extra is present it must be of the same length as value.
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # 
        # Corresponds to the JSON property `generalExtra`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :general_extra
      
        # Quantized Dense data.
        # Corresponds to the JSON property `value`
        # @return [Array<String>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @general_extra = args[:general_extra] if args.key?(:general_extra)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class DrishtiSparseFeatureData
        include Google::Apis::Core::Hashable
      
        # If extra is present it must be of the same length as label and value.
        # Corresponds to the JSON property `extra`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra>]
        attr_accessor :extra
      
        # 
        # Corresponds to the JSON property `generalExtra`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :general_extra
      
        # Indexed data. label and value must be of the same length.
        # Corresponds to the JSON property `label`
        # @return [Array<String>]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<Float>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra = args[:extra] if args.key?(:extra)
          @general_extra = args[:general_extra] if args.key?(:general_extra)
          @label = args[:label] if args.key?(:label)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # The attributes of encoded thumbnail images. Next id: 7.
      class DrishtiVesperEncodedThumbnail
        include Google::Apis::Core::Hashable
      
        # JPEG/WEBP quality factor in range [0,100].
        # Corresponds to the JSON property `encodingQuality`
        # @return [Fixnum]
        attr_accessor :encoding_quality
      
        # Image encoding type.
        # Corresponds to the JSON property `encodingType`
        # @return [String]
        attr_accessor :encoding_type
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Encoded thumbnail bytes. Prefer this over `image_string` as we are not
        # supposed to store image bytes in a proto string field.
        # Corresponds to the JSON property `imageBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :image_bytes
      
        # Please migrate to `image_bytes`.
        # Corresponds to the JSON property `imageString`
        # @return [String]
        attr_accessor :image_string
      
        # Thumbnail resolution.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encoding_quality = args[:encoding_quality] if args.key?(:encoding_quality)
          @encoding_type = args[:encoding_type] if args.key?(:encoding_type)
          @height = args[:height] if args.key?(:height)
          @image_bytes = args[:image_bytes] if args.key?(:image_bytes)
          @image_string = args[:image_string] if args.key?(:image_string)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # LINT: LEGACY_NAMES MovingThumbnail is defined as a short video clip that
      # represents the whole video content. Next id: 17.
      class DrishtiVesperMovingThumbnail
        include Google::Apis::Core::Hashable
      
        # The begin timestamp in milliseconds.
        # Corresponds to the JSON property `beginTimestampMs`
        # @return [Fixnum]
        attr_accessor :begin_timestamp_ms
      
        # The duration of the moving thumbnail in milliseconds. Note that the duration
        # may not be the difference between begin_timestamp_ms and end_timestamp_ms, esp
        # when the moving thumbnail covers multiple clips from the video.
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        # 
        # Corresponds to the JSON property `encodedGifAnimation`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded_gif_animation
      
        # The encoded video string.
        # Corresponds to the JSON property `encodedVideoString`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded_video_string
      
        # The encoded WebP animation.
        # Corresponds to the JSON property `encodedWebpAnimation`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded_webp_animation
      
        # The end timestamp in milliseconds.
        # Corresponds to the JSON property `endTimestampMs`
        # @return [Fixnum]
        attr_accessor :end_timestamp_ms
      
        # Pixel height of the moving thumbnail.
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # MovingThumbnail id (e.g., the video id).
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # If set, this is the algorithm version used to generate this moving thumbnail.
        # Corresponds to the JSON property `movingThumbnailerVersion`
        # @return [String]
        attr_accessor :moving_thumbnailer_version
      
        # MovingThumbnail name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The score of the moving thumbnail.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Sum of individual score components within a moving thumbnail. Used as input
        # for weight fitting.
        # Corresponds to the JSON property `scoreComponents`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperMovingThumbnailScoreComponents]
        attr_accessor :score_components
      
        # A set of single frame thumbnails in the MovingThumbnail.
        # Corresponds to the JSON property `thumbnails`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperThumbnail>]
        attr_accessor :thumbnails
      
        # MovingThumbnail type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The actual quality of the Webp animation. Note this value may not be equal to
        # the quality value requested in the animation creator's options. This is
        # because other requirements, such as the max file size, may force the creator
        # to lower the actual quality value.
        # Corresponds to the JSON property `webpQualityLevel`
        # @return [Float]
        attr_accessor :webp_quality_level
      
        # Pixel width of the moving thumbnail.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin_timestamp_ms = args[:begin_timestamp_ms] if args.key?(:begin_timestamp_ms)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @encoded_gif_animation = args[:encoded_gif_animation] if args.key?(:encoded_gif_animation)
          @encoded_video_string = args[:encoded_video_string] if args.key?(:encoded_video_string)
          @encoded_webp_animation = args[:encoded_webp_animation] if args.key?(:encoded_webp_animation)
          @end_timestamp_ms = args[:end_timestamp_ms] if args.key?(:end_timestamp_ms)
          @height = args[:height] if args.key?(:height)
          @id = args[:id] if args.key?(:id)
          @moving_thumbnailer_version = args[:moving_thumbnailer_version] if args.key?(:moving_thumbnailer_version)
          @name = args[:name] if args.key?(:name)
          @score = args[:score] if args.key?(:score)
          @score_components = args[:score_components] if args.key?(:score_components)
          @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
          @type = args[:type] if args.key?(:type)
          @webp_quality_level = args[:webp_quality_level] if args.key?(:webp_quality_level)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Sum of individual score components within a moving thumbnail. Used as input
      # for weight fitting.
      class DrishtiVesperMovingThumbnailScoreComponents
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `audienceRewindRatioScore`
        # @return [Float]
        attr_accessor :audience_rewind_ratio_score
      
        # 
        # Corresponds to the JSON property `iconicFaceScore`
        # @return [Float]
        attr_accessor :iconic_face_score
      
        # 
        # Corresponds to the JSON property `matchingScore`
        # @return [Float]
        attr_accessor :matching_score
      
        # 
        # Corresponds to the JSON property `motionScore`
        # @return [Float]
        attr_accessor :motion_score
      
        # 
        # Corresponds to the JSON property `titleMatchingScore`
        # @return [Float]
        attr_accessor :title_matching_score
      
        # 
        # Corresponds to the JSON property `videoThumbQualityScore`
        # @return [Float]
        attr_accessor :video_thumb_quality_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audience_rewind_ratio_score = args[:audience_rewind_ratio_score] if args.key?(:audience_rewind_ratio_score)
          @iconic_face_score = args[:iconic_face_score] if args.key?(:iconic_face_score)
          @matching_score = args[:matching_score] if args.key?(:matching_score)
          @motion_score = args[:motion_score] if args.key?(:motion_score)
          @title_matching_score = args[:title_matching_score] if args.key?(:title_matching_score)
          @video_thumb_quality_score = args[:video_thumb_quality_score] if args.key?(:video_thumb_quality_score)
        end
      end
      
      # The attributes of a video thumbnail.
      class DrishtiVesperThumbnail
        include Google::Apis::Core::Hashable
      
        # Thumbnail dense features
        # Corresponds to the JSON property `denseFeatures`
        # @return [Array<Float>]
        attr_accessor :dense_features
      
        # Thumbnail image as an encoded image. Deprecated, use encoded_thumbnails
        # instead.
        # Corresponds to the JSON property `encodedImageString`
        # @return [String]
        attr_accessor :encoded_image_string
      
        # Thumbnail image as an encoded image with smaller resolution. Deprecated, use
        # encoded_thumbnails instead.
        # Corresponds to the JSON property `encodedImageStringSmall`
        # @return [String]
        attr_accessor :encoded_image_string_small
      
        # Encoded thumbnail images.
        # Corresponds to the JSON property `encodedThumbnails`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperEncodedThumbnail>]
        attr_accessor :encoded_thumbnails
      
        # Thumbnail id.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Text in video thumbnails that was detected by OCR.
        # Corresponds to the JSON property `ocrText`
        # @return [String]
        attr_accessor :ocr_text
      
        # Thumbnail quality scores.
        # Corresponds to the JSON property `qualityScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperThumbnailQualityScore>]
        attr_accessor :quality_scores
      
        # If true, this thumbnail should update default thumbnail.
        # Corresponds to the JSON property `shouldUpdateDefaultThumbnail`
        # @return [Boolean]
        attr_accessor :should_update_default_thumbnail
        alias_method :should_update_default_thumbnail?, :should_update_default_thumbnail
      
        # Thumbnailer Version.
        # Corresponds to the JSON property `thumbnailerModelVersion`
        # @return [String]
        attr_accessor :thumbnailer_model_version
      
        # Thumbnail timestamp in milliseconds.
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        # Thumbnail type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Proto holding values for user reported thumbnails. Next id: 12
        # Corresponds to the JSON property `userReportedThumbnail`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportUserReportedThumbnail]
        attr_accessor :user_reported_thumbnail
      
        # All user reported thumbnails of interest.
        # Corresponds to the JSON property `userReportedThumbnails`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportUserReportedThumbnail>]
        attr_accessor :user_reported_thumbnails
      
        # Thumbnail version, i.e., the unix time in seconds when the thumbnail was
        # created.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dense_features = args[:dense_features] if args.key?(:dense_features)
          @encoded_image_string = args[:encoded_image_string] if args.key?(:encoded_image_string)
          @encoded_image_string_small = args[:encoded_image_string_small] if args.key?(:encoded_image_string_small)
          @encoded_thumbnails = args[:encoded_thumbnails] if args.key?(:encoded_thumbnails)
          @id = args[:id] if args.key?(:id)
          @ocr_text = args[:ocr_text] if args.key?(:ocr_text)
          @quality_scores = args[:quality_scores] if args.key?(:quality_scores)
          @should_update_default_thumbnail = args[:should_update_default_thumbnail] if args.key?(:should_update_default_thumbnail)
          @thumbnailer_model_version = args[:thumbnailer_model_version] if args.key?(:thumbnailer_model_version)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
          @type = args[:type] if args.key?(:type)
          @user_reported_thumbnail = args[:user_reported_thumbnail] if args.key?(:user_reported_thumbnail)
          @user_reported_thumbnails = args[:user_reported_thumbnails] if args.key?(:user_reported_thumbnails)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class DrishtiVesperThumbnailQualityScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Proto holding values for details about human labels.
      class DrishtiVesperUserReportHumanLabel
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `racyLevel`
        # @return [String]
        attr_accessor :racy_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @racy_level = args[:racy_level] if args.key?(:racy_level)
        end
      end
      
      # Proto holding values for details about score and the source model.
      class DrishtiVesperUserReportModelScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `modelName`
        # @return [String]
        attr_accessor :model_name
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @model_name = args[:model_name] if args.key?(:model_name)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Proto holding values for user reported thumbnails. Next id: 12
      class DrishtiVesperUserReportUserReportedThumbnail
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `denseFeatures`
        # @return [Array<Float>]
        attr_accessor :dense_features
      
        # Number of days in which volume is calculated.
        # Corresponds to the JSON property `duration`
        # @return [Fixnum]
        attr_accessor :duration
      
        # Proto holding values for details about human labels.
        # Corresponds to the JSON property `humanLabel`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportHumanLabel]
        attr_accessor :human_label
      
        # Daily aggregared impressions for the reported video.
        # Corresponds to the JSON property `impressions`
        # @return [Fixnum]
        attr_accessor :impressions
      
        # Whether the thumbnail needs a human label.
        # Corresponds to the JSON property `needHumanLabel`
        # @return [Boolean]
        attr_accessor :need_human_label
        alias_method :need_human_label?, :need_human_label
      
        # 
        # Corresponds to the JSON property `rawHumanLabels`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportHumanLabel>]
        attr_accessor :raw_human_labels
      
        # Proto holding values for details about score and the source model.
        # Corresponds to the JSON property `reportScore`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportModelScore]
        attr_accessor :report_score
      
        # 
        # Corresponds to the JSON property `reportType`
        # @return [String]
        attr_accessor :report_type
      
        # Proto holding values for details about score and the source model.
        # Corresponds to the JSON property `score`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperUserReportModelScore]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `useCase`
        # @return [String]
        attr_accessor :use_case
      
        # Number of reports.
        # Corresponds to the JSON property `volume`
        # @return [Fixnum]
        attr_accessor :volume
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dense_features = args[:dense_features] if args.key?(:dense_features)
          @duration = args[:duration] if args.key?(:duration)
          @human_label = args[:human_label] if args.key?(:human_label)
          @impressions = args[:impressions] if args.key?(:impressions)
          @need_human_label = args[:need_human_label] if args.key?(:need_human_label)
          @raw_human_labels = args[:raw_human_labels] if args.key?(:raw_human_labels)
          @report_score = args[:report_score] if args.key?(:report_score)
          @report_type = args[:report_type] if args.key?(:report_type)
          @score = args[:score] if args.key?(:score)
          @use_case = args[:use_case] if args.key?(:use_case)
          @volume = args[:volume] if args.key?(:volume)
        end
      end
      
      # Video level container for thumbnail with its attributes, e.g., timestamp, id,
      # quality scores, annotations, or features.
      class DrishtiVesperVideoThumbnail
        include Google::Apis::Core::Hashable
      
        # Video id.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `movingThumbnails`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperMovingThumbnail>]
        attr_accessor :moving_thumbnails
      
        # 
        # Corresponds to the JSON property `thumbnails`
        # @return [Array<Google::Apis::ContentwarehouseV1::DrishtiVesperThumbnail>]
        attr_accessor :thumbnails
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @moving_thumbnails = args[:moving_thumbnails] if args.key?(:moving_thumbnails)
          @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
        end
      end
      
      # Deep-linking data is used to construct a deep-link URI for an activity or
      # frame's embed, such that on click, the user is taken to the right place in a
      # mobile app. If the app is not installed, the user is taken to the app store.
      # If not on mobile, an analogous web uri is used.
      class EmbedsDeepLinkData
        include Google::Apis::Core::Hashable
      
        # Application ID (or project ID) from Google API Console.
        # Corresponds to the JSON property `appId`
        # @return [Fixnum]
        attr_accessor :app_id
      
        # The data for a Google API Console client is entered by a developer during
        # client registration and is stored in PackagingService.
        # Corresponds to the JSON property `client`
        # @return [Array<Google::Apis::ContentwarehouseV1::EmbedsPackagingServiceClient>]
        attr_accessor :client
      
        # The ID for non-URL content. Embeds may either have no analogous web presence
        # or prefer a native mobile experience if supported. In the case of no web
        # presence, instead of setting the "url" field of an embed, such developers will
        # set this field and other content fields, e.g. thumbnail, title, description.
        # If set, this field is used to construct the deep-link URI. Note that the
        # native experience is preferred over the web link and the web link is used as a
        # fallback.
        # Corresponds to the JSON property `deepLinkId`
        # @return [String]
        attr_accessor :deep_link_id
      
        # Analogous web presence. Used as desktop fallback or when no native link data
        # is present.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_id = args[:app_id] if args.key?(:app_id)
          @client = args[:client] if args.key?(:client)
          @deep_link_id = args[:deep_link_id] if args.key?(:deep_link_id)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Represents an embedded object in an update. This is a wrapper class that can
      # contain a single specific item proto in an extension field. Think of it as a
      # base class like `Message` in Java. Each item proto must declare that it
      # extends this proto: message ExampleObject ` option (item_type) =
      # EXAMPLE_OBJECT; extend EmbedClientItem ` optional ExampleObject example_object
      # = ; ` ` See go/es-embeds for details.
      class EmbedsEmbedClientItem
        include Google::Apis::Core::Hashable
      
        # The canonical ID of the embed. If absent, the canonical ID is equal to the ID;
        # if present, then the canonical ID represents an "equivalence class" of embeds
        # which really refer to the same object. (For example, the URLs http://www.foo.
        # com/ and http://foo.com/ refer to the same object) This field may be updated
        # periodically by background processes.
        # Corresponds to the JSON property `canonicalId`
        # @return [String]
        attr_accessor :canonical_id
      
        # Deep-linking data is used to construct a deep-link URI for an activity or
        # frame's embed, such that on click, the user is taken to the right place in a
        # mobile app. If the app is not installed, the user is taken to the app store.
        # If not on mobile, an analogous web uri is used.
        # Corresponds to the JSON property `deepLinkData`
        # @return [Google::Apis::ContentwarehouseV1::EmbedsDeepLinkData]
        attr_accessor :deep_link_data
      
        # The ID of the embed. This corresponds to the schema.org ID, as represented in
        # the ItemScope.id field.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # This field records where the ItemScope was retrieved, if it was created via a
        # web fetch.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::EmbedsProvenance]
        attr_accessor :provenance
      
        # The ID used to identify the embed during rendering. This field will match ID,
        # if set, otherwise it will be the ID of the parent activity. This field is only
        # populated on the server for client use and is not persisted to storage.
        # Corresponds to the JSON property `renderId`
        # @return [String]
        attr_accessor :render_id
      
        # Signature of the embed, used for verification.
        # Corresponds to the JSON property `signature`
        # @return [String]
        attr_accessor :signature
      
        # Transient generic data that will not be saved on the server.
        # Corresponds to the JSON property `transientData`
        # @return [Google::Apis::ContentwarehouseV1::EmbedsTransientData]
        attr_accessor :transient_data
      
        # The first value in `type` determines which extension field will be set. When
        # creating an EmbedClientItem, you only need to set the first (primary) type in
        # this field. When the server receives the item, it will populate the full type
        # list using the parent annotations in the ItemType enum.
        # Corresponds to the JSON property `type`
        # @return [Array<String>]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_id = args[:canonical_id] if args.key?(:canonical_id)
          @deep_link_data = args[:deep_link_data] if args.key?(:deep_link_data)
          @id = args[:id] if args.key?(:id)
          @provenance = args[:provenance] if args.key?(:provenance)
          @render_id = args[:render_id] if args.key?(:render_id)
          @signature = args[:signature] if args.key?(:signature)
          @transient_data = args[:transient_data] if args.key?(:transient_data)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Developers register a client in Google API Console to get the deep-linking
      # feature on Google+ posts or frames about their apps. The client data is stored
      # in this proto.
      class EmbedsPackagingServiceClient
        include Google::Apis::Core::Hashable
      
        # Android app's package name to generate the deep-link URI.
        # Corresponds to the JSON property `androidPackageName`
        # @return [String]
        attr_accessor :android_package_name
      
        # iOS app's App Store ID to generate the App Store URL when app is not installed
        # on device.
        # Corresponds to the JSON property `iosAppStoreId`
        # @return [String]
        attr_accessor :ios_app_store_id
      
        # iOS app's bundle ID to generate the deep-link URI.
        # Corresponds to the JSON property `iosBundleId`
        # @return [String]
        attr_accessor :ios_bundle_id
      
        # Type of Google API Console client.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_package_name = args[:android_package_name] if args.key?(:android_package_name)
          @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
          @ios_bundle_id = args[:ios_bundle_id] if args.key?(:ios_bundle_id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This field records where the ItemScope was retrieved, if it was created via a
      # web fetch.
      class EmbedsProvenance
        include Google::Apis::Core::Hashable
      
        # Annotation blob from Annotation Service.
        # Corresponds to the JSON property `annotationBlob`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :annotation_blob
      
        # Canonical url of the retrieved_url, if one was resolved during retrieval, for
        # example, if a rel="canonical" link tag was provided in the retrieved web page.
        # Corresponds to the JSON property `canonicalUrl`
        # @return [String]
        attr_accessor :canonical_url
      
        # The url originally passed in the PRS request, which should be used to re-
        # discover the content. Note that this URL may be a forwarding service or link
        # shortener (bit.ly), so it should not be assumed to be canonical, but should be
        # used for navigation back to the original source of the itemscope.
        # Corresponds to the JSON property `inputUrl`
        # @return [String]
        attr_accessor :input_url
      
        # Contains exact types as parsed, whether or not we recognized that type at
        # parse time. If an itemscope is created by merging SchemaOrg markup and open
        # graph markup then the first itemtype would be schemaorg type, the second would
        # be open graph and so on. example: http://schema.org/VideoObject, og:video.
        # movie Plain text; usually a URL
        # Corresponds to the JSON property `itemtype`
        # @return [Array<String>]
        attr_accessor :itemtype
      
        # The server retrieved timestamp (in msec).
        # Corresponds to the JSON property `retrievedTimestampMsec`
        # @return [Fixnum]
        attr_accessor :retrieved_timestamp_msec
      
        # The final URL that was the actual source of the itemscope, after any redirects.
        # Corresponds to the JSON property `retrievedUrl`
        # @return [String]
        attr_accessor :retrieved_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_blob = args[:annotation_blob] if args.key?(:annotation_blob)
          @canonical_url = args[:canonical_url] if args.key?(:canonical_url)
          @input_url = args[:input_url] if args.key?(:input_url)
          @itemtype = args[:itemtype] if args.key?(:itemtype)
          @retrieved_timestamp_msec = args[:retrieved_timestamp_msec] if args.key?(:retrieved_timestamp_msec)
          @retrieved_url = args[:retrieved_url] if args.key?(:retrieved_url)
        end
      end
      
      # Transient generic data that will not be saved on the server.
      class EmbedsTransientData
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Output of the classifier.
      class EntitySignalsClassificationOutput
        include Google::Apis::Core::Hashable
      
        # Filled if used logistic regression (see ewok.proto for available labels).
        # Corresponds to the JSON property `labels`
        # @return [Array<Google::Apis::ContentwarehouseV1::EntitySignalsWeightedRelevanceRating>]
        attr_accessor :labels
      
        # If using linear regression, this is the output value of the regression. If
        # using logistic regression, this is the weighted aggregated rating. See http://
        # go/entitymetric
        # Corresponds to the JSON property `relevanceScore`
        # @return [Float]
        attr_accessor :relevance_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @labels = args[:labels] if args.key?(:labels)
          @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
        end
      end
      
      # Collection of input, extracted features and classification output.
      class EntitySignalsEntityClassification
        include Google::Apis::Core::Hashable
      
        # Entity id.
        # Corresponds to the JSON property `entityId`
        # @return [String]
        attr_accessor :entity_id
      
        # Input features used in classification.
        # Corresponds to the JSON property `features`
        # @return [Array<Google::Apis::ContentwarehouseV1::EntitySignalsEntityFeature>]
        attr_accessor :features
      
        # Output of the classifier.
        # Corresponds to the JSON property `output`
        # @return [Google::Apis::ContentwarehouseV1::EntitySignalsClassificationOutput]
        attr_accessor :output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_id = args[:entity_id] if args.key?(:entity_id)
          @features = args[:features] if args.key?(:features)
          @output = args[:output] if args.key?(:output)
        end
      end
      
      # 
      class EntitySignalsEntityFeature
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `code`
        # @return [String]
        attr_accessor :code
      
        # Name of the feature. For a completely list of available features, please check
        # http://go/entityclassifierfeatures
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Value of the feature.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class EntitySignalsWeightedRelevanceRating
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `rating`
        # @return [String]
        attr_accessor :rating
      
        # 
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @rating = args[:rating] if args.key?(:rating)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # An EventId is a 128 bit identifier that uniquely identifies an event, such as
      # a query. The event time recorded to the nearest microsecond, along with
      # information about the process generating the event, ensures that all EventIds
      # are unique. Details of this EventId are described in a design document: http://
      # www/eng/designdocs/sawmill/adlogs.html
      class EventIdMessage
        include Google::Apis::Core::Hashable
      
        # process_id is an integer that identifies the process on this machine that
        # generated this event. This id is calculated once when the server generates its
        # first event, and may change if the process is migrated to a different host.
        # This field has a very specific format mandated by the logs collection
        # infrastructure, which is subject to change WITHOUT NOTICE. As of 2013-01-09,
        # this format is: uint32 process_id = (time(NULL) << 24) + (getpid() & 0xFFFFFF);
        # If you are generating an extended_pid directly, you MUST use one of the
        # maintained library implementations in order to generate it properly: C++ //
        # borg/borgletlib:extended_pid; call borg::ExtendedPid() Python //borg/
        # borgletlib/python:pyextendedpid; call ExtendedPid() Go //borg/borgletlib/go:
        # extendedpid; call Get() Java //java/com/google/common/logging; call EventId.
        # getPid() If you think that you need to parse the values of this field, please
        # contact logs-collection-dev@ to discuss your requirement.
        # Corresponds to the JSON property `processId`
        # @return [Fixnum]
        attr_accessor :process_id
      
        # server_ip is the IPv4 address or http://go/ghostid of the machine running the
        # server that created this event message. This allows us to distinguish between
        # events that occur at the same time on different servers. Format: 10.1.2.3 is
        # stored as 0x0a010203, and GHostId 1 as 0x00000001.
        # Corresponds to the JSON property `serverIp`
        # @return [Fixnum]
        attr_accessor :server_ip
      
        # time_usec is the number of microseconds since the epoch (i.e., since 1970-01-
        # 01 00:00:00 UTC) as an int64: 1e6 * (unix time) + microseconds. Applications
        # must ensure that EventIdMessages have increasing times, artificially
        # increasing time_usec to one greater than the previous value if necessary.
        # Alternate implementations were considered: 1. storing unix time and
        # microseconds separately would require a bit more storage, and the convenience
        # of having a single value representing the time seemed more useful than having
        # trivial access to a unix time. 2. storing unix time in the upper 32 bits would
        # allow for more precision - up to 4G events/second, but it wouldn't print
        # nicely as a decimal value and it seems unlikely that any single server would
        # ever sustain more than 1M events/second. 3. Java-compatible time uses millis -
        # this would limit servers to 1000 events per second - too small. Other names
        # for this field were considered, including time, time_stamp, and utime. We felt
        # that including the units in the name would tend to produce more readable code.
        # utime might be interpreted as user time. unix timestamp * 1e6 + microseconds
        # Corresponds to the JSON property `timeUsec`
        # @return [Fixnum]
        attr_accessor :time_usec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @process_id = args[:process_id] if args.key?(:process_id)
          @server_ip = args[:server_ip] if args.key?(:server_ip)
          @time_usec = args[:time_usec] if args.key?(:time_usec)
        end
      end
      
      # the extra info response from ascorer used to build snippets in GWS experiments
      class ExtraSnippetInfoResponse
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matchinfo`
        # @return [Google::Apis::ContentwarehouseV1::ExtraSnippetInfoResponseMatchInfo]
        attr_accessor :matchinfo
      
        # 
        # Corresponds to the JSON property `querysubitem`
        # @return [Array<Google::Apis::ContentwarehouseV1::ExtraSnippetInfoResponseQuerySubitem>]
        attr_accessor :querysubitem
      
        # 
        # Corresponds to the JSON property `tidbit`
        # @return [Array<Google::Apis::ContentwarehouseV1::ExtraSnippetInfoResponseTidbit>]
        attr_accessor :tidbit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matchinfo = args[:matchinfo] if args.key?(:matchinfo)
          @querysubitem = args[:querysubitem] if args.key?(:querysubitem)
          @tidbit = args[:tidbit] if args.key?(:tidbit)
        end
      end
      
      # 
      class ExtraSnippetInfoResponseMatchInfo
        include Google::Apis::Core::Hashable
      
        # bitvector of query items matching the title
        # Corresponds to the JSON property `titleMatches`
        # @return [Fixnum]
        attr_accessor :title_matches
      
        # bitvector of query items matching the url
        # Corresponds to the JSON property `urlMatches`
        # @return [Fixnum]
        attr_accessor :url_matches
      
        # bitvector of query items considered by chooser
        # Corresponds to the JSON property `weightedItems`
        # @return [Fixnum]
        attr_accessor :weighted_items
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @title_matches = args[:title_matches] if args.key?(:title_matches)
          @url_matches = args[:url_matches] if args.key?(:url_matches)
          @weighted_items = args[:weighted_items] if args.key?(:weighted_items)
        end
      end
      
      # A query term, phrase, or synonym. An original query term or phrase is called
      # an "item". Each item may have more than one "subitem" if there are synonyms.
      # In rare cases a subitem may correspond to multiple items, such as the subitem "
      # cia" in the query [central intelligence agency].
      class ExtraSnippetInfoResponseQuerySubitem
        include Google::Apis::Core::Hashable
      
        # Additional information from the SnippetQuery.
        # Corresponds to the JSON property `isHighlighted`
        # @return [Boolean]
        attr_accessor :is_highlighted
        alias_method :is_highlighted?, :is_highlighted
      
        # 
        # Corresponds to the JSON property `isOptional`
        # @return [Boolean]
        attr_accessor :is_optional
        alias_method :is_optional?, :is_optional
      
        # true iff this subitem was an original query term or phrase. Can only be false
        # if want_all_query_subitems == true in the request.
        # Corresponds to the JSON property `isOriginal`
        # @return [Boolean]
        attr_accessor :is_original
        alias_method :is_original?, :is_original
      
        # a bitvector of the query items corresponding to this subitem. Typically only
        # one bit is set, but see comment above.
        # Corresponds to the JSON property `items`
        # @return [Fixnum]
        attr_accessor :items
      
        # text associated with this query item
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # the weight of this query item, as calculated by SubitemWeight(): https://qwiki.
        # corp.google.com/display/Q/SnippetWeights
        # Corresponds to the JSON property `weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_highlighted = args[:is_highlighted] if args.key?(:is_highlighted)
          @is_optional = args[:is_optional] if args.key?(:is_optional)
          @is_original = args[:is_original] if args.key?(:is_original)
          @items = args[:items] if args.key?(:items)
          @text = args[:text] if args.key?(:text)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # 
      class ExtraSnippetInfoResponseTidbit
        include Google::Apis::Core::Hashable
      
        # this information is specific to anchors and is only returned if type == ANCHOR
        # Corresponds to the JSON property `anchorinfo`
        # @return [Google::Apis::ContentwarehouseV1::ExtraSnippetInfoResponseTidbitAnchorInfo]
        attr_accessor :anchorinfo
      
        # For tidbits only: position of tidbit in the document. More specifically,
        # tidbit is found at [begin, end) in the document's tokens.
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # a bitvector of each query term within this tidbit
        # Corresponds to the JSON property `items`
        # @return [Fixnum]
        attr_accessor :items
      
        # the score for this tidbit if there was one this is returned for Snippets and
        # Tidbits and is only meaningful for comparing between objects of the same type (
        # snippet to snippet, tidbit to tidbit)
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # the tidbit text, with search terms already highlighted
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchorinfo = args[:anchorinfo] if args.key?(:anchorinfo)
          @begin = args[:begin] if args.key?(:begin)
          @end = args[:end] if args.key?(:end)
          @items = args[:items] if args.key?(:items)
          @score = args[:score] if args.key?(:score)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # this information is specific to anchors and is only returned if type == ANCHOR
      class ExtraSnippetInfoResponseTidbitAnchorInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `offdomainCount`
        # @return [Fixnum]
        attr_accessor :offdomain_count
      
        # 
        # Corresponds to the JSON property `ondomainCount`
        # @return [Fixnum]
        attr_accessor :ondomain_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @offdomain_count = args[:offdomain_count] if args.key?(:offdomain_count)
          @ondomain_count = args[:ondomain_count] if args.key?(:ondomain_count)
        end
      end
      
      # 
      class FaceIndexing
        include Google::Apis::Core::Hashable
      
        # Always use image/search/utils/face_proto_util.h for packing and unpacking
        # these values.
        # Corresponds to the JSON property `mustangBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :mustang_bytes
      
        # 
        # Corresponds to the JSON property `mustangBytesVersion`
        # @return [Fixnum]
        attr_accessor :mustang_bytes_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mustang_bytes = args[:mustang_bytes] if args.key?(:mustang_bytes)
          @mustang_bytes_version = args[:mustang_bytes_version] if args.key?(:mustang_bytes_version)
        end
      end
      
      # 
      class FatcatCompactBinaryClassification
        include Google::Apis::Core::Hashable
      
        # Either binary_classifier will be set, using the enum above, or
        # binary_classifier_name will be set, if it is not one of the classifiers in the
        # enum - never both.
        # Corresponds to the JSON property `binaryClassifier`
        # @return [String]
        attr_accessor :binary_classifier
      
        # 
        # Corresponds to the JSON property `binaryClassifierName`
        # @return [String]
        attr_accessor :binary_classifier_name
      
        # A CompactDocClassification will not usually have a weight. For a
        # CompactSiteClassification, this value will be 0...127 corresponding to 0.0...1.
        # 0, indicating fraction of the site that this label applies to
        # Corresponds to the JSON property `discreteFraction`
        # @return [Fixnum]
        attr_accessor :discrete_fraction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @binary_classifier = args[:binary_classifier] if args.key?(:binary_classifier)
          @binary_classifier_name = args[:binary_classifier_name] if args.key?(:binary_classifier_name)
          @discrete_fraction = args[:discrete_fraction] if args.key?(:discrete_fraction)
        end
      end
      
      # The result of PetacatAnnotator. Each result contains: 1. RephilClusters; 2. At
      # most 5 verticals from each taxonomy, sorted by the probabilities in descending
      # order. 3. Binary classification results about page types and sensitive content.
      # The types of taxonomies include: verticals4, geo, verticals4_geo,
      # products_services, icm_im_audiences and icm_im_audiences_dev.
      class FatcatCompactDocClassification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `binary`
        # @return [Array<Google::Apis::ContentwarehouseV1::FatcatCompactBinaryClassification>]
        attr_accessor :binary
      
        # 
        # Corresponds to the JSON property `clusters`
        # @return [Google::Apis::ContentwarehouseV1::FatcatCompactRephilClusters]
        attr_accessor :clusters
      
        # 
        # Corresponds to the JSON property `epoch`
        # @return [String]
        attr_accessor :epoch
      
        # 
        # Corresponds to the JSON property `langCode`
        # @return [String]
        attr_accessor :lang_code
      
        # The id of the Rephil model used to generate the Rephil clusters. If it is
        # absent, Rephil 4 is assumed.
        # Corresponds to the JSON property `rephilModelId`
        # @return [Fixnum]
        attr_accessor :rephil_model_id
      
        # 
        # Corresponds to the JSON property `taxonomic`
        # @return [Array<Google::Apis::ContentwarehouseV1::FatcatCompactTaxonomicClassification>]
        attr_accessor :taxonomic
      
        # not needed if the url is the sstable / bigtable key used during intermediate
        # processing only
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # The relative weight of this doc within a site, typically something like
        # pagerank or navboost impressions. May be a large number (like an actual
        # pageviews estimate), not limited to a small range.
        # Corresponds to the JSON property `weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @binary = args[:binary] if args.key?(:binary)
          @clusters = args[:clusters] if args.key?(:clusters)
          @epoch = args[:epoch] if args.key?(:epoch)
          @lang_code = args[:lang_code] if args.key?(:lang_code)
          @rephil_model_id = args[:rephil_model_id] if args.key?(:rephil_model_id)
          @taxonomic = args[:taxonomic] if args.key?(:taxonomic)
          @url = args[:url] if args.key?(:url)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # 
      class FatcatCompactRephilClusters
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::FatcatCompactRephilClustersCluster>]
        attr_accessor :cluster
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster = args[:cluster] if args.key?(:cluster)
        end
      end
      
      # 
      class FatcatCompactRephilClustersCluster
        include Google::Apis::Core::Hashable
      
        # 0...127 corresponds to 0.0 - 1.0
        # Corresponds to the JSON property `discreteWeight`
        # @return [Fixnum]
        attr_accessor :discrete_weight
      
        # 
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discrete_weight = args[:discrete_weight] if args.key?(:discrete_weight)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A version of this proto for logging is available at cs/symbol:logged_fatcat.
      # LoggedCompactTaxonomicClassification
      class FatcatCompactTaxonomicClassification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `category`
        # @return [Array<Google::Apis::ContentwarehouseV1::FatcatCompactTaxonomicClassificationCategory>]
        attr_accessor :category
      
        # Either taxonomy will be set, using the enum above, or taxonomy_name will be
        # set (if the taxonomy is not one of the ones in the enum) - never both
        # Corresponds to the JSON property `taxonomy`
        # @return [String]
        attr_accessor :taxonomy
      
        # 
        # Corresponds to the JSON property `taxonomyName`
        # @return [String]
        attr_accessor :taxonomy_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @taxonomy = args[:taxonomy] if args.key?(:taxonomy)
          @taxonomy_name = args[:taxonomy_name] if args.key?(:taxonomy_name)
        end
      end
      
      # A taxonomic category. A classification consists of weight (totalling 1.0)
      # distributed among one or more categories.
      class FatcatCompactTaxonomicClassificationCategory
        include Google::Apis::Core::Hashable
      
        # go/petacat-faq#how-should-i-interpret-classification-weights Discrete to
        # reduce size. Range is [0,127], corresponding to [0.0,1.0].
        # Corresponds to the JSON property `discreteWeight`
        # @return [Fixnum]
        attr_accessor :discrete_weight
      
        # The category's ID, e.g. 20 for /Sports in the go/verticals4 taxonomy.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discrete_weight = args[:discrete_weight] if args.key?(:discrete_weight)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # http://go/contact-detail-hash.
      class FocusBackendContactDetailHash
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The hash here will be a 16-bit weak hash to avoid reverse engineering for
        # decoding the actual contact detail. The hash value is computed by the
        # fingerprint of the raw contact detail mod 2^16.
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A contact pointer that represents a contact (http://go/assistant-contact-id).
      class FocusBackendContactPointer
        include Google::Apis::Core::Hashable
      
        # The annotation ID. Annotations are only allowed to point to annotations that
        # do not themselves have a pointer (avoids any possibilty of loops). Cast this
        # field to string in javascript to make it compile in js.
        # Corresponds to the JSON property `annotationId`
        # @return [Fixnum]
        attr_accessor :annotation_id
      
        # //////////////////// DeviceRawContactId ////////////////////// Used by Device
        # Contacts Only. The Raw ID as assigned to the original contact on the device.
        # For more details see go/fbs-support-for-device-contacts.
        # Corresponds to the JSON property `deviceRawContactId`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendDeviceRawContactId]
        attr_accessor :device_raw_contact_id
      
        # The contact ID from the Focus backend. Cast this field to string in javascript
        # to make it compile in js.
        # Corresponds to the JSON property `focusContactId`
        # @return [Fixnum]
        attr_accessor :focus_contact_id
      
        # Additional contact ids that are not actively used to match contact pointers to
        # contacts. There may be overlap with primary or secondary contact ids.
        # Corresponds to the JSON property `otherContactId`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendOtherContactId]
        attr_accessor :other_contact_id
      
        # The secondary ID of a contact.
        # Corresponds to the JSON property `secondaryId`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendSecondaryContactId]
        attr_accessor :secondary_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
          @device_raw_contact_id = args[:device_raw_contact_id] if args.key?(:device_raw_contact_id)
          @focus_contact_id = args[:focus_contact_id] if args.key?(:focus_contact_id)
          @other_contact_id = args[:other_contact_id] if args.key?(:other_contact_id)
          @secondary_id = args[:secondary_id] if args.key?(:secondary_id)
        end
      end
      
      # //////////////////// DeviceContactId ////////////////////// Used by Device
      # Contacts only. For more details see go/fbs-support-for-device-contacts.
      class FocusBackendDeviceContactId
        include Google::Apis::Core::Hashable
      
        # DeviceContact Id.
        # Corresponds to the JSON property `ContactId`
        # @return [Fixnum]
        attr_accessor :contact_id
      
        # //////////////////// DeviceId ////////////////////// Used by Device Contacts
        # only. For more details see go/fbs-support-for-device-contacts.
        # Corresponds to the JSON property `DeviceId`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendDeviceId]
        attr_accessor :device_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_id = args[:contact_id] if args.key?(:contact_id)
          @device_id = args[:device_id] if args.key?(:device_id)
        end
      end
      
      # //////////////////// DeviceId ////////////////////// Used by Device Contacts
      # only. For more details see go/fbs-support-for-device-contacts.
      class FocusBackendDeviceId
        include Google::Apis::Core::Hashable
      
        # The GServices id on Android. See go/android-id.
        # Corresponds to the JSON property `AndroidDeviceId`
        # @return [Fixnum]
        attr_accessor :android_device_id
      
        # DeviceId.Hash is a SHA256 of some attribute of the user and device. For
        # Android devices: Hash = SHA256(gaia_account_name + “:” + “1” + “:” + (android
        # id - LSB)); For iOS devices: Hash = TOLOWER(HEX(GMCSComputeUserDeviceToken(
        # userId, iOsDeviceId)) For more details see go/client-instance-id.
        # Corresponds to the JSON property `Hash`
        # @return [String]
        attr_accessor :hash_prop
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_device_id = args[:android_device_id] if args.key?(:android_device_id)
          @hash_prop = args[:hash_prop] if args.key?(:hash_prop)
        end
      end
      
      # //////////////////// DeviceRawContactId ////////////////////// Used by Device
      # Contacts Only. The Raw ID as assigned to the original contact on the device.
      # For more details see go/fbs-support-for-device-contacts.
      class FocusBackendDeviceRawContactId
        include Google::Apis::Core::Hashable
      
        # //////////////////// DeviceId ////////////////////// Used by Device Contacts
        # only. For more details see go/fbs-support-for-device-contacts.
        # Corresponds to the JSON property `DeviceId`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendDeviceId]
        attr_accessor :device_id
      
        # Raw ID assigned by the device. Cast this field to string in javascript to make
        # it compile in js.
        # Corresponds to the JSON property `RawContactId`
        # @return [Fixnum]
        attr_accessor :raw_contact_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_id = args[:device_id] if args.key?(:device_id)
          @raw_contact_id = args[:raw_contact_id] if args.key?(:raw_contact_id)
        end
      end
      
      # Additional contact ids that are not actively used to match contact pointers to
      # contacts. There may be overlap with primary or secondary contact ids.
      class FocusBackendOtherContactId
        include Google::Apis::Core::Hashable
      
        # Device contact ID, when available: - The annotation points to a device contact,
        # and the device contact id was correctly populated when the annotation was
        # created. Note that the device contact id is populated once per device contact
        # on a device. It is distinct from RawContactId - a single device contact may
        # have multiple raw contact ids. - The annotation points to a Focus contact that
        # was merged with device contact information in Starlight. When the annotation
        # was created, a device contact id was available on the merged person object. -
        # The contact annotation was created from April 2021 onwards. All prior
        # annotations do not populate this field. ContactPointer creation relies on the
        # client caller to correctly populate the device contact id, and does not
        # enforce any assumptions on availability of this field. This field is repeated
        # because in rare cases Starlight may merge device contact information across
        # different devices into a single merged person object. WARNING: Use with
        # extreme caution! This ID is not stable. For more details see go/fbs-support-
        # for-device-contacts.
        # Corresponds to the JSON property `deviceContactId`
        # @return [Array<Google::Apis::ContentwarehouseV1::FocusBackendDeviceContactId>]
        attr_accessor :device_contact_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_contact_id = args[:device_contact_id] if args.key?(:device_contact_id)
        end
      end
      
      # The secondary ID of a contact.
      class FocusBackendSecondaryContactId
        include Google::Apis::Core::Hashable
      
        # The hashes of the contact details (e.g. phone number and email address).
        # Corresponds to the JSON property `contactDetailHash`
        # @return [Array<Google::Apis::ContentwarehouseV1::FocusBackendContactDetailHash>]
        attr_accessor :contact_detail_hash
      
        # The contact's full name, not hashed.
        # Corresponds to the JSON property `contactName`
        # @return [String]
        attr_accessor :contact_name
      
        # The hash of contact's full name, generated using Fingerprint2011(). Cast this
        # field to string in javascript to make it compile in js.
        # Corresponds to the JSON property `contactNameHash`
        # @return [Fixnum]
        attr_accessor :contact_name_hash
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_detail_hash = args[:contact_detail_hash] if args.key?(:contact_detail_hash)
          @contact_name = args[:contact_name] if args.key?(:contact_name)
          @contact_name_hash = args[:contact_name_hash] if args.key?(:contact_name_hash)
        end
      end
      
      # Citation contains the information needed to correctly attribute the source of
      # data.
      class FreebaseCitation
        include Google::Apis::Core::Hashable
      
        # Mid of the dataset.
        # Corresponds to the JSON property `dataset`
        # @return [String]
        attr_accessor :dataset
      
        # If set to true, the citation is required to be displayed when the data is used.
        # Corresponds to the JSON property `isAttributionRequired`
        # @return [Boolean]
        attr_accessor :is_attribution_required
        alias_method :is_attribution_required?, :is_attribution_required
      
        # Name of the project of the data's origin.
        # Corresponds to the JSON property `project`
        # @return [String]
        attr_accessor :project
      
        # The name of the provider of this information.
        # Corresponds to the JSON property `provider`
        # @return [String]
        attr_accessor :provider
      
        # A human readable statement of attribution.
        # Corresponds to the JSON property `statement`
        # @return [String]
        attr_accessor :statement
      
        # Uri link associated with this data.
        # Corresponds to the JSON property `uri`
        # @return [String]
        attr_accessor :uri
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dataset = args[:dataset] if args.key?(:dataset)
          @is_attribution_required = args[:is_attribution_required] if args.key?(:is_attribution_required)
          @project = args[:project] if args.key?(:project)
          @provider = args[:provider] if args.key?(:provider)
          @statement = args[:statement] if args.key?(:statement)
          @uri = args[:uri] if args.key?(:uri)
        end
      end
      
      # An Id contains the identifiers used to reference this topic (entity) in the
      # Knowledge Graph. The Knowledge Graph supports several forms of identifiers: - "
      # mids" (machine ids) that are assigned at creation time, and support a
      # resolution mechanism that tracks topics after they are merged (for more about
      # mids, see go/kg-mid), - "ids" are human-readable ids (HRIDs) that are derived
      # from a namespace hierarchy stored in Knowledge Graph, and a set of rules, - "
      # guids" are low-level ids historically used in Freebase (pre-Knowledge Graph,
      # deprecated). Only the mid and id are supplied here. Note that mids can be
      # converted to guids or uint64s (see //metaweb/util/mid/mid.h).
      class FreebaseId
        include Google::Apis::Core::Hashable
      
        # "id" may be a human readable ID (HRID) or a MID. Originally it was intended to
        # always be a human readable ID, but that convention was not always followed so
        # clients should be wary. Not every topic has an id.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The "mid" should be used whenever a globally unique, primary key into the
        # Knowledge Graph is needed. These keys are always prefixed with the "/m" and "/
        # g", (and more rarely the "/x" and "/t") namespaces, and are alphanumeric
        # strings consisting of lowercase letters excluding vowels, numbers and the
        # underscore character. (Applications should not assume a constant length for
        # these strings as Livegraph reserves the right to extend the number of
        # characters to accommodate more topics.)
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # Represents a geopoint, which is one of the possible Value types.
      class FreebaseLatLong
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `latDeg`
        # @return [Float]
        attr_accessor :lat_deg
      
        # 
        # Corresponds to the JSON property `longDeg`
        # @return [Float]
        attr_accessor :long_deg
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lat_deg = args[:lat_deg] if args.key?(:lat_deg)
          @long_deg = args[:long_deg] if args.key?(:long_deg)
        end
      end
      
      # Represents a measurements, which is one of the possible Value types. A
      # measurement value like "5.2 meter^2 / second" would be represented as:
      # magnitude: 5.2 unit ` unit_mid: "/m/mid_for_meter" power: 2 ` unit ` unit_mid:
      # "/m/mid_for_second" power: -1 `
      class FreebaseMeasurement
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `magnitude`
        # @return [Float]
        attr_accessor :magnitude
      
        # Repeated units are interpreted as a product. i.e. (meter ^ 1) * (second ^ -2)
        # Corresponds to the JSON property `unit`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebaseMeasurementUnit>]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @magnitude = args[:magnitude] if args.key?(:magnitude)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # 
      class FreebaseMeasurementUnit
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `power`
        # @return [Fixnum]
        attr_accessor :power
      
        # An Id contains the identifiers used to reference this topic (entity) in the
        # Knowledge Graph. The Knowledge Graph supports several forms of identifiers: - "
        # mids" (machine ids) that are assigned at creation time, and support a
        # resolution mechanism that tracks topics after they are merged (for more about
        # mids, see go/kg-mid), - "ids" are human-readable ids (HRIDs) that are derived
        # from a namespace hierarchy stored in Knowledge Graph, and a set of rules, - "
        # guids" are low-level ids historically used in Freebase (pre-Knowledge Graph,
        # deprecated). Only the mid and id are supplied here. Note that mids can be
        # converted to guids or uint64s (see //metaweb/util/mid/mid.h).
        # Corresponds to the JSON property `unit`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseId]
        attr_accessor :unit
      
        # Deprecated fields.
        # Corresponds to the JSON property `unitMid`
        # @return [String]
        attr_accessor :unit_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @power = args[:power] if args.key?(:power)
          @unit = args[:unit] if args.key?(:unit)
          @unit_mid = args[:unit_mid] if args.key?(:unit_mid)
        end
      end
      
      # List of ` predicate, ` object ` ` to be processed as a Nested Struct. Nested
      # Struct can be recursive. NestedStruct.property_value(i).value(j) may have
      # nested_struct field.
      class FreebaseNestedStruct
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `propertyValue`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebasePropertyValue>]
        attr_accessor :property_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @property_value = args[:property_value] if args.key?(:property_value)
        end
      end
      
      # A PropertyValue associates properties with values in the context of a topic.
      class FreebasePropertyValue
        include Google::Apis::Core::Hashable
      
        # An Id contains the identifiers used to reference this topic (entity) in the
        # Knowledge Graph. The Knowledge Graph supports several forms of identifiers: - "
        # mids" (machine ids) that are assigned at creation time, and support a
        # resolution mechanism that tracks topics after they are merged (for more about
        # mids, see go/kg-mid), - "ids" are human-readable ids (HRIDs) that are derived
        # from a namespace hierarchy stored in Knowledge Graph, and a set of rules, - "
        # guids" are low-level ids historically used in Freebase (pre-Knowledge Graph,
        # deprecated). Only the mid and id are supplied here. Note that mids can be
        # converted to guids or uint64s (see //metaweb/util/mid/mid.h).
        # Corresponds to the JSON property `property`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseId]
        attr_accessor :property
      
        # Indicates the total values that exist for this property, even if they aren't
        # all present in the value field, due to truncation.
        # Corresponds to the JSON property `totalValueCount`
        # @return [Fixnum]
        attr_accessor :total_value_count
      
        # The value associated with the property for the containing topic.
        # Corresponds to the JSON property `value`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebaseValue>]
        attr_accessor :value
      
        # If ValueStatus is not set at all, the implication is that there are well-known
        # value(s), specified in the "value" field. (It should be considered malformed
        # data to have value_status set when len(values) > 0.)
        # Corresponds to the JSON property `valueStatus`
        # @return [String]
        attr_accessor :value_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @property = args[:property] if args.key?(:property)
          @total_value_count = args[:total_value_count] if args.key?(:total_value_count)
          @value = args[:value] if args.key?(:value)
          @value_status = args[:value_status] if args.key?(:value_status)
        end
      end
      
      # A Topic represents a Knowledge Graph entity with its associated properties and
      # their values.
      class FreebaseTopic
        include Google::Apis::Core::Hashable
      
        # An Id contains the identifiers used to reference this topic (entity) in the
        # Knowledge Graph. The Knowledge Graph supports several forms of identifiers: - "
        # mids" (machine ids) that are assigned at creation time, and support a
        # resolution mechanism that tracks topics after they are merged (for more about
        # mids, see go/kg-mid), - "ids" are human-readable ids (HRIDs) that are derived
        # from a namespace hierarchy stored in Knowledge Graph, and a set of rules, - "
        # guids" are low-level ids historically used in Freebase (pre-Knowledge Graph,
        # deprecated). Only the mid and id are supplied here. Note that mids can be
        # converted to guids or uint64s (see //metaweb/util/mid/mid.h).
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseId]
        attr_accessor :id
      
        # The property-value bindings associated with the topic. Note that in the case
        # where a property is relevant to a topic based on its type, but no values of
        # that property are present for the topic, the PropertyValue will simply not
        # appear, rather than being present with a null value, or empty repeated value
        # list.
        # Corresponds to the JSON property `propertyValue`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebasePropertyValue>]
        attr_accessor :property_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @property_value = args[:property_value] if args.key?(:property_value)
        end
      end
      
      # Values are effectively a union of several possible Knowledge Graph types:
      # simple primitive datatypes such as booleans, integers and floats, references
      # to other Knowledge Graph topics (by id), or "compound values" which are
      # expressed as embedded topics with associated properties and values. Values
      # occur in indexed order (if any).
      class FreebaseValue
        include Google::Apis::Core::Hashable
      
        # key, uri, or datetime. Present when value is bool.
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # Citation contains the information needed to correctly attribute the source of
        # data.
        # Corresponds to the JSON property `citation`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseCitation]
        attr_accessor :citation
      
        # A Topic represents a Knowledge Graph entity with its associated properties and
        # their values.
        # Corresponds to the JSON property `compoundValue`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseTopic]
        attr_accessor :compound_value
      
        # Deletion provenance for this value.
        # Corresponds to the JSON property `deletionProvenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::StorageGraphBfgTripleProvenance>]
        attr_accessor :deletion_provenance
      
        # The lang of the display_value field.
        # Corresponds to the JSON property `displayLang`
        # @return [String]
        attr_accessor :display_lang
      
        # The display value of this value. This is a i18n-aware formatted value if
        # present.
        # Corresponds to the JSON property `displayValue`
        # @return [String]
        attr_accessor :display_value
      
        # An optional name for a proto field.
        # Corresponds to the JSON property `expectedProto`
        # @return [String]
        attr_accessor :expected_proto
      
        # Present when value is float.
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # An Id contains the identifiers used to reference this topic (entity) in the
        # Knowledge Graph. The Knowledge Graph supports several forms of identifiers: - "
        # mids" (machine ids) that are assigned at creation time, and support a
        # resolution mechanism that tracks topics after they are merged (for more about
        # mids, see go/kg-mid), - "ids" are human-readable ids (HRIDs) that are derived
        # from a namespace hierarchy stored in Knowledge Graph, and a set of rules, - "
        # guids" are low-level ids historically used in Freebase (pre-Knowledge Graph,
        # deprecated). Only the mid and id are supplied here. Note that mids can be
        # converted to guids or uint64s (see //metaweb/util/mid/mid.h).
        # Corresponds to the JSON property `idValue`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseId]
        attr_accessor :id_value
      
        # Index of the value relative to the containing property (if any). Knowledge
        # Graph supports a loose notion of indexing: some non-unique properties may have
        # indices, while others may not. Furthermore, for a single property, some values
        # may have indices (such as the top 5 actors in a film), while others may not (
        # the film's supporting cast). Un-indexed values will appear at the end of the
        # repeated value list. This field contains the index value only when is present
        # in the Knowledge Graph.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # Present when value is int.
        # Corresponds to the JSON property `intValue`
        # @return [Fixnum]
        attr_accessor :int_value
      
        # Whenever the value is text with TYPE_TEXT, the lang field is populated with
        # the III LanguageCode associated with the string_value field.
        # Corresponds to the JSON property `lang`
        # @return [String]
        attr_accessor :lang
      
        # Represents a geopoint, which is one of the possible Value types.
        # Corresponds to the JSON property `latLongValue`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseLatLong]
        attr_accessor :lat_long_value
      
        # Represents a measurements, which is one of the possible Value types. A
        # measurement value like "5.2 meter^2 / second" would be represented as:
        # magnitude: 5.2 unit ` unit_mid: "/m/mid_for_meter" power: 2 ` unit ` unit_mid:
        # "/m/mid_for_second" power: -1 `
        # Corresponds to the JSON property `measurementValue`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseMeasurement]
        attr_accessor :measurement_value
      
        # List of ` predicate, ` object ` ` to be processed as a Nested Struct. Nested
        # Struct can be recursive. NestedStruct.property_value(i).value(j) may have
        # nested_struct field.
        # Corresponds to the JSON property `nestedStruct`
        # @return [Google::Apis::ContentwarehouseV1::FreebaseNestedStruct]
        attr_accessor :nested_struct
      
        # Provenance for this value.
        # Corresponds to the JSON property `provenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::StorageGraphBfgTripleProvenance>]
        attr_accessor :provenance
      
        # Similar to string_value/etc but contains raw bytes.
        # Corresponds to the JSON property `rawValue`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :raw_value
      
        # Present when value is text, enum,
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # 
        # Corresponds to the JSON property `subgraphId`
        # @return [Array<Fixnum>]
        attr_accessor :subgraph_id
      
        # The ISO-8601 timestamp corresponding to when this value was created (when it
        # was written to the Knowledge Graph). Deprecated in favor of timestamp_usec.
        # Corresponds to the JSON property `timestamp`
        # @return [String]
        attr_accessor :timestamp
      
        # The microsecond timestamp corresponding to when this value was created.
        # Corresponds to the JSON property `timestampUsec`
        # @return [Fixnum]
        attr_accessor :timestamp_usec
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @citation = args[:citation] if args.key?(:citation)
          @compound_value = args[:compound_value] if args.key?(:compound_value)
          @deletion_provenance = args[:deletion_provenance] if args.key?(:deletion_provenance)
          @display_lang = args[:display_lang] if args.key?(:display_lang)
          @display_value = args[:display_value] if args.key?(:display_value)
          @expected_proto = args[:expected_proto] if args.key?(:expected_proto)
          @float_value = args[:float_value] if args.key?(:float_value)
          @id_value = args[:id_value] if args.key?(:id_value)
          @index = args[:index] if args.key?(:index)
          @int_value = args[:int_value] if args.key?(:int_value)
          @lang = args[:lang] if args.key?(:lang)
          @lat_long_value = args[:lat_long_value] if args.key?(:lat_long_value)
          @measurement_value = args[:measurement_value] if args.key?(:measurement_value)
          @nested_struct = args[:nested_struct] if args.key?(:nested_struct)
          @provenance = args[:provenance] if args.key?(:provenance)
          @raw_value = args[:raw_value] if args.key?(:raw_value)
          @string_value = args[:string_value] if args.key?(:string_value)
          @subgraph_id = args[:subgraph_id] if args.key?(:subgraph_id)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @timestamp_usec = args[:timestamp_usec] if args.key?(:timestamp_usec)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Next id: 127
      class GDocumentBase
        include Google::Apis::Core::Hashable
      
        # unix secs from epoch
        # Corresponds to the JSON property `ContentExpiryTime`
        # @return [Fixnum]
        attr_accessor :content_expiry_time
      
        # Sometimes the URL displayed in search results should be different from what
        # gets indexed (e.g. in enterprise, content management systems). If this value
        # is not set, we default to the regular URL.
        # Corresponds to the JSON property `DisplayUrl`
        # @return [String]
        attr_accessor :display_url
      
        # 64-bit docid of the document (usually fingerprint of URL, but not always).
        # WARNING: This does NOT uniquely identify a document ANYMORE. For a unique
        # identifier across all documents in production please refer to the field 'id().
        # key()' listed above.
        # Corresponds to the JSON property `DocId`
        # @return [Fixnum]
        attr_accessor :doc_id
      
        # 
        # Corresponds to the JSON property `ExternalFeedMetadata`
        # @return [String]
        attr_accessor :external_feed_metadata
      
        # Enterprise-specific external metadata. See http://engdoc/eng/designdocs/
        # enterprise/enterprise_indexing_metadata.html
        # Corresponds to the JSON property `ExternalHttpMetadata`
        # @return [String]
        attr_accessor :external_http_metadata
      
        # Deprecated, do not use, this field is not populated since 2012.
        # Corresponds to the JSON property `FilterForSafeSearch`
        # @return [Fixnum]
        attr_accessor :filter_for_safe_search
      
        # IP addr in binary (allows for IPv6)
        # Corresponds to the JSON property `IPAddr`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ip_addr
      
        # 
        # Corresponds to the JSON property `NoArchiveReason`
        # @return [Fixnum]
        attr_accessor :no_archive_reason
      
        # 
        # Corresponds to the JSON property `NoFollowReason`
        # @return [Fixnum]
        attr_accessor :no_follow_reason
      
        # 
        # Corresponds to the JSON property `NoImageIndexReason`
        # @return [Fixnum]
        attr_accessor :no_image_index_reason
      
        # 
        # Corresponds to the JSON property `NoImageframeOverlayReason`
        # @return [Fixnum]
        attr_accessor :no_imageframe_overlay_reason
      
        # When these reasons are set to a non zero value, the document should not be
        # indexed, or show a snippet, or show a cache, etc. These reasons are bit maps
        # of indexing.converter.RobotsInfo.RobotedReasons enum values reflecting the
        # places where the restriction was found.
        # Corresponds to the JSON property `NoIndexReason`
        # @return [Fixnum]
        attr_accessor :no_index_reason
      
        # 
        # Corresponds to the JSON property `NoPreviewReason`
        # @return [Fixnum]
        attr_accessor :no_preview_reason
      
        # 
        # Corresponds to the JSON property `NoSnippetReason`
        # @return [Fixnum]
        attr_accessor :no_snippet_reason
      
        # 
        # Corresponds to the JSON property `NoTranslateReason`
        # @return [Fixnum]
        attr_accessor :no_translate_reason
      
        # Pagerank for doc (if known)
        # Corresponds to the JSON property `Pagerank`
        # @return [Fixnum]
        attr_accessor :pagerank
      
        # Pagerank-NearestSeeds is an alternative pagerank score for the doc.
        # Corresponds to the JSON property `PagerankNS`
        # @return [Fixnum]
        attr_accessor :pagerank_ns
      
        # is the webmirror representative id of the canonical url. Urls with the same
        # repid are considered as dups in webmirror. WARNING: use this field with
        # caution! The webmirror duprules change frequently, so this value only reflects
        # the duprules at the time when the canonical's docjoin is built.
        # Corresponds to the JSON property `Repid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :repid
      
        # Citation data for science articles.
        # Corresponds to the JSON property `ScienceMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ScienceCitation]
        attr_accessor :science_metadata
      
        # WARNING: the URL does NOT uniquely identify a document ANYMORE. For a unique
        # identifier across all documents in production please refer to the field 'id().
        # key()' listed above. Reason: foo.bar:/http and foo.bar:/http:SMARTPHONE share
        # the same URL, but the body of the two documents might differ because of
        # different crawl-context (desktop vs. smartphone in this example).
        # Corresponds to the JSON property `URL`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `URLAfterRedirects`
        # @return [String]
        attr_accessor :url_after_redirects
      
        # See webutil/urlencoding
        # Corresponds to the JSON property `URLEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        # Main content section
        # Corresponds to the JSON property `content`
        # @return [Google::Apis::ContentwarehouseV1::GDocumentBaseContent]
        attr_accessor :content
      
        # 
        # Corresponds to the JSON property `directory`
        # @return [Array<Google::Apis::ContentwarehouseV1::GDocumentBaseDirectory>]
        attr_accessor :directory
      
        # 96-bit fingerprint of the canonical url's webmirror equivalence class name as
        # of when this cdoc was exported.
        # Corresponds to the JSON property `ecnFp`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn_fp
      
        # The primary identifier of a production document is the document key given in
        # the ServingDocumentIdentifier, which is the same as the row-key in Alexandria,
        # and represents a URL and its crawling context. In your production code, please
        # always assume that the document key is the only way to uniquely identify a
        # document. ## Recommended way of reading: const string& doc_key = cdoc.doc().id(
        # ).key(); ## CHECK(!doc_key.empty()); More background information can be found
        # in google3/indexing/crawler_id/servingdocumentidentifier.proto The
        # ServingDocumentIdentifier uniquely identifies a document in serving and also
        # distinguishes between experimental vs. production documents. The SDI is also
        # used as an input for the union/muppet key generation in serving.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::IndexingCrawlerIdServingDocumentIdentifier]
        attr_accessor :id
      
        # Next tag: 23
        # Corresponds to the JSON property `localsearchDocInfo`
        # @return [Google::Apis::ContentwarehouseV1::LocalsearchDocInfo]
        attr_accessor :localsearch_doc_info
      
        # Ocean data in docserver results (whole documents)
        # Corresponds to the JSON property `oceanDocInfo`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocInfo]
        attr_accessor :ocean_doc_info
      
        # The original, unconverted document, typically PDF or Word. Copied from
        # OriginalDoc field of doclogs. Unlike "Content", this does not contain any HTTP
        # headers. The content may be compressed using the same method as "Content". In
        # practice it is only compressed in the Teragoogle index. It is never compressed
        # in docjoins because those are compressed at the sstable level. In doclogs
        # content will only be compressed if the Trawler fetchreply is also compressed--
        # which is currently never and unlikely to change for performance reasons.
        # Corresponds to the JSON property `originalcontent`
        # @return [Google::Apis::ContentwarehouseV1::GDocumentBaseOriginalContent]
        attr_accessor :originalcontent
      
        # The user agent name used to crawl the URL. See //crawler/engine/
        # webmirror_user_agents.h for the list of user-agents (e.g. crawler::
        # WebmirrorUserAgents::kGoogleBot). NOTE: This field is copied from the first
        # WEBMIRROR FetchReplyClientInfo in trawler_fetch_info column. We leave this
        # field unpopulated if no WEBMIRROR FecthReplyClientInfo is found. As the
        # submission of cl/51488336, Alexandria starts to populate this field. However,
        # docjoins from freshdocs (or any other source), won't have this field populated,
        # because we believe no one needs to read this field from freshdocs docjoins.
        # Corresponds to the JSON property `userAgentName`
        # @return [String]
        attr_accessor :user_agent_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_expiry_time = args[:content_expiry_time] if args.key?(:content_expiry_time)
          @display_url = args[:display_url] if args.key?(:display_url)
          @doc_id = args[:doc_id] if args.key?(:doc_id)
          @external_feed_metadata = args[:external_feed_metadata] if args.key?(:external_feed_metadata)
          @external_http_metadata = args[:external_http_metadata] if args.key?(:external_http_metadata)
          @filter_for_safe_search = args[:filter_for_safe_search] if args.key?(:filter_for_safe_search)
          @ip_addr = args[:ip_addr] if args.key?(:ip_addr)
          @no_archive_reason = args[:no_archive_reason] if args.key?(:no_archive_reason)
          @no_follow_reason = args[:no_follow_reason] if args.key?(:no_follow_reason)
          @no_image_index_reason = args[:no_image_index_reason] if args.key?(:no_image_index_reason)
          @no_imageframe_overlay_reason = args[:no_imageframe_overlay_reason] if args.key?(:no_imageframe_overlay_reason)
          @no_index_reason = args[:no_index_reason] if args.key?(:no_index_reason)
          @no_preview_reason = args[:no_preview_reason] if args.key?(:no_preview_reason)
          @no_snippet_reason = args[:no_snippet_reason] if args.key?(:no_snippet_reason)
          @no_translate_reason = args[:no_translate_reason] if args.key?(:no_translate_reason)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @pagerank_ns = args[:pagerank_ns] if args.key?(:pagerank_ns)
          @repid = args[:repid] if args.key?(:repid)
          @science_metadata = args[:science_metadata] if args.key?(:science_metadata)
          @url = args[:url] if args.key?(:url)
          @url_after_redirects = args[:url_after_redirects] if args.key?(:url_after_redirects)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
          @content = args[:content] if args.key?(:content)
          @directory = args[:directory] if args.key?(:directory)
          @ecn_fp = args[:ecn_fp] if args.key?(:ecn_fp)
          @id = args[:id] if args.key?(:id)
          @localsearch_doc_info = args[:localsearch_doc_info] if args.key?(:localsearch_doc_info)
          @ocean_doc_info = args[:ocean_doc_info] if args.key?(:ocean_doc_info)
          @originalcontent = args[:originalcontent] if args.key?(:originalcontent)
          @user_agent_name = args[:user_agent_name] if args.key?(:user_agent_name)
        end
      end
      
      # Main content section
      class GDocumentBaseContent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AuthMethod`
        # @return [Fixnum]
        attr_accessor :auth_method
      
        # The actual length of the content: If Representation is compressed, this equals
        # to Content.UncompressedLength; otherwise it is the length of the
        # representation string.
        # Corresponds to the JSON property `ContentLength`
        # @return [Fixnum]
        attr_accessor :content_length
      
        # See enum ContentType in webutil/http/content-type.proto.
        # Corresponds to the JSON property `ContentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # Seconds since Unix epoch.
        # Corresponds to the JSON property `CrawlTime`
        # @return [Fixnum]
        attr_accessor :crawl_time
      
        # See //depot/google3/i18n/encodings/public/encodings.h Encoding of
        # representation
        # Corresponds to the JSON property `Encoding`
        # @return [Fixnum]
        attr_accessor :encoding
      
        # Set to false if Representation does not contain HTTP headers.
        # Corresponds to the JSON property `HasHttpHeader`
        # @return [Boolean]
        attr_accessor :has_http_header
        alias_method :has_http_header?, :has_http_header
      
        # A Language enum value. See: go/language-enum Default is english
        # Corresponds to the JSON property `Language`
        # @return [Fixnum]
        attr_accessor :language
      
        # If OriginalEncoding is present, the body part of the Representation was
        # converted to UTF-8, Encoding was set to UTF8, and OriginalEncoding was set to
        # the original encoding before conversion. However, the HTTP headers part of the
        # content might not be valid UTF-8. -1=an invalid value
        # Corresponds to the JSON property `OriginalEncoding`
        # @return [Fixnum]
        attr_accessor :original_encoding
      
        # Possibly compressed for old documents. It is not compressed for docjoins
        # produced by Raffia after ~2012.
        # Corresponds to the JSON property `Representation`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :representation
      
        # Historically present if Representation is compressed.
        # Corresponds to the JSON property `UncompressedLength`
        # @return [Fixnum]
        attr_accessor :uncompressed_length
      
        # Whether the content was visual right-to-left, and if so, what type of visual
        # document it is. Must be one of the values in enum VisualType from google3/
        # repository/rtl/visualtype.h Default is NOT_VISUAL_DOCUMENT. See http://wiki/
        # Main/RtlLanguages for background.
        # Corresponds to the JSON property `VisualType`
        # @return [Fixnum]
        attr_accessor :visual_type
      
        # Crawled file size of the original document.
        # Corresponds to the JSON property `crawledFileSize`
        # @return [Fixnum]
        attr_accessor :crawled_file_size
      
        # GeometryAnnotations, encoded with GeometryUtil::DeltaEncode() to reduce disk
        # space usage. Use GeometryUtil::DeltaDecode() to decode this field.
        # Corresponds to the JSON property `encodedGeometryAnnotations`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded_geometry_annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @auth_method = args[:auth_method] if args.key?(:auth_method)
          @content_length = args[:content_length] if args.key?(:content_length)
          @content_type = args[:content_type] if args.key?(:content_type)
          @crawl_time = args[:crawl_time] if args.key?(:crawl_time)
          @encoding = args[:encoding] if args.key?(:encoding)
          @has_http_header = args[:has_http_header] if args.key?(:has_http_header)
          @language = args[:language] if args.key?(:language)
          @original_encoding = args[:original_encoding] if args.key?(:original_encoding)
          @representation = args[:representation] if args.key?(:representation)
          @uncompressed_length = args[:uncompressed_length] if args.key?(:uncompressed_length)
          @visual_type = args[:visual_type] if args.key?(:visual_type)
          @crawled_file_size = args[:crawled_file_size] if args.key?(:crawled_file_size)
          @encoded_geometry_annotations = args[:encoded_geometry_annotations] if args.key?(:encoded_geometry_annotations)
        end
      end
      
      # The Directory proto group holds snippet and title metadata which is made
      # available to the snippet code. The proto group was originally created for
      # metadata coming from the Google Web Directory (gwd) project. It has since come
      # to be used to hold metadata from gwd and other sources.
      class GDocumentBaseDirectory
        include Google::Apis::Core::Hashable
      
        # encoded in UTF8
        # Corresponds to the JSON property `Category`
        # @return [String]
        attr_accessor :category
      
        # encoded in UTF8
        # Corresponds to the JSON property `Description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `DescriptionScore`
        # @return [Float]
        attr_accessor :description_score
      
        # "gwd", etc.
        # Corresponds to the JSON property `Identifier`
        # @return [String]
        attr_accessor :identifier
      
        # go/language-enum
        # Corresponds to the JSON property `Language`
        # @return [Fixnum]
        attr_accessor :language
      
        # encoded in UTF8
        # Corresponds to the JSON property `Title`
        # @return [String]
        attr_accessor :title
      
        # Deprecated; do not use. There is no code populating these fields as of Oct
        # 2017.
        # Corresponds to the JSON property `TitleScore`
        # @return [Float]
        attr_accessor :title_score
      
        # 
        # Corresponds to the JSON property `URL`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @description = args[:description] if args.key?(:description)
          @description_score = args[:description_score] if args.key?(:description_score)
          @identifier = args[:identifier] if args.key?(:identifier)
          @language = args[:language] if args.key?(:language)
          @title = args[:title] if args.key?(:title)
          @title_score = args[:title_score] if args.key?(:title_score)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # The original, unconverted document, typically PDF or Word. Copied from
      # OriginalDoc field of doclogs. Unlike "Content", this does not contain any HTTP
      # headers. The content may be compressed using the same method as "Content". In
      # practice it is only compressed in the Teragoogle index. It is never compressed
      # in docjoins because those are compressed at the sstable level. In doclogs
      # content will only be compressed if the Trawler fetchreply is also compressed--
      # which is currently never and unlikely to change for performance reasons.
      class GDocumentBaseOriginalContent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Representation`
        # @return [String]
        attr_accessor :representation
      
        # present iff rep is compressed
        # Corresponds to the JSON property `UncompressedLength`
        # @return [Fixnum]
        attr_accessor :uncompressed_length
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @representation = args[:representation] if args.key?(:representation)
          @uncompressed_length = args[:uncompressed_length] if args.key?(:uncompressed_length)
        end
      end
      
      # The generic version of a snippet response
      class GenericSnippetResponse
        include Google::Apis::Core::Hashable
      
        # Per-doc debug information.
        # Corresponds to the JSON property `debugInfo`
        # @return [Array<String>]
        attr_accessor :debug_info
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Lines of the snippet HTML. Typically gws concatenates these and lets the
        # browser wrap. The values include trailing spaces, so inserting additional
        # spaces is not necessary. However, for very old browsers, gws may insert break
        # tags after each snippet line. This field is confusing and poorly named; "
        # snippet_line" would be better. In particular, note that this does not return
        # multiple snippets for a result. Nor are these fields the individual tidbits of
        # the snippet.
        # Corresponds to the JSON property `snippet`
        # @return [Array<String>]
        attr_accessor :snippet
      
        # The title HTML. It may contain tags to denote query term matches. It may be
        # already truncated and "..." is put instead (note that truncation does not
        # always happen at the very end of the title text). However the existence of "...
        # " does not guarantee that the snippet generation algorithm truncated it; e.g.
        # webmasters themselves can write "...".
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Per-document response for a www DocInfo request. Next field position: 55
        # Corresponds to the JSON property `wwwSnippetResponse`
        # @return [Google::Apis::ContentwarehouseV1::WwwSnippetResponse]
        attr_accessor :www_snippet_response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @info = args[:info] if args.key?(:info)
          @snippet = args[:snippet] if args.key?(:snippet)
          @title = args[:title] if args.key?(:title)
          @www_snippet_response = args[:www_snippet_response] if args.key?(:www_snippet_response)
        end
      end
      
      # Actions supported by Madden for a local entity.
      class GeoOndemandAssistantSupportedActions
        include Google::Apis::Core::Hashable
      
        # Whether this local entity allows guest checkout for reservations.
        # Corresponds to the JSON property `allowsGuestCheckout`
        # @return [Boolean]
        attr_accessor :allows_guest_checkout
        alias_method :allows_guest_checkout?, :allows_guest_checkout
      
        # Whether or not this local entity supports asynchronous restaurant reservations,
        # through the above restaurant_reservation_url.
        # Corresponds to the JSON property `isAsynchronousRestaurantReservation`
        # @return [Boolean]
        attr_accessor :is_asynchronous_restaurant_reservation
        alias_method :is_asynchronous_restaurant_reservation?, :is_asynchronous_restaurant_reservation
      
        # URL for the Madden restaurant reservation flow, e.g. for display in a WebView.
        # Not populated if restaurant reservations are not supported for the local
        # entity.
        # Corresponds to the JSON property `restaurantReservationUrl`
        # @return [String]
        attr_accessor :restaurant_reservation_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allows_guest_checkout = args[:allows_guest_checkout] if args.key?(:allows_guest_checkout)
          @is_asynchronous_restaurant_reservation = args[:is_asynchronous_restaurant_reservation] if args.key?(:is_asynchronous_restaurant_reservation)
          @restaurant_reservation_url = args[:restaurant_reservation_url] if args.key?(:restaurant_reservation_url)
        end
      end
      
      # This class holds information about a single access point. An access point
      # establishes a relationship between a feature (like a POI or building) and some
      # other feature. For example, consider a TYPE_LOCALITY feature like Seattle. An
      # access point might be the TYPE_AIRPORT feature for Seattle-Tacoma
      # International Airport. The airport feature defines the access point to gain
      # airplane-based access to Seattle. A feature like Seattle will typically have
      # multiple access points. You can get to Seattle using airplanes, various forms
      # of public transit, or by driving a car. Thus Seattle would have multiple
      # access points. You may be able to get to Seattle by flying into SeaTac, or you
      # might be able to fly into Boeing Field, or Paine Field in Everett. You could
      # drive in from the North/South using I-5, or you could drive in from the East
      # using I-90. Many access points are from the road network. Thus the access
      # point for some building at 123 Main Street would likely be a segment that
      # defines the 100-200 block of "Main Street". A feature at the corner of "
      # Hollywood" and "Vine" streets might have access points from both named streets.
      # Access points are an optional field. Data editors may ignore them when
      # creating features or editing other fields. In these cases, other quality teams
      # will synthesize and update them. Several fields are also optional, as they are
      # derivable from other fields. Access points to non-TYPE_SEGMENT features should
      # always have the following fields set: - feature_type - feature_id - point
      # Location and reference fields: BASIC vs DERIVABLE Access points to
      # TYPE_SEGMENT features must have all the following BASIC fields: - feature_type
      # (of the segment, e.g. TYPE_ROAD or TYPE_VIRTUAL_SEGMENT) - point_off_segment (
      # or point; see "fuzzy point" note below) - unsuitable_travel_mode (may be empty)
      # - level (indoor access points only) The following are DERIVABLE fields, which
      # should only be added if the supplier is confident about their accuracy: -
      # feature_id - point_on_segment - segment_position Editing clients are
      # encouraged to set all fields, but they may set only the BASIC fields, in which
      # case quality teams may use the BASIC fields to snap to an appropriate segment
      # and derive the remaining fields. Example: The segment is split, so that the
      # portion that the access point is on has a new feature ID. Quality teams notice
      # that the point_on_segment is no longer on the segment with feature_id, finds
      # the new nearest segment based on feature_type and existing point_on_segment,
      # and re-derives a new feature_id, point_on_segment, and segment_position,
      # keeping other fields consistent. Fuzzy point special case If the editor does
      # not have side-of-road information for access points or is otherwise unsure of
      # the precise placement of the access point, it may supply the point field (and
      # not point_off_segment) as basic data instead, in which case quality teams may
      # generate the point_off_segment. Identity Access points are considered
      # semantically equivalent if they have the same geometry, including derived
      # fields, and the same references to other features (feature_id,
      # level_feature_id). For the exact definition, see cs/symbol:geostore::
      # AreAccessPointsEquivalent. Field definitions
      class GeostoreAccessPointProto
        include Google::Apis::Core::Hashable
      
        # RESERVED
        # Corresponds to the JSON property `canEnter`
        # @return [Boolean]
        attr_accessor :can_enter
        alias_method :can_enter?, :can_enter
      
        # RESERVED
        # Corresponds to the JSON property `canExit`
        # @return [Boolean]
        attr_accessor :can_exit
        alias_method :can_exit?, :can_exit
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # The type of the feature. Required, to allow handling the access point
        # differently based on feature type. For access points to non-TYPE_SEGMENT
        # features, this cached type also makes things easier for clients that aren't
        # running a bucketing map-reduce. For access points to TYPE_SEGMENT features,
        # this is used to find to find the nearest segment of the given type.
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `levelFeatureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :level_feature_id
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # For access points to non-TYPE_SEGMENT features, the location of the access
        # point. For access points to TYPE_SEGMENT features, this can be supplied as a
        # fuzzy access point that is not guaranteed to be on the correct side of road.
        # It should not be used by end clients in case of TYPE_SEGMENT access points.
        # Corresponds to the JSON property `point`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point
      
        # If the access point is defined by a TYPE_SEGMENT feature, this is the location
        # of the access point displaced slightly to the correct side of the segment.
        # This offset is in a direction perpendicular to the direction of travel along
        # the segment. The actual offset distance is unspecified. It would typically be
        # relatively small (approximately 1 meter). You can subtract the "off segment"
        # point from the "on segment" point to get a vector of unknown length pointing
        # from "on segment" point to the "off segment" point. You can then scale that
        # vector to whatever length you want. Note that extending this displacement
        # vector a large distance (10s of meters) may result in a new point that is in
        # the middle of some other feature (park, street, intersection). This is the
        # preferred basic geometry field for incoming data from editing clients and
        # importers, if side-of-road is well-established.
        # Corresponds to the JSON property `pointOffSegment`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point_off_segment
      
        # If the access point is defined by a TYPE_SEGMENT feature, this is the point on
        # the centerline of the segment that is closest to the actual access point. May
        # be re-derived if necessary to maintain precise placement on segment.
        # Corresponds to the JSON property `pointOnSegment`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point_on_segment
      
        # LINT.ThenChange(//depot/google3/geostore/cleanup/callbacks/\
        # ID_DUPLICATE_ACCESS_POINT.cc)
        # Corresponds to the JSON property `priority`
        # @return [String]
        attr_accessor :priority
      
        # If the access point is defined by a TYPE_SEGMENT feature, this is the location
        # of the access point expressed as a fractional distance along the segment. The
        # value runs from 0 to 1 inclusive. May be re-derived if necessary to maintain
        # precise placement on segment.
        # Corresponds to the JSON property `segmentPosition`
        # @return [Float]
        attr_accessor :segment_position
      
        # This list represents the travel modes for which this access-point should be
        # avoided. If this list is empty, the access-point is suitable for any travel
        # mode. If all access points are unsuitable for the current travel mode, client
        # should revert to other heuristics (e.g. feature center). This is only used for
        # access points to TYPE_SEGMENT features; access points to non-TYPE_SEGMENT
        # features, e.g. TYPE_ESTABLISHMENT_POI features with gcid:transit_station
        # GConcepts are just identified by feature_type and feature_id.
        # Corresponds to the JSON property `unsuitableTravelMode`
        # @return [Array<String>]
        attr_accessor :unsuitable_travel_mode
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @can_enter = args[:can_enter] if args.key?(:can_enter)
          @can_exit = args[:can_exit] if args.key?(:can_exit)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @level_feature_id = args[:level_feature_id] if args.key?(:level_feature_id)
          @metadata = args[:metadata] if args.key?(:metadata)
          @point = args[:point] if args.key?(:point)
          @point_off_segment = args[:point_off_segment] if args.key?(:point_off_segment)
          @point_on_segment = args[:point_on_segment] if args.key?(:point_on_segment)
          @priority = args[:priority] if args.key?(:priority)
          @segment_position = args[:segment_position] if args.key?(:segment_position)
          @unsuitable_travel_mode = args[:unsuitable_travel_mode] if args.key?(:unsuitable_travel_mode)
        end
      end
      
      # This class represents a parsed field within an address. NOTE: if you add a
      # field to this proto, please update the AreAddressComponentsEquivalent()
      # function in google3/geostore/base/internal/addresscomponent.cc
      class GeostoreAddressComponentProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # For components of TYPE_FEATURE or TYPE_LANDMARK, this is the feature type (
        # TYPE_COUNTRY, TYPE_LOCALITY, TYPE_ESTABLISHMENT_POI etc.). Note that some
        # features may not actually exist in the geostore (e.g. a village that we've
        # never heard of), in which case the feature_id will be missing but the
        # feature_type is still specified. Please refer to
        # IsValidAddressComponentFeatureType() in google3/geostore/base/public/
        # addresscomponent.h for the definitive list of feature types allowed for the
        # type (either TYPE_FEATURE or TYPE_LANDMARK) of components.
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # The order of this address component relative to the ones that share the same
        # feature_type in the AddressProto. For now, the primary use of this index field
        # is to handle ordering issue of multiple occurrences of AddressComponentProto
        # with feature_type of TYPE_ROUTE (and subtypes), or TYPE_POLITICAL, where the
        # order of the address components matters as there are dependences. 0 is the
        # smallest valid index value, representing the most specific address component.
        # Index value of 1 represents a relatively less specific address component of
        # the same feature_type on which the 0-indexed address component depends.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # The parsed_name field contains one or more names of an address component. Its
        # actual contents depends on where in the Geo/Google stack you are reading a
        # feature: 1. When an address is initially parsed via a feed or other raw input
        # and structured as an AddressProto, parsed_name should contain the set of names
        # that corresponds to the (possibly normalized) raw text from the raw input. In
        # MapFacts, the address component may be linked to an actual feature via
        # feature_id. Any address formatting directly from MapFacts should follow links
        # to retrieve names when possible. The parsed_name contents may be formatted
        # directly if the address component is unlinked following the same rules as
        # selecting and formatting the name of a feature. The cached parsed_name is
        # regularly refreshed from the linked feature with the minimal set of names for
        # address components (usually just a single, preferred name, in the local
        # language). 2. In serving systems, the names of linked features may be
        # denormalized into the parsed_name field to facilitate quicker address
        # formatting or for simple data filtering (e.g. finding all geocodes in
        # California by name). If reading a feature from such a system, the parsed_name
        # field could contain multiple names in multiple languages that reflect a cached
        # copy of the names associated with the linked features. Formatting of such
        # names should follow the same rules as selecting and formatting the name of a
        # feature itself.
        # Corresponds to the JSON property `parsedName`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreNameProto>]
        attr_accessor :parsed_name
      
        # This class represents a range of numbers in an address. It is an optional
        # additional field in the 'AddressComponentProto' message. This structure can be
        # used to model both single addresses and address ranges. There are two primary
        # use-cases for address ranges: definitions and references. Ranges are being
        # defined when they are present on the addresses of segment features. Ranges are
        # being referenced when they are present on non-segment features. NOTE: If you
        # add fields in this proto, consider updating the AreAddressRangesEquivalent()
        # function in google3/geostore/base/internal/addressrange.cc
        # Corresponds to the JSON property `range`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAddressRangeProto]
        attr_accessor :range
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # Additional text to append before and/or after the parsed_name, when the
        # address is formatted. Multiple instance should represent translations.
        # Currently, this is only permitted on TYPE_LANDMARK components, and only one
        # instance is permitted.
        # Corresponds to the JSON property `textAffix`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTextAffixProto>]
        attr_accessor :text_affix
      
        # Every address component has a type. Most address components correspond to one
        # of the feature types defined in FeatureProto, so rather than defining a
        # separate category system here, instead we mark them as TYPE_FEATURE and store
        # the FeatureProto type in the feature_type() field. This is how we handle
        # countries, cities, streets, etc. However, there are a few types of address
        # components that do not have a corresponding feature type (e.g. PO boxes).
        # These components have their type defined here. An address component of
        # TYPE_STREET_NUMBER may correspond to a physical entity that defines a street
        # number, such as a geocoded address or a land parcel. In this case, the address
        # component may have a link to the corresponding feature. A good reference for
        # what types of address components are possible is the xAL standard, which is a
        # published XML schema: http://www.oasis-open.org/committees/ciq/download.shtml.
        # This standard is the basis of the PostalAddress protocol message.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @index = args[:index] if args.key?(:index)
          @parsed_name = args[:parsed_name] if args.key?(:parsed_name)
          @range = args[:range] if args.key?(:range)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @text_affix = args[:text_affix] if args.key?(:text_affix)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Represents the unparsed portion of an address with an associated language.
      class GeostoreAddressLinesProto
        include Google::Apis::Core::Hashable
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # We place extra restrictions on languages in addition to what the III library
        # requires. See http://go/geo-schema-reference/feature-properties/languages.md
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # These lines are in display order.
        # Corresponds to the JSON property `line`
        # @return [Array<String>]
        attr_accessor :line
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @line = args[:line] if args.key?(:line)
        end
      end
      
      # This class represents an address, partial address, or address range. It is
      # intended to be attached to features to identify their address(es). Some
      # important points about addresses: - The addresses in the Geo Schema do *not*
      # include a component for the name of the feature, i.e. they are not self-
      # referential. For example, the name of a feature might be "Zack's Pizza" and
      # its address would be "123 Main Street". Similarly, streets, cities, and
      # counties do not include themselves as part of their address. The address of "
      # Seattle" is "King County, Washington, USA". If want to construct an address
      # that *does* include the feature name, you can simply prepend it to the other
      # address components. - Lakes, mountains, and other natural features do not
      # normally have addresses. Countries also do not have addresses because they are
      # at the top of the political hierarchy. - Address components in the Geo Schema
      # are listed in a particular order, independent of the conventions used by the
      # country in which they occur. The basic order is "smallest to largest" starting
      # with street numbers and routes, then political features, and ending with
      # postal features. The exact rules are defined by the implementation of the
      # AddressComponentOrdering::IsLessThan() function. - Some types of address
      # components may occur more than once in an address. For example, a UK address
      # with a "dependent thoroughfare" would have two components of TYPE_ROUTE (i.e.
      # street names). These are listed in the order they are normally written.
      class GeostoreAddressProto
        include Google::Apis::Core::Hashable
      
        # The unparsed portion (lines) of the address. An address can have multiple
        # unparsed portions. Multiple unparsed portions sharing the same language should
        # be modeled as one address_lines instance having multiple lines. Historically,
        # we also supported uparsed portions in different languages, but we no longer do.
        # Consequently, only one value is allowed for this field despite the fact that
        # it is repeated. See go/address-lines-multi-language for information about why
        # we made this change. If any components are filled in, this is supplemental to (
        # i.e. disjoint from) them. Furthermore, this must be the most specific portion
        # of the address (except for the portion, if any, stored in the name field of
        # feature.proto). Unparsed lines are always formatted together in a block. Other
        # address components are never formatted between the address lines. This doesn't
        # imply that the address lines are always either the first or the last part of
        # the formatted output.
        # Corresponds to the JSON property `addressLines`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAddressLinesProto>]
        attr_accessor :address_lines
      
        # A list of parsed address components, e.g. the street, city, etc. An address
        # range is one type of component.
        # Corresponds to the JSON property `component`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAddressComponentProto>]
        attr_accessor :component
      
        # ** DEPRECATED ** This field is now deprecated (see b/33268032). If you want to
        # store cross street information as part of an address, use the address_lines
        # field.
        # Corresponds to the JSON property `crossStreet`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAddressComponentProto>]
        attr_accessor :cross_street
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # This class represents an address, partial address, or address range. It is
        # intended to be attached to features to identify their address(es). Some
        # important points about addresses: - The addresses in the Geo Schema do *not*
        # include a component for the name of the feature, i.e. they are not self-
        # referential. For example, the name of a feature might be "Zack's Pizza" and
        # its address would be "123 Main Street". Similarly, streets, cities, and
        # counties do not include themselves as part of their address. The address of "
        # Seattle" is "King County, Washington, USA". If want to construct an address
        # that *does* include the feature name, you can simply prepend it to the other
        # address components. - Lakes, mountains, and other natural features do not
        # normally have addresses. Countries also do not have addresses because they are
        # at the top of the political hierarchy. - Address components in the Geo Schema
        # are listed in a particular order, independent of the conventions used by the
        # country in which they occur. The basic order is "smallest to largest" starting
        # with street numbers and routes, then political features, and ending with
        # postal features. The exact rules are defined by the implementation of the
        # AddressComponentOrdering::IsLessThan() function. - Some types of address
        # components may occur more than once in an address. For example, a UK address
        # with a "dependent thoroughfare" would have two components of TYPE_ROUTE (i.e.
        # street names). These are listed in the order they are normally written.
        # Corresponds to the JSON property `partialDenormalization`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAddressProto]
        attr_accessor :partial_denormalization
      
        # The opaque ID of the address template that contains rules for structuring this
        # address. The id of the address template can be retrieved using google3/
        # geostore/address_templates/public/address_templates.h
        # Corresponds to the JSON property `templateId`
        # @return [String]
        attr_accessor :template_id
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address_lines = args[:address_lines] if args.key?(:address_lines)
          @component = args[:component] if args.key?(:component)
          @cross_street = args[:cross_street] if args.key?(:cross_street)
          @metadata = args[:metadata] if args.key?(:metadata)
          @partial_denormalization = args[:partial_denormalization] if args.key?(:partial_denormalization)
          @template_id = args[:template_id] if args.key?(:template_id)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
        end
      end
      
      # This class represents a range of numbers in an address. It is an optional
      # additional field in the 'AddressComponentProto' message. This structure can be
      # used to model both single addresses and address ranges. There are two primary
      # use-cases for address ranges: definitions and references. Ranges are being
      # defined when they are present on the addresses of segment features. Ranges are
      # being referenced when they are present on non-segment features. NOTE: If you
      # add fields in this proto, consider updating the AreAddressRangesEquivalent()
      # function in google3/geostore/base/internal/addressrange.cc
      class GeostoreAddressRangeProto
        include Google::Apis::Core::Hashable
      
        # Two or more address numbers. Each number represents an address that was
        # mentioned by the data provider.
        # Corresponds to the JSON property `number`
        # @return [Array<Fixnum>]
        attr_accessor :number
      
        # For address range definitions: Two or more interpolation parameter values. The
        # length of this array must match the length of the number array, and each
        # parameter number specifies the position of the corresponding address number.
        # Each value is an interpolation between 0.0 and 1.0 inclusive. The value is
        # proportional to the distance traveled along the segment's polyline starting at
        # its origin. The parameters must be provided in increasing order and the values
        # in the number array must be in strictly increasing or decreasing order. We
        # make an exception for singleton addresses, which are represented as two copies
        # of a (number, parameter) pair, for backwards compatibility. For address range
        # references: This array must be empty.
        # Corresponds to the JSON property `parameter`
        # @return [Array<Float>]
        attr_accessor :parameter
      
        # If specified, the prefix or suffix is applied to all numbers in the range. For
        # example, this can be used to indicate that addresses B1 through B99 are on one
        # side of the street, while A1 through A99 are on the other side of the street.
        # Corresponds to the JSON property `prefix`
        # @return [String]
        attr_accessor :prefix
      
        # If 'same_parity' is true, then all 'number' values must have the same parity (
        # even or odd), and this address range only includes addresses whose parity is
        # the same as the given 'number' values.
        # Corresponds to the JSON property `sameParity`
        # @return [Boolean]
        attr_accessor :same_parity
        alias_method :same_parity?, :same_parity
      
        # 
        # Corresponds to the JSON property `suffix`
        # @return [String]
        attr_accessor :suffix
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @number = args[:number] if args.key?(:number)
          @parameter = args[:parameter] if args.key?(:parameter)
          @prefix = args[:prefix] if args.key?(:prefix)
          @same_parity = args[:same_parity] if args.key?(:same_parity)
          @suffix = args[:suffix] if args.key?(:suffix)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
        end
      end
      
      # A feature’s geometry that is populated from the 3D Geometry Store. Please see
      # go/a3d-and-mapfacts for design details.
      class GeostoreAnchoredGeometryProto
        include Google::Apis::Core::Hashable
      
        # The ID to be used to fetch the feature’s geometry from the 3D Geometry Store.
        # Corresponds to the JSON property `geometryId`
        # @return [String]
        attr_accessor :geometry_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @geometry_id = args[:geometry_id] if args.key?(:geometry_id)
        end
      end
      
      # A container for speed limits that allows tagging with a correctness trust
      # level.
      class GeostoreAppliedSpeedLimitProto
        include Google::Apis::Core::Hashable
      
        # A speed limit, containing both the limit and the conditions in which it
        # applies.
        # Corresponds to the JSON property `speedLimit`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSpeedLimitProto]
        attr_accessor :speed_limit
      
        # The level of trust we have in this speed limit value.
        # Corresponds to the JSON property `trustLevel`
        # @return [String]
        attr_accessor :trust_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @speed_limit = args[:speed_limit] if args.key?(:speed_limit)
          @trust_level = args[:trust_level] if args.key?(:trust_level)
        end
      end
      
      # An AttachmentProto contains structured data of a client-specified type. An
      # attachment is uniquely identified by the combination of its attachment_id and
      # client_name_space fields.
      class GeostoreAttachmentsAttachmentProto
        include Google::Apis::Core::Hashable
      
        # attachment_id distinguishes messages of the same type_id associated with the
        # same feature. It can not be set to 0x0.
        # Corresponds to the JSON property `attachmentId`
        # @return [Fixnum]
        attr_accessor :attachment_id
      
        # This field specifies a namespace identifier that can be used to track the
        # sources of attachments in a human friendly format. Name spaces must be at most
        # 64 characters long and must be composed entirely of alphanumeric characters,
        # hyphens, and underscores. No other characters are allowed.
        # Corresponds to the JSON property `clientNameSpace`
        # @return [String]
        attr_accessor :client_name_space
      
        # comment is a human-readable string that is logged whenever this attachment is
        # processed by the framework.
        # Corresponds to the JSON property `comment`
        # @return [String]
        attr_accessor :comment
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `messages`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :messages
      
        # type_id determines the type of the actual attachment that should be set in the
        # messages MessageSet. It can not be set to 0x0.
        # Corresponds to the JSON property `typeId`
        # @return [Fixnum]
        attr_accessor :type_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attachment_id = args[:attachment_id] if args.key?(:attachment_id)
          @client_name_space = args[:client_name_space] if args.key?(:client_name_space)
          @comment = args[:comment] if args.key?(:comment)
          @messages = args[:messages] if args.key?(:messages)
          @type_id = args[:type_id] if args.key?(:type_id)
        end
      end
      
      # Used to represent the unique id of an attribute.
      class GeostoreAttributeIdProto
        include Google::Apis::Core::Hashable
      
        # The id of the attribute. Stored as a stripped format of the gcid (e.g. "foo"
        # instead of "gcid:att_foo").
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Set because it's required, but not really meaningful in geostore (always set
        # to "Geo").
        # Corresponds to the JSON property `providerId`
        # @return [String]
        attr_accessor :provider_id
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @provider_id = args[:provider_id] if args.key?(:provider_id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Protocol buffer for attaching attributes and values to instances. This is for
      # assigning a particular attribute and value to a repository item, not for
      # metadata. For protocol buffers that represents metadata about attributes and
      # values, see CanonicalAttribute in itemclass.proto and ValueSpace in valuespace.
      # proto.
      class GeostoreAttributeProto
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `applicationData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :application_data
      
        # 
        # Corresponds to the JSON property `attributeDisplay`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAttributeValueDisplayProto>]
        attr_accessor :attribute_display
      
        # 
        # Corresponds to the JSON property `booleanValue`
        # @return [Boolean]
        attr_accessor :boolean_value
        alias_method :boolean_value?, :boolean_value
      
        # Used to represent the unique id of an attribute.
        # Corresponds to the JSON property `canonicalAttributeId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAttributeIdProto]
        attr_accessor :canonical_attribute_id
      
        # 
        # Corresponds to the JSON property `doubleValue`
        # @return [Float]
        attr_accessor :double_value
      
        # For those attribute ids that expect their values to be taken from an
        # enumeration-style set of values, that value's gcid should be stored here, e.g.
        # "gcid:attval_yes".
        # Corresponds to the JSON property `enumIdValue`
        # @return [String]
        attr_accessor :enum_id_value
      
        # 
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # 
        # Corresponds to the JSON property `int64Value`
        # @return [Fixnum]
        attr_accessor :int64_value
      
        # 
        # Corresponds to the JSON property `integerValue`
        # @return [Fixnum]
        attr_accessor :integer_value
      
        # Used to represent the unique id of an attribute.
        # Corresponds to the JSON property `itemClassId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAttributeIdProto]
        attr_accessor :item_class_id
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `protoValue`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :proto_value
      
        # The attribute value falls into one of these fields, based on value_type:
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # 
        # Corresponds to the JSON property `uint32Value`
        # @return [Fixnum]
        attr_accessor :uint32_value
      
        # Used to store language-specific names of this attribute's value (e.g. a
        # translation into another language).
        # Corresponds to the JSON property `valueDisplay`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAttributeValueDisplayProto>]
        attr_accessor :value_display
      
        # Used to represent the unique id of an attribute.
        # Corresponds to the JSON property `valueSpaceId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAttributeIdProto]
        attr_accessor :value_space_id
      
        # 
        # Corresponds to the JSON property `valueType`
        # @return [String]
        attr_accessor :value_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_data = args[:application_data] if args.key?(:application_data)
          @attribute_display = args[:attribute_display] if args.key?(:attribute_display)
          @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
          @canonical_attribute_id = args[:canonical_attribute_id] if args.key?(:canonical_attribute_id)
          @double_value = args[:double_value] if args.key?(:double_value)
          @enum_id_value = args[:enum_id_value] if args.key?(:enum_id_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @int64_value = args[:int64_value] if args.key?(:int64_value)
          @integer_value = args[:integer_value] if args.key?(:integer_value)
          @item_class_id = args[:item_class_id] if args.key?(:item_class_id)
          @metadata = args[:metadata] if args.key?(:metadata)
          @proto_value = args[:proto_value] if args.key?(:proto_value)
          @string_value = args[:string_value] if args.key?(:string_value)
          @uint32_value = args[:uint32_value] if args.key?(:uint32_value)
          @value_display = args[:value_display] if args.key?(:value_display)
          @value_space_id = args[:value_space_id] if args.key?(:value_space_id)
          @value_type = args[:value_type] if args.key?(:value_type)
        end
      end
      
      # Used to help display language-specific names of attributes.
      class GeostoreAttributeValueDisplayProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `synonym`
        # @return [String]
        attr_accessor :synonym
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @synonym = args[:synonym] if args.key?(:synonym)
        end
      end
      
      # 
      class GeostoreBarrierLogicalMaterialProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `material`
        # @return [Array<String>]
        attr_accessor :material
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @material = args[:material] if args.key?(:material)
        end
      end
      
      # A BestLocaleProto holds information about the best-match locale for a feature.
      # Clients may use this information to determine the appropriate local name of a
      # feature.
      class GeostoreBestLocaleProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `locale`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :locale
      
        # The ID of the localization policy to apply when selecting a name for a feature.
        # This field should always be set. If feature_id is also defined, this field
        # should have the same localization policy ID as the referenced locale feature.
        # Localization policy IDs are arbitrary identifiers (up to some number of bytes;
        # see geostore/base/public/constants.h) that uniquely distinguish a set of
        # language-selection rules.
        # Corresponds to the JSON property `localizationPolicyId`
        # @return [String]
        attr_accessor :localization_policy_id
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
          @localization_policy_id = args[:localization_policy_id] if args.key?(:localization_policy_id)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # The reference to a BizBuilder listing. For details on BizBuilder see http://
      # g3doc/commerce/bizbuilder/backend/g3doc/index.md
      class GeostoreBizBuilderReferenceProto
        include Google::Apis::Core::Hashable
      
        # Listing id. Used in queries to BizBuilder backend for listing access.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A border represents a line of division between two features of the same type (
      # i.e. United States and Mexico, but not California and Mexico). Borders are
      # only used for features that tile an area. For example, country features have
      # borders with one another because they tile an area of land. Country features
      # do not have borders with province features because those two types of features
      # may intersect with each other. The geometry of a border will often be similar (
      # or derived from) the geometry of the two features that it separates. However,
      # it is useful to have borders represented by stand-alone features for map-
      # styling purposes. Ideally, the geometry in a border feature would be exactly
      # the same as the common edges of the polygonal geometry of the two features.
      # This may not always be true in practice. At some point in the future we would
      # like to build a network of borders for features that are supposed to tile with
      # each other. The network would be composed of different border types meeting at
      # endpoint intersections. In the process of building this network, we would
      # perform small geometry corrections to ensure that the borders align properly
      # at all zoom levels. Border features are intended primarily for map drawing,
      # and they would rarely be useful for geocoding. One exception would be for
      # famous borders like the "Mason Dixon Line" or the "Berlin Wall." The standard
      # feature properties have the following interpretations: name - Borders rarely
      # have names unless they notable in their own right (e.g. "Mason Dixon Line", "
      # Berlin Wall"). point - A border should not have point geometry. polyline - A
      # border should have a single polyline that represents the division between the
      # two features. polygon - A border should not have polygon geometry.
      class GeostoreBorderProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureIdLeft`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id_left
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureIdRight`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id_right
      
        # The logical borders which this border is a part of.
        # Corresponds to the JSON property `logicalBorder`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :logical_border
      
        # List of border status overrides. Due to legal reasons, we may be required to
        # display some borders differently on some domains for instance.
        # Corresponds to the JSON property `overrideStatus`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreOverrideBorderStatusProto>]
        attr_accessor :override_status
      
        # The border status identifies the legal status of the border line.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # The type of the features this border separates. Should always be a subtype of
        # TYPE_POLITICAL. NOTE: as of December 2019, we currently require this to be
        # equal to TYPE_COUNTRY or TYPE_ADMINISTRATIVE_AREA1. In the future, we may
        # support TYPE_BORDER for lower types of political features.
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id_left = args[:feature_id_left] if args.key?(:feature_id_left)
          @feature_id_right = args[:feature_id_right] if args.key?(:feature_id_right)
          @logical_border = args[:logical_border] if args.key?(:logical_border)
          @override_status = args[:override_status] if args.key?(:override_status)
          @status = args[:status] if args.key?(:status)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class GeostoreBoundingMarkerProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `boundingMarker`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :bounding_marker
      
        # A token that can be used to identify the version of the data about this
        # bounding marker.
        # Corresponds to the JSON property `boundingMarkerToken`
        # @return [String]
        attr_accessor :bounding_marker_token
      
        # Which part of the flowline does this association refer to? These should be
        # between 0 and 1. These are optionally set, but can be approximated
        # geometrically if they aren’t set. NOTE: These refer to the geometry of this
        # feature.
        # Corresponds to the JSON property `flowlineAdjacencyBeginFraction`
        # @return [Float]
        attr_accessor :flowline_adjacency_begin_fraction
      
        # 
        # Corresponds to the JSON property `flowlineAdjacencyEndFraction`
        # @return [Float]
        attr_accessor :flowline_adjacency_end_fraction
      
        # Which part of the marker track does this association refer to? These should be
        # between 0 and 1. These are optionally set, but can be approximated
        # geometrically if they aren’t set. NOTE: These refer to the geometry of the
        # marker feature.
        # Corresponds to the JSON property `markerAdjacencyBeginFraction`
        # @return [Float]
        attr_accessor :marker_adjacency_begin_fraction
      
        # 
        # Corresponds to the JSON property `markerAdjacencyEndFraction`
        # @return [Float]
        attr_accessor :marker_adjacency_end_fraction
      
        # Which side of the flowline does the marker occur on.
        # Corresponds to the JSON property `side`
        # @return [String]
        attr_accessor :side
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_marker = args[:bounding_marker] if args.key?(:bounding_marker)
          @bounding_marker_token = args[:bounding_marker_token] if args.key?(:bounding_marker_token)
          @flowline_adjacency_begin_fraction = args[:flowline_adjacency_begin_fraction] if args.key?(:flowline_adjacency_begin_fraction)
          @flowline_adjacency_end_fraction = args[:flowline_adjacency_end_fraction] if args.key?(:flowline_adjacency_end_fraction)
          @marker_adjacency_begin_fraction = args[:marker_adjacency_begin_fraction] if args.key?(:marker_adjacency_begin_fraction)
          @marker_adjacency_end_fraction = args[:marker_adjacency_end_fraction] if args.key?(:marker_adjacency_end_fraction)
          @side = args[:side] if args.key?(:side)
        end
      end
      
      # This protocol buffer holds the building-specific attributes for features of
      # type TYPE_COMPOUND_BUILDING.
      class GeostoreBuildingProto
        include Google::Apis::Core::Hashable
      
        # The height of the base of this building, in meters above ground-level, if
        # known.
        # Corresponds to the JSON property `baseHeightMetersAgl`
        # @return [Float]
        attr_accessor :base_height_meters_agl
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `defaultDisplayLevel`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :default_display_level
      
        # The number of floors above the base of the building, if known. For example a
        # regular 1-story building would set this to "1". Use a value of
        # GeostoreConstants::kDefaultHeightPerFloor when converting "floors" to "
        # height_meters".
        # Corresponds to the JSON property `floors`
        # @return [Fixnum]
        attr_accessor :floors
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `floorsMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :floors_metadata
      
        # The height of the building above its base, in meters, if known.
        # Corresponds to the JSON property `heightMeters`
        # @return [Float]
        attr_accessor :height_meters
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `heightMetersMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :height_meters_metadata
      
        # The levels in this building, in no particular order. These levels refer back
        # to the building via another strong reference (the LevelProto.building field).
        # Corresponds to the JSON property `level`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :level
      
        # "Structure" denotes a physical architecture of the building that is readily
        # visible. This attribute is useful in that rarer structures can make good
        # landmarks.
        # Corresponds to the JSON property `structure`
        # @return [String]
        attr_accessor :structure
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_height_meters_agl = args[:base_height_meters_agl] if args.key?(:base_height_meters_agl)
          @default_display_level = args[:default_display_level] if args.key?(:default_display_level)
          @floors = args[:floors] if args.key?(:floors)
          @floors_metadata = args[:floors_metadata] if args.key?(:floors_metadata)
          @height_meters = args[:height_meters] if args.key?(:height_meters)
          @height_meters_metadata = args[:height_meters_metadata] if args.key?(:height_meters_metadata)
          @level = args[:level] if args.key?(:level)
          @structure = args[:structure] if args.key?(:structure)
        end
      end
      
      # This holds data specific to business chain features.
      class GeostoreBusinessChainProto
        include Google::Apis::Core::Hashable
      
        # Canonical GConcepts describe the ideal state of the GConcepts of this business
        # chain's members.
        # Corresponds to the JSON property `canonicalGconcepts`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreCanonicalGConceptProto>]
        attr_accessor :canonical_gconcepts
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_gconcepts = args[:canonical_gconcepts] if args.key?(:canonical_gconcepts)
        end
      end
      
      # A BusinessHoursProto stores a weekly schedule of opening hours for a business (
      # represented as a BusinessHours message) together with other closely related
      # information that is Geo-specific.
      class GeostoreBusinessHoursProto
        include Google::Apis::Core::Hashable
      
        # We divide up a week into individual open intervals. If any are present then
        # they must be arranged in strictly increasing order, with non-empty spaces
        # between successive intervals, and all times between 0 and 604800, the number
        # of seconds in a week.
        # Corresponds to the JSON property `data`
        # @return [Google::Apis::ContentwarehouseV1::BusinessHours]
        attr_accessor :data
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Message containing calls to action specified by the business owner.
      class GeostoreCallToActionProto
        include Google::Apis::Core::Hashable
      
        # Required.
        # Corresponds to the JSON property `ctaType`
        # @return [String]
        attr_accessor :cta_type
      
        # A web location for a Feature. URLs should always be stored in repeated fields
        # because some objects (eg. transit schedules in Brussels) have different URLs
        # for different languages.
        # Corresponds to the JSON property `url`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreUrlProto]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cta_type = args[:cta_type] if args.key?(:cta_type)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # This proto represents a canonical gconcept of a business chain's members.
      class GeostoreCanonicalGConceptProto
        include Google::Apis::Core::Hashable
      
        # A GConceptInstanceProto contains a GConceptID (which is the unique identifier
        # of a GConcept, a category in the Geo Ontology).
        # Corresponds to the JSON property `gconcept`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreGConceptInstanceProto]
        attr_accessor :gconcept
      
        # Whether the gconcept must be on a member. This must be true for a primary
        # gconcept.
        # Corresponds to the JSON property `isRequired`
        # @return [Boolean]
        attr_accessor :is_required
        alias_method :is_required?, :is_required
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gconcept = args[:gconcept] if args.key?(:gconcept)
          @is_required = args[:is_required] if args.key?(:is_required)
        end
      end
      
      # This protocol buffer holds S2 cell covering for the feature. See util/geometry/
      # s2cell_union.h for more information on S2 cells. See geostore/base/public/
      # cellcovering.h for utility functions.
      class GeostoreCellCoveringProto
        include Google::Apis::Core::Hashable
      
        # Array of S2 cell ids that represent the covering. There is no preset limit on
        # how many cells can be used.
        # Corresponds to the JSON property `cellId`
        # @return [Array<Fixnum>]
        attr_accessor :cell_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cell_id = args[:cell_id] if args.key?(:cell_id)
        end
      end
      
      # Generic item proto. This is intended to have only certain aspects filled (e.g.
      # photo only, name + price). Valid combinations of properties are enforced by
      # linters.
      class GeostoreComposableItemProto
        include Google::Apis::Core::Hashable
      
        # Message containing calls to action specified by the business owner.
        # Corresponds to the JSON property `callToAction`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCallToActionProto]
        attr_accessor :call_to_action
      
        # 
        # Corresponds to the JSON property `jobMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreJobMetadata]
        attr_accessor :job_metadata
      
        # Any photos describing this item.
        # Corresponds to the JSON property `media`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreMediaItemProto>]
        attr_accessor :media
      
        # The repeated name_info field is for price list sections listed in multiple
        # languages. At least one name_info containing id must be specified. There
        # should be at most one name_info for any given language. When representing a
        # job item, there should be exactly one name_info specified.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        # Represents if an item is offered at a business. For TYPE_JOB, this represents
        # if this job is offered by the corresponding business
        # Corresponds to the JSON property `offered`
        # @return [String]
        attr_accessor :offered
      
        # This message represents a price range of an attribute. The meaning of the
        # price bounds is domain specific. But mainly they are soft bounds for a normal
        # usage. E.g. "restaurant prices" are subject to an higher level of "soft"
        # bounds than "museum admission price"
        # Corresponds to the JSON property `price`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceRangeProto]
        attr_accessor :price
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
          @job_metadata = args[:job_metadata] if args.key?(:job_metadata)
          @media = args[:media] if args.key?(:media)
          @name_info = args[:name_info] if args.key?(:name_info)
          @offered = args[:offered] if args.key?(:offered)
          @price = args[:price] if args.key?(:price)
        end
      end
      
      # A count value tagged with a comparison operator. This can be used for axle
      # count, trailer count, etc.
      class GeostoreCountComparisonProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `comparisonOperator`
        # @return [String]
        attr_accessor :comparison_operator
      
        # 
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @comparison_operator = args[:comparison_operator] if args.key?(:comparison_operator)
          @count = args[:count] if args.key?(:count)
        end
      end
      
      # Possible patterns of a crossing stripe (any element that denotes a point on a
      # segment or lane at which the vehicle must stop or yield). These include
      # crosswalks, stop, and yield lines.
      class GeostoreCrossingStripePatternProto
        include Google::Apis::Core::Hashable
      
        # Describes a single physical marker line.
        # Corresponds to the JSON property `borderLine`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePhysicalLineProto]
        attr_accessor :border_line
      
        # 
        # Corresponds to the JSON property `borderPattern`
        # @return [String]
        attr_accessor :border_pattern
      
        # Colors found on this crossing.
        # Corresponds to the JSON property `color`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePaintedElementLogicalColorProto>]
        attr_accessor :color
      
        # 
        # Corresponds to the JSON property `stripePattern`
        # @return [String]
        attr_accessor :stripe_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @border_line = args[:border_line] if args.key?(:border_line)
          @border_pattern = args[:border_pattern] if args.key?(:border_pattern)
          @color = args[:color] if args.key?(:color)
          @stripe_pattern = args[:stripe_pattern] if args.key?(:stripe_pattern)
        end
      end
      
      # Protocol buffer describing a curve that connects two externally specified
      # endpoints.
      class GeostoreCurveConnectionProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `bezierParams`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCurveConnectionProtoBezierParams]
        attr_accessor :bezier_params
      
        # 
        # Corresponds to the JSON property `circleParams`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCurveConnectionProtoCircleParams]
        attr_accessor :circle_params
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bezier_params = args[:bezier_params] if args.key?(:bezier_params)
          @circle_params = args[:circle_params] if args.key?(:circle_params)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class GeostoreCurveConnectionProtoBezierParams
        include Google::Apis::Core::Hashable
      
        # Internal Bezier handles. One can be used for a quadratic curve, two for cubic
        # Beziers.
        # Corresponds to the JSON property `controlPoint`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreCurveConnectionProtoBezierParamsControlPoint>]
        attr_accessor :control_point
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @control_point = args[:control_point] if args.key?(:control_point)
        end
      end
      
      # 
      class GeostoreCurveConnectionProtoBezierParamsControlPoint
        include Google::Apis::Core::Hashable
      
        # We use this parameterization to make curves change predictable when endpoints
        # move. Each point P is defined in terms of the straight edge [S, E] between the
        # start point of the curve S and its end point E. *P / / / S *------------* E
        # Counter-clockwise angle between vector SE and vector SP.
        # Corresponds to the JSON property `angleDegrees`
        # @return [Float]
        attr_accessor :angle_degrees
      
        # Distance(S, P) in units of Distance(S, E).
        # Corresponds to the JSON property `distanceMultiplier`
        # @return [Float]
        attr_accessor :distance_multiplier
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @angle_degrees = args[:angle_degrees] if args.key?(:angle_degrees)
          @distance_multiplier = args[:distance_multiplier] if args.key?(:distance_multiplier)
        end
      end
      
      # 
      class GeostoreCurveConnectionProtoCircleParams
        include Google::Apis::Core::Hashable
      
        # Arc radius. Must be greater than half-distance between two endpoints.
        # Corresponds to the JSON property `radius`
        # @return [Float]
        attr_accessor :radius
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @radius = args[:radius] if args.key?(:radius)
        end
      end
      
      # Every data source used to construct a data repository has an associated
      # feature that provides more information about it. The standard feature
      # properties have the following interpretations: bound - The bounds must
      # includes all features that refer to this data source, so that bucketing
      # MapReduce passes work correctly. name - The provider name associated with this
      # data source. It is expected to remain constant from release to release, and
      # between datasets. address - should be empty. point, polyline, polygon - should
      # be empty. source_info - should not be set. child - should be empty.
      class GeostoreDataSourceProto
        include Google::Apis::Core::Hashable
      
        # This is the URL of a website representing this DataSource as a whole. If this
        # DataSource feature is specific to a particular dataset or product, the page
        # may contain information relevant to that dataset or product or may be the main
        # page of the organization.
        # Corresponds to the JSON property `attributionUrl`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreUrlProto>]
        attr_accessor :attribution_url
      
        # A UTF8 string that will be inserted in copyright messages to refer to this
        # copyright owner, e.g. "Tele Atlas".
        # Corresponds to the JSON property `copyrightOwner`
        # @return [String]
        attr_accessor :copyright_owner
      
        # The copyright year of this data (which may be different than the year of the
        # release date), e.g. 2005.
        # Corresponds to the JSON property `copyrightYear`
        # @return [Fixnum]
        attr_accessor :copyright_year
      
        # A free-form description of this data source. Ideally the description should
        # include: - Where the data was obtained (URL, company name, individual, etc). -
        # Where to find detailed documentation. - A brief summary of the licensing terms.
        # - As much internal and external contact information as possible (e.g. who to
        # ask about licensing questions, interpreting the data, updating the data,
        # fixing bugs in the importer, etc).
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The build information of the importer binary used to generate this data source.
        # Corresponds to the JSON property `importerBuildInfo`
        # @return [String]
        attr_accessor :importer_build_info
      
        # The build target of the importer binary used to generate this data source.
        # Corresponds to the JSON property `importerBuildTarget`
        # @return [String]
        attr_accessor :importer_build_target
      
        # The Perforce client information of the importer binary used to generate this
        # data source.
        # Corresponds to the JSON property `importerClientInfo`
        # @return [String]
        attr_accessor :importer_client_info
      
        # If the importer was built as an MPM, the version number can be stored in this
        # field. As with build_info, this can be useful when tracking down issues that
        # may be due to the use of a particular binary.
        # Corresponds to the JSON property `importerMpmVersion`
        # @return [String]
        attr_accessor :importer_mpm_version
      
        # The timestamp of the importer binary used to generate this data source.
        # Corresponds to the JSON property `importerTimestamp`
        # @return [String]
        attr_accessor :importer_timestamp
      
        # The provider type of this data source.
        # Corresponds to the JSON property `provider`
        # @return [String]
        attr_accessor :provider
      
        # For every key that is used in raw_data from this source, there must be a
        # corresponding entry in raw_metadata that describes this key.
        # Corresponds to the JSON property `rawMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRawMetadataProto>]
        attr_accessor :raw_metadata
      
        # A release string that doesn't have to be a date. This is provided so that we
        # can preserve provider release strings that aren't based on dates. If you don't
        # set it, the release_date will get formatted into this field for debugging
        # purposes.
        # Corresponds to the JSON property `release`
        # @return [String]
        attr_accessor :release
      
        # The release date of this data.
        # Corresponds to the JSON property `releaseDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :release_date
      
        # A data provider defined string describing the source dataset from which the
        # features of this data source were generated. For example, the MultiNet "fra"
        # dataset produces features for both France and Monaco.
        # Corresponds to the JSON property `sourceDataset`
        # @return [String]
        attr_accessor :source_dataset
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribution_url = args[:attribution_url] if args.key?(:attribution_url)
          @copyright_owner = args[:copyright_owner] if args.key?(:copyright_owner)
          @copyright_year = args[:copyright_year] if args.key?(:copyright_year)
          @description = args[:description] if args.key?(:description)
          @importer_build_info = args[:importer_build_info] if args.key?(:importer_build_info)
          @importer_build_target = args[:importer_build_target] if args.key?(:importer_build_target)
          @importer_client_info = args[:importer_client_info] if args.key?(:importer_client_info)
          @importer_mpm_version = args[:importer_mpm_version] if args.key?(:importer_mpm_version)
          @importer_timestamp = args[:importer_timestamp] if args.key?(:importer_timestamp)
          @provider = args[:provider] if args.key?(:provider)
          @raw_metadata = args[:raw_metadata] if args.key?(:raw_metadata)
          @release = args[:release] if args.key?(:release)
          @release_date = args[:release_date] if args.key?(:release_date)
          @source_dataset = args[:source_dataset] if args.key?(:source_dataset)
        end
      end
      
      # 
      class GeostoreDateTimeProto
        include Google::Apis::Core::Hashable
      
        # This attribute describes the precision of the date and time. It would be
        # unusual for a data provider to provide a precision along with their date. It
        # is more likely that the precision of a date will be inferred from the date
        # format. For example "19th century" is likely to be correct to the century,
        # while "1800" is probably correct to the year. The precision should be
        # semantically interpreted as a cast, so a DateTimeProto object with a seconds
        # value corresponding to 2018-03-28 18:40:00 UTC and a precision of MONTH should
        # be interpreted as "March 2018". The enums above are only some of the possible
        # precision levels for dates and times. Clients may wish to add more precision
        # enums in the future. However, these enums must be ordered by decreasing
        # duration. Clients should be able to write date formatting code that looks like
        # this: if (datetime.precision() <= DateTimeProto::PRECISION_CENTURY) ` date =
        # FormatCenturyDate(proto.seconds()); ` else if (proto.precision() <= case
        # DateTimeProto::PRECISION_DECADE) ` date = FormatDecadeDate(proto.seconds()); `
        # else ` ... ` See geostore/base/public/datetime.h for date formatting utility
        # functions.
        # Corresponds to the JSON property `precision`
        # @return [String]
        attr_accessor :precision
      
        # Number of seconds since (or before) the UNIX epoch (January 1, 1970). This is
        # also the standard epoch for Java and Python time representations. If it is
        # important for this time be displayed correctly for different time zones,
        # convert the time to Coordinated Universal Time (UTC).
        # Corresponds to the JSON property `seconds`
        # @return [Float]
        attr_accessor :seconds
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @precision = args[:precision] if args.key?(:precision)
          @seconds = args[:seconds] if args.key?(:seconds)
        end
      end
      
      # A dimension value tagged with a comparison operator. This can be used for
      # height, width, or length.
      class GeostoreDimensionComparisonProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `comparisonOperator`
        # @return [String]
        attr_accessor :comparison_operator
      
        # A dimension with a numerical value and unit. This can be a height, width, or
        # length.
        # Corresponds to the JSON property `dimensionWithUnit`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDimensionProto]
        attr_accessor :dimension_with_unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @comparison_operator = args[:comparison_operator] if args.key?(:comparison_operator)
          @dimension_with_unit = args[:dimension_with_unit] if args.key?(:dimension_with_unit)
        end
      end
      
      # A dimension with a numerical value and unit. This can be a height, width, or
      # length.
      class GeostoreDimensionProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dimension`
        # @return [Float]
        attr_accessor :dimension
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dimension = args[:dimension] if args.key?(:dimension)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # This holds data specific to rendering a POI on a map. It's derived from data
      # already in MapFacts, e.g. containing features and the feature's point field.
      # If empty, this proto should be ignored for rendering. See go/maps-render-
      # alignment for motivation and more details.
      class GeostoreDisplayDataProto
        include Google::Apis::Core::Hashable
      
        # The location where this feature should be rendered.
        # Corresponds to the JSON property `displayLocation`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :display_location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_location = args[:display_location] if args.key?(:display_location)
        end
      end
      
      # This protocol buffer holds the doodle-specific attributes for features of type
      # TYPE_DOODLE.
      class GeostoreDoodleProto
        include Google::Apis::Core::Hashable
      
        # The type of this feature -- see comments above.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A single cost which will apply based on the duration of utilization. The cost
      # may apply once, or repeatedly on some interval, to account for the total
      # utilization. If the duration expressed by range_start_seconds and
      # range_end_seconds do not cover the entire duration of the utilization (i.e.
      # from 0 to some time greater than the total utilization time), this must be
      # combined with other DurationBasedRateProtos such that the entire duration of
      # the utilization is accounted for. See go/rate-schema for more details.
      class GeostoreDurationBasedRateProto
        include Google::Apis::Core::Hashable
      
        # If true, represents that the rate is free; i.e. the price is 0 in any currency.
        # If this is true, price must be empty.
        # Corresponds to the JSON property `isFree`
        # @return [Boolean]
        attr_accessor :is_free
        alias_method :is_free?, :is_free
      
        # The billable unit of the rate; i.e. after having utilized the service for
        # exactly periodicity_seconds, the total cost should increase by ‘price’. For
        # example, if the rate expresses a price per hour, then periodicity_seconds
        # should be set to 3600. If this is unset, then the rate does not vary based on
        # duration, and price represents a flat cost. May only be set if price is
        # nonempty.
        # Corresponds to the JSON property `periodicitySeconds`
        # @return [Fixnum]
        attr_accessor :periodicity_seconds
      
        # The total price, in each applicable currency, of utilizing the service for
        # periodicity_seconds, or for the entire duration expressed by
        # range_start_seconds and range_end_seconds if periodicity_seconds is 0. Each
        # entry should have an ID of /measurement_unit/money_value and consist of two
        # properties: one with an ID of /measurement_unit/money_value/amount and a float
        # value with the amount, and another with the ID /measurement_unit/money_value/
        # currency and an ID value with the MID of the proper currency. May only be set
        # if is_free is false.
        # Corresponds to the JSON property `price`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebaseTopic>]
        attr_accessor :price
      
        # Upper bound for durations to match, exclusive. Unset implies indefinite.
        # Corresponds to the JSON property `rangeEndSeconds`
        # @return [Fixnum]
        attr_accessor :range_end_seconds
      
        # Lower bound for durations to match, inclusive. Required; a value of 0
        # expresses that the price applies from the start of the utilization period.
        # Corresponds to the JSON property `rangeStartSeconds`
        # @return [Fixnum]
        attr_accessor :range_start_seconds
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_free = args[:is_free] if args.key?(:is_free)
          @periodicity_seconds = args[:periodicity_seconds] if args.key?(:periodicity_seconds)
          @price = args[:price] if args.key?(:price)
          @range_end_seconds = args[:range_end_seconds] if args.key?(:range_end_seconds)
          @range_start_seconds = args[:range_start_seconds] if args.key?(:range_start_seconds)
        end
      end
      
      # Represents raster digital elevation model data.
      class GeostoreElevationModelProto
        include Google::Apis::Core::Hashable
      
        # Defines the relative order in which terrain data should be rendered. Features
        # with higher blend_order should be blended on top of features with lower
        # blend_order. NOTE: this is backwards from the way BlendRank works in
        # Magrathean.
        # Corresponds to the JSON property `blendOrder`
        # @return [Fixnum]
        attr_accessor :blend_order
      
        # The zoom level at which this data is defined. Level 0 is world level data, and
        # each increase in zoom level corresponds to a factor of 2 increase in scale.
        # Corresponds to the JSON property `dataLevel`
        # @return [Fixnum]
        attr_accessor :data_level
      
        # The maximum (finest) level at which this terrain data has sufficient
        # resolution to be displayed.
        # Corresponds to the JSON property `dataMaxlevel`
        # @return [Fixnum]
        attr_accessor :data_maxlevel
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `elevationData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :elevation_data
      
        # If true, all of the data contained in this feature is available at the next
        # highest (more detailed) level. If this is true, partial_child_data_available
        # should also be true.
        # Corresponds to the JSON property `fullChildDataAvailable`
        # @return [Boolean]
        attr_accessor :full_child_data_available
        alias_method :full_child_data_available?, :full_child_data_available
      
        # If true, at least part of the data contained in this feature is available at
        # the next highest (more detailed) level.
        # Corresponds to the JSON property `partialChildDataAvailable`
        # @return [Boolean]
        attr_accessor :partial_child_data_available
        alias_method :partial_child_data_available?, :partial_child_data_available
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blend_order = args[:blend_order] if args.key?(:blend_order)
          @data_level = args[:data_level] if args.key?(:data_level)
          @data_maxlevel = args[:data_maxlevel] if args.key?(:data_maxlevel)
          @elevation_data = args[:elevation_data] if args.key?(:elevation_data)
          @full_child_data_available = args[:full_child_data_available] if args.key?(:full_child_data_available)
          @partial_child_data_available = args[:partial_child_data_available] if args.key?(:partial_child_data_available)
        end
      end
      
      # This protocol buffer holds elevation and related data.
      class GeostoreElevationProto
        include Google::Apis::Core::Hashable
      
        # The average elevation of the feature in meters above the local mean sea level.
        # Corresponds to the JSON property `averageElevationMeters`
        # @return [Float]
        attr_accessor :average_elevation_meters
      
        # This protocol buffer holds related data for features of type TYPE_PEAK and
        # TYPE_VOLCANO.
        # Corresponds to the JSON property `peak`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePeakProto]
        attr_accessor :peak
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_elevation_meters = args[:average_elevation_meters] if args.key?(:average_elevation_meters)
          @peak = args[:peak] if args.key?(:peak)
        end
      end
      
      # This protocol buffer holds entrance-specific attributes for features of type
      # TYPE_ENTRANCE.
      class GeostoreEntranceProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `allowance`
        # @return [String]
        attr_accessor :allowance
      
        # DEPRECATED. Please use enter_or_exit instead.
        # Corresponds to the JSON property `canEnter`
        # @return [Boolean]
        attr_accessor :can_enter
        alias_method :can_enter?, :can_enter
      
        # Whether the target can be entered through this entrance. Whether the target
        # can be exited through this entrance.
        # Corresponds to the JSON property `canExit`
        # @return [Boolean]
        attr_accessor :can_exit
        alias_method :can_exit?, :can_exit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowance = args[:allowance] if args.key?(:allowance)
          @can_enter = args[:can_enter] if args.key?(:can_enter)
          @can_exit = args[:can_exit] if args.key?(:can_exit)
        end
      end
      
      # Models a relationship between a feature and its entrance or exit.
      class GeostoreEntranceReferenceProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
        end
      end
      
      # This protocol buffer holds establishment-specific attributes for features of
      # type TYPE_ESTABLISHMENT.
      class GeostoreEstablishmentProto
        include Google::Apis::Core::Hashable
      
        # The reference to a BizBuilder listing. For details on BizBuilder see http://
        # g3doc/commerce/bizbuilder/backend/g3doc/index.md
        # Corresponds to the JSON property `bizbuilderReference`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBizBuilderReferenceProto]
        attr_accessor :bizbuilder_reference
      
        # Regular opening hours for the establishment (weekly schedule).
        # Corresponds to the JSON property `hours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :hours
      
        # Message to represent opening hours including regular weekly hours and a set of
        # exceptions.
        # Corresponds to the JSON property `openingHours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreOpeningHoursProto]
        attr_accessor :opening_hours
      
        # Pricing for products and services offered. Example: menus for restaurants.
        # Corresponds to the JSON property `priceInfo`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoProto]
        attr_accessor :price_info
      
        # This proto represents the geographic area served by an establishment. WARNING:
        # This proto is not meant to be used directly. Please use the provided libraries.
        # http://google3/geostore/base/public/service_area.h http://google3/java/com/
        # google/geostore/base/ServiceArea.java
        # Corresponds to the JSON property `serviceArea`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreServiceAreaProto]
        attr_accessor :service_area
      
        # Telephone number and related information.
        # Corresponds to the JSON property `telephone`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTelephoneProto>]
        attr_accessor :telephone
      
        # ** DEPRECATED ** This is deprecated in favor of the top-level (in FeatureProto)
        # set of GConcepts. The type of establishment -- see comments above.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bizbuilder_reference = args[:bizbuilder_reference] if args.key?(:bizbuilder_reference)
          @hours = args[:hours] if args.key?(:hours)
          @opening_hours = args[:opening_hours] if args.key?(:opening_hours)
          @price_info = args[:price_info] if args.key?(:price_info)
          @service_area = args[:service_area] if args.key?(:service_area)
          @telephone = args[:telephone] if args.key?(:telephone)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # An ExceptionalHoursProto holds information about exceptional (non-regular)
      # hours for a business, such as holiday hours.
      class GeostoreExceptionalHoursProto
        include Google::Apis::Core::Hashable
      
        # A BusinessHoursProto stores a weekly schedule of opening hours for a business (
        # represented as a BusinessHours message) together with other closely related
        # information that is Geo-specific.
        # Corresponds to the JSON property `hours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBusinessHoursProto]
        attr_accessor :hours
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # The dates for which this exception applies, expressed as a half open interval.
        # For example, an exception that applies for the entire month of December 2015
        # should have a range December 1, 2015 to January 1, 2016. Any regular hours
        # that start on days in this range are ignored and replaced by the exceptional
        # hours for that day. The TimeIntervalProto for the range must be a fully
        # specified, non-empty, and non-inverted range of dates. Concretely, the
        # requirements are: * the range must be a TYPE_RANGE interval * the interval may
        # not be inverted * the endpoints of the interval must specify a year, month,
        # and day * the day_type of each endpoint must be type DAY_OF_MONTH * the
        # endpoints may not specify hour, minute, second, week, or week_type * the begin
        # endpoint must predate the end endpoint
        # Corresponds to the JSON property `range`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeIntervalProto]
        attr_accessor :range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hours = args[:hours] if args.key?(:hours)
          @metadata = args[:metadata] if args.key?(:metadata)
          @range = args[:range] if args.key?(:range)
        end
      end
      
      # 
      class GeostoreExistenceProto
        include Google::Apis::Core::Hashable
      
        # Structured reason for the permanent closure (if any).
        # Corresponds to the JSON property `closeReason`
        # @return [String]
        attr_accessor :close_reason
      
        # Indicates whether the place is closed (permanently or temporarily), i.e., not
        # operational in the present, but was at in the past and/or will be in the
        # future. WARNING: New code should use Geo Schema's libraries instead,
        # specifically the OpeningStatus APIs, available in: * C++ (cs/f:google3/
        # geostore/base/public/feature.h%20function:ExistenceState) * Java (cs/f:google3/
        # java/com/google/geostore/base/Existence.java%20function:OpeningStatus) *
        # Python (cs/f:google3/geostore/base/public/python/feature.clif%
        # 20existence_state)
        # Corresponds to the JSON property `closed`
        # @return [Boolean]
        attr_accessor :closed
        alias_method :closed?, :closed
      
        # RESERVED
        # Corresponds to the JSON property `endAsOfDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :end_as_of_date
      
        # 
        # Corresponds to the JSON property `endDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :end_date
      
        # ** DEPRECATED ** This field is now deprecated (see b/22878252). Please use the
        # Geo Schema GetFeatureBirthTimestamp() API to extract the birth timestamp of a
        # feature. The timestamp in seconds since the UNIX epoch (January 1, 1970) when
        # this feature becomes live in the Geo repository. Different from start_date in
        # that this is the birth date of Google's representation of the place whereas
        # start_date is the birth date of the place in the physical world.
        # Corresponds to the JSON property `featureBirthTimestampSeconds`
        # @return [Fixnum]
        attr_accessor :feature_birth_timestamp_seconds
      
        # Indicates whether the feature is marked as removed in the Geo repository.
        # Removed features are still present in the Geo repository but are considered to
        # be in an inactive state (not valid for lint purposes, not retrievable except
        # explicitly by feature ID, etc.). NOTE: If you have access to a complete
        # FeatureProto, do NOT read this bit directly to find out whether a feature is
        # removed. Instead, rely on the IsFeatureRemoved() API, available in C++ (
        # geostore/base/public/feature.h) and Java (geostore/base/Feature.java).
        # Corresponds to the JSON property `removed`
        # @return [Boolean]
        attr_accessor :removed
        alias_method :removed?, :removed
      
        # Structured reason why the feature is marked as removed. Relevant only when
        # removed == true.
        # Corresponds to the JSON property `removedReason`
        # @return [String]
        attr_accessor :removed_reason
      
        # (Initial) opening and (permanent) closing dates of the establishment, such
        # that start_date is the first day open and end_date is the first day closed.
        # The only allowed precisions are PRECISION_DAY, PRECISION_MONTH, PRECISION_YEAR.
        # DateTimeProto.seconds should have the lowest legal value for the desired date/
        # time and precision. E.g. for PRECISION_MONTH, 2019-02-15 21:10:30 is not valid,
        # it should be 2019-02-01 00:00:00 instead. NOTE: The start_date and end_date
        # are stored in UTC but should be interpreted as being in the local timezone. So
        # clients should convert the DateTimeProto to local (civil) time using UTC+0,
        # and then treat the result as local to the feature.
        # Corresponds to the JSON property `startDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :start_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @close_reason = args[:close_reason] if args.key?(:close_reason)
          @closed = args[:closed] if args.key?(:closed)
          @end_as_of_date = args[:end_as_of_date] if args.key?(:end_as_of_date)
          @end_date = args[:end_date] if args.key?(:end_date)
          @feature_birth_timestamp_seconds = args[:feature_birth_timestamp_seconds] if args.key?(:feature_birth_timestamp_seconds)
          @removed = args[:removed] if args.key?(:removed)
          @removed_reason = args[:removed_reason] if args.key?(:removed_reason)
          @start_date = args[:start_date] if args.key?(:start_date)
        end
      end
      
      # Provenance information for sub-fields of this feature.
      class GeostoreFeatureFieldMetadataProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fieldProvenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureFieldMetadataProtoFieldProvenance>]
        attr_accessor :field_provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_provenance = args[:field_provenance] if args.key?(:field_provenance)
        end
      end
      
      # 
      class GeostoreFeatureFieldMetadataProtoFieldProvenance
        include Google::Apis::Core::Hashable
      
        # Represents all fields for which this SourceInfo is valid. NOTE: Field paths
        # are rooted at FeatureProto level.
        # Corresponds to the JSON property `fieldPath`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreStableFieldPathProto>]
        attr_accessor :field_path
      
        # This is a minimal version of SourceInfoProto.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreProvenanceProto]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_path = args[:field_path] if args.key?(:field_path)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # Metadata related to the history of a given feature in the Geo repository.
      class GeostoreFeatureHistoryMetadataProto
        include Google::Apis::Core::Hashable
      
        # The timestamp (in microseconds since the UNIX epoch) when this feature first
        # went live in the Geo repository. Note that this has no relation to the birth
        # data of that geographical entity in the real world.
        # Corresponds to the JSON property `featureBirthTimestampUs`
        # @return [Fixnum]
        attr_accessor :feature_birth_timestamp_us
      
        # The timestamp (in microseconds since the UNIX epoch) of the last modification
        # to the feature. Note this includes attachment modifications. The feature's
        # initial creation is also considered as a modification. This is useful for
        # those that consume features via both listening to notifications and reading
        # from repository snapshots. This timestamp can be used to decide whether a
        # feature in the snapshot was already seen in a more recent state through the
        # notifications.
        # Corresponds to the JSON property `lastModificationTimestampUs`
        # @return [Fixnum]
        attr_accessor :last_modification_timestamp_us
      
        # The timestamp (in microseconds since the UNIX epoch) of the deletion time of
        # the feature. If the feature is currently removed, this field gets populated
        # with the timestamp the feature first became removed after being live (or being
        # removed from beginning). This field won't be set if the feature is live.
        # Corresponds to the JSON property `removalTimestampUs`
        # @return [Fixnum]
        attr_accessor :removal_timestamp_us
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_birth_timestamp_us = args[:feature_birth_timestamp_us] if args.key?(:feature_birth_timestamp_us)
          @last_modification_timestamp_us = args[:last_modification_timestamp_us] if args.key?(:last_modification_timestamp_us)
          @removal_timestamp_us = args[:removal_timestamp_us] if args.key?(:removal_timestamp_us)
        end
      end
      
      # Feature ID forwardings. There are many different types of ID forwardings, some
      # of which are attached to live features, others to removed features. This
      # information is available in multiple forms (with different completeness
      # guarantees): (1) in RPC responses to read requests to the live Geo repository;
      # (2) on disk, as part of the metadata section of features found in the (
      # inactive) features snapshots; (3) on disk, as part of a separate
      # feature_id_forwardings side table.
      class GeostoreFeatureIdForwardingsProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `duplicateOf`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :duplicate_of
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `forwardedId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :forwarded_id
      
        # If other features have been marked as DUPLICATE of this feature, this is the
        # set of all such feature IDs. All feature IDs in this set should be for removed
        # (aka inactive) features. Note that in the context of historical read requests
        # against MapFacts (when ReadRequest.version_selection.timestamp is set), this
        # field won't be set.
        # Corresponds to the JSON property `inactiveDuplicate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :inactive_duplicate
      
        # A simple list of feature IDs.
        # Corresponds to the JSON property `replacedBy`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdListProto]
        attr_accessor :replaced_by
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `transitivelyDuplicateOf`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :transitively_duplicate_of
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duplicate_of = args[:duplicate_of] if args.key?(:duplicate_of)
          @forwarded_id = args[:forwarded_id] if args.key?(:forwarded_id)
          @inactive_duplicate = args[:inactive_duplicate] if args.key?(:inactive_duplicate)
          @replaced_by = args[:replaced_by] if args.key?(:replaced_by)
          @transitively_duplicate_of = args[:transitively_duplicate_of] if args.key?(:transitively_duplicate_of)
        end
      end
      
      # A simple list of feature IDs.
      class GeostoreFeatureIdListProto
        include Google::Apis::Core::Hashable
      
        # The list of feature IDs. While the exact semantics of these IDs are usage-
        # dependent, the list should never be empty or contain duplicates.
        # Corresponds to the JSON property `id`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A globally unique identifier associated with each feature. We use 128-bit
      # identifiers so that we have lots of bits available to distinguish between
      # features. The feature id currently consists of a 64-bit "cell id" that **
      # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
      # bit fingerprint of other identifying information. See more on each respective
      # field in its comments. Feature ids are first assigned when the data is created
      # in MapFacts. After initial creation of the feature, they are immutable. This
      # means that the only properties that you should rely on are that they are
      # unique, and that cell_ids often - but not always - preserve spatial locality.
      # The degree of locality varies as the feature undergoes geometry changes, and
      # should not in general be considered a firm guarantee of the location of any
      # particular feature. In fact, some locationless features have randomized cell
      # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
      # the id field of features will be globally unique. Using the fprint allows
      # consumers who don't need the spatial benefit of cell ids to uniquely identify
      # features in a 64-bit address space. This property is not guaranteed for other
      # sources of FeatureProtos.
      class GeostoreFeatureIdProto
        include Google::Apis::Core::Hashable
      
        # The S2CellId corresponding to the approximate location of this feature as of
        # when it was first created. This can be of variable accuracy, ranging from the
        # exact centroid of the feature at creation, a very large S2 Cell, or even being
        # completely randomized for locationless features. Cell ids have the nice
        # property that they follow a space-filling curve over the surface of the earth.
        # (See s2cellid.h for details.) WARNING: Clients should only use cell IDs to
        # perform spatial locality optimizations. There is no strict guarantee that the
        # cell ID of a feature is related to the current geometry of the feature in any
        # way.
        # Corresponds to the JSON property `cellId`
        # @return [Fixnum]
        attr_accessor :cell_id
      
        # A 64-bit fingerprint used to identify features. Most clients should rely on
        # MapFacts or OneRing to choose fingerprints. If creating new fprints, the
        # strategy should be chosen so that the chance of collision is remote or non-
        # existent, and the distribution should be reasonably uniform. For example, if
        # the source data assigns unique ids to features, then a fingerprint of the
        # provider name, version, and source id is sufficient.
        # Corresponds to the JSON property `fprint`
        # @return [Fixnum]
        attr_accessor :fprint
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cell_id = args[:cell_id] if args.key?(:cell_id)
          @fprint = args[:fprint] if args.key?(:fprint)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
        end
      end
      
      # General metadata related to a given feature in the Geo repository.
      class GeostoreFeatureMetadataProto
        include Google::Apis::Core::Hashable
      
        # This field indicates whether the feature is subject to bulk updates. Caution
        # must be exercised while editing such features since the changes made by the
        # edits will be overwritten by the bulk update (if the feature is bulk updated).
        # See go/mapfacts-abu for more information.
        # Corresponds to the JSON property `bulkUpdatable`
        # @return [String]
        attr_accessor :bulk_updatable
      
        # core_version_token is an opaque token representing the version of the core
        # fields of the feature. This field is not updated when attachments are changed.
        # Corresponds to the JSON property `coreVersionToken`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :core_version_token
      
        # Provenance information for sub-fields of this feature.
        # Corresponds to the JSON property `fieldMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureFieldMetadataProto]
        attr_accessor :field_metadata
      
        # Feature ID forwardings. There are many different types of ID forwardings, some
        # of which are attached to live features, others to removed features. This
        # information is available in multiple forms (with different completeness
        # guarantees): (1) in RPC responses to read requests to the live Geo repository;
        # (2) on disk, as part of the metadata section of features found in the (
        # inactive) features snapshots; (3) on disk, as part of a separate
        # feature_id_forwardings side table.
        # Corresponds to the JSON property `forwardings`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdForwardingsProto]
        attr_accessor :forwardings
      
        # Metadata related to the history of a given feature in the Geo repository.
        # Corresponds to the JSON property `history`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureHistoryMetadataProto]
        attr_accessor :history
      
        # version_token is an opaque token representing the version of this feature. It
        # can be used as a concurrency token when sending edits.
        # Corresponds to the JSON property `versionToken`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :version_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bulk_updatable = args[:bulk_updatable] if args.key?(:bulk_updatable)
          @core_version_token = args[:core_version_token] if args.key?(:core_version_token)
          @field_metadata = args[:field_metadata] if args.key?(:field_metadata)
          @forwardings = args[:forwardings] if args.key?(:forwardings)
          @history = args[:history] if args.key?(:history)
          @version_token = args[:version_token] if args.key?(:version_token)
        end
      end
      
      # Message to represent a "feature property" as an abstract construct. Most
      # feature properties are mapped one to one with the EditProto field types.
      # However in some cases the EditProto field type granularity is too coarse to
      # support use-cases that rely on feature properties (such as per-value rights
      # tracking). When that is the case, the feature property is augmented with a
      # secondary field.
      class GeostoreFeaturePropertyIdProto
        include Google::Apis::Core::Hashable
      
        # field_type == ATTACHMENT
        # Corresponds to the JSON property `attachmentTypeId`
        # @return [Fixnum]
        attr_accessor :attachment_type_id
      
        # field_type == FEATURE_ATTRIBUTE
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        # 
        # Corresponds to the JSON property `fieldType`
        # @return [String]
        attr_accessor :field_type
      
        # field_type == KNOWLEDGE_GRAPH_PROPERTY
        # Corresponds to the JSON property `kgPropertyId`
        # @return [String]
        attr_accessor :kg_property_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attachment_type_id = args[:attachment_type_id] if args.key?(:attachment_type_id)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
          @field_type = args[:field_type] if args.key?(:field_type)
          @kg_property_id = args[:kg_property_id] if args.key?(:kg_property_id)
        end
      end
      
      # Every entry in the GeoStore database is called a "feature". A feature is
      # represented as a discriminated union of all the different feature types, where
      # the actual feature type is specified by the "type" field. There are also
      # various fields that are meaningful for most or all feature types, such as
      # bounding regions and names. Every feature has a globally unique id that can be
      # used to refer to it from other features.
      class GeostoreFeatureProto
        include Google::Apis::Core::Hashable
      
        # Optional access point information. Access points hold detailed information
        # about routing endpoints. For example, the main Google office is at "1600
        # Amphitheatre Parkway". The feature representing that office has a polygon, a
        # center, and an address with components for the street number, route, locality,
        # etc. The access point information, on the other hand, identifies the specific
        # segment, the latitude/longitude of the driveway, and so forth.
        # Corresponds to the JSON property `accessPoint`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAccessPointProto>]
        attr_accessor :access_point
      
        # Address for this feature. A Geo Schema address is designed to model a mailing
        # address, so only features that have mailing addresses in the real world may
        # have addresses. Each feature should have only one address. If you want to
        # describe the geographic location of a feature which does not have a mailing
        # address with respect to other well-known features, some other schema
        # constructs should be used. Note that the field is defined as repeated though
        # features that use this field with its intended semantics are constrained to
        # have a single address even if they may have multiple mailing addresses in the
        # real world. The “single address” rule is enforced by lint. Current exceptions
        # to the single address rule and mailing address rule are described in the g3doc.
        # Bear note that the schema team is actively working on eliminating these
        # exceptions. http://go/geo-addresses Note the following conventions: -
        # Addresses follow the postal hierarchy, not the political hierarchy. Addresses
        # may have components that refer to political entities when those entities also
        # appear in the postal hierarchy. - As stated previously, but it bears repeating,
        # addresses on features are mailing addresses. In many cases the physical
        # address and the mailing address are the same but the address stored on a
        # feature represents the mailing address of the feature. An example of a non-
        # physical mailing address would be a PO Box. - These addresses are commonly
        # defined and verifiable by a governmental authority (e.g. the United States
        # Postal Service in the United States, Royal Mail in the United Kingdom,
        # Correios in Brazil, etc.) and should follow conventions and rules defined by
        # those authorities.
        # Corresponds to the JSON property `address`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAddressProto>]
        attr_accessor :address
      
        # A feature’s geometry that is populated from the 3D Geometry Store. Please see
        # go/a3d-and-mapfacts for design details.
        # Corresponds to the JSON property `anchoredGeometry`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAnchoredGeometryProto]
        attr_accessor :anchored_geometry
      
        # The collection of attachments for this feature. Documentation: http://go/geo-
        # attachments
        # Corresponds to the JSON property `attachment`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAttachmentsAttachmentProto>]
        attr_accessor :attachment
      
        # ** DEPRECATED ** A list of attributes that describe defined aspects of this
        # feature. An attribute must be a concrete, high quality, and editable piece of
        # information about a feature, and must be used on some general consumer facing
        # Google property. The data types used for attributes must be primitive types or
        # reusable in a generic manner.
        # Corresponds to the JSON property `attribute`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAttributeProto>]
        attr_accessor :attribute
      
        # A BestLocaleProto holds information about the best-match locale for a feature.
        # Clients may use this information to determine the appropriate local name of a
        # feature.
        # Corresponds to the JSON property `bestLocale`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBestLocaleProto]
        attr_accessor :best_locale
      
        # A border represents a line of division between two features of the same type (
        # i.e. United States and Mexico, but not California and Mexico). Borders are
        # only used for features that tile an area. For example, country features have
        # borders with one another because they tile an area of land. Country features
        # do not have borders with province features because those two types of features
        # may intersect with each other. The geometry of a border will often be similar (
        # or derived from) the geometry of the two features that it separates. However,
        # it is useful to have borders represented by stand-alone features for map-
        # styling purposes. Ideally, the geometry in a border feature would be exactly
        # the same as the common edges of the polygonal geometry of the two features.
        # This may not always be true in practice. At some point in the future we would
        # like to build a network of borders for features that are supposed to tile with
        # each other. The network would be composed of different border types meeting at
        # endpoint intersections. In the process of building this network, we would
        # perform small geometry corrections to ensure that the borders align properly
        # at all zoom levels. Border features are intended primarily for map drawing,
        # and they would rarely be useful for geocoding. One exception would be for
        # famous borders like the "Mason Dixon Line" or the "Berlin Wall." The standard
        # feature properties have the following interpretations: name - Borders rarely
        # have names unless they notable in their own right (e.g. "Mason Dixon Line", "
        # Berlin Wall"). point - A border should not have point geometry. polyline - A
        # border should have a single polyline that represents the division between the
        # two features. polygon - A border should not have polygon geometry.
        # Corresponds to the JSON property `border`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBorderProto]
        attr_accessor :border
      
        # A latitude-longitude rectangle, represented as two diagonally opposite points "
        # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
        # includes its boundary. The latitude bounds must be in the range -90 to 90
        # degrees inclusive, and the longitude bounds must be in the range -180 to 180
        # degrees inclusive. Various cases include: - If lo == hi, the rectangle
        # consists of a single point. - If lo.longitude > hi.longitude, the longitude
        # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
        # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
        # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
        # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
        # latitude range is empty.
        # Corresponds to the JSON property `bound`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRectProto]
        attr_accessor :bound
      
        # This protocol buffer holds the building-specific attributes for features of
        # type TYPE_COMPOUND_BUILDING.
        # Corresponds to the JSON property `building`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBuildingProto]
        attr_accessor :building
      
        # This holds data specific to business chain features.
        # Corresponds to the JSON property `businessChain`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBusinessChainProto]
        attr_accessor :business_chain
      
        # The conceptual center of the feature, used for routing. For cities, this would
        # be the center of the downtown, or maybe the location of city hall. For states
        # and countries it might be the capital city. Most feature types will not have a
        # conceptual center - by default, routing will use the centroid of the feature's
        # geometry. If you need a feature center point consider using
        # GetFeatureGeometryCenter() function from geostore/base/public/feature.h rather
        # than reading from this field directly.
        # Corresponds to the JSON property `center`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :center
      
        # Features can define themselves as a collection of other features. For example,
        # a route is a collection of road segments, and a feature for the "Great Lakes"
        # could be defined as lakes Superior, Michigan, Huron, Erie, and Ontario. It is
        # not recommended to design a multi level tree using the child field to build up
        # a feature because it requires fetching many features to see the details of the
        # feature. In practice this is used to model archipelago, route, transit (
        # agencies, lines, trips, departures), and river features. The geometry of a
        # feature is implicitly defined by its children, so if a feature has children
        # then it should not have any points, polylines, or polygons. In general, this
        # field should not be used to represent political or postal hierarchies. For
        # example, a county would not list its cities as children, because the county is
        # not defined in terms of its cities (it also contains unincorporated areas, etc.
        # ).
        # Corresponds to the JSON property `child`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :child
      
        # This protocol buffer holds S2 cell covering for the feature. See util/geometry/
        # s2cell_union.h for more information on S2 cells. See geostore/base/public/
        # cellcovering.h for utility functions.
        # Corresponds to the JSON property `covering`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCellCoveringProto]
        attr_accessor :covering
      
        # Every data source used to construct a data repository has an associated
        # feature that provides more information about it. The standard feature
        # properties have the following interpretations: bound - The bounds must
        # includes all features that refer to this data source, so that bucketing
        # MapReduce passes work correctly. name - The provider name associated with this
        # data source. It is expected to remain constant from release to release, and
        # between datasets. address - should be empty. point, polyline, polygon - should
        # be empty. source_info - should not be set. child - should be empty.
        # Corresponds to the JSON property `dataSource`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDataSourceProto]
        attr_accessor :data_source
      
        # This holds data specific to rendering a POI on a map. It's derived from data
        # already in MapFacts, e.g. containing features and the feature's point field.
        # If empty, this proto should be ignored for rendering. See go/maps-render-
        # alignment for motivation and more details.
        # Corresponds to the JSON property `displayData`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDisplayDataProto]
        attr_accessor :display_data
      
        # This protocol buffer holds the doodle-specific attributes for features of type
        # TYPE_DOODLE.
        # Corresponds to the JSON property `doodle`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDoodleProto]
        attr_accessor :doodle
      
        # This protocol buffer holds elevation and related data.
        # Corresponds to the JSON property `elevation`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreElevationProto]
        attr_accessor :elevation
      
        # Represents raster digital elevation model data.
        # Corresponds to the JSON property `elevationModel`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreElevationModelProto]
        attr_accessor :elevation_model
      
        # This protocol buffer holds entrance-specific attributes for features of type
        # TYPE_ENTRANCE.
        # Corresponds to the JSON property `entrance`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreEntranceProto]
        attr_accessor :entrance
      
        # This protocol buffer holds establishment-specific attributes for features of
        # type TYPE_ESTABLISHMENT.
        # Corresponds to the JSON property `establishment`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreEstablishmentProto]
        attr_accessor :establishment
      
        # A list of feature ids of polygon based restrictions that do not apply to this
        # feature. This may only include features of TYPE_REGULATED_AREA that also have
        # a feature.regulated_area.restriction field defined. Setting this field opts
        # the feature out of all restrictions set on that regulated area.
        # Corresponds to the JSON property `exemptRegulatedArea`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :exempt_regulated_area
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `futureGeometry`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :future_geometry
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `futureGeometryFor`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :future_geometry_for
      
        # If set, the feature's actual location can be assumed to be somewhere within a
        # circle of this radius, centered on the feature's location. More information on
        # this field at go/gpm-definition-update. NOTE: Only applicable to features with
        # 'point' geometry. Please contact geo-schema-team@ if you have non-point use
        # cases for which this field would be useful.
        # Corresponds to the JSON property `geometryPrecisionMeters`
        # @return [Float]
        attr_accessor :geometry_precision_meters
      
        # Geopolitical (unsimplified) polygons for a feature for different geopolitical
        # use cases. See go/unsimplified-poly.
        # Corresponds to the JSON property `geopoliticalGeometry`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreGeopoliticalGeometryProto]
        attr_accessor :geopolitical_geometry
      
        # ** DEPRECATED ** Features can have zero or more HTML texts associated with
        # them. These might be HTML balloons used by Google Earth, for example.
        # Corresponds to the JSON property `htmlText`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreHtmlTextProto>]
        attr_accessor :html_text
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :id
      
        # The inferred geometry of a feature contains all the features which, together,
        # define the geometry of a feature. This happens by: 1. Taking the union of all
        # polygons of features referenced in "includes_geometry_of". 2. Subtract the
        # geometries of all the features referenced in "excludes_geometry_of". See: go/
        # inferred-geometry for more information.
        # Corresponds to the JSON property `inferredGeometry`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreInferredGeometryProto]
        attr_accessor :inferred_geometry
      
        # This protocol buffer holds S2 cell covering for the feature. See util/geometry/
        # s2cell_union.h for more information on S2 cells. See geostore/base/public/
        # cellcovering.h for utility functions.
        # Corresponds to the JSON property `interiorCovering`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCellCoveringProto]
        attr_accessor :interior_covering
      
        # Main proto for all internal fields to be stored at the feature level.
        # Corresponds to the JSON property `internal`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreInternalFeatureProto]
        attr_accessor :internal
      
        # A TYPE_INTERSECTION feature represents a common endpoint of one or more
        # segments in a transportation network at which the segments are connected. An
        # intersection in the real world may be more complicated than that (e.g.,
        # comprise multiple segment endpoints or have extra attributes), which can be
        # modeled with an additional TYPE_INTERSECTION_GROUP feature, if needed (see
        # intersectiongroup.proto). The standard feature properties are interpreted as
        # follows: name - This should always be empty. Intersections that have a "
        # special" name (e.g. Reads Corner intersection, PEI, Canada) should point to a
        # separate TYPE_INTERSECTION_GROUP feature that captures it. Intersections which
        # are named according to their cross streets do not need this requirement, since
        # their name can be determined by looking at the routes associated with each
        # segment. address - This should always be empty. point - Specifies the center
        # of the intersection. This should be the last vertex of all the segments which
        # terminate at this intersection. polyline - This should always be empty.
        # polygon - This should always be empty. child - This should always be empty.
        # Corresponds to the JSON property `intersection`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreIntersectionProto]
        attr_accessor :intersection
      
        # Our TYPE_INTERSECTION features model the point where one or more segments
        # terminate. This is topological definition: it may not match what a typical
        # user would think of as an "intersection". Consider the intersections where
        # Hayes, Market, Larkin, and 9th Street meet near (37.77765, -122.41638) in San
        # Francisco. Most people would probably consider this a single feature, even
        # though we model it as four separate TYPE_INTERSECTION features. The
        # TYPE_INTERSECTION_GROUP is used to model the user's concept of a real-world
        # intersection, which also includes turn lanes or a whole roundabout (a logical
        # intersection). For the purposes of modeling turn restrictions and lane
        # connections, a smaller grouping is needed to model the "core" part of the
        # intersection where there are no lane markings. This is called a core or
        # artifact group. An intersection group must contain at least two intersections
        # or add some information (e.g. a name or a polygon) compared to the
        # intersection itself, or else must not exist. The standard feature properties
        # are interpreted as follows: name - Can be used to specify any "special" names
        # associated with this intersection (e.g. Reads Corner intersection, PEI, Canada)
        # . Intersections that are named according to their cross streets do not need to
        # specify this field, since this can be determined by looking at the routes
        # associated with each segment. address - This should always be empty. point -
        # Specifies the center of the intersection. This is basically the point where
        # the intersection name should be rendered. Can be omitted in favor of a polygon.
        # polyline - This should always be empty. polygon - Specifies the two-
        # dimensional extent of the intersection. This may substitute to the point field,
        # though having a center set is desirable in this case. child - This should
        # always be empty.
        # Corresponds to the JSON property `intersectionGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreIntersectionGroupProto]
        attr_accessor :intersection_group
      
        # Properties that apply to this feature whose schema is defined in the Knowledge
        # Graph schema (see https://hume.google.com/graph/schema). Not all properties
        # that exist in the KG schema can be asserted via this mechanism. The set of
        # properties that are allowed to be set on a feature depends on the feature's
        # GConcepts (and feature type). For instance, only gcid:country features may
        # have the /geo/type/country/president property (made up example, since that
        # property doesn't actually exist in the KG schema). GConcept hierarchy is taken
        # into account for deciding the set of allowed properties. Additionally, the
        # specific properties allowed are further constrained by the list specified at
        # go/kg-property-allowlist. NOTE: not all types of properties are allowed to
        # appear in the Geo Schema. For now, we limit ourselves to properties whose
        # value type is TYPE_BOOL, TYPE_COMPOUND, TYPE_DATETIME, TYPE_FLOAT, TYPE_ID,
        # TYPE_INT, TYPE_NESTED_STRUCT, TYPE_TEXT, or TYPE_URI. NOTE(b/35039936): We are
        # in the process of changing how a KG property with multiple values is stored in
        # this field. Currently, such a KG property is stored in a single instance of
        # the kg_property field. However, we will be changing this so that each value
        # will be stored in its own instance of kg_property. Any client that wants to
        # read from this field should be prepared to read data represented in either
        # format. See b/35039936 or the announcement at http://g/geo-schema-announce/
        # 7IXR3Fex8to/7yFyT5UoAwAJ for an example and more details. The mechanism to
        # assert that a KG property has no value is via the property_value_status field
        # below. freebase.PropertyValue.value_status is not allowed be set here for
        # consistency reason.
        # Corresponds to the JSON property `kgProperty`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebasePropertyValue>]
        attr_accessor :kg_property
      
        # The reference to an entity in the KnowledgeGraph. For details on the
        # KnowledgeGraph see http://goto/kg.
        # Corresponds to the JSON property `knowledgeGraphReference`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreKnowledgeGraphReferenceProto]
        attr_accessor :knowledge_graph_reference
      
        # This proto contains attributes relevant to physical lane markers.
        # Corresponds to the JSON property `laneMarker`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreLaneMarkerProto]
        attr_accessor :lane_marker
      
        # A feature used to represent a logical level, e.g. floor. A feature belonging
        # to a given level should point to the level feature using relation
        # RELATION_ON_LEVEL. The standard feature properties are interpreted as follows:
        # name - Levels should have names according to the following: * Short, elevator-
        # style names, such as "L" for "Lobby" and "2" for "Second floor", must be
        # included and must be tagged with FLAG_ABBREVIATED. There must be an
        # unambiguous "best" abbreviated name. * Longer names such as "Ticketing" or "
        # Upper Level" may be present when the level has a specific name. * Non-
        # abbreviated names should only be added if they are known to meaningfully
        # expand upon the abbreviated name. For example, the long name "Observation Deck
        # 2" for the abbreviated name "OD2" is a good additional name. In contrast, the
        # name "Level 2" for the abbreviated name "2" is not desired. address - This
        # should always be empty. point, polyline, polygon, center - These should never
        # be set (since we are representing a logical entity). preferred_viewport - This
        # should be the approximate extent of the level. child - This should always be
        # empty.
        # Corresponds to the JSON property `level`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreLevelProto]
        attr_accessor :level
      
        # A locale is a meta-feature that describes the geographic extent of
        # localization preferences such as the local language, and formatting
        # conventions for numbers, dates and monetary values. Multilingual areas may be
        # contained by multiple locales. We try to model locales fine-grained enough for
        # deciding which languages are typically used within a city. For example, while
        # French is an official language for all of Switzerland, we would prefer to have
        # Zurich contained by a separate (more fine-grained) Swiss-German locale
        # indicating that German, not French, is the predominantly spoken language in
        # this city. Note that language borders are frequently considered a political
        # question and often don't have clearly defined extents. For example, California
        # has a significant Spanish-speaking population, but Spanish is not an official
        # language of California.
        # Corresponds to the JSON property `locale`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreLocaleProto]
        attr_accessor :locale
      
        # A logical border is a grouping of border features, which together model a
        # divide between two regions. The borders within this grouping share common
        # attributes, such as the regions they divide, and may represent a conceptual
        # group of borders, of which may be wholly disputed, wholly undisputed, or a
        # mixture of disputed and undisputed. Note that any borders within this group
        # may be part of multiple logical borders. A logical border is required to have
        # a name describing what the grouping represents (e.g. "US - Mexico Border", "
        # Kosovo - Serbia Border (Disputed)").
        # Corresponds to the JSON property `logicalBorder`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreLogicalBorderProto]
        attr_accessor :logical_border
      
        # General metadata related to a given feature in the Geo repository.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureMetadataProto]
        attr_accessor :metadata
      
        # The name(s) of this feature. A feature may have different names in different
        # languages, colloquial or "vanity" names, etc.
        # Corresponds to the JSON property `name`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreNameProto>]
        attr_accessor :name
      
        # Information about a feature's operations, e.g. when the feature is temporarily
        # closed.
        # Corresponds to the JSON property `operations`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreOperationsProto]
        attr_accessor :operations
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `originalId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :original_id
      
        # 
        # Corresponds to the JSON property `parent`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :parent
      
        # Used to describe the parking facilities provided by or available to a feature.
        # Features of TYPE_ROAD or TYPE_COMPOUND can have a ParkingProto (with
        # parking_provider_feature unset) that describes the parking facilities provided
        # by that feature. Features of TYPE_COMPOUND or TYPE_ESTABLISHMENT_POI can have
        # a ParkingProto (with parking_provider_feature set) to indicate that the
        # feature has dedicated parking and provide details about it, and defer some
        # details of the parking facilities to the referent feature(s). ParkingProto is
        # maintained by the Harbor Pilot team (go/harbor-pilot). Detailed modeling
        # information is described at go/parking-schema.
        # Corresponds to the JSON property `parking`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreParkingProto]
        attr_accessor :parking
      
        # Defines the geometry of the feature. The geometry may be specified as an
        # arbitrary union of points, poses, polylines, tracks, and polygons. Points,
        # poses, polylines, and tracks are assumed to represent regions of unspecified
        # size or width rather than regions of zero area. Most features should have some
        # sort of geometry. Geometry may be synthesized if none is available (e.g.,
        # polygons for postal codes). The synthetic_geometry flag should be set in that
        # case. Point is currently enforced as a non-repeating field for all feature
        # types, though it is defined as repeating in case future modeling requires
        # multiple points. The number of allowed polylines, tracks, or polygons vary
        # based on feature type. A feature can have at most one pose (it is an optional
        # field).
        # Corresponds to the JSON property `point`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePointProto>]
        attr_accessor :point
      
        # This protocol buffer is included from feature.proto as an optional message.
        # Political features represent the different ways that people are divided into
        # geographical regions.
        # Corresponds to the JSON property `political`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePoliticalProto]
        attr_accessor :political
      
        # 
        # Corresponds to the JSON property `polygon`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePolygonProto>]
        attr_accessor :polygon
      
        # A general non-self-intersecting spherical polygon, consisting of one or more
        # loops defining multiple disconnected regions possibly with holes. All loops
        # should be oriented CCW around the region they define. This applies to the
        # exterior loop(s) as well as any holes. Within MapFacts (and underlying
        # infrastructure) the data fields may be replaced by a single shape_id; see
        # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
        # work with public functions in //geostore/base/public/polygon.h.
        # Corresponds to the JSON property `polygonForDisplay`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePolygonProto]
        attr_accessor :polygon_for_display
      
        # 
        # Corresponds to the JSON property `polyline`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePolyLineProto>]
        attr_accessor :polyline
      
        # A pose is an object's position in space, as well as its orientation. All
        # fields except lat and lng are optional. All fields are in the WGS-84 ellipsoid,
        # and rotations are right-hand rule (i.e. if the right hand thumb points along
        # a vector, curled fingers indicate positive rotation direction). An un-rotated
        # pose would be pointing due North, along the surface of the ellipsoid.
        # Rotations are applied in the order: yaw, pitch, roll. Note that the rotation
        # axes are rotated along with the model for each rotation step. WARNING: This
        # proto is not meant to be used directly. Please use the provided libraries: //
        # geostore/base/public/pose.h //java/com/google/geostore/base/Pose.java
        # Corresponds to the JSON property `pose`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePoseProto]
        attr_accessor :pose
      
        # A latitude-longitude rectangle, represented as two diagonally opposite points "
        # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
        # includes its boundary. The latitude bounds must be in the range -90 to 90
        # degrees inclusive, and the longitude bounds must be in the range -180 to 180
        # degrees inclusive. Various cases include: - If lo == hi, the rectangle
        # consists of a single point. - If lo.longitude > hi.longitude, the longitude
        # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
        # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
        # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
        # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
        # latitude range is empty.
        # Corresponds to the JSON property `preferredViewport`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRectProto]
        attr_accessor :preferred_viewport
      
        # The value status of properties on this feature. For example, this specifies
        # whether the feature is known to have no name (this is the value status of the '
        # FEATURE_NAME' property). Only property IDs which have no specific value are
        # allowed to have a value status. Note: not all field types will be supported,
        # please contact geo schema team if you want to enable this field for a field
        # type that is not currently supported.
        # Corresponds to the JSON property `propertyValueStatus`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePropertyValueStatusProto>]
        attr_accessor :property_value_status
      
        # WARNING: Please do NOT introduce new uses of this field; treat it as if it
        # were deprecated. For appropriate ranking contacts, see g3doc/company/teams/
        # gdeng/geo-schema-reference/home/feature-properties/rank.md. A floating-point
        # number between 0.0 and 1.0 indicating how "important" we think this feature is.
        # This can be used to decide which features to render on maps, and how to rank
        # results when the user does a search. The rank can depend on any number of
        # factors such as the number of references to this feature in web pages,
        # geographic size, population, number of referring geographic entities, "
        # priority" information encoded in the source data, etc.
        # Corresponds to the JSON property `rank`
        # @return [Float]
        attr_accessor :rank
      
        # This message is embedded within a FeatureProto. It has rank calculation
        # details such as available rank signals and rank signal mixer used to compute
        # final rank. For more details, see the Oyster Rank wiki page: http://wiki.corp.
        # google.com/twiki/bin/view/Main/OysterRank
        # Corresponds to the JSON property `rankDetails`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRankDetailsProto]
        attr_accessor :rank_details
      
        # The container for all GConceptInstances associated with a feature.
        # Corresponds to the JSON property `rawGconceptInstanceContainer`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreOntologyRawGConceptInstanceContainerProto]
        attr_accessor :raw_gconcept_instance_container
      
        # A collection of information that applies to a polygonal area.
        # Corresponds to the JSON property `regulatedArea`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRegulatedAreaProto]
        attr_accessor :regulated_area
      
        # For TYPE_COUNTRY or TYPE_ADMINISTRATIVE_AREA1 features, this field defines the
        # associated TYPE_BORDERs which reference this feature. The linked TYPE_BORDERs
        # must have the feature.border set, pointing to this feature. TYPE_COUNTRY or
        # TYPE_ADMINISTRATIVE_AREA1 features must have this field set for each
        # TYPE_BORDER referencing them.
        # Corresponds to the JSON property `relatedBorder`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :related_border
      
        # Logical relationship to other features that are entrances or exits to this
        # feature.
        # Corresponds to the JSON property `relatedEntrance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreEntranceReferenceProto>]
        attr_accessor :related_entrance
      
        # Geographic or logical relationships to other features. Importers don't need to
        # fill a geographic relationship in - it is handled by related feature
        # processing by a standalone pipeline. Adding "contained by" country relations
        # is however encouraged (and required for TYPE_ROUTE features). WARNING: Updates
        # to this field handled by standalone pipelines are NOT atomic with regard to
        # updates to the features being referenced; we do not guarantee that a given
        # MapFacts snapshot will be consistent between this field and the related
        # features.
        # Corresponds to the JSON property `relatedFeature`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRelationProto>]
        attr_accessor :related_feature
      
        # Terminal points associated with this feature. For instance, an airport
        # terminal may have specifically designated pickup and drop-off points.
        # Corresponds to the JSON property `relatedTerminalPoint`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :related_terminal_point
      
        # Contains time zones known to be associated with a feature. Most features are
        # associated with the single time zone that contains them. However, some larger
        # features (countries, continents, etc.) are associated with all of the time
        # zones they contain. Most features can have any number of related time zones,
        # but TYPE_SEGMENT and TYPE_ESTABLISHMENT_POI features can have at most 1.
        # Corresponds to the JSON property `relatedTimezone`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTimezoneProto>]
        attr_accessor :related_timezone
      
        # A restriction group represents common properties of a set of restrictions on
        # segments that are associated with the same underlying cause across a
        # geographic region. Every segment referenced by this restriction group should
        # have at least one restriction that refers backs to this restriction group. The
        # standard feature properties have the following interpretations: name - A name
        # that represents the name for this restriction group. kg_property - A reference
        # back to a KG event in case this restriction group belongs to an event in KG. /
        # geo/type/restriction_group/associated_event contains a mid to the associated
        # event.
        # Corresponds to the JSON property `restrictionGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRestrictionGroupProto]
        attr_accessor :restriction_group
      
        # A road monitor is a device that observes traffic for road violations like
        # speeding or running a red light. These are modeled within MapFacts so that
        # navigation services can warn users when they drive along road segments that
        # are monitored.
        # Corresponds to the JSON property `roadMonitor`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRoadMonitorProto]
        attr_accessor :road_monitor
      
        # A route is a collection of segments that forms a logical group - usually a
        # named road or highway. Segments can belong to more than one route, and the
        # segments of one route may be a subset of the segments of another route (e.g. I-
        # 5 N is a subset of I-5). Segments in the collection that define the route do
        # not need to constitute a single uninterrupted line, there can be disconnects.
        # The standard feature properties are interpreted as follows: name - Routes
        # should have one or more names. (While unnamed roads certainly exist in the
        # real world, we choose not to create route features for such roads. Instead,
        # the unnamed segments are merely not part of any route.) address - This should
        # always be empty. type - Specifies a particular route subtype, see feature.
        # proto. point - This should always be empty. polyline - This should always be
        # empty. polygon - This should always be empty. child - The pairs of segments
        # that belong to this route (a given route should always reference segments in
        # both travel directions).
        # Corresponds to the JSON property `route`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRouteProto]
        attr_accessor :route
      
        # This protocol buffer holds school district specific attributes for features of
        # TYPE_SCHOOL_DISTRICT.
        # Corresponds to the JSON property `schoolDistrict`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSchoolDistrictProto]
        attr_accessor :school_district
      
        # ---------------------------------------------------------------------------
        # WARNING - if you add new fields to SegmentProto (or to other protos used by
        # SegmentProto), you need to: - ensure that the ShortSegmentsMerger class (in
        # geostore/tools/internal/mr-mergesegments.cc) is aware of them, otherwise the
        # new fields will be discarded randomly. - consider whether they should be
        # cleared in the ClearFeature() function (in maps/render/process-high-priority-
        # roads.cc) if they are irrelevant for rendering high priority roads at far-out
        # zoom levels. - update the test cases that ensure these two packages know all
        # the SegmentProto fields in both mr-mergesegments_test.cc and maps/render/
        # process-high-priority-roads_test.cc or you will break the VersaTile build. ----
        # -----------------------------------------------------------------------
        # Corresponds to the JSON property `segment`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSegmentProto]
        attr_accessor :segment
      
        # A segment path describes a path through a short set of segments. The segment
        # path can be used for any purpose. At the moment, only TYPE_ROAD_SIGN features
        # can have associated segment paths: The segment path lists the segments that
        # refer to the sign. These are the segments for which the sign is applicable.
        # The sign's physical location is independent of the segments in the path.
        # Corresponds to the JSON property `segmentPath`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSegmentPathProto]
        attr_accessor :segment_path
      
        # A RoadSignProto holds the details of a road sign. Currently this is simply a
        # list of the items that appear on the sign and their relative position.
        # Corresponds to the JSON property `sign`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRoadSignProto]
        attr_accessor :sign
      
        # This protocol buffer holds attributes for features of TYPE_SKI_BOUNDARY.
        # Corresponds to the JSON property `skiBoundary`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSkiBoundaryProto]
        attr_accessor :ski_boundary
      
        # This protocol buffer holds attributes for features of TYPE_SKI_LIFT.
        # Corresponds to the JSON property `skiLift`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSkiLiftProto]
        attr_accessor :ski_lift
      
        # This protocol buffer holds attributes for features of TYPE_SKI_TRAIL.
        # Corresponds to the JSON property `skiTrail`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSkiTrailProto]
        attr_accessor :ski_trail
      
        # MapFacts GAIA ID assigned to this feature. These values are virtual GAIA IDs
        # from MapFacts, and as such are not stored in Focus.
        # Corresponds to the JSON property `socialReference`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSocialReferenceProto]
        attr_accessor :social_reference
      
        # A list of the data sources that were used to construct this feature, together
        # with optional "raw data" in the provider's format. Raw data should not be used
        # by production clients but may be useful for exploring data that is not
        # currently converted to a canonical form.
        # Corresponds to the JSON property `sourceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreSourceInfoProto>]
        attr_accessor :source_info
      
        # All features can have "existence" information associated with them.
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreExistenceProto]
        attr_accessor :status
      
        # Represents information about the store front geoemtry. Only
        # TYPE_ESTABLISHMENT_POI should have this field set.
        # Corresponds to the JSON property `storefrontGeometry`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAnchoredGeometryProto>]
        attr_accessor :storefront_geometry
      
        # We prefer features that have geometry over those that do not. In some cases we
        # synthesize geometry (e.g., polygons for postal codes). This flag is set to
        # indicate features that have such synthetic geometry.
        # Corresponds to the JSON property `syntheticGeometry`
        # @return [Boolean]
        attr_accessor :synthetic_geometry
        alias_method :synthetic_geometry?, :synthetic_geometry
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # Captures full model representing the feature's 3D geometry. Should only be
        # found on TYPE_COMPOUND_BUILDING features for now, but not part of the
        # BuildingProto extension for possible future extensions.
        # Corresponds to the JSON property `threeDimModel`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreThreeDimensionalModelProto]
        attr_accessor :three_dim_model
      
        # A collection of information that applies to a toll cluster.
        # Corresponds to the JSON property `tollCluster`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTollClusterProto]
        attr_accessor :toll_cluster
      
        # Defines the geometry of a feature as a sequence of 6D poses, including lat,
        # lng, altitude, roll, pitch, and yaw. Only lat and lng are typically required.
        # Each track has an index so that they can be viewed in a stable order.
        # Corresponds to the JSON property `track`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTrackProto>]
        attr_accessor :track
      
        # A transit line is a named set of transit trips that are advertised to
        # passengers under a common name, and a number of attributes that are true for
        # all those trips. There is no requirement for each trip to travel through the
        # same list of stops or use the same legs, so a line can contain trips in
        # opposite directions or with variations in the sequence of stops. See go/
        # oysterpedia for an overview of the transit feature types. The standard feature
        # properties are interpreted as follows: name - The names of this line,
        # including both long and short names, if available. Short names like "10" or "
        # Blue" should carry the FLAG_ABBREVIATED, long names like "Dublin/Pleasanton
        # line" should not. The preferred name (one per language) for displaying the
        # line on its own (e.g., as a search result for the line) should carry the
        # FLAG_PREFERRED. website - The official web page describing this line. Repeated
        # if multilingual. Line features have no geometry (neither points nor polylines
        # nor polygons). Within Transit Oyster, geometry can be found in legs.
        # Additional data only in Transit Oyster: child - The legs of this line, in no
        # particular order. source_info - Specifies the GTFS routes that match this
        # feature. Each is given as a PROVIDER_GOOGLE_TRANSIT source_info where dataset
        # is the feed name and cookie is the route_id.
        # Corresponds to the JSON property `transitLine`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTransitLineProto]
        attr_accessor :transit_line
      
        # A line variant is a specific instantiation of a line concept, denoted by the
        # ordered set of stops and collection of segments that it traverses. Line
        # variants are modeled as TYPE_ROUTE features with gcid:transit_line_variant.
        # This proto stores line-variant-specific information that is not generally
        # applicable to all routes. Schema Design Doc: go/transit-line-concepts-and-
        # variants
        # Corresponds to the JSON property `transitLineVariant`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTransitLineVariantProto]
        attr_accessor :transit_line_variant
      
        # Encapsulates information related to an individual transit station.
        # Corresponds to the JSON property `transitStation`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTransitStationProto]
        attr_accessor :transit_station
      
        # The type of this feature -- see comments above.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # A proto representing a vertical ordering of a feature. NOTE: This shouldn’t be
        # used if a more specific field can be used instead. E.g., for TYPE_SEGMENT
        # features grade_level field should be preferred. For indoor features
        # RELATION_ON_LEVEL should be preferred. See go/aboutgrades for comparison of
        # various types of levels available.
        # Corresponds to the JSON property `verticalOrdering`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreVerticalOrderingProto]
        attr_accessor :vertical_ordering
      
        # A general non-self-intersecting spherical polygon, consisting of one or more
        # loops defining multiple disconnected regions possibly with holes. All loops
        # should be oriented CCW around the region they define. This applies to the
        # exterior loop(s) as well as any holes. Within MapFacts (and underlying
        # infrastructure) the data fields may be replaced by a single shape_id; see
        # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
        # work with public functions in //geostore/base/public/polygon.h.
        # Corresponds to the JSON property `waterRemovedPolygon`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePolygonProto]
        attr_accessor :water_removed_polygon
      
        # The official website of this feature. Stored as a repeated field to allow for
        # multilingual official websites (see comments in url.proto).
        # Corresponds to the JSON property `website`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreUrlProto>]
        attr_accessor :website
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_point = args[:access_point] if args.key?(:access_point)
          @address = args[:address] if args.key?(:address)
          @anchored_geometry = args[:anchored_geometry] if args.key?(:anchored_geometry)
          @attachment = args[:attachment] if args.key?(:attachment)
          @attribute = args[:attribute] if args.key?(:attribute)
          @best_locale = args[:best_locale] if args.key?(:best_locale)
          @border = args[:border] if args.key?(:border)
          @bound = args[:bound] if args.key?(:bound)
          @building = args[:building] if args.key?(:building)
          @business_chain = args[:business_chain] if args.key?(:business_chain)
          @center = args[:center] if args.key?(:center)
          @child = args[:child] if args.key?(:child)
          @covering = args[:covering] if args.key?(:covering)
          @data_source = args[:data_source] if args.key?(:data_source)
          @display_data = args[:display_data] if args.key?(:display_data)
          @doodle = args[:doodle] if args.key?(:doodle)
          @elevation = args[:elevation] if args.key?(:elevation)
          @elevation_model = args[:elevation_model] if args.key?(:elevation_model)
          @entrance = args[:entrance] if args.key?(:entrance)
          @establishment = args[:establishment] if args.key?(:establishment)
          @exempt_regulated_area = args[:exempt_regulated_area] if args.key?(:exempt_regulated_area)
          @future_geometry = args[:future_geometry] if args.key?(:future_geometry)
          @future_geometry_for = args[:future_geometry_for] if args.key?(:future_geometry_for)
          @geometry_precision_meters = args[:geometry_precision_meters] if args.key?(:geometry_precision_meters)
          @geopolitical_geometry = args[:geopolitical_geometry] if args.key?(:geopolitical_geometry)
          @html_text = args[:html_text] if args.key?(:html_text)
          @id = args[:id] if args.key?(:id)
          @inferred_geometry = args[:inferred_geometry] if args.key?(:inferred_geometry)
          @interior_covering = args[:interior_covering] if args.key?(:interior_covering)
          @internal = args[:internal] if args.key?(:internal)
          @intersection = args[:intersection] if args.key?(:intersection)
          @intersection_group = args[:intersection_group] if args.key?(:intersection_group)
          @kg_property = args[:kg_property] if args.key?(:kg_property)
          @knowledge_graph_reference = args[:knowledge_graph_reference] if args.key?(:knowledge_graph_reference)
          @lane_marker = args[:lane_marker] if args.key?(:lane_marker)
          @level = args[:level] if args.key?(:level)
          @locale = args[:locale] if args.key?(:locale)
          @logical_border = args[:logical_border] if args.key?(:logical_border)
          @metadata = args[:metadata] if args.key?(:metadata)
          @name = args[:name] if args.key?(:name)
          @operations = args[:operations] if args.key?(:operations)
          @original_id = args[:original_id] if args.key?(:original_id)
          @parent = args[:parent] if args.key?(:parent)
          @parking = args[:parking] if args.key?(:parking)
          @point = args[:point] if args.key?(:point)
          @political = args[:political] if args.key?(:political)
          @polygon = args[:polygon] if args.key?(:polygon)
          @polygon_for_display = args[:polygon_for_display] if args.key?(:polygon_for_display)
          @polyline = args[:polyline] if args.key?(:polyline)
          @pose = args[:pose] if args.key?(:pose)
          @preferred_viewport = args[:preferred_viewport] if args.key?(:preferred_viewport)
          @property_value_status = args[:property_value_status] if args.key?(:property_value_status)
          @rank = args[:rank] if args.key?(:rank)
          @rank_details = args[:rank_details] if args.key?(:rank_details)
          @raw_gconcept_instance_container = args[:raw_gconcept_instance_container] if args.key?(:raw_gconcept_instance_container)
          @regulated_area = args[:regulated_area] if args.key?(:regulated_area)
          @related_border = args[:related_border] if args.key?(:related_border)
          @related_entrance = args[:related_entrance] if args.key?(:related_entrance)
          @related_feature = args[:related_feature] if args.key?(:related_feature)
          @related_terminal_point = args[:related_terminal_point] if args.key?(:related_terminal_point)
          @related_timezone = args[:related_timezone] if args.key?(:related_timezone)
          @restriction_group = args[:restriction_group] if args.key?(:restriction_group)
          @road_monitor = args[:road_monitor] if args.key?(:road_monitor)
          @route = args[:route] if args.key?(:route)
          @school_district = args[:school_district] if args.key?(:school_district)
          @segment = args[:segment] if args.key?(:segment)
          @segment_path = args[:segment_path] if args.key?(:segment_path)
          @sign = args[:sign] if args.key?(:sign)
          @ski_boundary = args[:ski_boundary] if args.key?(:ski_boundary)
          @ski_lift = args[:ski_lift] if args.key?(:ski_lift)
          @ski_trail = args[:ski_trail] if args.key?(:ski_trail)
          @social_reference = args[:social_reference] if args.key?(:social_reference)
          @source_info = args[:source_info] if args.key?(:source_info)
          @status = args[:status] if args.key?(:status)
          @storefront_geometry = args[:storefront_geometry] if args.key?(:storefront_geometry)
          @synthetic_geometry = args[:synthetic_geometry] if args.key?(:synthetic_geometry)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @three_dim_model = args[:three_dim_model] if args.key?(:three_dim_model)
          @toll_cluster = args[:toll_cluster] if args.key?(:toll_cluster)
          @track = args[:track] if args.key?(:track)
          @transit_line = args[:transit_line] if args.key?(:transit_line)
          @transit_line_variant = args[:transit_line_variant] if args.key?(:transit_line_variant)
          @transit_station = args[:transit_station] if args.key?(:transit_station)
          @type = args[:type] if args.key?(:type)
          @vertical_ordering = args[:vertical_ordering] if args.key?(:vertical_ordering)
          @water_removed_polygon = args[:water_removed_polygon] if args.key?(:water_removed_polygon)
          @website = args[:website] if args.key?(:website)
        end
      end
      
      # Internal field metadata. This part is not exposed to downstream consumers of
      # the repository (read-only clients) but is available to upstream providers to
      # the repository (read-write clients).
      class GeostoreFieldMetadataProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `internal`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreInternalFieldMetadataProto]
        attr_accessor :internal
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @internal = args[:internal] if args.key?(:internal)
        end
      end
      
      # Proto used to represent rights for a field type. See go/geo-rights for more
      # details. NOTE: Use google3/geostore/provenance/public/rights.h or google3/java/
      # com/google/geostore/provenance/rights/Rights.swig instead of accessing this
      # proto directly.
      class GeostoreFieldWithRightsProto
        include Google::Apis::Core::Hashable
      
        # ** DEPRECATED ** If field_type is set to FEATURE_ATTRIBUTE or
        # KNOWLEDGE_GRAPH_PROPERTY, the attribute ID / KG property ID that makes this
        # field with rights complete.
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        # Message to represent a "feature property" as an abstract construct. Most
        # feature properties are mapped one to one with the EditProto field types.
        # However in some cases the EditProto field type granularity is too coarse to
        # support use-cases that rely on feature properties (such as per-value rights
        # tracking). When that is the case, the feature property is augmented with a
        # secondary field.
        # Corresponds to the JSON property `featurePropertyId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeaturePropertyIdProto]
        attr_accessor :feature_property_id
      
        # The field type for which the rights level are tracked on. The default value
        # here has to match the value of fieldtype::NONE.
        # Corresponds to the JSON property `fieldType`
        # @return [Fixnum]
        attr_accessor :field_type
      
        # The minimum rights level for all the current values on the field type.
        # Corresponds to the JSON property `minRightsLevel`
        # @return [String]
        attr_accessor :min_rights_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
          @feature_property_id = args[:feature_property_id] if args.key?(:feature_property_id)
          @field_type = args[:field_type] if args.key?(:field_type)
          @min_rights_level = args[:min_rights_level] if args.key?(:min_rights_level)
        end
      end
      
      # Wrapper to hold data related to a lane’s track, extendable for future data.
      class GeostoreFlowLineProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `track`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTrackProto]
        attr_accessor :track
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @track = args[:track] if args.key?(:track)
        end
      end
      
      # Example: the choice of chicken, beef, or tofu for the Thai Basil dish. Each
      # option would have its own name, price, allergen info, etc. Note: This proto
      # stores both food and service items despite the name.
      class GeostoreFoodMenuItemOptionProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `allergenAbsent`
        # @return [Array<String>]
        attr_accessor :allergen_absent
      
        # 
        # Corresponds to the JSON property `allergenPresent`
        # @return [Array<String>]
        attr_accessor :allergen_present
      
        # 
        # Corresponds to the JSON property `calories`
        # @return [Fixnum]
        attr_accessor :calories
      
        # Ingredients of the food dish option.
        # Corresponds to the JSON property `ingredients`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFoodMenuItemOptionProtoIngredient>]
        attr_accessor :ingredients
      
        # Photos of the food dish option.
        # Corresponds to the JSON property `media`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreMediaItemProto>]
        attr_accessor :media
      
        # The repeated name_info field here is for item options with names or
        # descriptions listed in multiple languages. When an item option has no names or
        # descriptions, the size of the repeated field name_info may be 0. For example,
        # when a food menu item does not have multiple options, the item option proto is
        # used only to specify price and nutritional information, so it will not have a
        # name_info field. There should be at most one name_info for any given language.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        # This message represents nutrition facts for a food dish.
        # Corresponds to the JSON property `nutritionFacts`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFacts]
        attr_accessor :nutrition_facts
      
        # This message denotes the serving portion size of a food dish.
        # Corresponds to the JSON property `portionSize`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFoodMenuItemOptionProtoPortionSize]
        attr_accessor :portion_size
      
        # Methods on how the food dish option is prepared.
        # Corresponds to the JSON property `preparationMethods`
        # @return [Array<String>]
        attr_accessor :preparation_methods
      
        # This message represents a price range of an attribute. The meaning of the
        # price bounds is domain specific. But mainly they are soft bounds for a normal
        # usage. E.g. "restaurant prices" are subject to an higher level of "soft"
        # bounds than "museum admission price"
        # Corresponds to the JSON property `price`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceRangeProto]
        attr_accessor :price
      
        # 
        # Corresponds to the JSON property `restriction`
        # @return [Array<String>]
        attr_accessor :restriction
      
        # Number of people can be served by this food dish option.
        # Corresponds to the JSON property `servesNumPeople`
        # @return [Fixnum]
        attr_accessor :serves_num_people
      
        # 
        # Corresponds to the JSON property `spiciness`
        # @return [String]
        attr_accessor :spiciness
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allergen_absent = args[:allergen_absent] if args.key?(:allergen_absent)
          @allergen_present = args[:allergen_present] if args.key?(:allergen_present)
          @calories = args[:calories] if args.key?(:calories)
          @ingredients = args[:ingredients] if args.key?(:ingredients)
          @media = args[:media] if args.key?(:media)
          @name_info = args[:name_info] if args.key?(:name_info)
          @nutrition_facts = args[:nutrition_facts] if args.key?(:nutrition_facts)
          @portion_size = args[:portion_size] if args.key?(:portion_size)
          @preparation_methods = args[:preparation_methods] if args.key?(:preparation_methods)
          @price = args[:price] if args.key?(:price)
          @restriction = args[:restriction] if args.key?(:restriction)
          @serves_num_people = args[:serves_num_people] if args.key?(:serves_num_people)
          @spiciness = args[:spiciness] if args.key?(:spiciness)
        end
      end
      
      # This message denotes an ingredient information of a food dish.
      class GeostoreFoodMenuItemOptionProtoIngredient
        include Google::Apis::Core::Hashable
      
        # The repeated name_info field is for the ingredient in multiple languages.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name_info = args[:name_info] if args.key?(:name_info)
        end
      end
      
      # This message denotes the serving portion size of a food dish.
      class GeostoreFoodMenuItemOptionProtoPortionSize
        include Google::Apis::Core::Hashable
      
        # Required.
        # Corresponds to the JSON property `quantity`
        # @return [Fixnum]
        attr_accessor :quantity
      
        # Required. The repeated name_info field is for the unit in multiple languages.
        # Corresponds to the JSON property `unit`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @quantity = args[:quantity] if args.key?(:quantity)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # A food menu item must have a name although it can have multiple names in
      # different languages. Example: Thai Basil. Price for this item is specified in
      # the item_option field. Since the price of an item may be unknown, e.g.
      # seasonal price, there is nothing that requires an item_option to be present in
      # the FoodMenuItemProto.
      class GeostoreFoodMenuItemProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `itemOption`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFoodMenuItemOptionProto>]
        attr_accessor :item_option
      
        # The repeated name_info field is for items listed in multiple languages.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @item_option = args[:item_option] if args.key?(:item_option)
          @name_info = args[:name_info] if args.key?(:name_info)
        end
      end
      
      # A GConceptInstanceProto contains a GConceptID (which is the unique identifier
      # of a GConcept, a category in the Geo Ontology).
      class GeostoreGConceptInstanceProto
        include Google::Apis::Core::Hashable
      
        # The unique identifier of a GConcept (e.g. "gcid:railway").
        # Corresponds to the JSON property `gconceptId`
        # @return [String]
        attr_accessor :gconcept_id
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # The relative prominence of this category to this feature according to the data
        # provider, as one of the values from the enum above. Prominence is a measure of
        # how well the given GConcept describes the feature. An example is a gas station
        # with convenience store and ATM. All three GConcepts are very relevant, but the
        # gas_station GConcept is the most prominent. If the prominence of this GConcept
        # is unknown, this field should not be set.
        # Corresponds to the JSON property `prominence`
        # @return [String]
        attr_accessor :prominence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gconcept_id = args[:gconcept_id] if args.key?(:gconcept_id)
          @metadata = args[:metadata] if args.key?(:metadata)
          @prominence = args[:prominence] if args.key?(:prominence)
        end
      end
      
      # Geopolitical (unsimplified) polygons for a feature for different geopolitical
      # use cases. See go/unsimplified-poly.
      class GeostoreGeopoliticalGeometryProto
        include Google::Apis::Core::Hashable
      
        # A general non-self-intersecting spherical polygon, consisting of one or more
        # loops defining multiple disconnected regions possibly with holes. All loops
        # should be oriented CCW around the region they define. This applies to the
        # exterior loop(s) as well as any holes. Within MapFacts (and underlying
        # infrastructure) the data fields may be replaced by a single shape_id; see
        # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
        # work with public functions in //geostore/base/public/polygon.h.
        # Corresponds to the JSON property `restOfWorldPolygon`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePolygonProto]
        attr_accessor :rest_of_world_polygon
      
        # A general non-self-intersecting spherical polygon, consisting of one or more
        # loops defining multiple disconnected regions possibly with holes. All loops
        # should be oriented CCW around the region they define. This applies to the
        # exterior loop(s) as well as any holes. Within MapFacts (and underlying
        # infrastructure) the data fields may be replaced by a single shape_id; see
        # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
        # work with public functions in //geostore/base/public/polygon.h.
        # Corresponds to the JSON property `selfPolygon`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePolygonProto]
        attr_accessor :self_polygon
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @rest_of_world_polygon = args[:rest_of_world_polygon] if args.key?(:rest_of_world_polygon)
          @self_polygon = args[:self_polygon] if args.key?(:self_polygon)
        end
      end
      
      # The grade level of a segment represents the relative altitude of the segment
      # at a particular point along the segment. This level is in relation to other
      # segments at the same point. For example, you might have a freeway at level = 0
      # and an overpass at level = 2. Vertical segments are represented by a polyline
      # containing only 1 vertex and exactly two grade_level in segment.proto whose
      # indices are 0. grade_level(0) represents the relative height at the start
      # point of the segments, and grade_level(1) represents the one at the end point.
      class GeostoreGradeLevelProto
        include Google::Apis::Core::Hashable
      
        # The index of the point along the segment, where 0 is the starting point. This
        # means that the index of a point along a segment and its sibling will be
        # different.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # The grade level of the indexed point. The grade level can be thought of as a
        # relative vertical ordering with respect to other segments at the same point,
        # where larger/more positive numbers are "higher". Negative grade level values
        # are allowed and are typically used for points below grade level (0 is a common
        # choice to represent the level of points at the ground level). For vertical
        # segments, the height, i.e. the vertical length, is represented by difference
        # of levels in millimeters. For example, feature.segment().grade_level(0).level()
        # == 0 and feature.segment().grade_level(1).level() == 5000, then the length of
        # the vertical segment feature is 5000 millimeters (5 meters).
        # Corresponds to the JSON property `level`
        # @return [Fixnum]
        attr_accessor :level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
          @level = args[:level] if args.key?(:level)
        end
      end
      
      # Represents HTML text associated with a feature.
      class GeostoreHtmlTextProto
        include Google::Apis::Core::Hashable
      
        # Zero or more texts of the specified type, in various languages. If this is a
        # HTML_DESCRIPTION blob then these texts would hold the description in English,
        # German, and so forth. The text is an HTML fragment, not a full page. The
        # fragment should be suitable for including in a DIV. It must have balanced HTML
        # tags. It may use HTML's "class" attributes to assign classes to HTML elements.
        # This allows the HTML to be formatted by an (external) style sheet. The HTML
        # should not have embedded style sheet definitions, nor should it have embedded
        # JavaScript.
        # Corresponds to the JSON property `text`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLanguageTaggedTextProto>]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # The inferred geometry of a feature contains all the features which, together,
      # define the geometry of a feature. This happens by: 1. Taking the union of all
      # polygons of features referenced in "includes_geometry_of". 2. Subtract the
      # geometries of all the features referenced in "excludes_geometry_of". See: go/
      # inferred-geometry for more information.
      class GeostoreInferredGeometryProto
        include Google::Apis::Core::Hashable
      
        # Features whose geometry depends on this feature's geometry.
        # Corresponds to the JSON property `definesGeometryFor`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :defines_geometry_for
      
        # Features whose geometry to exclude while inferring geometry.
        # Corresponds to the JSON property `excludesGeometryOf`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :excludes_geometry_of
      
        # Features whose geometry to include while inferring geometry.
        # Corresponds to the JSON property `includesGeometryOf`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :includes_geometry_of
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @defines_geometry_for = args[:defines_geometry_for] if args.key?(:defines_geometry_for)
          @excludes_geometry_of = args[:excludes_geometry_of] if args.key?(:excludes_geometry_of)
          @includes_geometry_of = args[:includes_geometry_of] if args.key?(:includes_geometry_of)
        end
      end
      
      # Main proto for all internal fields to be stored at the feature level.
      class GeostoreInternalFeatureProto
        include Google::Apis::Core::Hashable
      
        # A unique identifier for this feature's polygon data which is being held
        # externally in Shapestore (see go/shapestore).
        # Corresponds to the JSON property `polygonShapeId`
        # @return [String]
        attr_accessor :polygon_shape_id
      
        # A unique identifier for this feature's rest-of-world view polygon data which
        # is being held externally in Shapestore (see go/shapestore). This is part of
        # the feature's geopolitical geometry.
        # Corresponds to the JSON property `restOfWorldPolygonShapeId`
        # @return [String]
        attr_accessor :rest_of_world_polygon_shape_id
      
        # Proto used to represent rights for FeatureProto. See go/geo-rights for more
        # details. NOTE: Use google3/geostore/provenance/public/rights.h or google3/java/
        # com/google/geostore/provenance/rights/Rights.swig instead of accessing this
        # proto directly.
        # Corresponds to the JSON property `rightsStatus`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRightsStatusProto]
        attr_accessor :rights_status
      
        # A unique identifier for this feature's self view polygon data which is being
        # held externally in Shapestore (see go/shapestore). This is part of the feature'
        # s geopolitical geometry.
        # Corresponds to the JSON property `selfPolygonShapeId`
        # @return [String]
        attr_accessor :self_polygon_shape_id
      
        # Trust signals/annotations for the feature. In an input feature, these signals
        # are computed at the beginning of the pipeline and are immutable during the
        # processing. In output features, this proto may define the rules/criteria that
        # a newer edit should meet, in order to be applied.
        # Corresponds to the JSON property `trust`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTrustSignalsProto]
        attr_accessor :trust_prop
      
        # A unique identifier for this feature's water-removed polygon data which is
        # being held externally in Shapestore (see go/shapestore).
        # Corresponds to the JSON property `waterRemovedPolygonShapeId`
        # @return [String]
        attr_accessor :water_removed_polygon_shape_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @polygon_shape_id = args[:polygon_shape_id] if args.key?(:polygon_shape_id)
          @rest_of_world_polygon_shape_id = args[:rest_of_world_polygon_shape_id] if args.key?(:rest_of_world_polygon_shape_id)
          @rights_status = args[:rights_status] if args.key?(:rights_status)
          @self_polygon_shape_id = args[:self_polygon_shape_id] if args.key?(:self_polygon_shape_id)
          @trust_prop = args[:trust_prop] if args.key?(:trust_prop)
          @water_removed_polygon_shape_id = args[:water_removed_polygon_shape_id] if args.key?(:water_removed_polygon_shape_id)
        end
      end
      
      # 
      class GeostoreInternalFieldMetadataProto
        include Google::Apis::Core::Hashable
      
        # Whether or not the piece of data has been generated automatically (i.e., by a
        # bot/automated process based on heuristics/algorithms rather than coming as a
        # fact set by some human user or data provider based on their knowledge). Note
        # that this does NOT imply that the value was set as a result of a bot operation
        # on the repository, since it is conceivable to use a bot/automated process
        # simply as a way of convenience to ingest large amount of canonical/ground
        # truth data.
        # Corresponds to the JSON property `isAuto`
        # @return [Boolean]
        attr_accessor :is_auto
        alias_method :is_auto?, :is_auto
      
        # Information about the source providing the piece of data this metadata is
        # attached to.
        # Corresponds to the JSON property `sourceSummary`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreInternalSourceSummaryProto]
        attr_accessor :source_summary
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_auto = args[:is_auto] if args.key?(:is_auto)
          @source_summary = args[:source_summary] if args.key?(:source_summary)
        end
      end
      
      # Internal-only proto used to express additional information about segments.
      # This is intended for communicating extra information between editing clients
      # and the repository, and should not be used by or visible to clients. WARNING -
      # if you add new fields to InternalSegmentProto, make sure that geostore/tools/
      # internal/mr-mergesegments_test.cc is aware of them.
      class GeostoreInternalSegmentProto
        include Google::Apis::Core::Hashable
      
        # The set of restrictions that apply to this segment; these are actually *
        # POSITIVE* restrictions, i.e. they are known to be allowed.
        # Corresponds to the JSON property `travelAllowance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRestrictionProto>]
        attr_accessor :travel_allowance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @travel_allowance = args[:travel_allowance] if args.key?(:travel_allowance)
        end
      end
      
      # 
      class GeostoreInternalSourceSummaryProto
        include Google::Apis::Core::Hashable
      
        # Within the above provider, the dataset from which this piece of data was
        # generated. For fields that are auto-generated the "dataset" is likely to be
        # some algorithm's or program's name. Similar to SourceInfoProto.dataset but
        # with the difference that it is required to always be set. Providers that don't
        # have a concept of dataset may use "default".
        # Corresponds to the JSON property `dataset`
        # @return [String]
        attr_accessor :dataset
      
        # The data provider from which this piece of data was generated. Equivalent to
        # SourceInfoProto.provider in the public schema.
        # Corresponds to the JSON property `provider`
        # @return [String]
        attr_accessor :provider
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dataset = args[:dataset] if args.key?(:dataset)
          @provider = args[:provider] if args.key?(:provider)
        end
      end
      
      # Our TYPE_INTERSECTION features model the point where one or more segments
      # terminate. This is topological definition: it may not match what a typical
      # user would think of as an "intersection". Consider the intersections where
      # Hayes, Market, Larkin, and 9th Street meet near (37.77765, -122.41638) in San
      # Francisco. Most people would probably consider this a single feature, even
      # though we model it as four separate TYPE_INTERSECTION features. The
      # TYPE_INTERSECTION_GROUP is used to model the user's concept of a real-world
      # intersection, which also includes turn lanes or a whole roundabout (a logical
      # intersection). For the purposes of modeling turn restrictions and lane
      # connections, a smaller grouping is needed to model the "core" part of the
      # intersection where there are no lane markings. This is called a core or
      # artifact group. An intersection group must contain at least two intersections
      # or add some information (e.g. a name or a polygon) compared to the
      # intersection itself, or else must not exist. The standard feature properties
      # are interpreted as follows: name - Can be used to specify any "special" names
      # associated with this intersection (e.g. Reads Corner intersection, PEI, Canada)
      # . Intersections that are named according to their cross streets do not need to
      # specify this field, since this can be determined by looking at the routes
      # associated with each segment. address - This should always be empty. point -
      # Specifies the center of the intersection. This is basically the point where
      # the intersection name should be rendered. Can be omitted in favor of a polygon.
      # polyline - This should always be empty. polygon - Specifies the two-
      # dimensional extent of the intersection. This may substitute to the point field,
      # though having a center set is desirable in this case. child - This should
      # always be empty.
      class GeostoreIntersectionGroupProto
        include Google::Apis::Core::Hashable
      
        # All artifact intersection groups that are in this logical group.
        # Corresponds to the JSON property `childGroup`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :child_group
      
        # 
        # Corresponds to the JSON property `groupType`
        # @return [String]
        attr_accessor :group_type
      
        # The list of TYPE_INTERSECTION features that form this intersection group, but
        # are NOT in any of this group's child groups. This could be an empty list,
        # though that is sub-optimal. Even an empty list would allow the paint team to
        # draw a label for a named intersection, but a non-empty list would, for example,
        # enable PathFinder to generate better directions. Each of the
        # TYPE_INTERSECTION feature referred here must refer back to this feature in its
        # IntersectionProto.
        # Corresponds to the JSON property `intersection`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :intersection
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `parentGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :parent_group
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child_group = args[:child_group] if args.key?(:child_group)
          @group_type = args[:group_type] if args.key?(:group_type)
          @intersection = args[:intersection] if args.key?(:intersection)
          @parent_group = args[:parent_group] if args.key?(:parent_group)
        end
      end
      
      # A TYPE_INTERSECTION feature represents a common endpoint of one or more
      # segments in a transportation network at which the segments are connected. An
      # intersection in the real world may be more complicated than that (e.g.,
      # comprise multiple segment endpoints or have extra attributes), which can be
      # modeled with an additional TYPE_INTERSECTION_GROUP feature, if needed (see
      # intersectiongroup.proto). The standard feature properties are interpreted as
      # follows: name - This should always be empty. Intersections that have a "
      # special" name (e.g. Reads Corner intersection, PEI, Canada) should point to a
      # separate TYPE_INTERSECTION_GROUP feature that captures it. Intersections which
      # are named according to their cross streets do not need this requirement, since
      # their name can be determined by looking at the routes associated with each
      # segment. address - This should always be empty. point - Specifies the center
      # of the intersection. This should be the last vertex of all the segments which
      # terminate at this intersection. polyline - This should always be empty.
      # polygon - This should always be empty. child - This should always be empty.
      class GeostoreIntersectionProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `intersectionGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :intersection_group
      
        # RESERVED
        # Corresponds to the JSON property `outSegment`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :out_segment
      
        # The list of segments that terminate at this intersection, in any order. Note
        # that all segments are directed towards the intersection, i.e. their endpoints
        # indicate what sort of intersection this is. This should not be empty because
        # an intersection with no associated segment is meaningless.
        # Corresponds to the JSON property `segment`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :segment
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `tollClusterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :toll_cluster_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intersection_group = args[:intersection_group] if args.key?(:intersection_group)
          @out_segment = args[:out_segment] if args.key?(:out_segment)
          @segment = args[:segment] if args.key?(:segment)
          @toll_cluster_id = args[:toll_cluster_id] if args.key?(:toll_cluster_id)
        end
      end
      
      # 
      class GeostoreJobMetadata
        include Google::Apis::Core::Hashable
      
        # Describes how much time the service is going to take, e.g. how long it takes
        # to do a haircut. Value of seconds must be from +60 (1 min) to +31,536,000 (365
        # days) inclusive. Value of nanos must be zero.
        # Corresponds to the JSON property `duration`
        # @return [String]
        attr_accessor :duration
      
        # Represents the name of a potential grouping of items. For TYPE_JOB, this is
        # the category names of the categories that a user picked this job type from at
        # the time of input.
        # Corresponds to the JSON property `jobRelatedCategories`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreJobRelatedCategory>]
        attr_accessor :job_related_categories
      
        # Unique identifier for a job. This is required for standard jobs and blank for
        # free-form jobs. Job type ids are prefixed with "job_type_id:". Notice this is
        # a unique string representation of a job across languages. E.g., “job_type_id:
        # air_duct_repair”. The existence of a job_type_id means the job type is a
        # standard one, and has a corresponding entry in the Standard Jobs Taxonomy.
        # Corresponds to the JSON property `jobTypeId`
        # @return [String]
        attr_accessor :job_type_id
      
        # Represents the MID corresponding to the job_category entity in the Knowledge
        # Graph. For example, job_type_id="job_type_id:install_faucet", job_type_mid="/g/
        # 11hzzxjv3f".
        # Corresponds to the JSON property `jobTypeMid`
        # @return [String]
        attr_accessor :job_type_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duration = args[:duration] if args.key?(:duration)
          @job_related_categories = args[:job_related_categories] if args.key?(:job_related_categories)
          @job_type_id = args[:job_type_id] if args.key?(:job_type_id)
          @job_type_mid = args[:job_type_mid] if args.key?(:job_type_mid)
        end
      end
      
      # This is the category that a user picked this job type from at the time of
      # input. The field serves two purposes: 1) The name is used in consumer surface
      # similar to the heading name today (i.e., grouping jobs under the category. 2)
      # The gcid is needed mainly for free-formed entries, for which GMB needs to map
      # them to corresponding categories in the frontend, if applicable. Notice that
      # the name and the id are both not expected to be in sync with gcid deprecation
      # or location category change per product decision. In other words, they are not
      # guaranteed to stay in sync, only guaranteed true at time of creation.
      class GeostoreJobRelatedCategory
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `gcid`
        # @return [String]
        attr_accessor :gcid
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Category name in the primary language of the feature. Generally intended to be
        # used as a fallback when we are unable to fetch the name in the user's language.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcid = args[:gcid] if args.key?(:gcid)
          @language = args[:language] if args.key?(:language)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # The reference to an entity in the KnowledgeGraph. For details on the
      # KnowledgeGraph see http://goto/kg.
      class GeostoreKnowledgeGraphReferenceProto
        include Google::Apis::Core::Hashable
      
        # KG Identifier (MID). For details, see http://go/ke-bg-knowledge-graph#mids.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # This protocol buffer represents the association between a segment and a
      # landmark feature. Notes: - References to TYPE_SEGMENT features should always
      # point to the even sibling. - Self-references are allowed but the referencing
      # segment's sibling is required to have a self-reference as well (the above
      # requirement to always reference the even sibling still applies).
      class GeostoreLandmarkReferenceProto
        include Google::Apis::Core::Hashable
      
        # The type of the landmark feature. Allowed types: - TYPE_CARTOGRAPHIC e.g. a
        # putting green or water hazard - TYPE_COMPOUND e.g. - the Empire state building
        # (TYPE_COMPOUND_BUILDING) - a park (TYPE_COMPOUND_GROUNDS) - a section of a
        # retail store (TYPE_COMPOUND_SECTION) - TYPE_ESTABLISHMENT e.g. - the Eiffel
        # Tower (TYPE_ESTABLISHMENT_BUILDING) - a sports field (
        # TYPE_ESTABLISHMENT_GROUNDS) - Starbucks (TYPE_ESTABLISHMENT_POI) -
        # TYPE_INTERSECTION_GROUP e.g. a major intersection - TYPE_NATURAL_FEATURE e.g.
        # a river - TYPE_SEGMENT e.g. a bike trail or train tracks
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `landmark`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :landmark
      
        # The mode(s) of travel for which this landmark is useful.
        # Corresponds to the JSON property `travelMode`
        # @return [Array<String>]
        attr_accessor :travel_mode
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @landmark = args[:landmark] if args.key?(:landmark)
          @travel_mode = args[:travel_mode] if args.key?(:travel_mode)
        end
      end
      
      # This proto contains attributes relevant to physical lane markers.
      class GeostoreLaneMarkerProto
        include Google::Apis::Core::Hashable
      
        # If this is a physical barrier marker, represent materials found on the marker.
        # Corresponds to the JSON property `barrierMaterials`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBarrierLogicalMaterialProto]
        attr_accessor :barrier_materials
      
        # Possible patterns of a crossing stripe (any element that denotes a point on a
        # segment or lane at which the vehicle must stop or yield). These include
        # crosswalks, stop, and yield lines.
        # Corresponds to the JSON property `crossingPattern`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCrossingStripePatternProto]
        attr_accessor :crossing_pattern
      
        # Stripe pattern, spacing, and color for longitudinal markers.
        # Corresponds to the JSON property `linearPattern`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreLinearStripePatternProto]
        attr_accessor :linear_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @barrier_materials = args[:barrier_materials] if args.key?(:barrier_materials)
          @crossing_pattern = args[:crossing_pattern] if args.key?(:crossing_pattern)
          @linear_pattern = args[:linear_pattern] if args.key?(:linear_pattern)
        end
      end
      
      # Describes an individual road lane. Not only driving lanes, but also parking
      # and biking lanes are covered by this. Note that we may eventually add curbs
      # and walking to this schema. MOTIVATION/DESIGN DISCUSSION The intent of this
      # schema is to model a schematic representation of the road for a bunch of use
      # cases within GMM, navigation, map tiles. For rendering, we do not want to
      # represent the geometry of each lane exactly, but do want to model types/width/
      # gaps/lane markings so that a schematic rendering can be made. For navigation,
      # we model lane connectivity and restrictions per lane, so that Pathfinder can
      # potentially pick routes based on lanes, and definitely use the lanes to better
      # describe the path to the driver. This schema is driven by the GT team, which
      # is likely to be the only provider of this data. It is based on compromises
      # that we are working out with other teams, based on what our operators can
      # reasonably collect and what is useful. See docs here: https://docs.google.com/
      # a/google.com/document/d/11XJ1WvqS5Sm7MxWXzzc3tnsk49VhrR3BYFjiRMAzYm0/edit?hl=
      # en_US https://docs.google.com/a/google.com/document/d/1nzdupynTUKE8xY8JcfvQbU-
      # KWtCJ6IwHiTaCxuq40EM/edit?hl=en_US Note: Some lane information (width, surface
      # type, etc) may duplicate or contradict information stored at the segment level.
      class GeostoreLaneProto
        include Google::Apis::Core::Hashable
      
        # References to any gcid:physical_lane_marker features that bound this lane.
        # Corresponds to the JSON property `boundingMarker`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreBoundingMarkerProto>]
        attr_accessor :bounding_marker
      
        # If the current lane is part of a merge/split area, indicates the type (split
        # or merge) and whether the current lane is on the left or right or in the
        # middle of the merge/split area, as seen in the direction of traffic. See go/
        # lane-split-merge-schema
        # Corresponds to the JSON property `conjoinedCategory`
        # @return [String]
        attr_accessor :conjoined_category
      
        # Gap between this lane and the next in meters. This is relevant when the
        # divider is physical, or a wide painted area. For regular painted single or
        # double lines, there is no gap. This distance is duplicated between the
        # innermost lanes for each side. Note that this is not used to describe smallish
        # islands - this is only for long-running gaps. In particular, this models the
        # median width, the gap between HOV lanes/regular lanes on freeways, and the
        # road verge between a curb and sidewalk. Note on split roads: We can model any
        # split road with a median as a single sibling pair with this distance set to
        # the width of the median, or as two one-way sibling pairs.
        # Corresponds to the JSON property `distanceToNextLane`
        # @return [Float]
        attr_accessor :distance_to_next_lane
      
        # Wrapper to hold data related to a lane’s track, extendable for future data.
        # Corresponds to the JSON property `flow`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFlowLineProto]
        attr_accessor :flow
      
        # Connections to lanes of other segments at the end of this segment. These
        # connections model the connectivity where you don't have to do a lane change
        # maneuver. If any lane connection is present, assume that all others are
        # forbidden. Also note that segment level restrictions do apply if present, and
        # can disallow some turn even if the lanes are connected. For instance, this can
        # happen with timed or vehicle type based restrictions on the segment. If lane
        # connectivity implies a segment-level restriction (can't transition to some
        # target segment), that restriction will also exist as a segment level
        # restriction. In effect - PathFinder does not have to look at lane connectivity
        # to figure out segment connectivity. Example: Typically, lanes are just
        # connected to one other lane. Example: A splitting lane is connected to the two
        # resulting lanes. Example: At an intersection, a lane is connected to crossing
        # lanes according to how lanes are painted across the intersection. In the
        # common case, the target segment will be connected to the same intersection as
        # this segment. That will however NOT be true for complex intersections where
        # there is an intersection group. The connections will be across the whole group,
        # connecting to one of the outgoing segments from the group. This is analogous
        # to how we do turn restrictions around intersection groups.
        # Corresponds to the JSON property `laneConnection`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLaneProtoLaneConnection>]
        attr_accessor :lane_connection
      
        # clang-format on Whether the divider to the inside of this lane can be crossed.
        # Note that we assume this is symmetric, and that this also describes whether
        # someone in the next inside lane can cross to this one. The "inside" lane is
        # the one with a lower lane_number. Note on lane markers: We do not model the
        # painting, but only the resulting legality. There are many painted marker
        # styles and colors that lead to the same legality. We expect Paint or
        # Driveabout to render lanes stylized, with solid meaning "can't cross", and
        # dashed meaning "can cross". Note on varying legality along segment: ALLOWED
        # takes precedence - even if some small portion has a restriction (such as right
        # before an intersection) , the lane change will be ALLOWED.
        # Corresponds to the JSON property `laneDividerCrossing`
        # @return [String]
        attr_accessor :lane_divider_crossing
      
        # These indicate for what portion of the segment the lane's flowline exactly
        # follows the segment, and the lane is of constant width. This will be set to
        # not include the whole segment where there is a split/turn/merge at either end
        # of the lane. The painting of the lane should completely synthesize the lane
        # geometry outside of this portion, connecting it to neighboring lanes to make
        # graphical nice.
        # Corresponds to the JSON property `laneFollowsSegmentBeginFraction`
        # @return [Float]
        attr_accessor :lane_follows_segment_begin_fraction
      
        # 
        # Corresponds to the JSON property `laneFollowsSegmentEndFraction`
        # @return [Float]
        attr_accessor :lane_follows_segment_end_fraction
      
        # Lanes are numbered from inside of the road outward, i.e. the lane next to the
        # center line is lane 0. The lanes then stack outwards, towards the side that
        # one drives on this segment (right or left). NOTE: do NOT use the lane_number
        # as index for lookup. Lane_number is not guaranteed to match the segment.lane
        # repeated field index.
        # Corresponds to the JSON property `laneNumber`
        # @return [Fixnum]
        attr_accessor :lane_number
      
        # A token that can be used to identify the version of the data about this lane.
        # Corresponds to the JSON property `laneToken`
        # @return [String]
        attr_accessor :lane_token
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # Restrictions that apply to this lane only. Examples include HOV lanes. If a
        # lane restriction implies a segment-level restriction (can't route on the
        # segment at all), that restriction will also exist as a segment level
        # restriction. In effect - PathFinder does not have to look at lane restrictions
        # to figure out segment restrictions.
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRestrictionProto>]
        attr_accessor :restriction
      
        # True if this lane is usable in both directions (left-turn lane, reversing lane,
        # one-lane road, etc). To get the total number of lanes for a road, add up the
        # lanes in each direction counting 0.5 for each shared lane.
        # Corresponds to the JSON property `shared`
        # @return [Boolean]
        attr_accessor :shared
        alias_method :shared?, :shared
      
        # References to any gcid:physical_lane_marker features that intersect this lane,
        # with the implication that a moving vehicle should stop there.
        # Corresponds to the JSON property `stopLine`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :stop_line
      
        # clang-format on LINT.ThenChange(//depot/google3/geostore/base/proto/segment.
        # proto) Unlike the surface in SegmentProto, this field does not have a default
        # value. This is because the lane-level surface overrides the segment-level
        # surface. The lane's surface should be unset unless explicitly overriding the
        # segment's surface.
        # Corresponds to the JSON property `surface`
        # @return [String]
        attr_accessor :surface
      
        # clang-format on
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Width of this lane in meters. In many cases, we will collect this data by
        # dividing the total road width by the number of lanes. On accuracy: This is a
        # rough average width along this segment. If and when we wanted to be more
        # accurate, we'd extend this schema to have full polygons for segments/lanes
        # rather than just this average width.
        # Corresponds to the JSON property `width`
        # @return [Float]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_marker = args[:bounding_marker] if args.key?(:bounding_marker)
          @conjoined_category = args[:conjoined_category] if args.key?(:conjoined_category)
          @distance_to_next_lane = args[:distance_to_next_lane] if args.key?(:distance_to_next_lane)
          @flow = args[:flow] if args.key?(:flow)
          @lane_connection = args[:lane_connection] if args.key?(:lane_connection)
          @lane_divider_crossing = args[:lane_divider_crossing] if args.key?(:lane_divider_crossing)
          @lane_follows_segment_begin_fraction = args[:lane_follows_segment_begin_fraction] if args.key?(:lane_follows_segment_begin_fraction)
          @lane_follows_segment_end_fraction = args[:lane_follows_segment_end_fraction] if args.key?(:lane_follows_segment_end_fraction)
          @lane_number = args[:lane_number] if args.key?(:lane_number)
          @lane_token = args[:lane_token] if args.key?(:lane_token)
          @metadata = args[:metadata] if args.key?(:metadata)
          @restriction = args[:restriction] if args.key?(:restriction)
          @shared = args[:shared] if args.key?(:shared)
          @stop_line = args[:stop_line] if args.key?(:stop_line)
          @surface = args[:surface] if args.key?(:surface)
          @type = args[:type] if args.key?(:type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class GeostoreLaneProtoLaneConnection
        include Google::Apis::Core::Hashable
      
        # References to any gcid:physical_lane_marker features that bound this lane
        # connection.
        # Corresponds to the JSON property `boundingMarker`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreBoundingMarkerProto>]
        attr_accessor :bounding_marker
      
        # A token that can be used to identify the version of the data about this lane
        # connection.
        # Corresponds to the JSON property `connectionToken`
        # @return [String]
        attr_accessor :connection_token
      
        # Protocol buffer describing a curve that connects two externally specified
        # endpoints.
        # Corresponds to the JSON property `curve`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCurveConnectionProto]
        attr_accessor :curve
      
        # Wrapper to hold data related to a lane’s track, extendable for future data.
        # Corresponds to the JSON property `flow`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFlowLineProto]
        attr_accessor :flow
      
        # This is the lane number on the target segment. This field is not set if the
        # target segment doesn't have lanes, or we don't know the exact connectivity.
        # Corresponds to the JSON property `laneNumber`
        # @return [Fixnum]
        attr_accessor :lane_number
      
        # True if this connects to the unique, natural continuation of the current lane.
        # At most one LaneConnection per lane can have this field set true. This
        # attribute is of interest to ADAS providers as a hint to which lane a vehicle
        # is likely to follow, in the absence of other information about the vehicle's
        # planned path.
        # Corresponds to the JSON property `primaryConnection`
        # @return [Boolean]
        attr_accessor :primary_connection
        alias_method :primary_connection?, :primary_connection
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `segment`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :segment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_marker = args[:bounding_marker] if args.key?(:bounding_marker)
          @connection_token = args[:connection_token] if args.key?(:connection_token)
          @curve = args[:curve] if args.key?(:curve)
          @flow = args[:flow] if args.key?(:flow)
          @lane_number = args[:lane_number] if args.key?(:lane_number)
          @primary_connection = args[:primary_connection] if args.key?(:primary_connection)
          @segment = args[:segment] if args.key?(:segment)
        end
      end
      
      # Represents a piece of text with an associated language.
      class GeostoreLanguageTaggedTextProto
        include Google::Apis::Core::Hashable
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # We place extra restrictions on languages in addition to what the III library
        # requires. See http://go/geo-schema-reference/feature-properties/languages.md
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # The text (UTF-8 encoding).
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # A feature used to represent a logical level, e.g. floor. A feature belonging
      # to a given level should point to the level feature using relation
      # RELATION_ON_LEVEL. The standard feature properties are interpreted as follows:
      # name - Levels should have names according to the following: * Short, elevator-
      # style names, such as "L" for "Lobby" and "2" for "Second floor", must be
      # included and must be tagged with FLAG_ABBREVIATED. There must be an
      # unambiguous "best" abbreviated name. * Longer names such as "Ticketing" or "
      # Upper Level" may be present when the level has a specific name. * Non-
      # abbreviated names should only be added if they are known to meaningfully
      # expand upon the abbreviated name. For example, the long name "Observation Deck
      # 2" for the abbreviated name "OD2" is a good additional name. In contrast, the
      # name "Level 2" for the abbreviated name "2" is not desired. address - This
      # should always be empty. point, polyline, polygon, center - These should never
      # be set (since we are representing a logical entity). preferred_viewport - This
      # should be the approximate extent of the level. child - This should always be
      # empty.
      class GeostoreLevelProto
        include Google::Apis::Core::Hashable
      
        # The building(s) to which this level belongs. A level will typically belong to
        # a single building, but it is valid for a single level to be shared by multiple
        # buildings (for example, a large underground parking lot). These buildings
        # refer back to the level via another strong reference (the BuildingProto.level
        # field).
        # Corresponds to the JSON property `building`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :building
      
        # The elevation of this level relative to the ground level, in levels. 0 =
        # ground floor (even in locales that call the ground floor "1st floor"); 0.5 =
        # between ground and first floor, eg mezzanine; 1 = first floor (one level above
        # ground floor); -3 = three levels below ground floor.
        # Corresponds to the JSON property `number`
        # @return [Float]
        attr_accessor :number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @building = args[:building] if args.key?(:building)
          @number = args[:number] if args.key?(:number)
        end
      end
      
      # 
      class GeostoreLinearStripePatternProto
        include Google::Apis::Core::Hashable
      
        # A linear marker may consist of one or more parallel physical lines. These are
        # ordered left to right along the direction of the marker core polyline.
        # Corresponds to the JSON property `line`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePhysicalLineProto>]
        attr_accessor :line
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @line = args[:line] if args.key?(:line)
        end
      end
      
      # This message describes the details of a single language within a locale.
      class GeostoreLocaleLanguageProto
        include Google::Apis::Core::Hashable
      
        # The language associated with this preference. The external form of a Google
        # International Identifiers Initiative (III) LanguageCode object. See google3/
        # i18n/identifiers/languagecode.h for details. We place extra restrictions on
        # languages in addition to what the III library requires. See http://go/geo-
        # schema-reference/feature-properties/languages.md
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Flag to indicate if the associated language is "official" within a locale.
        # Corresponds to the JSON property `official`
        # @return [Boolean]
        attr_accessor :official
        alias_method :official?, :official
      
        # This value represents the preference of the associated language within a
        # locale. It must be between 0.0 and 1.0.
        # Corresponds to the JSON property `preference`
        # @return [Float]
        attr_accessor :preference
      
        # Percentage of population that can speak the associated language within a
        # locale. It must be between 0 and 100.
        # Corresponds to the JSON property `speakingPercent`
        # @return [Float]
        attr_accessor :speaking_percent
      
        # Percentage of population that can write the associated language within a
        # locale. It must be between 0 and 100.
        # Corresponds to the JSON property `writingPercent`
        # @return [Float]
        attr_accessor :writing_percent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @official = args[:official] if args.key?(:official)
          @preference = args[:preference] if args.key?(:preference)
          @speaking_percent = args[:speaking_percent] if args.key?(:speaking_percent)
          @writing_percent = args[:writing_percent] if args.key?(:writing_percent)
        end
      end
      
      # A locale is a meta-feature that describes the geographic extent of
      # localization preferences such as the local language, and formatting
      # conventions for numbers, dates and monetary values. Multilingual areas may be
      # contained by multiple locales. We try to model locales fine-grained enough for
      # deciding which languages are typically used within a city. For example, while
      # French is an official language for all of Switzerland, we would prefer to have
      # Zurich contained by a separate (more fine-grained) Swiss-German locale
      # indicating that German, not French, is the predominantly spoken language in
      # this city. Note that language borders are frequently considered a political
      # question and often don't have clearly defined extents. For example, California
      # has a significant Spanish-speaking population, but Spanish is not an official
      # language of California.
      class GeostoreLocaleProto
        include Google::Apis::Core::Hashable
      
        # This holds the list of languages spoken within a locale.
        # Corresponds to the JSON property `language`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLocaleLanguageProto>]
        attr_accessor :language
      
        # The ID of the localization policy (from googledata/geostore/localization/
        # localization_policies.textpb) to apply to features that have this locale as
        # their best match locale. Localization policy IDs are arbitrary identifiers
        # that uniquely distinguish a set of language-selection rules.
        # Corresponds to the JSON property `localizationPolicyId`
        # @return [String]
        attr_accessor :localization_policy_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @localization_policy_id = args[:localization_policy_id] if args.key?(:localization_policy_id)
        end
      end
      
      # A logical border is a grouping of border features, which together model a
      # divide between two regions. The borders within this grouping share common
      # attributes, such as the regions they divide, and may represent a conceptual
      # group of borders, of which may be wholly disputed, wholly undisputed, or a
      # mixture of disputed and undisputed. Note that any borders within this group
      # may be part of multiple logical borders. A logical border is required to have
      # a name describing what the grouping represents (e.g. "US - Mexico Border", "
      # Kosovo - Serbia Border (Disputed)").
      class GeostoreLogicalBorderProto
        include Google::Apis::Core::Hashable
      
        # All the border segments which make up this logical border. Border segments
        # must be TYPE_BORDER features which have the same left/right features. This is
        # a many-to-many bidirectional relationship, so any border segment within this
        # list might be part of another logical border.
        # Corresponds to the JSON property `borderSegment`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :border_segment
      
        # The logical border status identifies its legal status. This is similar to the
        # BorderStatus present within border segments, but applies to the group as a
        # whole.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @border_segment = args[:border_segment] if args.key?(:border_segment)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Media item attached to an element of price list.
      class GeostoreMediaItemProto
        include Google::Apis::Core::Hashable
      
        # The FIFE url associated with the media. NOTE: This FIFE URL must be PII-free,
        # see go/product-catalogue-photo-storage
        # Corresponds to the JSON property `googleUrl`
        # @return [String]
        attr_accessor :google_url
      
        # 
        # Corresponds to the JSON property `mediaFormat`
        # @return [String]
        attr_accessor :media_format
      
        # The mediaKey associated with the media. NOTE: This media key must be PII-free,
        # see go/product-catalogue-photo-storage
        # Corresponds to the JSON property `mediaKey`
        # @return [String]
        attr_accessor :media_key
      
        # Width and height of the original photo in pixels.
        # Corresponds to the JSON property `mediaSize`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreMediaItemProtoMediaSize]
        attr_accessor :media_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @google_url = args[:google_url] if args.key?(:google_url)
          @media_format = args[:media_format] if args.key?(:media_format)
          @media_key = args[:media_key] if args.key?(:media_key)
          @media_size = args[:media_size] if args.key?(:media_size)
        end
      end
      
      # Width and height of the original photo in pixels.
      class GeostoreMediaItemProtoMediaSize
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `originalHeightPx`
        # @return [Fixnum]
        attr_accessor :original_height_px
      
        # 
        # Corresponds to the JSON property `originalWidthPx`
        # @return [Fixnum]
        attr_accessor :original_width_px
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @original_height_px = args[:original_height_px] if args.key?(:original_height_px)
          @original_width_px = args[:original_width_px] if args.key?(:original_width_px)
        end
      end
      
      # A name for a Feature (street name, point of interest, city, building, etc). We
      # currently use NameProto for two essentially disjoint purposes: 1. Common names,
      # which can be language-specific, or have other kinds of variations. 2. Opaque
      # IDs, such as postal codes, which only have the `text` field set, and
      # potentially some flags. This includes internal-only features like template ids.
      # Each NameProto representing a common name corresponds to an assertion that a
      # fluent speaker or writer of a language would recognize NameProto.text to name
      # the given feature in that language. As such, NameProtos are stored in a
      # repeated field, often having: 1. multiple names with the same text and varying
      # languages, and 2. multiple names with the same language and varying texts.
      class GeostoreNameProto
        include Google::Apis::Core::Hashable
      
        # clang-format on The set of flags that apply to this name.
        # Corresponds to the JSON property `flag`
        # @return [Array<String>]
        attr_accessor :flag
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # These strings should be treated as opaque blobs. You can use
        # LanguageCodeConverter::FromOther to convert the string to a LanguageCode
        # reference. You can then call methods on the LanguageCode class to extract
        # language/script/region subtags (if any). See also http://g3doc/i18n/
        # identifiers/g3doc/using-iii. We place extra restrictions on languages in
        # addition to what the III library requires. See go/geo-schema-reference/feature-
        # properties/languages. This field may be missing if the name does not have a
        # concept of language but should be set if the language is unknown.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # ** DEPRECATED ** The name text provided in the original source data (UTF-8
        # encoding). This is the text provided in the source data unmodified with the
        # exception of being converted to UTF-8 and stripping extra leading, trailing
        # and duplicate whitespaces (if necessary).
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # The short name text (UTF-8 encoding). Acronyms/abbreviations should be
        # consistently used, for example "NE 57th St" rather than "Northeast 57th Street"
        # , "N.E 57th St." or some other variant. This field should be populated with
        # the chosen canonical version of the shortened name, based on per-term
        # transformations. For feature specific abbreviations (such as 'CA' for '
        # California'), one should define a separate name with FLAG_ABBREVIATED set. For
        # other variants of the shortened name that are not the canonical one, devise
        # client based logic (ex: query rewriting rules).
        # Corresponds to the JSON property `shortText`
        # @return [String]
        attr_accessor :short_text
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # The name text (UTF-8 encoding). Acronyms/abbreviations should be fully
        # expanded, for example "Northeast 57th Street" rather than "NE 57th St". They
        # can be shortened at display or geocode time. This decision prevents ambiguity
        # over such issues as whether "St" represents "Street" or "Saint". However, it
        # pushes language-specific knowledge into code. We will have libraries and data
        # files to contract acronyms/abbreviations at run-time.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flag = args[:flag] if args.key?(:flag)
          @language = args[:language] if args.key?(:language)
          @metadata = args[:metadata] if args.key?(:metadata)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @short_text = args[:short_text] if args.key?(:short_text)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # The container for all GConceptInstances associated with a feature.
      class GeostoreOntologyRawGConceptInstanceContainerProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `instance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreOntologyRawGConceptInstanceProto>]
        attr_accessor :instance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @instance = args[:instance] if args.key?(:instance)
        end
      end
      
      # A RawGConceptInstanceProto contains all data required by both internal and
      # external clients. We store the 'public' data in a GConceptInstanceProto and
      # the 'private' data inside of RawGConceptInstanceProto. NOTE: this doesn't
      # really match the design we want anymore. Please talk to the Geo Schema team if
      # you are planning to make use of the "private" fields below.
      class GeostoreOntologyRawGConceptInstanceProto
        include Google::Apis::Core::Hashable
      
        # A GConceptInstanceProto contains a GConceptID (which is the unique identifier
        # of a GConcept, a category in the Geo Ontology).
        # Corresponds to the JSON property `instance`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreGConceptInstanceProto]
        attr_accessor :instance
      
        # ** DEPRECATED ** Was this GConcept explicitly added by an edit? Examples of
        # gconcepts not added by edits include those inferred through geo ontology and
        # those mapped from legacy category forms by the feature updater. Note that it
        # is possible for both is_added_by_edit and is_inferred to be true - it means
        # this gconcept is added by an edit and there is also another more fine-grained
        # gconcept added by an edit.
        # Corresponds to the JSON property `isAddedByEdit`
        # @return [Boolean]
        attr_accessor :is_added_by_edit
        alias_method :is_added_by_edit?, :is_added_by_edit
      
        # RESERVED
        # Corresponds to the JSON property `isInferred`
        # @return [Boolean]
        attr_accessor :is_inferred
        alias_method :is_inferred?, :is_inferred
      
        # ** DEPRECATED ** These two fields combined describe the source of a
        # GConceptInstance. They are based on geostore/base/proto/datasourceprovider.
        # proto. Their use has been deprecated. Use the FieldMetadataProto inside
        # instance instead.
        # Corresponds to the JSON property `provider`
        # @return [String]
        attr_accessor :provider
      
        # 
        # Corresponds to the JSON property `sourceDataset`
        # @return [String]
        attr_accessor :source_dataset
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @instance = args[:instance] if args.key?(:instance)
          @is_added_by_edit = args[:is_added_by_edit] if args.key?(:is_added_by_edit)
          @is_inferred = args[:is_inferred] if args.key?(:is_inferred)
          @provider = args[:provider] if args.key?(:provider)
          @source_dataset = args[:source_dataset] if args.key?(:source_dataset)
        end
      end
      
      # Message to represent opening hours including regular weekly hours and a set of
      # exceptions.
      class GeostoreOpeningHoursProto
        include Google::Apis::Core::Hashable
      
        # Date delimited exceptions to the typical recurring opening hours. May only be
        # present if regular weekly hours are also specified.
        # Corresponds to the JSON property `exception`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreExceptionalHoursProto>]
        attr_accessor :exception
      
        # A BusinessHoursProto stores a weekly schedule of opening hours for a business (
        # represented as a BusinessHours message) together with other closely related
        # information that is Geo-specific.
        # Corresponds to the JSON property `regularHours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreBusinessHoursProto]
        attr_accessor :regular_hours
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @exception = args[:exception] if args.key?(:exception)
          @regular_hours = args[:regular_hours] if args.key?(:regular_hours)
        end
      end
      
      # Information about a feature's operations, e.g. when the feature is temporarily
      # closed.
      class GeostoreOperationsProto
        include Google::Apis::Core::Hashable
      
        # Records temporary status change of the feature, such as remodel, vacation, etc.
        # : the feature is temporarily (but not permanently) unavailable. This prevents
        # users from going to the feature. Supports an arbitrary number of past, present,
        # and future temporary closures, with the feature's data owner choosing which
        # range of past and future closures to permit or guarantee to keep. All start
        # and end dates must be unique from each other. If two consecutive dates are a
        # start and an end of a TemporaryClosureProto, then the two dates must be from
        # the same TemporaryClosureProto. Otherwise, exact dates may be missing so long
        # as there exist a possible sequence of temporary closures with both exact
        # start_date and end_date that keeps any known exact start_date and end_date.
        # The earliest temporary closure must begin after whenever initial operations
        # begin. Likewise, the latest temporary closure must end before whenever the
        # permanent closure begins. NOTE: does *not* guarantee chronological order.
        # Corresponds to the JSON property `temporaryClosure`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTemporaryClosureProto>]
        attr_accessor :temporary_closure
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @temporary_closure = args[:temporary_closure] if args.key?(:temporary_closure)
        end
      end
      
      # This message captures a border status override. For instance, if the
      # TYPE_BORDER feature between China and Hong Kong must be hidden on ditu.google.
      # cn (the Chinese domain for Google Maps) but may be displayed on other domains,
      # we will have a country override border status for "CN" set to
      # STATUS_NEVER_DISPLAY. At least one override restriction must be defined.
      # Currently the only supported restriction is by country code.
      class GeostoreOverrideBorderStatusProto
        include Google::Apis::Core::Hashable
      
        # The two-letter ISO 3166-1 country code corresponding to the domain this status
        # override applies to, when rendering the border polyline.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # The override status, from the BorderStatus enumeration. The value here must be
        # different from the main status (otherwise there's no point in providing the
        # override).
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Painted element logical color. Most legal definitions only specify a color
      # category (like "yellow") and don't specify an exact hue, rather stating that
      # the colors must be distinguishable from each other. We refer to this as the "
      # logical" color.
      class GeostorePaintedElementLogicalColorProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `color`
        # @return [String]
        attr_accessor :color
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @color = args[:color] if args.key?(:color)
        end
      end
      
      # Describes the parking allowances for a feature, or the situations and
      # requirements under which one may be permitted to park, such as certain vehicle
      # types, valet parking, and permit parking. Also describes the cost of parking,
      # which may vary based on the time and duration parked. Includes vehicle type,
      # any other conditions for eligibility, and the cost of parking, which may vary
      # based on the time and duration parked. If is_discount is set to true on a
      # given allowance, that allowance represents a discount that can be applied to
      # lower the cost of non-discount allowances specified on feature via
      # parking_provider_feature. In this way, allowances can be 'layered,' i.e.
      # appended, onto each other when denormalizing references via
      # parking_provider_feature.
      class GeostoreParkingAllowanceProto
        include Google::Apis::Core::Hashable
      
        # The type of parking for this allowance. Allowance details only apply to the
        # type of parking specified.
        # Corresponds to the JSON property `allowanceType`
        # @return [String]
        attr_accessor :allowance_type
      
        # If true, this allowance represents a discount rather than an individual rate;
        # any rate values specified in this allowance describe a discount to be applied
        # to the non-discount allowances in the ParkingProto.
        # Corresponds to the JSON property `isDiscount`
        # @return [Boolean]
        attr_accessor :is_discount
        alias_method :is_discount?, :is_discount
      
        # If this rate requires validation, this expresses the minimum purchase required
        # for validation in each applicable currency. Should have an ID of /
        # measurement_unit/money_value and consist of two properties: one with an ID of /
        # measurement_unit/money_value/amount and a float value with the amount, and
        # another with the ID /measurement_unit/money_value/currency and an ID value
        # with the MID of the proper currency (from the /finance/currency type). A value
        # of 0 suggests that no purchase is required. If empty, this suggests that no
        # validation is required for this rate.
        # Corresponds to the JSON property `minPurchaseForValidation`
        # @return [Array<Google::Apis::ContentwarehouseV1::FreebaseTopic>]
        attr_accessor :min_purchase_for_validation
      
        # Any additional details about the permit type; e.g. “Zone A”. In any local
        # languages. Should only be set if allowance_type is PERMIT.
        # Corresponds to the JSON property `permitType`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLanguageTaggedTextProto>]
        attr_accessor :permit_type
      
        # The types of services that this parking allowance applies to. For instance,
        # some cities have streets that only allow traditional taxis to pick up
        # passengers.
        # Corresponds to the JSON property `serviceType`
        # @return [Array<String>]
        attr_accessor :service_type
      
        # Describes the rate structures. Each TimeBasedRateProto defines a rate which
        # may apply based on a particular arrival, departure or utilization time; for
        # example, one rate might apply if arriving before 9am, and another might apply
        # regardless of arrival or departure time.
        # Corresponds to the JSON property `timeBasedRate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTimeBasedRateProto>]
        attr_accessor :time_based_rate
      
        # Restrictions on which vehicle type(s) the allowance applies to. By default,
        # the allowance applies to any vehicle types.
        # Corresponds to the JSON property `vehicleType`
        # @return [String]
        attr_accessor :vehicle_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowance_type = args[:allowance_type] if args.key?(:allowance_type)
          @is_discount = args[:is_discount] if args.key?(:is_discount)
          @min_purchase_for_validation = args[:min_purchase_for_validation] if args.key?(:min_purchase_for_validation)
          @permit_type = args[:permit_type] if args.key?(:permit_type)
          @service_type = args[:service_type] if args.key?(:service_type)
          @time_based_rate = args[:time_based_rate] if args.key?(:time_based_rate)
          @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
        end
      end
      
      # Used to describe the parking facilities provided by or available to a feature.
      # Features of TYPE_ROAD or TYPE_COMPOUND can have a ParkingProto (with
      # parking_provider_feature unset) that describes the parking facilities provided
      # by that feature. Features of TYPE_COMPOUND or TYPE_ESTABLISHMENT_POI can have
      # a ParkingProto (with parking_provider_feature set) to indicate that the
      # feature has dedicated parking and provide details about it, and defer some
      # details of the parking facilities to the referent feature(s). ParkingProto is
      # maintained by the Harbor Pilot team (go/harbor-pilot). Detailed modeling
      # information is described at go/parking-schema.
      class GeostoreParkingProto
        include Google::Apis::Core::Hashable
      
        # Describes the parking allowances for the feature, which are the situations and
        # requirements under which one is permitted to park at the feature’s parking
        # facilities, or discounts that a user may be eligible for.
        # Corresponds to the JSON property `allowance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreParkingAllowanceProto>]
        attr_accessor :allowance
      
        # Message to represent opening hours including regular weekly hours and a set of
        # exceptions.
        # Corresponds to the JSON property `openingHours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreOpeningHoursProto]
        attr_accessor :opening_hours
      
        # Indicates whether long-term parking is available at the feature; if true, long-
        # term parking is available at the feature and parking allowances may be present
        # on this feature, or parking_provider_feature may indicate defered parking
        # feature(s). If false, this is an explicit statement that there is no long-term
        # parking associated with this feature. If unset, we don't know whether there is
        # long-term parking associated with this feature. If false or unset, only
        # additional restrictions or short-term allowances will be populated.
        # Corresponds to the JSON property `parkingAvailable`
        # @return [Boolean]
        attr_accessor :parking_available
        alias_method :parking_available?, :parking_available
      
        # If empty, indicates that the feature containing this ParkingProto provides
        # parking facilities, which are described by this proto. If nonempty, indicates
        # that the feature with this ParkingProto does not contain parking facilities
        # itself, but visitors of this feature may use the parking available to the
        # referent feature(s). The referent feature(s) may themselves contain parking
        # facilities or defer to other features. A ParkingProto may defer parking
        # details to another feature, but still include its own data. This suggests that
        # a visitor of the referrer feature is eligible for different rates or discounts.
        # The data in these fields applies transitively, and any fields in a referrer
        # may be applied to the referent (for a visitor of the referrer).
        # Corresponds to the JSON property `parkingProviderFeature`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :parking_provider_feature
      
        # Describes any parking restrictions that apply to this feature. Should only be
        # set on road segments for which parking is explicitly prohibited for some or
        # all times; for roads which do not prohibit parking and for all other
        # facilities, the ability to park should be expressed using allowances. In the
        # instance that both a restriction and an allowance applies at a given time,
        # restrictions always have precedence over the same parking allowances. However,
        # explicit short-term allowances (PICKUP_GOODS, PICKUP_PASSENGERS) take
        # precedence over general NO_PARKING, NO_STANDING, or NO_STOPPING restrictions.
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreParkingRestrictionProto>]
        attr_accessor :restriction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowance = args[:allowance] if args.key?(:allowance)
          @opening_hours = args[:opening_hours] if args.key?(:opening_hours)
          @parking_available = args[:parking_available] if args.key?(:parking_available)
          @parking_provider_feature = args[:parking_provider_feature] if args.key?(:parking_provider_feature)
          @restriction = args[:restriction] if args.key?(:restriction)
        end
      end
      
      # Expresses a parking restriction on a road; i.e. times at which parking on the
      # road is prohibited.
      class GeostoreParkingRestrictionProto
        include Google::Apis::Core::Hashable
      
        # Times at which parking is prohibited.
        # Corresponds to the JSON property `restrictedHours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :restricted_hours
      
        # clang-format on The type of restriction that applies at this time.
        # Corresponds to the JSON property `restrictionType`
        # @return [String]
        attr_accessor :restriction_type
      
        # The types of services that this parking restriction applies to. We expect most
        # parking restrictions to apply to all services, but some airports have specific
        # rideshare parking or taxi parking zones.
        # Corresponds to the JSON property `serviceType`
        # @return [Array<String>]
        attr_accessor :service_type
      
        # The types of vehicles that this parking restriction applies to. For instance,
        # some streets may allow motorcycles to park but not automobiles or trucks.
        # Corresponds to the JSON property `vehicleType`
        # @return [Array<String>]
        attr_accessor :vehicle_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @restricted_hours = args[:restricted_hours] if args.key?(:restricted_hours)
          @restriction_type = args[:restriction_type] if args.key?(:restriction_type)
          @service_type = args[:service_type] if args.key?(:service_type)
          @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
        end
      end
      
      # This protocol buffer holds related data for features of type TYPE_PEAK and
      # TYPE_VOLCANO.
      class GeostorePeakProto
        include Google::Apis::Core::Hashable
      
        # Topographic prominence in meters: the height of the peak’s summit above the
        # lowest contour line encircling it and no higher summit.
        # Corresponds to the JSON property `prominenceMeters`
        # @return [Float]
        attr_accessor :prominence_meters
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @prominence_meters = args[:prominence_meters] if args.key?(:prominence_meters)
        end
      end
      
      # A crossing describes a path from the end point of a segment to the start point
      # of its sibling. Each individual crossing should uniquely represent a
      # physically distinct crossing in the real world. Pedestrian crossings are
      # bidirectional. This proto represents "simple" crossings. More complicated
      # crossings (such as the diagonal crosswalk at Shibuya Station in Tokyo) will be
      # represented using a separate pedestrian network. Example 1: Standard four way
      # crossing. Assume each road (A/B/C) has a crosswalk (denoted by a '-') right
      # before intersection X. Assume crossing at D is prohibited (denoted by a '%').
      # Assume "prime" roads (A',B',...) are OUT segments relative to X. A\\A' B//B' \\
      # // \\ // - - X - % // \\ // \\ C'//C D'\\D * A CROSSABLE PedestrianCrossing
      # should be added to A, B and C. * An UNCROSSABLE PedestrianCrossing should be
      # added to D. Example 2: Simple intersection with one crossing. Assume
      # intersection X was added to accommodate the crosswalk (through X, denoted by '-
      # '). Assume "prime" roads (A',B',...) are OUT segments relative to X. A\\A' \\ \
      # \ -X- \\ \\ B'\\B * A CROSSABLE PedestrianCrossing must be added to either A
      # or B, but not both because each real-world crossing should be represented
      # exactly once. Duplicative crossings may be arbitrarily removed.
      class GeostorePedestrianCrossingProto
        include Google::Apis::Core::Hashable
      
        # This value specifies the angle of the crosswalk. Zero degrees represents a
        # crosswalk perpendicular to the direction of travel, towards the right side of
        # the segment. The crosswalk angle, winds clockwise. Range [-90, 90]. The
        # following crosswalk would have a 15 degree angle: / / <--/---------------------
        # ----------- / /
        # Corresponds to the JSON property `angleDegrees`
        # @return [Float]
        attr_accessor :angle_degrees
      
        # This value enables crossing anywhere (not just at the segment’s endpoint),
        # typically used on long, low-traffic residential streets. This attribute is
        # only respected for trivial segment -> sibling routes. All other routes can
        # cross at a MapFacts intersection.
        # Corresponds to the JSON property `crossAnywhere`
        # @return [Boolean]
        attr_accessor :cross_anywhere
        alias_method :cross_anywhere?, :cross_anywhere
      
        # Crossing type is used as a restriction and can also be used for rendering.
        # Corresponds to the JSON property `crossingType`
        # @return [String]
        attr_accessor :crossing_type
      
        # The crossing offset defines a fraction between the distance from the segment
        # endpoint to the centerline of the crosswalk and the length of the segment. For
        # example, the segment length is 20 meters and the distance from segment end to
        # center of crosswalk is 2 meters, the value of offset will be 0.1.
        # Corresponds to the JSON property `offset`
        # @return [Float]
        attr_accessor :offset
      
        # Restrictions for this crossing (such as constructions on the crosswalk). They
        # must not have subpath or travel_mode.
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRestrictionProto>]
        attr_accessor :restriction
      
        # This value defines the full width of the crossing in the direction
        # perpendicular to the direction which pedestrians walk on the crossing (in
        # meters). The crossing is allowed to "spill" into the next segment (0.5 * width
        # can be greater than the offset). Cannot be a negative value.
        # Corresponds to the JSON property `width`
        # @return [Float]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @angle_degrees = args[:angle_degrees] if args.key?(:angle_degrees)
          @cross_anywhere = args[:cross_anywhere] if args.key?(:cross_anywhere)
          @crossing_type = args[:crossing_type] if args.key?(:crossing_type)
          @offset = args[:offset] if args.key?(:offset)
          @restriction = args[:restriction] if args.key?(:restriction)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Describes a single physical marker line.
      class GeostorePhysicalLineProto
        include Google::Apis::Core::Hashable
      
        # Applicable for DASHED and DOTTED_DASHED lines.
        # Corresponds to the JSON property `dashLengthMeters`
        # @return [Float]
        attr_accessor :dash_length_meters
      
        # Painted element logical color. Most legal definitions only specify a color
        # category (like "yellow") and don't specify an exact hue, rather stating that
        # the colors must be distinguishable from each other. We refer to this as the "
        # logical" color.
        # Corresponds to the JSON property `gapColor`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePaintedElementLogicalColorProto]
        attr_accessor :gap_color
      
        # Applicable for DASHED, DOTTED, and DOTTED_DASHED lines.
        # Corresponds to the JSON property `gapLengthMeters`
        # @return [Float]
        attr_accessor :gap_length_meters
      
        # 
        # Corresponds to the JSON property `material`
        # @return [Array<String>]
        attr_accessor :material
      
        # Painted element logical color. Most legal definitions only specify a color
        # category (like "yellow") and don't specify an exact hue, rather stating that
        # the colors must be distinguishable from each other. We refer to this as the "
        # logical" color.
        # Corresponds to the JSON property `paintColor`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePaintedElementLogicalColorProto]
        attr_accessor :paint_color
      
        # 
        # Corresponds to the JSON property `pattern`
        # @return [String]
        attr_accessor :pattern
      
        # A token that can be used to identify the version of the data about this marker
        # line.
        # Corresponds to the JSON property `physicalLineToken`
        # @return [String]
        attr_accessor :physical_line_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dash_length_meters = args[:dash_length_meters] if args.key?(:dash_length_meters)
          @gap_color = args[:gap_color] if args.key?(:gap_color)
          @gap_length_meters = args[:gap_length_meters] if args.key?(:gap_length_meters)
          @material = args[:material] if args.key?(:material)
          @paint_color = args[:paint_color] if args.key?(:paint_color)
          @pattern = args[:pattern] if args.key?(:pattern)
          @physical_line_token = args[:physical_line_token] if args.key?(:physical_line_token)
        end
      end
      
      # 
      class GeostorePointProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `latE7`
        # @return [Fixnum]
        attr_accessor :lat_e7
      
        # 
        # Corresponds to the JSON property `lngE7`
        # @return [Fixnum]
        attr_accessor :lng_e7
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lat_e7 = args[:lat_e7] if args.key?(:lat_e7)
          @lng_e7 = args[:lng_e7] if args.key?(:lng_e7)
          @metadata = args[:metadata] if args.key?(:metadata)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
        end
      end
      
      # PointWithHeightProto encodes lat/lng through PointProto and contains altitude
      # information.
      class GeostorePointWithHeightProto
        include Google::Apis::Core::Hashable
      
        # Altitude of this point is assumed to be relative to the ground level.
        # Corresponds to the JSON property `altitudeMeters`
        # @return [Float]
        attr_accessor :altitude_meters
      
        # 
        # Corresponds to the JSON property `point`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @altitude_meters = args[:altitude_meters] if args.key?(:altitude_meters)
          @point = args[:point] if args.key?(:point)
        end
      end
      
      # This protocol buffer is included from feature.proto as an optional message.
      # Political features represent the different ways that people are divided into
      # geographical regions.
      class GeostorePoliticalProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `capital`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :capital
      
        # The Gross Domestic Product of the political region measured in millions of
        # current United States dollars. It must not be negative.
        # Corresponds to the JSON property `grossDomesticProductUsdMillions`
        # @return [Float]
        attr_accessor :gross_domestic_product_usd_millions
      
        # Percentage of population that are literate within a political region. It must
        # be between 0 and 100.
        # Corresponds to the JSON property `literacyPercent`
        # @return [Float]
        attr_accessor :literacy_percent
      
        # The number of people in this political region. This field is intended to store
        # accurate population, not an estimation such as representative value for
        # population range. It must not be negative.
        # Corresponds to the JSON property `population`
        # @return [Fixnum]
        attr_accessor :population
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @capital = args[:capital] if args.key?(:capital)
          @gross_domestic_product_usd_millions = args[:gross_domestic_product_usd_millions] if args.key?(:gross_domestic_product_usd_millions)
          @literacy_percent = args[:literacy_percent] if args.key?(:literacy_percent)
          @population = args[:population] if args.key?(:population)
        end
      end
      
      # 
      class GeostorePolyLineProto
        include Google::Apis::Core::Hashable
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # A sequence of vertices connected by geodesics (the equivalent of straight
        # lines on the sphere). Adjacent vertices are connected by the shorter of the
        # two geodesics that connect them, i.e. all edges are 180 degrees or less. Note
        # that the edge definition becomes numerically unstable as the arc length
        # approaches 180 degrees. Polylines are generally expected to be non-self-
        # intersecting, but any such restriction is imposed by the user of the polyline
        # rather than the polyline itself.
        # Corresponds to the JSON property `vertex`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePointProto>]
        attr_accessor :vertex
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @vertex = args[:vertex] if args.key?(:vertex)
        end
      end
      
      # A general non-self-intersecting spherical polygon, consisting of one or more
      # loops defining multiple disconnected regions possibly with holes. All loops
      # should be oriented CCW around the region they define. This applies to the
      # exterior loop(s) as well as any holes. Within MapFacts (and underlying
      # infrastructure) the data fields may be replaced by a single shape_id; see
      # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
      # work with public functions in //geostore/base/public/polygon.h.
      class GeostorePolygonProto
        include Google::Apis::Core::Hashable
      
        # The polygon loops above are basically flat: each point has a latitude and a
        # longitude but no altitude. We don't want to build real 3D models here, but we
        # do want to be able to generate 2.5D models. A 2.5D model is built by
        # translating the flat polygon upward some distance (base) then extruding it
        # upward some additional distance (height). The elevation of the bottom of the
        # extruded polygon (above ground level).
        # Corresponds to the JSON property `baseMeters`
        # @return [Float]
        attr_accessor :base_meters
      
        # ** DEPRECATED ** This is part of a splitting strategy for large polygons,
        # which was never fully launched and we decided not to pursue. For features with
        # very complex polygonal geometry, we break up the polygon into pieces that
        # align with S2 cells at various levels. We do this for performance reasons as
        # some geometry operations have quadratic complexity with regards to the total
        # number of vertices. In these cases, we store the S2 cell ID corresponding to
        # the piece of the overall polygon that is described by this specific
        # PolygonProto message. Each polygon piece is expected to be fully contained by
        # the S2 cell corresponding to this cell ID. However, note that the S2 cell ID
        # is not required to correspond to the smallest S2 cell that fully contains the
        # polygon (and often won't be). In addition, polygon pieces are required to not
        # have any overlap (which translates to having entirely disjoint S2 cell IDs, i.
        # e. one can not be parent (or grand parent, etc.) of another).
        # Corresponds to the JSON property `cellId`
        # @return [Fixnum]
        attr_accessor :cell_id
      
        # Encoding of the polygon using S2Polygon::Encode()'s compressed representation.
        # Corresponds to the JSON property `encoded`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded
      
        # The distance from the bottom of the extruded polygon to the top.
        # Corresponds to the JSON property `heightMeters`
        # @return [Float]
        attr_accessor :height_meters
      
        # ** DEPRECATED ** We have switched to using exclusively the encoded form in the
        # wire format to and from MapFacts, so this field should never be populated
        # there. See go/encoded-polygons for more info. "Classic" polygon representation,
        # defined by one or more loops. The last vertex of each polyline is implicitly
        # connected to the first vertex. All loops should be specified in CCW order.
        # Corresponds to the JSON property `loop`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePolyLineProto>]
        attr_accessor :loop
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # A unique identifier for this polygon's data which is being held externally in
        # Shapestore (see go/shapestore). This is only ever set internally within
        # MapFacts or underlying infrastructure and if set is set in lieu of other
        # fields. Clients of MapFacts (or anyone downstream of them) can rely on the
        # guarantee that this field will never be set and that the actual data for the
        # polygon will be present instead. This field has been deprecated in favor of
        # FeatureProto.internal.polygon_shape_id
        # Corresponds to the JSON property `shapeId`
        # @return [String]
        attr_accessor :shape_id
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # Some polygons are known to be rough proxies for a feature's "real" polygonal
        # representation. Such polygons are generally unsuitable for display. Rendering
        # clients should not show these in most cases. Polygons unsuitable for display
        # do have other uses, such as user location or containment analysis, or as an
        # input to learning algorithms. This is an orthogonal concept to FeatureProto.
        # synthetic_geometry, which only pertains to the method by which a polygon was
        # created, rather than its fidelity to ground truth. For features that have
        # multiple polygons, this bit should be consistently set to the same value on
        # all polygons.
        # Corresponds to the JSON property `unsuitableForDisplay`
        # @return [Boolean]
        attr_accessor :unsuitable_for_display
        alias_method :unsuitable_for_display?, :unsuitable_for_display
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_meters = args[:base_meters] if args.key?(:base_meters)
          @cell_id = args[:cell_id] if args.key?(:cell_id)
          @encoded = args[:encoded] if args.key?(:encoded)
          @height_meters = args[:height_meters] if args.key?(:height_meters)
          @loop = args[:loop] if args.key?(:loop)
          @metadata = args[:metadata] if args.key?(:metadata)
          @shape_id = args[:shape_id] if args.key?(:shape_id)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @unsuitable_for_display = args[:unsuitable_for_display] if args.key?(:unsuitable_for_display)
        end
      end
      
      # A pose is an object's position in space, as well as its orientation. All
      # fields except lat and lng are optional. All fields are in the WGS-84 ellipsoid,
      # and rotations are right-hand rule (i.e. if the right hand thumb points along
      # a vector, curled fingers indicate positive rotation direction). An un-rotated
      # pose would be pointing due North, along the surface of the ellipsoid.
      # Rotations are applied in the order: yaw, pitch, roll. Note that the rotation
      # axes are rotated along with the model for each rotation step. WARNING: This
      # proto is not meant to be used directly. Please use the provided libraries: //
      # geostore/base/public/pose.h //java/com/google/geostore/base/Pose.java
      class GeostorePoseProto
        include Google::Apis::Core::Hashable
      
        # The height of the poses above the WGS-84 ellipsoid in meters.
        # Corresponds to the JSON property `altitude`
        # @return [Float]
        attr_accessor :altitude
      
        # The index of the PoseProto in a list of PoseProtos.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # The latitude of the pose in degrees [-90, 90].
        # Corresponds to the JSON property `lat`
        # @return [Float]
        attr_accessor :lat
      
        # The longitude of the pose in degrees (-180,180].
        # Corresponds to the JSON property `lng`
        # @return [Float]
        attr_accessor :lng
      
        # The rotation around the longitude line East tangent in degrees [-90, 90].
        # Corresponds to the JSON property `pitch`
        # @return [Float]
        attr_accessor :pitch
      
        # The rotation around the latitude line North tangent in degrees (-180, 180].
        # Corresponds to the JSON property `roll`
        # @return [Float]
        attr_accessor :roll
      
        # The rotation around the Up vector, from North, in degrees (-180, 180].
        # Corresponds to the JSON property `yaw`
        # @return [Float]
        attr_accessor :yaw
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @altitude = args[:altitude] if args.key?(:altitude)
          @index = args[:index] if args.key?(:index)
          @lat = args[:lat] if args.key?(:lat)
          @lng = args[:lng] if args.key?(:lng)
          @pitch = args[:pitch] if args.key?(:pitch)
          @roll = args[:roll] if args.key?(:roll)
          @yaw = args[:yaw] if args.key?(:yaw)
        end
      end
      
      # This message represents nutrition facts for a food dish.
      class GeostorePriceInfoFoodNutritionFacts
        include Google::Apis::Core::Hashable
      
        # This message denotes calories information with an upper bound and lower bound
        # range.
        # Corresponds to the JSON property `calories`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsCaloriesFact]
        attr_accessor :calories
      
        # This message denotes nutrition information with an upper bound and lower bound
        # range and can be represented by mass unit.
        # Corresponds to the JSON property `cholesterol`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsNutritionFact]
        attr_accessor :cholesterol
      
        # This message denotes nutrition information with an upper bound and lower bound
        # range and can be represented by mass unit.
        # Corresponds to the JSON property `protein`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsNutritionFact]
        attr_accessor :protein
      
        # This message denotes nutrition information with an upper bound and lower bound
        # range and can be represented by mass unit.
        # Corresponds to the JSON property `sodium`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsNutritionFact]
        attr_accessor :sodium
      
        # This message denotes nutrition information with an upper bound and lower bound
        # range and can be represented by mass unit.
        # Corresponds to the JSON property `totalCarbohydrate`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsNutritionFact]
        attr_accessor :total_carbohydrate
      
        # This message denotes nutrition information with an upper bound and lower bound
        # range and can be represented by mass unit.
        # Corresponds to the JSON property `totalFat`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoFoodNutritionFactsNutritionFact]
        attr_accessor :total_fat
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calories = args[:calories] if args.key?(:calories)
          @cholesterol = args[:cholesterol] if args.key?(:cholesterol)
          @protein = args[:protein] if args.key?(:protein)
          @sodium = args[:sodium] if args.key?(:sodium)
          @total_carbohydrate = args[:total_carbohydrate] if args.key?(:total_carbohydrate)
          @total_fat = args[:total_fat] if args.key?(:total_fat)
        end
      end
      
      # This message denotes calories information with an upper bound and lower bound
      # range.
      class GeostorePriceInfoFoodNutritionFactsCaloriesFact
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lowerAmount`
        # @return [Fixnum]
        attr_accessor :lower_amount
      
        # Unit of the given calories information.
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # 
        # Corresponds to the JSON property `upperAmount`
        # @return [Fixnum]
        attr_accessor :upper_amount
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lower_amount = args[:lower_amount] if args.key?(:lower_amount)
          @unit = args[:unit] if args.key?(:unit)
          @upper_amount = args[:upper_amount] if args.key?(:upper_amount)
        end
      end
      
      # This message denotes nutrition information with an upper bound and lower bound
      # range and can be represented by mass unit.
      class GeostorePriceInfoFoodNutritionFactsNutritionFact
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lowerAmount`
        # @return [Float]
        attr_accessor :lower_amount
      
        # Unit of the given nutrition information.
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # 
        # Corresponds to the JSON property `upperAmount`
        # @return [Float]
        attr_accessor :upper_amount
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lower_amount = args[:lower_amount] if args.key?(:lower_amount)
          @unit = args[:unit] if args.key?(:unit)
          @upper_amount = args[:upper_amount] if args.key?(:upper_amount)
        end
      end
      
      # 
      class GeostorePriceInfoProto
        include Google::Apis::Core::Hashable
      
        # The actual food menus. This is a repeated field because a restaurant may offer
        # multiple menus, e.g. for different language or for different available time,
        # such as holidays vs non-holidays.
        # Corresponds to the JSON property `priceList`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListProto>]
        attr_accessor :price_list
      
        # All URLs that give price list information for this establishment. For food
        # menus, this would represent menu_urls. Note that this field is a repeated list
        # of UrlListProtos. Each UrlListProto instance in the list is intended to hold
        # lists of URLs that are translations of the same URL.
        # Corresponds to the JSON property `priceListUrl`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreUrlListProto>]
        attr_accessor :price_list_url
      
        # Providers of PriceInfo (e.g. SinglePlatform, YEXT) send verified and
        # unverified listings. PriceInfoStatus is used to encapsulate this information.
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePriceInfoStatus]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @price_list = args[:price_list] if args.key?(:price_list)
          @price_list_url = args[:price_list_url] if args.key?(:price_list_url)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Providers of PriceInfo (e.g. SinglePlatform, YEXT) send verified and
      # unverified listings. PriceInfoStatus is used to encapsulate this information.
      class GeostorePriceInfoStatus
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isVerified`
        # @return [Boolean]
        attr_accessor :is_verified
        alias_method :is_verified?, :is_verified
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_verified = args[:is_verified] if args.key?(:is_verified)
        end
      end
      
      # A PriceListNameInfoProto is used by PriceListProto and fields and messages
      # contained in it for storing names, descriptions, languages, and IDs. The name
      # field and the description field must be in the same language, as specified by
      # the language field. None of the fields in this proto is required, although it
      # is not expected to have the language field set unless there is a name or
      # description. When the language field is not set, it is understood to be the
      # preferred language of the locale where the establishment is located. An empty
      # string for any of the fields is treated the same as having the fields not set.
      class GeostorePriceListNameInfoProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # IDs are intended to be unique identifiers of PriceInfoLists, Sections, and
        # Menu items. This is enforced by the ID_DUPLICATE_PRICE_LIST_ID lint.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # We place extra restrictions on languages in addition to what the III library
        # requires. See go/geo-schema-reference/feature-properties/languages.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @id = args[:id] if args.key?(:id)
          @language = args[:language] if args.key?(:language)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # A PriceListProto can be used to represent any type of price lists, one of
      # which is a menu of food and drinks. It contains names and descriptions,
      # together with its source URL list if it is extracted or attributed to that URL.
      # The names and descriptions are represented using repeated PriceListNameInfo
      # fields to allow versions in different languages. A PriceListProto may contain
      # multiple sections; in the context of a food menu, this would be multiple menu
      # sections, e.g. for breakfast, lunch, dinner, prix fixe, or dinner for two, etc.
      # At least one menu section must be present. Each section contains a number of
      # items; for food menus, it may be FoodMenuItems defined below. At least one
      # item must be present in each section.
      class GeostorePriceListProto
        include Google::Apis::Core::Hashable
      
        # The time period when this price list is available. Establishments are not
        # required to give available_time for any given price list, however, when this
        # field is not set, the price list is understood as available any time the
        # establishment is open.
        # Corresponds to the JSON property `availableTime`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :available_time
      
        # Cuisine information if the location the price lists attached to is an eligible
        # feature for a food menu price list. Cuisine information should also only show
        # up in a food price list.
        # Corresponds to the JSON property `cuisines`
        # @return [Array<String>]
        attr_accessor :cuisines
      
        # The repeated name_info field is for price lists listed in multiple languages.
        # When a price list has no names or descriptions, the size of the repeated field
        # name_info may be 0. There should be at most one name_info for any given
        # language.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        # Each price list may have multiple sections. Note that these sections within
        # the same price list should most times contain only the same type of items for
        # sale, e.g. all sections should usually contain only food items if the
        # enclosing price list is representing food menu. However, sometimes such a
        # requirement may be wrong, for example, McDonald's may sell burgers as well as
        # toys, and the toys may be in its own section. Thus we don't enforce any
        # requirement that all sections contain only the same type of items.
        # Corresponds to the JSON property `section`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListSectionProto>]
        attr_accessor :section
      
        # Hold a list of URLs, usually to contain translations of a single URL.
        # Corresponds to the JSON property `sourceUrl`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreUrlListProto]
        attr_accessor :source_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @available_time = args[:available_time] if args.key?(:available_time)
          @cuisines = args[:cuisines] if args.key?(:cuisines)
          @name_info = args[:name_info] if args.key?(:name_info)
          @section = args[:section] if args.key?(:section)
          @source_url = args[:source_url] if args.key?(:source_url)
        end
      end
      
      # A PriceListSectionProto is used to store a section of a PriceListProto. For
      # example, for a PriceListProto representing a food menu, a
      # PriceListSectionProto represents a menu section. Each PriceListSectionProto
      # contains a repeated list of items for sale; these items can be products or
      # services. Right now every section should contain items of one type.
      class GeostorePriceListSectionProto
        include Google::Apis::Core::Hashable
      
        # Message containing calls to action specified by the business owner.
        # Corresponds to the JSON property `callToAction`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCallToActionProto]
        attr_accessor :call_to_action
      
        # To store food and drink items when the containing PriceListSectionProto is a
        # food menu section.
        # Corresponds to the JSON property `foodItem`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFoodMenuItemProto>]
        attr_accessor :food_item
      
        # To store any items when the containing PriceListSectionProto is not food /
        # legacy services.
        # Corresponds to the JSON property `item`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreComposableItemProto>]
        attr_accessor :item
      
        # This has to have at most one value.
        # Corresponds to the JSON property `itemType`
        # @return [Array<String>]
        attr_accessor :item_type
      
        # One or more media items (photos, videos, etc.) describing this section /
        # category.
        # Corresponds to the JSON property `media`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreMediaItemProto>]
        attr_accessor :media
      
        # The repeated name_info field is for price list sections listed in multiple
        # languages. When a price list section has no names or descriptions, the size of
        # the repeated field name_info may be 0. There should be at most one name_info
        # for any given language.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceListNameInfoProto>]
        attr_accessor :name_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
          @food_item = args[:food_item] if args.key?(:food_item)
          @item = args[:item] if args.key?(:item)
          @item_type = args[:item_type] if args.key?(:item_type)
          @media = args[:media] if args.key?(:media)
          @name_info = args[:name_info] if args.key?(:name_info)
        end
      end
      
      # This message represents a price range of an attribute. The meaning of the
      # price bounds is domain specific. But mainly they are soft bounds for a normal
      # usage. E.g. "restaurant prices" are subject to an higher level of "soft"
      # bounds than "museum admission price"
      class GeostorePriceRangeProto
        include Google::Apis::Core::Hashable
      
        # Currency code for the price range: a valid currency code from i18n/identifiers/
        # currencycode.h. Lower and upper price are both assumed to use the same
        # currency.
        # Corresponds to the JSON property `currency`
        # @return [String]
        attr_accessor :currency
      
        # This message allows unbounded price ranges. e.g. Lower_price is undefined. At
        # least one of the two prices must be set for the price range to be meaningful.
        # Corresponds to the JSON property `lowerPrice`
        # @return [Float]
        attr_accessor :lower_price
      
        # clang-format on
        # Corresponds to the JSON property `units`
        # @return [String]
        attr_accessor :units
      
        # 
        # Corresponds to the JSON property `upperPrice`
        # @return [Float]
        attr_accessor :upper_price
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @currency = args[:currency] if args.key?(:currency)
          @lower_price = args[:lower_price] if args.key?(:lower_price)
          @units = args[:units] if args.key?(:units)
          @upper_price = args[:upper_price] if args.key?(:upper_price)
        end
      end
      
      # PropertyValueStatusProto specifies what we know about a field corresponding to
      # FeaturePropertyId's value in the absence of any specific value. For now, it
      # just indicates when we know that there is no value. Eventually it might also
      # indicate that we know it has value, just not what it is, etc.
      class GeostorePropertyValueStatusProto
        include Google::Apis::Core::Hashable
      
        # Message to represent a "feature property" as an abstract construct. Most
        # feature properties are mapped one to one with the EditProto field types.
        # However in some cases the EditProto field type granularity is too coarse to
        # support use-cases that rely on feature properties (such as per-value rights
        # tracking). When that is the case, the feature property is augmented with a
        # secondary field.
        # Corresponds to the JSON property `propertyId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeaturePropertyIdProto]
        attr_accessor :property_id
      
        # `value_status` specifies whether the feature has a value for the property.
        # This should always be set to something other than the default value (`
        # PROPERTY_VALUE_STATUS_UNSPECIFIED`).
        # Corresponds to the JSON property `valueStatus`
        # @return [String]
        attr_accessor :value_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @property_id = args[:property_id] if args.key?(:property_id)
          @value_status = args[:value_status] if args.key?(:value_status)
        end
      end
      
      # This is a minimal version of SourceInfoProto.
      class GeostoreProvenanceProto
        include Google::Apis::Core::Hashable
      
        # The dataset from which this the referenced data was created. The content of
        # this string will be determined by the data provider, and may encode extra
        # information, such as data confidence.
        # Corresponds to the JSON property `dataset`
        # @return [String]
        attr_accessor :dataset
      
        # The data provider from which the referenced data was generated.
        # Corresponds to the JSON property `provider`
        # @return [String]
        attr_accessor :provider
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dataset = args[:dataset] if args.key?(:dataset)
          @provider = args[:provider] if args.key?(:provider)
        end
      end
      
      # This message is embedded within a FeatureProto. It has rank calculation
      # details such as available rank signals and rank signal mixer used to compute
      # final rank. For more details, see the Oyster Rank wiki page: http://wiki.corp.
      # google.com/twiki/bin/view/Main/OysterRank
      class GeostoreRankDetailsProto
        include Google::Apis::Core::Hashable
      
        # A list of signals. Each one is extracted separately by a SignalExtractor.
        # Corresponds to the JSON property `signal`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRankSignalProto>]
        attr_accessor :signal
      
        # The signal mixer that was used to calculate the rank.
        # Corresponds to the JSON property `signalMixerType`
        # @return [String]
        attr_accessor :signal_mixer_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @signal = args[:signal] if args.key?(:signal)
          @signal_mixer_type = args[:signal_mixer_type] if args.key?(:signal_mixer_type)
        end
      end
      
      # This message is embedded in the RankDetailsProto (below). It represents one
      # rank signal, which is a floating point value estimating the Oyster Rank of the
      # feature.
      class GeostoreRankSignalProto
        include Google::Apis::Core::Hashable
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # A value in the range [0, 1] estimating Oyster Rank according to this signal.
        # Non-provider specific signals (e.g. SIGNAL_POPULATION) are interpreted by some
        # common code in the ranking pipeline. Because of that, data providers should
        # leave this field empty when setting such signals (so that the rank assignment
        # can be uniform across all features regardless of contributing data providers).
        # On the other hand, provider-specific signals (e.g. SIGNAL_ZENRIN_CITY_CATEGORY)
        # are required to specify the rank field (it is not optional for them). That is
        # because no code other than that of the provider itself will be able to fill in
        # a meaningful value later on. We don't want clients to be reading from the
        # raw_scalar / raw_string fields to interpret the data.
        # Corresponds to the JSON property `rank`
        # @return [Float]
        attr_accessor :rank
      
        # The raw scalar value that was used to compute 'rank' above. The meaning of
        # this attribute changes depending on the signal type.
        # Corresponds to the JSON property `rawScalar`
        # @return [Float]
        attr_accessor :raw_scalar
      
        # The raw string value that was used to compute 'rank' above. The meaning of
        # this attribute changes depending on the signal type.
        # Corresponds to the JSON property `rawString`
        # @return [String]
        attr_accessor :raw_string
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @rank = args[:rank] if args.key?(:rank)
          @raw_scalar = args[:raw_scalar] if args.key?(:raw_scalar)
          @raw_string = args[:raw_string] if args.key?(:raw_string)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A RawDataProto is a key-value pair that represents arbitrary source data from
      # a particular provider. Raw data can be attached to features using their
      # source_info field.
      class GeostoreRawDataProto
        include Google::Apis::Core::Hashable
      
        # The key associated with this data item. For source data in shape file format,
        # this will typically be a column name. Keys need to be unique with respect to a
        # particular data source (see DataSourceProto), but they do not need to be
        # globally unique. You can look up the documentation for a key (e.g. a longer
        # label and description) by following the source_id link of the parent
        # SourceInfoProto, which takes you to a TYPE_DATA_SOURCE feature, and then
        # looking up the corresponding RawMetadataProto object for this key in that
        # feature's optional data_source field.
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # All data items are represented as strings, the logic being that it is easy to
        # convert other data types to strings, and there is no need to access this data
        # efficiently.
        # Corresponds to the JSON property `valueString`
        # @return [String]
        attr_accessor :value_string
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @value_string = args[:value_string] if args.key?(:value_string)
        end
      end
      
      # 
      class GeostoreRawMetadataProto
        include Google::Apis::Core::Hashable
      
        # Method to use when conflating together RawDataProto values at the same key NB:
        # If you add a new ConflationMethod, then you must add the corresponding logic
        # to MergeRawData to conflate the RawDataProto values using this method.
        # Corresponds to the JSON property `conflationMethod`
        # @return [String]
        attr_accessor :conflation_method
      
        # Self-contained documentation about what this field represents and how its
        # values are encoded.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The key being described.
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # A longer, human-readable name associated with this key. The label might be
        # used in a data explorer tool, for example.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conflation_method = args[:conflation_method] if args.key?(:conflation_method)
          @description = args[:description] if args.key?(:description)
          @key = args[:key] if args.key?(:key)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # A latitude-longitude rectangle, represented as two diagonally opposite points "
      # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
      # includes its boundary. The latitude bounds must be in the range -90 to 90
      # degrees inclusive, and the longitude bounds must be in the range -180 to 180
      # degrees inclusive. Various cases include: - If lo == hi, the rectangle
      # consists of a single point. - If lo.longitude > hi.longitude, the longitude
      # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
      # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
      # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
      # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
      # latitude range is empty.
      class GeostoreRectProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hi`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :hi
      
        # 
        # Corresponds to the JSON property `lo`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :lo
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hi = args[:hi] if args.key?(:hi)
          @lo = args[:lo] if args.key?(:lo)
        end
      end
      
      # A collection of information that applies to a polygonal area.
      class GeostoreRegulatedAreaProto
        include Google::Apis::Core::Hashable
      
        # The set of restrictions that apply to a zone. These restrictions may limit the
        # routability of every segment contained within the defined feature.polygon.
        # Repeated restrictions are treated collectively as an OR meaning that segments
        # in the zone are only routable if none of the restrictions apply. If any
        # segments within the defined polygon should not have these restrictions applied,
        # they must list this regulated area's feature id in their feature.
        # exempt_regulated_area field.
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRestrictionProto>]
        attr_accessor :restriction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @restriction = args[:restriction] if args.key?(:restriction)
        end
      end
      
      # This message is embedded within a FeatureProto, and represents a geographic or
      # logical relationship of that feature to some other feature. Note that some
      # relation types are there purely for the purpose of grouping together other
      # relation types. They are noted as ABSTRACT in comments. Other relation types
      # are no longer supported / in use. They are noted as DEPRECATED in comments (
      # and marked with the standard deprecated option, too). Other relation types are
      # reserved for future use or just not intended for use at all, for various
      # internal reasons. They are noted as RESERVED in comments. WARNING: Updates to
      # this proto within a FeatureProto's related_feature field handled by standalone
      # pipelines and are NOT atomic with regard to updates to the features being
      # referenced; we do not guarantee that a given MapFacts snapshot will be
      # consistent between this field and the related features.
      class GeostoreRelationProto
        include Google::Apis::Core::Hashable
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # If and only if the other feature is of TYPE_COUNTRY, the 2-letter country code.
        # This is the FLAG_COUNTRY_CODE_2 name of the country component.
        # Corresponds to the JSON property `otherFeatureCountryCode`
        # @return [String]
        attr_accessor :other_feature_country_code
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `otherFeatureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :other_feature_id
      
        # RESERVED
        # Corresponds to the JSON property `otherFeatureName`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreNameProto>]
        attr_accessor :other_feature_name
      
        # If and only if the other feature is of TYPE_DISPUTED_AREA, the territorial
        # administrator found in its GeopoliticalAttachmentProto.administered_by field,
        # if any. Since this string is copied exactly, it may be a 2-letter country code
        # or another type of descriptive string.
        # Corresponds to the JSON property `otherFeatureTerritorialAdministrator`
        # @return [String]
        attr_accessor :other_feature_territorial_administrator
      
        # The type of the feature to which we're relating.
        # Corresponds to the JSON property `otherFeatureType`
        # @return [Fixnum]
        attr_accessor :other_feature_type
      
        # ** DEPRECATED ** If relation is exactly RELATION_OVERLAPS but not any of its
        # subcategories, overlap_fraction contains an estimate of the fraction of the
        # geometry of this feature that intersects with the other feature, ranging from
        # 0.0 to 1.0. Note that this is a rough estimate based on cell coverings, and
        # may not be very accurate. In particular, values of 0.0 and 1.0 are possible,
        # even though in principle they should not be.
        # Corresponds to the JSON property `overlapFraction`
        # @return [Float]
        attr_accessor :overlap_fraction
      
        # The relationship of the feature that contains this RelationProto to the
        # feature other_feature_id. Note the relation_is_reversed field below. Some
        # relations imply weak references, other strong ones. Strong references are
        # annotated above but you can also refer to IsRelationStrong() in geostore/base/
        # public/relation.h.
        # Corresponds to the JSON property `relation`
        # @return [String]
        attr_accessor :relation
      
        # RESERVED
        # Corresponds to the JSON property `relationIsReversed`
        # @return [Boolean]
        attr_accessor :relation_is_reversed
        alias_method :relation_is_reversed?, :relation_is_reversed
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @other_feature_country_code = args[:other_feature_country_code] if args.key?(:other_feature_country_code)
          @other_feature_id = args[:other_feature_id] if args.key?(:other_feature_id)
          @other_feature_name = args[:other_feature_name] if args.key?(:other_feature_name)
          @other_feature_territorial_administrator = args[:other_feature_territorial_administrator] if args.key?(:other_feature_territorial_administrator)
          @other_feature_type = args[:other_feature_type] if args.key?(:other_feature_type)
          @overlap_fraction = args[:overlap_fraction] if args.key?(:overlap_fraction)
          @relation = args[:relation] if args.key?(:relation)
          @relation_is_reversed = args[:relation_is_reversed] if args.key?(:relation_is_reversed)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
        end
      end
      
      # A restriction group represents common properties of a set of restrictions on
      # segments that are associated with the same underlying cause across a
      # geographic region. Every segment referenced by this restriction group should
      # have at least one restriction that refers backs to this restriction group. The
      # standard feature properties have the following interpretations: name - A name
      # that represents the name for this restriction group. kg_property - A reference
      # back to a KG event in case this restriction group belongs to an event in KG. /
      # geo/type/restriction_group/associated_event contains a mid to the associated
      # event.
      class GeostoreRestrictionGroupProto
        include Google::Apis::Core::Hashable
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # FeatureId of all segments that have a RestrictionProto referring back to this
        # RestrictionGroup.
        # Corresponds to the JSON property `segment`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :segment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @segment = args[:segment] if args.key?(:segment)
        end
      end
      
      # A restriction is an expression that limits when an action can be taken. Each
      # restriction has a set of conditions. If all of the conditions are true, then
      # the restriction applies and the action cannot be taken. For example, the
      # restriction "no turns 3-5pm except buses" would have two conditions: "time is
      # 3-5pm" and "vehicle is not a bus". If both of these conditions apply, the
      # restriction is true, and the turn is prohibited. Multiple restrictions may
      # apply to the same action. Clients handle this by always declaring
      # RestrictionProto as a "repeated" element. The semantics of having multiple
      # restrictions are that if any restriction applies, then the action cannot be
      # taken. In other words, restrictions are OR-ed together. Putting all of this
      # together, a set of RestrictionProtos can be interpreted as an bool expression
      # in disjunctive normal form: (A and B) or (D and E and F) or (G and H) The
      # action is prohibited if this expression is true. Note that a restriction with
      # no conditions is always true, i.e. its action is always prohibited.
      class GeostoreRestrictionProto
        include Google::Apis::Core::Hashable
      
        # The restriction only applies in these specific autonomous driving product
        # scenarios. NOTE: This should only be set on restrictions with
        # TRAVEL_AUTONOMOUS_VEHICLE travel mode.
        # Corresponds to the JSON property `autonomousDrivingProducts`
        # @return [Array<String>]
        attr_accessor :autonomous_driving_products
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `intersectionGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :intersection_group
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `restrictionGroup`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :restriction_group
      
        # When specified, restriction applies only at particular times (operating hours
        # or times of the year: reversing lanes, seasonal roads, no left turns from 3-
        # 5pm Mon-Fri except holidays). Otherwise, restriction is in effect at all times.
        # Corresponds to the JSON property `schedule`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :schedule
      
        # The scope that the restriction applies to. - SCOPE_DIRECTION means the segment/
        # sibling pair is restricted in the direction of the segment that contains this
        # RestrictionProto. For segment/sibling pairs with pedestrian facilities (and
        # thus side-of-road routing) the RestrictionProto restricts both facilities in
        # the direction of the segment (assuming that the restriction applies to travel
        # mode TRAVEL_PEDESTRIAN). - SCOPE_SIDE means the RestrictionProto applies only
        # to the side of road that the containing segment represents. That sibling's
        # pedestrian facility is restricted in both directions. Schema constraints: -
        # SCOPE_SIDE must be set if and only if travel_mode == [TRAVEL_PEDESTRIAN] and
        # the segment containing the restriction has PEDESTRIAN_FACILITY_PRESENT. Such
        # restrictions must have no subpath. - All other restrictions must have this
        # field set to SCOPE_DIRECTION (whether explicitly or implicitly). This
        # distinction is necessary for cases such as pedestrian facility on one-way
        # segment/sibling roads.
        # Corresponds to the JSON property `scope`
        # @return [String]
        attr_accessor :scope
      
        # Restriction Style defines the semantics of the subpath field, as defined above
        # in the documentation of subpath.
        # Corresponds to the JSON property `style`
        # @return [String]
        attr_accessor :style
      
        # "subpath" specifies the GeoStore segments that this restriction applies to,
        # according to the restriction_style field below. Segments that are referenced
        # by this subpath field also refer to this feature back via the same subpath
        # field. For all styles of restriction, all segments in the subpath must have
        # identical copies of the restriction. In other words, restrictions are
        # duplicated along every segment in the subpath. Note that subpaths of length 1
        # do not have any purpose and are disallowed. Note that it is possible to
        # represent restrictions either using STYLE_CONTIGUOUS, or depending on the
        # length of the subpath, one of the more specific STYLE_SINGLE, STYLE_TURN, or
        # STYLE_IN_OUT. New code should use the more specific alternatives if possible,
        # as they support instant updates. For restriction_style == STYLE_CONTIGUOUS (
        # the default): "subpath" can either be empty, for a single-segment restriction,
        # or it specifies exactly the sequence of segments which this restriction
        # applies to. The subpath may be used to specify a turn restriction (a subpath
        # of length 2) or to prohibit more complex maneuvers. For example, when merging
        # onto a road from the right-hand side it may not be possible to make an
        # immediate left turn due to insufficient time to cross the intervening lanes or
        # the presence of a physical barrier. This would be indicated by a subpath
        # restriction of length 3 or more. For restriction_style == STYLE_SINGLE: The
        # subpath field of the Restriction must be empty. The restriction applies only
        # to the segment it is attached to. There must not be an intersection group
        # specified. For restriction_style == STYLE_TURN: The subpath field of the
        # Restriction must contain exactly two segments. The first is called the "
        # in_segment", the second is the "out_segment". They must be contiguous, i.e.
        # the end intersection of the in_segment is the start intersection of the
        # out_segment. The restriction applies only to a direct maneuver from the
        # in_segment to the out_segment. Other paths from the in_segment to the
        # out_segment are not restricted. There must not be an intersection group
        # specified. For restriction_style == STYLE_IN_OUT: The subpath field of the
        # Restriction must contain exactly two segments. The first is called the "
        # in_segment", the second is the "out_segment". Note that the two segments
        # define paths, but may not actually be one. The end intersection of the
        # in_segment must be in an intersection group which also contains the start
        # intersection of the out_segment. The in- and out-segments are not required to
        # be adjacent, but may be. Either way, the restriction applies to any path from
        # the in_segment to the out_segment through the intersection group, not just
        # direct turns. The intersection_group must be specified. Note that clients
        # which read restrictions and need to know which paths are restricted by a given
        # IN_OUT restriction must expand the IN_OUT restriction by finding all paths
        # through the intersection group from the in_segment to the out_segment.
        # Corresponds to the JSON property `subpath`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :subpath
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # Restriction applies only to the given travel modes. This field should always
        # be set, but may be missing in old data. WARNING: Restrictions with no travel
        # modes are DEPRECATED. Historically, no travel modes has meant "all travel
        # modes", except they didn't really even mean that, because Pathfinder would use
        # a complex set of heuristics to interpret the "correct" travel modes.
        # Pathfinder currently (last updated August 2013) has heuristics to cope with
        # incomplete data that reduce or extend application of the specified
        # restrictions to pedestrians or bicycles. We are actively working to remove
        # these heuristics and replace them with explicit, correct travel modes in the
        # data. See b/8746491.
        # Corresponds to the JSON property `travelMode`
        # @return [Array<String>]
        attr_accessor :travel_mode
      
        # clang-format on The type of restriction. This is not a condition, but rather
        # tells you what kind of restriction it is. This field should always be set.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # A set of vehicle attribute conditionals (ex: weight >= 20T && num_trailers = 2)
        # used to define a slice of all possible vehicles. This can be useful for
        # filtering one or more vehicles by a predicate.
        # Corresponds to the JSON property `vehicleAttributeFilter`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreVehicleAttributeFilterProto]
        attr_accessor :vehicle_attribute_filter
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @autonomous_driving_products = args[:autonomous_driving_products] if args.key?(:autonomous_driving_products)
          @intersection_group = args[:intersection_group] if args.key?(:intersection_group)
          @metadata = args[:metadata] if args.key?(:metadata)
          @restriction_group = args[:restriction_group] if args.key?(:restriction_group)
          @schedule = args[:schedule] if args.key?(:schedule)
          @scope = args[:scope] if args.key?(:scope)
          @style = args[:style] if args.key?(:style)
          @subpath = args[:subpath] if args.key?(:subpath)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @travel_mode = args[:travel_mode] if args.key?(:travel_mode)
          @type = args[:type] if args.key?(:type)
          @vehicle_attribute_filter = args[:vehicle_attribute_filter] if args.key?(:vehicle_attribute_filter)
        end
      end
      
      # Proto used to represent rights for FeatureProto. See go/geo-rights for more
      # details. NOTE: Use google3/geostore/provenance/public/rights.h or google3/java/
      # com/google/geostore/provenance/rights/Rights.swig instead of accessing this
      # proto directly.
      class GeostoreRightsStatusProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fieldWithRights`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFieldWithRightsProto>]
        attr_accessor :field_with_rights
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_with_rights = args[:field_with_rights] if args.key?(:field_with_rights)
        end
      end
      
      # A RoadConditionalProto defines conditions that affect when the road traversal
      # information is applicable.
      class GeostoreRoadConditionalProto
        include Google::Apis::Core::Hashable
      
        # Specifies what times the information is applicable. This can be specific times
        # (3-5 PM) or days of the week (Mon - Fri), as well as more general times like
        # school hours, dusk to dawn, etc. If no value is set, the restriction is
        # applicable at all times.
        # Corresponds to the JSON property `timeSchedule`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :time_schedule
      
        # A set of vehicle attribute conditionals (ex: weight >= 20T && num_trailers = 2)
        # used to define a slice of all possible vehicles. This can be useful for
        # filtering one or more vehicles by a predicate.
        # Corresponds to the JSON property `vehicleAttribute`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreVehicleAttributeFilterProto]
        attr_accessor :vehicle_attribute
      
        # Restrictions applying to specific types of vehicles.
        # Corresponds to the JSON property `vehicleType`
        # @return [Array<String>]
        attr_accessor :vehicle_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @time_schedule = args[:time_schedule] if args.key?(:time_schedule)
          @vehicle_attribute = args[:vehicle_attribute] if args.key?(:vehicle_attribute)
          @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
        end
      end
      
      # A road monitor is a device that observes traffic for road violations like
      # speeding or running a red light. These are modeled within MapFacts so that
      # navigation services can warn users when they drive along road segments that
      # are monitored.
      class GeostoreRoadMonitorProto
        include Google::Apis::Core::Hashable
      
        # The TYPE_ROAD segment features that this road monitor may observe.
        # Corresponds to the JSON property `monitoredRoad`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :monitored_road
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @monitored_road = args[:monitored_road] if args.key?(:monitored_road)
        end
      end
      
      # Below is some horrible ASCII art and a description of the components of a road
      # sign. +-------------------+ | A11 E50 Paris | | Chartres | +-------------------
      # + This sign would be composed of four components (all of them text components,
      # the only option we support for now). The three in the first row would all have
      # a "major_position" of zero. Their "minor_position" values would be zero for "
      # A11", one for "E50", and two for "Paris". The component in the second row
      # would have "major_position" value of one. This message provides the details of
      # a single component of a road sign. A component defines its position within a
      # sign, its type, and its content.
      class GeostoreRoadSignComponentProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # The type of the feature referred to by this component. If feature_id is
        # specified type of that feature should be the same as this field.
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # This is the "major" position of this component within the set of components
        # that make up a sign. This number can be thought of as the "row" of the sign on
        # which the component appears, but no guarantees are made that there is a one-to-
        # one mapping between "major_position" and the rows of information on the actual
        # sign being modeled. A "major_position" value of zero would indicate that the
        # component is near the top of the sign.
        # Corresponds to the JSON property `majorPosition`
        # @return [Fixnum]
        attr_accessor :major_position
      
        # This is the position of a component within the components of a sign that share
        # a common "major_position". It can be though of as the "column" of the
        # component, but like "major_position", no guarantees are made regarding its
        # mapping to reality. For data sources that don't provide enough information to
        # determine a component's major and minor positions, major position should be
        # populated and minor position should not be present. A "minor_position" value
        # of zero would indicate that the component is near the "beginning" of the sign.
        # In countries where signs are read from left to right, "minor_position" zero
        # would be near the left side of the sign.
        # Corresponds to the JSON property `minorPosition`
        # @return [Fixnum]
        attr_accessor :minor_position
      
        # The direction of traffic for the referenced TYPE_ROUTE feature.
        # Corresponds to the JSON property `routeDirection`
        # @return [String]
        attr_accessor :route_direction
      
        # A name for a Feature (street name, point of interest, city, building, etc). We
        # currently use NameProto for two essentially disjoint purposes: 1. Common names,
        # which can be language-specific, or have other kinds of variations. 2. Opaque
        # IDs, such as postal codes, which only have the `text` field set, and
        # potentially some flags. This includes internal-only features like template ids.
        # Each NameProto representing a common name corresponds to an assertion that a
        # fluent speaker or writer of a language would recognize NameProto.text to name
        # the given feature in that language. As such, NameProtos are stored in a
        # repeated field, often having: 1. multiple names with the same text and varying
        # languages, and 2. multiple names with the same language and varying texts.
        # Corresponds to the JSON property `text`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreNameProto]
        attr_accessor :text
      
        # This type of content represented by this sign component.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @major_position = args[:major_position] if args.key?(:major_position)
          @minor_position = args[:minor_position] if args.key?(:minor_position)
          @route_direction = args[:route_direction] if args.key?(:route_direction)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A RoadSignProto holds the details of a road sign. Currently this is simply a
      # list of the items that appear on the sign and their relative position.
      class GeostoreRoadSignProto
        include Google::Apis::Core::Hashable
      
        # The list of components for a single road sign. A sign may be composed of
        # multiple components, each with its own position and content.
        # Corresponds to the JSON property `component`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRoadSignComponentProto>]
        attr_accessor :component
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @component = args[:component] if args.key?(:component)
        end
      end
      
      # This protocol buffer holds metadata about the association between a segment
      # and a route.
      class GeostoreRouteAssociationProto
        include Google::Apis::Core::Hashable
      
        # clang-format on
        # Corresponds to the JSON property `displayPreference`
        # @return [String]
        attr_accessor :display_preference
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `route`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :route
      
        # The direction of the TYPE_ROUTE feature in this route association. A small
        # number of countries (mostly just the United States, Mexico, and Canada) use
        # directional routes. For example, in the United States highway US-1 is referred
        # to as US-1 North or US-1 South on the sides where flow of traffic moves in
        # those directions.
        # Corresponds to the JSON property `routeDirection`
        # @return [String]
        attr_accessor :route_direction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_preference = args[:display_preference] if args.key?(:display_preference)
          @metadata = args[:metadata] if args.key?(:metadata)
          @route = args[:route] if args.key?(:route)
          @route_direction = args[:route_direction] if args.key?(:route_direction)
        end
      end
      
      # A route is a collection of segments that forms a logical group - usually a
      # named road or highway. Segments can belong to more than one route, and the
      # segments of one route may be a subset of the segments of another route (e.g. I-
      # 5 N is a subset of I-5). Segments in the collection that define the route do
      # not need to constitute a single uninterrupted line, there can be disconnects.
      # The standard feature properties are interpreted as follows: name - Routes
      # should have one or more names. (While unnamed roads certainly exist in the
      # real world, we choose not to create route features for such roads. Instead,
      # the unnamed segments are merely not part of any route.) address - This should
      # always be empty. type - Specifies a particular route subtype, see feature.
      # proto. point - This should always be empty. polyline - This should always be
      # empty. polygon - This should always be empty. child - The pairs of segments
      # that belong to this route (a given route should always reference segments in
      # both travel directions).
      class GeostoreRouteProto
        include Google::Apis::Core::Hashable
      
        # The feature type of the route children. Should be set if and only if all
        # children are of the same feature type.
        # Corresponds to the JSON property `childType`
        # @return [Fixnum]
        attr_accessor :child_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child_type = args[:child_type] if args.key?(:child_type)
        end
      end
      
      # This protocol buffer holds school district specific attributes for features of
      # TYPE_SCHOOL_DISTRICT.
      class GeostoreSchoolDistrictProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A segment path describes a path through a short set of segments. The segment
      # path can be used for any purpose. At the moment, only TYPE_ROAD_SIGN features
      # can have associated segment paths: The segment path lists the segments that
      # refer to the sign. These are the segments for which the sign is applicable.
      # The sign's physical location is independent of the segments in the path.
      class GeostoreSegmentPathProto
        include Google::Apis::Core::Hashable
      
        # Specifies a sequence of feature ids of GeoStore segments. The feature ids are
        # ordered. The path "AB" is not the same as the path "BA". The segments along
        # the path are assumed to be connected via the appropriate intersections. The
        # segment features that are referenced by this subpath refer to this feature
        # back via the road_sign field in segment proto extension.
        # Corresponds to the JSON property `subpath`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :subpath
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @subpath = args[:subpath] if args.key?(:subpath)
        end
      end
      
      # ---------------------------------------------------------------------------
      # WARNING - if you add new fields to SegmentProto (or to other protos used by
      # SegmentProto), you need to: - ensure that the ShortSegmentsMerger class (in
      # geostore/tools/internal/mr-mergesegments.cc) is aware of them, otherwise the
      # new fields will be discarded randomly. - consider whether they should be
      # cleared in the ClearFeature() function (in maps/render/process-high-priority-
      # roads.cc) if they are irrelevant for rendering high priority roads at far-out
      # zoom levels. - update the test cases that ensure these two packages know all
      # the SegmentProto fields in both mr-mergesegments_test.cc and maps/render/
      # process-high-priority-roads_test.cc or you will break the VersaTile build. ----
      # -----------------------------------------------------------------------
      class GeostoreSegmentProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `advisoryMaximumSpeed`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAppliedSpeedLimitProto>]
        attr_accessor :advisory_maximum_speed
      
        # RESERVED
        # Corresponds to the JSON property `altitude`
        # @return [Array<Float>]
        attr_accessor :altitude
      
        # The average speed that should be expected along this route under normal
        # conditions, in kilometers per hour. (Hopefully we'll replace this with
        # something a lot more sophisticated.)
        # Corresponds to the JSON property `avgSpeedKph`
        # @return [Float]
        attr_accessor :avg_speed_kph
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `avgSpeedKphMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :avg_speed_kph_metadata
      
        # clang-format on
        # Corresponds to the JSON property `barrier`
        # @return [String]
        attr_accessor :barrier
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `barrierMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :barrier_metadata
      
        # clang-format on
        # Corresponds to the JSON property `bicycleFacility`
        # @return [String]
        attr_accessor :bicycle_facility
      
        # 
        # Corresponds to the JSON property `bicycleSafety`
        # @return [String]
        attr_accessor :bicycle_safety
      
        # 
        # Corresponds to the JSON property `condition`
        # @return [String]
        attr_accessor :condition
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `conditionMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :condition_metadata
      
        # If known, the date that construction is scheduled to begin.
        # Corresponds to the JSON property `constructionBeginDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :construction_begin_date
      
        # If known, the date that construction is scheduled to end.
        # Corresponds to the JSON property `constructionEndDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :construction_end_date
      
        # 
        # Corresponds to the JSON property `constructionStatus`
        # @return [String]
        attr_accessor :construction_status
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `constructionStatusMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :construction_status_metadata
      
        # Whether the segment is covered by a roof etc. If this field is missing, the
        # status is unknown.
        # Corresponds to the JSON property `covered`
        # @return [Boolean]
        attr_accessor :covered
        alias_method :covered?, :covered
      
        # Average distance between the segment's polyline and edge of the road on this
        # side in meters. It need not be equal to the sum of width of all lanes in this
        # direction. This width includes on-street bicycle lanes but excludes off-street
        # lanes such as sidewalks. The edge of the road is the rightmost edge for
        # segments in right side driving countries and leftmost edge for left side
        # driving countries. Width of the road is sum of this and sibling's
        # distance_to_edge.
        # Corresponds to the JSON property `distanceToEdge`
        # @return [Float]
        attr_accessor :distance_to_edge
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `distanceToEdgeMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :distance_to_edge_metadata
      
        # These indicate for what portion of the segment does the outer curb of the
        # segment follow the segment polyline - i.e., where do the sweep curves connect
        # along the outer curb. If unspecified, may be assumed to be equal to lane
        # retraction, preferring outermost lane.
        # Corresponds to the JSON property `edgeFollowsSegmentBeginFraction`
        # @return [Float]
        attr_accessor :edge_follows_segment_begin_fraction
      
        # 
        # Corresponds to the JSON property `edgeFollowsSegmentEndFraction`
        # @return [Float]
        attr_accessor :edge_follows_segment_end_fraction
      
        # clang-format on
        # Corresponds to the JSON property `elevation`
        # @return [String]
        attr_accessor :elevation
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `elevationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :elevation_metadata
      
        # clang-format on
        # Corresponds to the JSON property `endpoint`
        # @return [String]
        attr_accessor :endpoint
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `endpointMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :endpoint_metadata
      
        # Detailed information about grade levels along the segment. If a
        # GradeLevelProto is not present for any point (index) along the segment, the
        # default grade level is zero. In between two points (indexes), the grade level
        # of the segment is taken to be the max of the grade levels on either side of it.
        # See gradelevel.proto for semantics of repeated indexes.
        # Corresponds to the JSON property `gradeLevel`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreGradeLevelProto>]
        attr_accessor :grade_level
      
        # Internal-only proto used to express additional information about segments.
        # This is intended for communicating extra information between editing clients
        # and the repository, and should not be used by or visible to clients. WARNING -
        # if you add new fields to InternalSegmentProto, make sure that geostore/tools/
        # internal/mr-mergesegments_test.cc is aware of them.
        # Corresponds to the JSON property `internal`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreInternalSegmentProto]
        attr_accessor :internal
      
        # If specified, the perpendicular offset in meters from a road segment to an
        # interpolated address along that road segment. See go/synthetic-address-
        # positions.
        # Corresponds to the JSON property `interpolationOffsetMeters`
        # @return [Float]
        attr_accessor :interpolation_offset_meters
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `intersection`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :intersection
      
        # Specifies whether the max_permitted_speed_kph was derived from a heuristic as
        # opposed to coming from an authoritative source.
        # Corresponds to the JSON property `isMaxPermittedSpeedDerived`
        # @return [Boolean]
        attr_accessor :is_max_permitted_speed_derived
        alias_method :is_max_permitted_speed_derived?, :is_max_permitted_speed_derived
      
        # Detailed information about each lane in this direction, if available. Lanes
        # are numbered from inside of the road outward, i.e. the lane next to the center
        # line is lane 0. Note that lanes that are valid for travel in both directions
        # appear in both segments of a segment pair (left turn lanes, one-lane roads,
        # some passing lanes, reversing lanes). Some lanes may not be usable by cars,
        # such as bike lanes. Also, some lanes may not exist along the entire segment, e.
        # g. left- or right-turn lanes that appear just before the intersection.
        # Corresponds to the JSON property `lane`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLaneProto>]
        attr_accessor :lane
      
        # The legal maximum, legal minimum, and advisory (recommended but non-legally
        # binding) maximum speed limits that are permitted on this segment. These should
        # be the segment's legal limits; however, note that it may contain estimated
        # values based on country-wide defaults and other heuristics (see '
        # AppliedSpeedLimitProto.trust_level'). Before exposing these fields to users as
        # the legal speed limit please consult with Google lawyers.
        # Corresponds to the JSON property `legalMaximumSpeed`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAppliedSpeedLimitProto>]
        attr_accessor :legal_maximum_speed
      
        # 
        # Corresponds to the JSON property `legalMinimumSpeed`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreAppliedSpeedLimitProto>]
        attr_accessor :legal_minimum_speed
      
        # The maximum speed that is permitted on this segment, in kilometers per hour.
        # This should be the segment's legal speed limit; however, note that it may
        # contain estimated values based on country-wide defaults and other heuristics (
        # see 'is_max_permitted_speed_derived' below). Before exposing this field to
        # users as the legal speed limit please consult with Google lawyers.
        # Corresponds to the JSON property `maxPermittedSpeedKph`
        # @return [Float]
        attr_accessor :max_permitted_speed_kph
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `maxPermittedSpeedKphMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :max_permitted_speed_kph_metadata
      
        # Specifies whether this segment carries right-hand traffic (cars keep to the
        # right side of the road) instead of left-hand traffic (cars keep to the left
        # side). This is true for US roads and false for UK roads, for example. See go/
        # wikip/Left-_and_right-hand_traffic.
        # Corresponds to the JSON property `onRight`
        # @return [Boolean]
        attr_accessor :on_right
        alias_method :on_right?, :on_right
      
        # A crossing describes a path from the end point of a segment to the start point
        # of its sibling. Each individual crossing should uniquely represent a
        # physically distinct crossing in the real world. Pedestrian crossings are
        # bidirectional. This proto represents "simple" crossings. More complicated
        # crossings (such as the diagonal crosswalk at Shibuya Station in Tokyo) will be
        # represented using a separate pedestrian network. Example 1: Standard four way
        # crossing. Assume each road (A/B/C) has a crosswalk (denoted by a '-') right
        # before intersection X. Assume crossing at D is prohibited (denoted by a '%').
        # Assume "prime" roads (A',B',...) are OUT segments relative to X. A\\A' B//B' \\
        # // \\ // - - X - % // \\ // \\ C'//C D'\\D * A CROSSABLE PedestrianCrossing
        # should be added to A, B and C. * An UNCROSSABLE PedestrianCrossing should be
        # added to D. Example 2: Simple intersection with one crossing. Assume
        # intersection X was added to accommodate the crosswalk (through X, denoted by '-
        # '). Assume "prime" roads (A',B',...) are OUT segments relative to X. A\\A' \\ \
        # \ -X- \\ \\ B'\\B * A CROSSABLE PedestrianCrossing must be added to either A
        # or B, but not both because each real-world crossing should be represented
        # exactly once. Duplicative crossings may be arbitrarily removed.
        # Corresponds to the JSON property `pedestrianCrossing`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePedestrianCrossingProto]
        attr_accessor :pedestrian_crossing
      
        # clang-format on
        # Corresponds to the JSON property `pedestrianFacility`
        # @return [String]
        attr_accessor :pedestrian_facility
      
        # 
        # Corresponds to the JSON property `pedestrianGrade`
        # @return [String]
        attr_accessor :pedestrian_grade
      
        # LINT.ThenChange(//depot/google3/maps/pathfinder/pgraph/pgraph-segment-
        # categories.cc)
        # Corresponds to the JSON property `priority`
        # @return [String]
        attr_accessor :priority
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `priorityMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :priority_metadata
      
        # The set of restrictions that apply to this segment. Restrictions may make a
        # single segment, turn, or more complex maneuver along a set of segments
        # unroutable for the specified travel modes, or may only add penalties or
        # warnings, depending on the restriction type. Turn restrictions are one example
        # of a restriction. By default, turns are allowed onto all outgoing segments
        # from this segment's intersection (including the sibling of this segment, i.e.
        # U-turns are allowed by default). If any of these turns are disallowed they
        # will be listed as "subpath restrictions". A subpath restriction disallows
        # travel on given sequence of segments. In the case of a disallowed turn, the
        # subpath simply consists of the source and destination feature ids. There may
        # also be restrictions that apply to all travel on this segment (e.g. chains
        # required, or closed in winter), or restrictions that just apply to certain
        # lanes (e.g. high occupancy vehicle lanes).
        # Corresponds to the JSON property `restriction`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRestrictionProto>]
        attr_accessor :restriction
      
        # The road monitors that monitor this segment for traffic violations.
        # Corresponds to the JSON property `roadMonitor`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :road_monitor
      
        # The road sign(s) which this segment refers to. These are features of
        # TYPE_ROAD_SIGN that are applicable to this segment. For example, a sign that
        # says "TO KIRKLAND" might apply to several segments on a freeway off-ramp (
        # until the end of the ramp). Note that this field makes it easy to find the
        # signs for a given road segment. The feature for the sign lists the segments
        # that refer to it.
        # Corresponds to the JSON property `roadSign`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :road_sign
      
        # The route(s) to which this segment belongs.
        # Corresponds to the JSON property `route`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :route
      
        # Holds metadata about the associations between this segment and the route
        # features listed in the route field. This metadata need not be present; the
        # only consistency requirement is that every feature ID that appears inside '
        # route_association' must also appear in the repeated 'route' field. If a route
        # does not appear in route_association, consumers should assume that it has a
        # default initialized RouteAssociationProto.
        # Corresponds to the JSON property `routeAssociation`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRouteAssociationProto>]
        attr_accessor :route_association
      
        # Indicates whether the segment's opposing lanes of traffic are separated from
        # this segment, and hence have been represented in a separate feature. This
        # means that there are two pairs of siblings instead of one.
        # Corresponds to the JSON property `separatedRoadways`
        # @return [Boolean]
        attr_accessor :separated_roadways
        alias_method :separated_roadways?, :separated_roadways
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `sibling`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :sibling
      
        # clang-format on LINT.ThenChange(//depot/google3/geostore/base/proto/lane.proto)
        # If this option is missing it means that the surface is unknown. Specific
        # lanes may override this segment-level surface type.
        # Corresponds to the JSON property `surface`
        # @return [String]
        attr_accessor :surface
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `surfaceMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :surface_metadata
      
        # The geometric sweeps between this segment and nearby segments, used for real
        # road width rendering. A sweep describes the surface that connects to segments.
        # Corresponds to the JSON property `sweep`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreSweepProto>]
        attr_accessor :sweep
      
        # If this segment is part of a toll road. It would be nice to have data about
        # the toll cost, locations of toll booths, and so forth. Sadly, we don't have
        # this data at this time.
        # Corresponds to the JSON property `tollRoad`
        # @return [Boolean]
        attr_accessor :toll_road
        alias_method :toll_road?, :toll_road
      
        # clang-format on LINT.ThenChange(//depot/google3/maps/pathfinder/pgraph/pgraph-
        # segment-categories.cc)
        # Corresponds to the JSON property `usage`
        # @return [String]
        attr_accessor :usage
      
        # A collection of landmarks that are visible when traveling along this segment
        # and useful for wayfinding to users following routes using this segment. The
        # landmark need not be on the segment. Each segment in a pair of siblings
        # specifies its landmarks independently. A landmark applicable to both appears
        # in both.
        # Corresponds to the JSON property `visibleLandmark`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreLandmarkReferenceProto>]
        attr_accessor :visible_landmark
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @advisory_maximum_speed = args[:advisory_maximum_speed] if args.key?(:advisory_maximum_speed)
          @altitude = args[:altitude] if args.key?(:altitude)
          @avg_speed_kph = args[:avg_speed_kph] if args.key?(:avg_speed_kph)
          @avg_speed_kph_metadata = args[:avg_speed_kph_metadata] if args.key?(:avg_speed_kph_metadata)
          @barrier = args[:barrier] if args.key?(:barrier)
          @barrier_metadata = args[:barrier_metadata] if args.key?(:barrier_metadata)
          @bicycle_facility = args[:bicycle_facility] if args.key?(:bicycle_facility)
          @bicycle_safety = args[:bicycle_safety] if args.key?(:bicycle_safety)
          @condition = args[:condition] if args.key?(:condition)
          @condition_metadata = args[:condition_metadata] if args.key?(:condition_metadata)
          @construction_begin_date = args[:construction_begin_date] if args.key?(:construction_begin_date)
          @construction_end_date = args[:construction_end_date] if args.key?(:construction_end_date)
          @construction_status = args[:construction_status] if args.key?(:construction_status)
          @construction_status_metadata = args[:construction_status_metadata] if args.key?(:construction_status_metadata)
          @covered = args[:covered] if args.key?(:covered)
          @distance_to_edge = args[:distance_to_edge] if args.key?(:distance_to_edge)
          @distance_to_edge_metadata = args[:distance_to_edge_metadata] if args.key?(:distance_to_edge_metadata)
          @edge_follows_segment_begin_fraction = args[:edge_follows_segment_begin_fraction] if args.key?(:edge_follows_segment_begin_fraction)
          @edge_follows_segment_end_fraction = args[:edge_follows_segment_end_fraction] if args.key?(:edge_follows_segment_end_fraction)
          @elevation = args[:elevation] if args.key?(:elevation)
          @elevation_metadata = args[:elevation_metadata] if args.key?(:elevation_metadata)
          @endpoint = args[:endpoint] if args.key?(:endpoint)
          @endpoint_metadata = args[:endpoint_metadata] if args.key?(:endpoint_metadata)
          @grade_level = args[:grade_level] if args.key?(:grade_level)
          @internal = args[:internal] if args.key?(:internal)
          @interpolation_offset_meters = args[:interpolation_offset_meters] if args.key?(:interpolation_offset_meters)
          @intersection = args[:intersection] if args.key?(:intersection)
          @is_max_permitted_speed_derived = args[:is_max_permitted_speed_derived] if args.key?(:is_max_permitted_speed_derived)
          @lane = args[:lane] if args.key?(:lane)
          @legal_maximum_speed = args[:legal_maximum_speed] if args.key?(:legal_maximum_speed)
          @legal_minimum_speed = args[:legal_minimum_speed] if args.key?(:legal_minimum_speed)
          @max_permitted_speed_kph = args[:max_permitted_speed_kph] if args.key?(:max_permitted_speed_kph)
          @max_permitted_speed_kph_metadata = args[:max_permitted_speed_kph_metadata] if args.key?(:max_permitted_speed_kph_metadata)
          @on_right = args[:on_right] if args.key?(:on_right)
          @pedestrian_crossing = args[:pedestrian_crossing] if args.key?(:pedestrian_crossing)
          @pedestrian_facility = args[:pedestrian_facility] if args.key?(:pedestrian_facility)
          @pedestrian_grade = args[:pedestrian_grade] if args.key?(:pedestrian_grade)
          @priority = args[:priority] if args.key?(:priority)
          @priority_metadata = args[:priority_metadata] if args.key?(:priority_metadata)
          @restriction = args[:restriction] if args.key?(:restriction)
          @road_monitor = args[:road_monitor] if args.key?(:road_monitor)
          @road_sign = args[:road_sign] if args.key?(:road_sign)
          @route = args[:route] if args.key?(:route)
          @route_association = args[:route_association] if args.key?(:route_association)
          @separated_roadways = args[:separated_roadways] if args.key?(:separated_roadways)
          @sibling = args[:sibling] if args.key?(:sibling)
          @surface = args[:surface] if args.key?(:surface)
          @surface_metadata = args[:surface_metadata] if args.key?(:surface_metadata)
          @sweep = args[:sweep] if args.key?(:sweep)
          @toll_road = args[:toll_road] if args.key?(:toll_road)
          @usage = args[:usage] if args.key?(:usage)
          @visible_landmark = args[:visible_landmark] if args.key?(:visible_landmark)
        end
      end
      
      # This proto represents the geographic area served by an establishment. WARNING:
      # This proto is not meant to be used directly. Please use the provided libraries.
      # http://google3/geostore/base/public/service_area.h http://google3/java/com/
      # google/geostore/base/ServiceArea.java
      class GeostoreServiceAreaProto
        include Google::Apis::Core::Hashable
      
        # The features that make up the service area for this establishment. These
        # features are subject to the following constraints applied by editing
        # middleware (notably, not strictly enforced by lints in storage): 1. The
        # following feature types (and their subtypes) may be used: + TYPE_ISLAND +
        # TYPE_POLITICAL, except the following prohibited subtypes: - TYPE_CONSTITUENCY -
        # TYPE_LAND_PARCEL + TYPE_POSTAL 2. There is a maximum limit (currently 20) to
        # the number of areas which may be provided. This is due to serving efficiency
        # limitations. 3. There are no additional geometry requirements for these
        # features beyond the requirements based on the feature types above. In practice
        # this means that these features will either have polygonal or point-based
        # geometries. 4. These referenced features are generally required to have names,
        # though this is not strictly enforced.
        # Corresponds to the JSON property `servedFeature`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :served_feature
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @served_feature = args[:served_feature] if args.key?(:served_feature)
        end
      end
      
      # Defines an ordered reference to a line variant’s stop.
      class GeostoreServicedStopProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :id
      
        # An index representing the order in which the above station is serviced by the
        # line variant.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # This protocol buffer holds attributes for features of TYPE_SKI_BOUNDARY.
      class GeostoreSkiBoundaryProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This protocol buffer holds attributes for features of TYPE_SKI_LIFT.
      class GeostoreSkiLiftProto
        include Google::Apis::Core::Hashable
      
        # clang-format on
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This protocol buffer holds attributes for features of TYPE_SKI_TRAIL.
      class GeostoreSkiTrailProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `difficulty`
        # @return [String]
        attr_accessor :difficulty
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @difficulty = args[:difficulty] if args.key?(:difficulty)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # MapFacts GAIA ID assigned to this feature. These values are virtual GAIA IDs
      # from MapFacts, and as such are not stored in Focus.
      class GeostoreSocialReferenceProto
        include Google::Apis::Core::Hashable
      
        # WARNING: Please do NOT introduce new uses; treat this field as if it were
        # deprecated.
        # Corresponds to the JSON property `baseGaiaId`
        # @return [Fixnum]
        attr_accessor :base_gaia_id
      
        # GAIA ID used when a business has been claimed. This value is a robot GAIA ID.
        # Robots are a special type of GAIA account used to denote identity for a user
        # or a group of users, but are not logged-in directly by a user.
        # Corresponds to the JSON property `claimedGaiaId`
        # @return [Fixnum]
        attr_accessor :claimed_gaia_id
      
        # WARNING: Please do NOT introduce new uses; treat this field as if it were
        # deprecated.
        # Corresponds to the JSON property `gaiaIdForDisplay`
        # @return [Fixnum]
        attr_accessor :gaia_id_for_display
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_gaia_id = args[:base_gaia_id] if args.key?(:base_gaia_id)
          @claimed_gaia_id = args[:claimed_gaia_id] if args.key?(:claimed_gaia_id)
          @gaia_id_for_display = args[:gaia_id_for_display] if args.key?(:gaia_id_for_display)
        end
      end
      
      # Source infos are the canonical way to establish data provenance. They can
      # currently be set on features, edits, and issues. Every feature has a repeated
      # list of SourceInfoProto messages to describe the source data that was used in
      # building this feature. The data includes a feature id that points to
      # additional data about the data source (version, copyright notice, etc), and
      # optional "raw data" that is taken directly from the provider's format and has
      # not been converted to a canonical form.
      class GeostoreSourceInfoProto
        include Google::Apis::Core::Hashable
      
        # This is the URL of a page representing all the data from this source in this
        # feature. It may have be the ultimate source of the data (in case of scraping)
        # or merely the same data styled according the provider's taste. There is a
        # similar field in DataSourceProto which is NOT cached in this field, since it
        # has a different meaning.
        # Corresponds to the JSON property `attributionUrl`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreUrlProto>]
        attr_accessor :attribution_url
      
        # The time that this particular piece of data was collected. If different
        # attributes were collected on different dates, this is the date of the most
        # recent edit.
        # Corresponds to the JSON property `collectionDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :collection_date
      
        # A source info may have a magic cookie whose content and semantics are defined
        # by the specific import process or third-party feed. For feeds that are
        # processed by Distillery, the cookie, when set, should contain the unique
        # identifier for the feature as provided by the feed.
        # Corresponds to the JSON property `cookie`
        # @return [String]
        attr_accessor :cookie
      
        # The dataset from which this SourceInfoProto was created. The content of this
        # string will be determined by the data provider (e.g. for MultiNet data, "fra"
        # would indicate the dataset for France). This field is unnecessary for
        # providers that deliver a single dataset per release (e.g. Basarsoft).
        # Corresponds to the JSON property `dataset`
        # @return [String]
        attr_accessor :dataset
      
        # The Gaia ID of the user who provided us with this data. This field should
        # never be set on source infos present on features, but may be set on source
        # infos present on edits. DEPRECATED: Most clients should use the "user" field
        # instead where Gaia IDs are encrypted.
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # UserProto identifies a (human) user of Geo Data. Its primary use is in
        # describing the source of pieces of data (e.g. edits). It could be a simple
        # identifier, but isn't so that we can store it in the clear while still
        # preventing correlation between a user's contribution.
        # Corresponds to the JSON property `impersonationUser`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreUserProto]
        attr_accessor :impersonation_user
      
        # The name of the layer from which this SourceInfoProto was created.
        # Corresponds to the JSON property `layer`
        # @return [String]
        attr_accessor :layer
      
        # The OGR feature identifier from which this SourceInfoProto was created. This
        # is an internal OGR record identifier and has nothing to do with any of the
        # feature's fields or the FeatureIdProto for the FeatureProto containing this
        # SourceInfoProto. This field is present only for debugging purposes and
        # possible use in the match pattern of a FeatureChangeProto designed to fix bad
        # source data very early in the importing process.
        # Corresponds to the JSON property `ogrFid`
        # @return [Fixnum]
        attr_accessor :ogr_fid
      
        # The data provider from which this source info was generated. The value must be
        # equal to the one on the TYPE_DATA_SOURCE feature referenced by this source
        # info via the source_id reference (see above).
        # Corresponds to the JSON property `provider`
        # @return [Fixnum]
        attr_accessor :provider
      
        # A source info may optionally have a set of key-value pairs that provide "raw
        # data" specific to that source. The types of raw data available will vary from
        # one provider to another and should not be used in production code. Instead,
        # new fields and/or protocol buffers should be defined to represent this
        # information in a canonical form, and the relevant importers should be modified
        # to populate these new fields.
        # Corresponds to the JSON property `rawData`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRawDataProto>]
        attr_accessor :raw_data
      
        # The data release from which this SourceInfoProto was created. The format for
        # this string is provider-dependent (e.g. a MultiNet release would look like "
        # 2008.01").
        # Corresponds to the JSON property `release`
        # @return [String]
        attr_accessor :release
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `sourceId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :source_id
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `temporaryData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :temporary_data
      
        # UserProto identifies a (human) user of Geo Data. Its primary use is in
        # describing the source of pieces of data (e.g. edits). It could be a simple
        # identifier, but isn't so that we can store it in the clear while still
        # preventing correlation between a user's contribution.
        # Corresponds to the JSON property `user`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreUserProto]
        attr_accessor :user
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribution_url = args[:attribution_url] if args.key?(:attribution_url)
          @collection_date = args[:collection_date] if args.key?(:collection_date)
          @cookie = args[:cookie] if args.key?(:cookie)
          @dataset = args[:dataset] if args.key?(:dataset)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @impersonation_user = args[:impersonation_user] if args.key?(:impersonation_user)
          @layer = args[:layer] if args.key?(:layer)
          @ogr_fid = args[:ogr_fid] if args.key?(:ogr_fid)
          @provider = args[:provider] if args.key?(:provider)
          @raw_data = args[:raw_data] if args.key?(:raw_data)
          @release = args[:release] if args.key?(:release)
          @source_id = args[:source_id] if args.key?(:source_id)
          @temporary_data = args[:temporary_data] if args.key?(:temporary_data)
          @user = args[:user] if args.key?(:user)
        end
      end
      
      # Trust related information about the input source (feed or user) to help
      # feature summarization. Typically, the values in this proto are either based on
      # source's previous observations (e.g., a blocked LBC user or a trusted feed) or
      # their status (Google hired operator or admin user). The proto can later
      # contain a more granular trust score or correctness probabilities. A higher
      # enum value indicates a more trusted source. Leaving room in the value space
      # for adding more granular enums, if they become necessary later.
      class GeostoreSourceTrustProto
        include Google::Apis::Core::Hashable
      
        # The level of trust for the source of the observation.
        # Corresponds to the JSON property `level`
        # @return [String]
        attr_accessor :level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @level = args[:level] if args.key?(:level)
        end
      end
      
      # A speed limit, containing both the limit and the conditions in which it
      # applies.
      class GeostoreSpeedLimitProto
        include Google::Apis::Core::Hashable
      
        # The type of speed limit.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The conditions under which this speed limit is applicable. If multiple
        # conditions are set, at least one of them must be true.
        # Corresponds to the JSON property `condition`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreRoadConditionalProto>]
        attr_accessor :condition
      
        # A speed value and unit.
        # Corresponds to the JSON property `speedWithUnit`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSpeedProto]
        attr_accessor :speed_with_unit
      
        # A speed limit without a limit value. Used to indicate the absence of a speed
        # limit.
        # Corresponds to the JSON property `unlimitedSpeed`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreUnlimitedSpeedProto]
        attr_accessor :unlimited_speed
      
        # A speed limit whose value can change based on road, traffic, and weather
        # conditions.
        # Corresponds to the JSON property `variableSpeed`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreVariableSpeedProto]
        attr_accessor :variable_speed
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @condition = args[:condition] if args.key?(:condition)
          @speed_with_unit = args[:speed_with_unit] if args.key?(:speed_with_unit)
          @unlimited_speed = args[:unlimited_speed] if args.key?(:unlimited_speed)
          @variable_speed = args[:variable_speed] if args.key?(:variable_speed)
        end
      end
      
      # A speed value and unit.
      class GeostoreSpeedProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `speed`
        # @return [Float]
        attr_accessor :speed
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @speed = args[:speed] if args.key?(:speed)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # Represents a way to traverse nested fields by referencing their token fields.
      # Everything starts relative to a known root message, specified externally. E.g.,
      # suppose we have a feature proto that has a lane with token 0x123 which in
      # turn has a lane connection with token 0x456 for which we want to assert
      # something about flowline altitudes. The field path in that case will look like:
      # field_path: ` field_num: 31 # segment ` field_path: ` field_num: 6 # lane
      # version_token: "0x123" ` field_path: ` field_num: 8 # lane_connection
      # version_token: "0x456" ` field_path: ` field_num: 3 # flow ` field_path: `
      # field_num: 1 # track ` field_path: ` # Note: pose is repeated. By not
      # specifying a token we refer to all poses # in a track. field_num: 2 # pose `
      # field_path: ` field_num: 4 # altitude ` This path could also be represented
      # succinctly in a more human-friendly form as something like: segment.lane[@
      # 0x123].lane_connection[@0x456].flow.track.pose[*].altitude
      class GeostoreStableFieldPathProto
        include Google::Apis::Core::Hashable
      
        # A sequence of field selectors to be traversed starting from the root message.
        # Corresponds to the JSON property `fieldPath`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreStableFieldPathProtoStableFieldSelector>]
        attr_accessor :field_path
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_path = args[:field_path] if args.key?(:field_path)
        end
      end
      
      # 
      class GeostoreStableFieldPathProtoStableFieldSelector
        include Google::Apis::Core::Hashable
      
        # Field number to select.
        # Corresponds to the JSON property `fieldNum`
        # @return [Fixnum]
        attr_accessor :field_num
      
        # Select repeated field entry by its version token. If this is used, then the
        # message referenced by field_num must have a token field annotated with the (
        # version_token) field option. Must be omitted for leaf non-repeated fields. If
        # unset for a repeated field, we consider this selector to apply equally to all
        # descendants.
        # Corresponds to the JSON property `versionToken`
        # @return [String]
        attr_accessor :version_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_num = args[:field_num] if args.key?(:field_num)
          @version_token = args[:version_token] if args.key?(:version_token)
        end
      end
      
      # This protocol buffer represents the 2D polygon connecting two segments at an
      # intersection. Collectively, sweep polygons represent intersections for real
      # road width rendering. Notes: - Sweeps represent geometry between the *end* of
      # one segment and the *end* of the other segment (modulo retraction values). -
      # Sweeps are strongly referenced, meaning geometry is stored on both segments
      # involved in the sweep. For example, in the diagram below, the sweep between A
      # and B would be stored on both segment A and segment B. | B | v --A--> - Sweeps
      # are not strictly stored on adjacent segments. Disconnected segments (e.g.,
      # segments separated by an intersection group) may also contain sweeps.
      class GeostoreSweepProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `otherSegmentFeatureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :other_segment_feature_id
      
        # A general non-self-intersecting spherical polygon, consisting of one or more
        # loops defining multiple disconnected regions possibly with holes. All loops
        # should be oriented CCW around the region they define. This applies to the
        # exterior loop(s) as well as any holes. Within MapFacts (and underlying
        # infrastructure) the data fields may be replaced by a single shape_id; see
        # comments on shape_id below. Any such PolygonProtos shouldn't be expected to
        # work with public functions in //geostore/base/public/polygon.h.
        # Corresponds to the JSON property `polygon`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePolygonProto]
        attr_accessor :polygon
      
        # Protocol buffer describing a curve that connects two externally specified
        # endpoints.
        # Corresponds to the JSON property `sweepCurve`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreCurveConnectionProto]
        attr_accessor :sweep_curve
      
        # A token that can be used to identify the version of the data about this sweep.
        # Corresponds to the JSON property `sweepToken`
        # @return [String]
        attr_accessor :sweep_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @other_segment_feature_id = args[:other_segment_feature_id] if args.key?(:other_segment_feature_id)
          @polygon = args[:polygon] if args.key?(:polygon)
          @sweep_curve = args[:sweep_curve] if args.key?(:sweep_curve)
          @sweep_token = args[:sweep_token] if args.key?(:sweep_token)
        end
      end
      
      # This protocol buffer is used to represent telephone numbers and related
      # information.
      class GeostoreTelephoneProto
        include Google::Apis::Core::Hashable
      
        # RESERVED
        # Corresponds to the JSON property `callRate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePriceRangeProto>]
        attr_accessor :call_rate
      
        # RESERVED
        # Corresponds to the JSON property `contactCategory`
        # @return [String]
        attr_accessor :contact_category
      
        # 
        # Corresponds to the JSON property `flag`
        # @return [Array<String>]
        attr_accessor :flag
      
        # True if this phone number is not unique to this establishment and might be
        # shared with other features. In case an establishment shares a phone number
        # with a business chain of which it is a member, and the number canonically
        # belongs to that chain, it should be marked as shared for the establishment but
        # not shared for the chain.
        # Corresponds to the JSON property `isSharedNumber`
        # @return [Boolean]
        attr_accessor :is_shared_number
        alias_method :is_shared_number?, :is_shared_number
      
        # RESERVED
        # Corresponds to the JSON property `label`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreNameProto>]
        attr_accessor :label
      
        # RESERVED
        # Corresponds to the JSON property `language`
        # @return [Array<String>]
        attr_accessor :language
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # ** DEPRECATED ** This is deprecated in favor of phone_number below. An
        # internationalized representation of a phone number. See //location/country/
        # telephonenumber.proto
        # Corresponds to the JSON property `number`
        # @return [Google::Apis::ContentwarehouseV1::TelephoneNumber]
        attr_accessor :number
      
        # The PhoneNumber object that is used by all LibPhoneNumber API's to fully
        # represent a phone number.
        # Corresponds to the JSON property `phoneNumber`
        # @return [Google::Apis::ContentwarehouseV1::I18nPhonenumbersPhoneNumber]
        attr_accessor :phone_number
      
        # RESERVED
        # Corresponds to the JSON property `serviceLocationFeature`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :service_location_feature
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @call_rate = args[:call_rate] if args.key?(:call_rate)
          @contact_category = args[:contact_category] if args.key?(:contact_category)
          @flag = args[:flag] if args.key?(:flag)
          @is_shared_number = args[:is_shared_number] if args.key?(:is_shared_number)
          @label = args[:label] if args.key?(:label)
          @language = args[:language] if args.key?(:language)
          @metadata = args[:metadata] if args.key?(:metadata)
          @number = args[:number] if args.key?(:number)
          @phone_number = args[:phone_number] if args.key?(:phone_number)
          @service_location_feature = args[:service_location_feature] if args.key?(:service_location_feature)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This protocol buffer stores information related to temporary closure of a
      # feature. The only allowed precisions for a date is PRECISION_DAY.
      # DateTimeProto.seconds should have the lowest legal value for the desired date/
      # time and precision. E.g. for PRECISION_MONTH, 2019-02-15 21:10:30 is not valid,
      # it should be 2019-02-01 00:00:00 instead. NOTE: Each date is stored in UTC
      # but should be interpreted as being in the local timezone. So clients should
      # convert the DateTimeProto to local (civil) time using UTC+0, and then treat
      # the result as local to the feature.
      class GeostoreTemporaryClosureProto
        include Google::Apis::Core::Hashable
      
        # The latest when this closure may end, if the exact date is unknown. If set,
        # the feature is operational again no later than this date.
        # Corresponds to the JSON property `endAsOfDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :end_as_of_date
      
        # RESERVED
        # Corresponds to the JSON property `endDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :end_date
      
        # The latest when this closure may start, if the exact date is unknown. If set,
        # the feature is temporarily closed starting no later than this date.
        # Corresponds to the JSON property `startAsOfDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :start_as_of_date
      
        # RESERVED
        # Corresponds to the JSON property `startDate`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreDateTimeProto]
        attr_accessor :start_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_as_of_date = args[:end_as_of_date] if args.key?(:end_as_of_date)
          @end_date = args[:end_date] if args.key?(:end_date)
          @start_as_of_date = args[:start_as_of_date] if args.key?(:start_as_of_date)
          @start_date = args[:start_date] if args.key?(:start_date)
        end
      end
      
      # Represents text (with an associated language) that is affixed to the beginning
      # and/or end of a primary text.
      class GeostoreTextAffixProto
        include Google::Apis::Core::Hashable
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # These strings should be treated as opaque blobs. You can use
        # LanguageCodeConverter::FromOther to convert the string to a LanguageCode
        # reference. You can then call methods on the LanguageCode class to extract
        # language/script/region subtags (if any). See also http://g3doc/i18n/
        # identifiers/g3doc/using-iii. We place extra restrictions on languages in
        # addition to what the III library requires. See http://go/geo-schema-reference/
        # feature-properties/languages.md
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Text to prepend to the primary text, including any necessary trailing
        # whitespace. At least one of prefix or suffix is required.
        # Corresponds to the JSON property `prefix`
        # @return [String]
        attr_accessor :prefix
      
        # Text to append to the end of the primary text, including any necessary leading
        # whitespace. At least one of prefix or suffix is required.
        # Corresponds to the JSON property `suffix`
        # @return [String]
        attr_accessor :suffix
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @prefix = args[:prefix] if args.key?(:prefix)
          @suffix = args[:suffix] if args.key?(:suffix)
        end
      end
      
      # 
      class GeostoreThreeDimensionalModelProto
        include Google::Apis::Core::Hashable
      
        # Triangle vertex indices, each triple defines a triangle.
        # Corresponds to the JSON property `pointIndices`
        # @return [Array<Fixnum>]
        attr_accessor :point_indices
      
        # We store a triangular mesh in indexed format. Points array.
        # Corresponds to the JSON property `points`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePointWithHeightProto>]
        attr_accessor :points
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @point_indices = args[:point_indices] if args.key?(:point_indices)
          @points = args[:points] if args.key?(:points)
        end
      end
      
      # A rate which applies based on the precise times of utilization. Defines a rate,
      # as well as restrictions on the start and end times which must be satisfied in
      # order to be eligible for the rate. See go/rate-schema for more details.
      class GeostoreTimeBasedRateProto
        include Google::Apis::Core::Hashable
      
        # The rates for this rule. Each duration_based_rate defines the costs associated
        # with a particular duration of a stay. There must be at least one rate with
        # range_start_seconds set to 0 and there cannot be gaps between durations (i.e.
        # there should be no interval uncovered between 0 and the largest
        # range_end_seconds of any duration-based rate).
        # Corresponds to the JSON property `durationBasedRate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreDurationBasedRateProto>]
        attr_accessor :duration_based_rate
      
        # If true, tax is included in the prices in this rate. If false, additional
        # taxes may apply.
        # Corresponds to the JSON property `taxIncluded`
        # @return [Boolean]
        attr_accessor :tax_included
        alias_method :tax_included?, :tax_included
      
        # 
        # Corresponds to the JSON property `validEndWithin`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :valid_end_within
      
        # Time period during which utilization of this rate must start in order to be
        # eligible for the rate. If not set, there is no restriction on the time when
        # the utilization starts.
        # Corresponds to the JSON property `validStartWithin`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :valid_start_within
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duration_based_rate = args[:duration_based_rate] if args.key?(:duration_based_rate)
          @tax_included = args[:tax_included] if args.key?(:tax_included)
          @valid_end_within = args[:valid_end_within] if args.key?(:valid_end_within)
          @valid_start_within = args[:valid_start_within] if args.key?(:valid_start_within)
        end
      end
      
      # 
      class GeostoreTimeComponentProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `componentType`
        # @return [String]
        attr_accessor :component_type
      
        # The time component is the intersection of these intervals
        # Corresponds to the JSON property `interval`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTimeIntervalProto>]
        attr_accessor :interval
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @component_type = args[:component_type] if args.key?(:component_type)
          @interval = args[:interval] if args.key?(:interval)
        end
      end
      
      # Not all combinations of optional fields in TimeEndpointProto are allowed. The
      # granularity of time is a path along the directed graph with these edges:
      # second -> minute minute -> hour hour -> day of week hour -> day of month hour -
      # > day of year day of week -> week of month day of week -> week of year day of
      # month -> month day of year -> year week of month -> month week of year -> year
      # month -> year A TimeEndpointProto may not specify two fields that are
      # unordered with respect to each other ("day of year" and "day of week", for
      # instance). The absence of fields larger than any specified field indicates
      # repetition (e.g. no year indicates that the interval occurs every year). The
      # absence of units that are "smaller" than the largest specified unit indicates
      # a default lowest value (no hour means midnight (0)). When intersecting time
      # intervals, "smaller" units repeat within the "larger" unit as many times as
      # necessary. For example, the intersection of the interval from hour 0 to hour
      # 24 with the interval from second 0 to second 1 is equivalent to the union of
      # the set of intervals which represents the first second of every minute of
      # every hour of every day. ------------------------------------------------------
      # ----------------------- WARNING - if you add new fields to TimeEndpointProto
      # you need to: - ensure AreTimeEndpointsEquivalent considers the new fields (and
      # update the corresponding tests) -----------------------------------------------
      # ------------------------------
      class GeostoreTimeEndpointProto
        include Google::Apis::Core::Hashable
      
        # Valid ranges are 0-7, 1-31, and 1-366 (see day_type below)
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # 
        # Corresponds to the JSON property `dayType`
        # @return [String]
        attr_accessor :day_type
      
        # Valid range is 0-24. Because it could be unclear what wrapping hours mean in
        # relation to days, 24 is used to denote midnight at the end of a day.
        # Corresponds to the JSON property `hour`
        # @return [Fixnum]
        attr_accessor :hour
      
        # Valid range is 0-59, except when a repetitive minute interval ends at the end
        # of an hour, in which case 60 is a legal end value.
        # Corresponds to the JSON property `minute`
        # @return [Fixnum]
        attr_accessor :minute
      
        # 
        # Corresponds to the JSON property `month`
        # @return [String]
        attr_accessor :month
      
        # Valid range is 0-59, except when a repetitive second interval ends at the end
        # of a minute, in which case 60 is a legal end value.
        # Corresponds to the JSON property `second`
        # @return [Fixnum]
        attr_accessor :second
      
        # Valid ranges are 0-5 and 1-53 (depending on the value of week_type, see below).
        # Corresponds to the JSON property `week`
        # @return [Fixnum]
        attr_accessor :week
      
        # 
        # Corresponds to the JSON property `weekType`
        # @return [String]
        attr_accessor :week_type
      
        # 
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @day_type = args[:day_type] if args.key?(:day_type)
          @hour = args[:hour] if args.key?(:hour)
          @minute = args[:minute] if args.key?(:minute)
          @month = args[:month] if args.key?(:month)
          @second = args[:second] if args.key?(:second)
          @week = args[:week] if args.key?(:week)
          @week_type = args[:week_type] if args.key?(:week_type)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # 
      class GeostoreTimeIntervalProto
        include Google::Apis::Core::Hashable
      
        # Not all combinations of optional fields in TimeEndpointProto are allowed. The
        # granularity of time is a path along the directed graph with these edges:
        # second -> minute minute -> hour hour -> day of week hour -> day of month hour -
        # > day of year day of week -> week of month day of week -> week of year day of
        # month -> month day of year -> year week of month -> month week of year -> year
        # month -> year A TimeEndpointProto may not specify two fields that are
        # unordered with respect to each other ("day of year" and "day of week", for
        # instance). The absence of fields larger than any specified field indicates
        # repetition (e.g. no year indicates that the interval occurs every year). The
        # absence of units that are "smaller" than the largest specified unit indicates
        # a default lowest value (no hour means midnight (0)). When intersecting time
        # intervals, "smaller" units repeat within the "larger" unit as many times as
        # necessary. For example, the intersection of the interval from hour 0 to hour
        # 24 with the interval from second 0 to second 1 is equivalent to the union of
        # the set of intervals which represents the first second of every minute of
        # every hour of every day. ------------------------------------------------------
        # ----------------------- WARNING - if you add new fields to TimeEndpointProto
        # you need to: - ensure AreTimeEndpointsEquivalent considers the new fields (and
        # update the corresponding tests) -----------------------------------------------
        # ------------------------------
        # Corresponds to the JSON property `begin`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeEndpointProto]
        attr_accessor :begin
      
        # Not all combinations of optional fields in TimeEndpointProto are allowed. The
        # granularity of time is a path along the directed graph with these edges:
        # second -> minute minute -> hour hour -> day of week hour -> day of month hour -
        # > day of year day of week -> week of month day of week -> week of year day of
        # month -> month day of year -> year week of month -> month week of year -> year
        # month -> year A TimeEndpointProto may not specify two fields that are
        # unordered with respect to each other ("day of year" and "day of week", for
        # instance). The absence of fields larger than any specified field indicates
        # repetition (e.g. no year indicates that the interval occurs every year). The
        # absence of units that are "smaller" than the largest specified unit indicates
        # a default lowest value (no hour means midnight (0)). When intersecting time
        # intervals, "smaller" units repeat within the "larger" unit as many times as
        # necessary. For example, the intersection of the interval from hour 0 to hour
        # 24 with the interval from second 0 to second 1 is equivalent to the union of
        # the set of intervals which represents the first second of every minute of
        # every hour of every day. ------------------------------------------------------
        # ----------------------- WARNING - if you add new fields to TimeEndpointProto
        # you need to: - ensure AreTimeEndpointsEquivalent considers the new fields (and
        # update the corresponding tests) -----------------------------------------------
        # ------------------------------
        # Corresponds to the JSON property `end`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeEndpointProto]
        attr_accessor :end
      
        # If true, then this interval actually encodes the complement of the specified
        # occasion or range. For example, the following TimeIntervalProto encodes all
        # times other than the month of May. TimeIntervalProto[ type = TYPE_RANGE
        # inverted = true begin = TimeEndpointProto[ month = MAY ] end =
        # TimeEndpointProto[ month = JUNE ] ]
        # Corresponds to the JSON property `inverted`
        # @return [Boolean]
        attr_accessor :inverted
        alias_method :inverted?, :inverted
      
        # clang-format on
        # Corresponds to the JSON property `occasion`
        # @return [String]
        attr_accessor :occasion
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @end = args[:end] if args.key?(:end)
          @inverted = args[:inverted] if args.key?(:inverted)
          @occasion = args[:occasion] if args.key?(:occasion)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class GeostoreTimeScheduleProto
        include Google::Apis::Core::Hashable
      
        # The schedule is the union of these components.
        # Corresponds to the JSON property `component`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreTimeComponentProto>]
        attr_accessor :component
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @component = args[:component] if args.key?(:component)
        end
      end
      
      # A TimezoneProto holds information about a feature's related time zone.
      class GeostoreTimezoneProto
        include Google::Apis::Core::Hashable
      
        # i18n recognized time zone identifier. For the full list of identifiers, see
        # google3/i18n/identifiers/data/timezones.txt.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # A collection of information that applies to a toll cluster.
      class GeostoreTollClusterProto
        include Google::Apis::Core::Hashable
      
        # The list of TYPE_INTERSECTION features that are toll points and form this toll
        # cluster. A toll cluser can consist of either a single or a group of
        # intersection points called toll points at the end of various road segments in
        # MapFacts that represent one or more lanes passing through a toll fixture that
        # all go to the same routing destination. This relationship is reciprocal, as a
        # toll point intersection also stores a reference to the toll cluster it belongs
        # to. A toll cluster must have reference to one or more toll points i.e.
        # toll_cluster.intersection should always be populated.
        # Corresponds to the JSON property `intersection`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :intersection
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intersection = args[:intersection] if args.key?(:intersection)
        end
      end
      
      # 
      class GeostoreTrackProto
        include Google::Apis::Core::Hashable
      
        # The index of this TrackProto in a list of TrackProtos.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # The instantaneous pose of points along this track. The fields set inside each
        # pose must be set consistently along the track.
        # Corresponds to the JSON property `pose`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostorePoseProto>]
        attr_accessor :pose
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
          @pose = args[:pose] if args.key?(:pose)
        end
      end
      
      # A transit line is a named set of transit trips that are advertised to
      # passengers under a common name, and a number of attributes that are true for
      # all those trips. There is no requirement for each trip to travel through the
      # same list of stops or use the same legs, so a line can contain trips in
      # opposite directions or with variations in the sequence of stops. See go/
      # oysterpedia for an overview of the transit feature types. The standard feature
      # properties are interpreted as follows: name - The names of this line,
      # including both long and short names, if available. Short names like "10" or "
      # Blue" should carry the FLAG_ABBREVIATED, long names like "Dublin/Pleasanton
      # line" should not. The preferred name (one per language) for displaying the
      # line on its own (e.g., as a search result for the line) should carry the
      # FLAG_PREFERRED. website - The official web page describing this line. Repeated
      # if multilingual. Line features have no geometry (neither points nor polylines
      # nor polygons). Within Transit Oyster, geometry can be found in legs.
      # Additional data only in Transit Oyster: child - The legs of this line, in no
      # particular order. source_info - Specifies the GTFS routes that match this
      # feature. Each is given as a PROVIDER_GOOGLE_TRANSIT source_info where dataset
      # is the feed name and cookie is the route_id.
      class GeostoreTransitLineProto
        include Google::Apis::Core::Hashable
      
        # The transit agencies responsible for operating this line. All lines should
        # have at least one agency, and most will have exactly one. The following cases
        # are reasons for multiple agencies: - Code share: Two or more agencies share
        # trips - Alternations: Each trip is run by one of multiple agencies -
        # Additional: All trips run by one agency, but a second one sells tickets In all
        # cases the order has no meaning. Clarification comes from the trips.
        # Corresponds to the JSON property `agency`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :agency
      
        # The background color of labels for that transit line. The encoding is like in
        # HTML or CSS, eg. 0x11ff00 means a bit of red, full green, no blue, in sRGB
        # color space. The most significant byte must be zero, i.e. no transparency.
        # Corresponds to the JSON property `labelBackgroundColor`
        # @return [Fixnum]
        attr_accessor :label_background_color
      
        # The text color of labels for that transit line. Encoding like
        # label_background_color.
        # Corresponds to the JSON property `labelTextColor`
        # @return [Fixnum]
        attr_accessor :label_text_color
      
        # The transit stations (establishment POIs with gcid:transit_station) which this
        # transit line can go through, in no particular order. Usage note: The source of
        # truth are the transit leg features in Transit Oyster. In MapFacts, that
        # information is cached in two locations: in this field, and in transit station
        # attachments on POIs. Do not assume these locations are always up to date and/
        # or synchronized with each other.
        # Corresponds to the JSON property `stations`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :stations
      
        # The type of vehicle that applies to all trips that use this line.
        # Corresponds to the JSON property `vehicleType`
        # @return [String]
        attr_accessor :vehicle_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agency = args[:agency] if args.key?(:agency)
          @label_background_color = args[:label_background_color] if args.key?(:label_background_color)
          @label_text_color = args[:label_text_color] if args.key?(:label_text_color)
          @stations = args[:stations] if args.key?(:stations)
          @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
        end
      end
      
      # A line variant is a specific instantiation of a line concept, denoted by the
      # ordered set of stops and collection of segments that it traverses. Line
      # variants are modeled as TYPE_ROUTE features with gcid:transit_line_variant.
      # This proto stores line-variant-specific information that is not generally
      # applicable to all routes. Schema Design Doc: go/transit-line-concepts-and-
      # variants
      class GeostoreTransitLineVariantProto
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `lineConcept`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :line_concept
      
        # Ordered list of stations or platforms serviced by this line variant. The order
        # is captured by the ServicedStopProto.index field.
        # Corresponds to the JSON property `stops`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreServicedStopProto>]
        attr_accessor :stops
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @line_concept = args[:line_concept] if args.key?(:line_concept)
          @stops = args[:stops] if args.key?(:stops)
        end
      end
      
      # Encapsulates information related to an individual transit station.
      class GeostoreTransitStationProto
        include Google::Apis::Core::Hashable
      
        # Transit agencies which service this transit station. A station can be serviced
        # by one or more transit agencies. See go/transit-agency-relation-migration for
        # more information.
        # Corresponds to the JSON property `agencies`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto>]
        attr_accessor :agencies
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agencies = args[:agencies] if args.key?(:agencies)
        end
      end
      
      # 
      class GeostoreTrustSignalsProto
        include Google::Apis::Core::Hashable
      
        # Trust related information about the input source (feed or user) to help
        # feature summarization. Typically, the values in this proto are either based on
        # source's previous observations (e.g., a blocked LBC user or a trusted feed) or
        # their status (Google hired operator or admin user). The proto can later
        # contain a more granular trust score or correctness probabilities. A higher
        # enum value indicates a more trusted source. Leaving room in the value space
        # for adding more granular enums, if they become necessary later.
        # Corresponds to the JSON property `sourceTrust`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreSourceTrustProto]
        attr_accessor :source_trust
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_trust = args[:source_trust] if args.key?(:source_trust)
        end
      end
      
      # A speed limit without a limit value. Used to indicate the absence of a speed
      # limit.
      class GeostoreUnlimitedSpeedProto
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Hold a list of URLs, usually to contain translations of a single URL.
      class GeostoreUrlListProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `url`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreUrlProto>]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # A web location for a Feature. URLs should always be stored in repeated fields
      # because some objects (eg. transit schedules in Brussels) have different URLs
      # for different languages.
      class GeostoreUrlProto
        include Google::Apis::Core::Hashable
      
        # The external form of a Google International Identifiers Initiative (III)
        # LanguageCode object. See google3/i18n/identifiers/languagecode.h for details.
        # We place extra restrictions on languages in addition to what the III library
        # requires. See http://go/geo-schema-reference/feature-properties/languages.md
        # This field represents the language of the content of the web site. It may be
        # missing if the web site is language-independent or if the language is unknown.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Internal field metadata. This part is not exposed to downstream consumers of
        # the repository (read-only clients) but is available to upstream providers to
        # the repository (read-write clients).
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFieldMetadataProto]
        attr_accessor :metadata
      
        # ** DEPRECATED ** The pagerank of this URL. Valid values [0, 65535] See http://
        # wiki/Main/NearestSeeds for more information.
        # Corresponds to the JSON property `pagerank`
        # @return [Fixnum]
        attr_accessor :pagerank
      
        # The URL.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @metadata = args[:metadata] if args.key?(:metadata)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # UserProto identifies a (human) user of Geo Data. Its primary use is in
      # describing the source of pieces of data (e.g. edits). It could be a simple
      # identifier, but isn't so that we can store it in the clear while still
      # preventing correlation between a user's contribution.
      class GeostoreUserProto
        include Google::Apis::Core::Hashable
      
        # The user Gaia ID in encrypted form. Wipeout ids take value of "" in bytes.
        # Corresponds to the JSON property `encryptedGaiaId`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encrypted_gaia_id
      
        # Required. The name of the key used to encrypt the Gaia ID.
        # Corresponds to the JSON property `encryptionKeyName`
        # @return [String]
        attr_accessor :encryption_key_name
      
        # Required (valid default provided). The config ID of the owner of the above
        # encryption_key_name. This field must be set if the encryption key name is *not*
        # "mapfacts_gaia_id_encryption_key".
        # Corresponds to the JSON property `keystoreConfigId`
        # @return [Fixnum]
        attr_accessor :keystore_config_id
      
        # If possible, writers should set this to a full user email, including the
        # domain. Readers should not assume that this is a well-formed email address.
        # This field may only be set by Atlas, Pushpin and OneRing because they are
        # internal tools which have a PWG exception to store textual usernames in the
        # clear.
        # Corresponds to the JSON property `username`
        # @return [String]
        attr_accessor :username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encrypted_gaia_id = args[:encrypted_gaia_id] if args.key?(:encrypted_gaia_id)
          @encryption_key_name = args[:encryption_key_name] if args.key?(:encryption_key_name)
          @keystore_config_id = args[:keystore_config_id] if args.key?(:keystore_config_id)
          @username = args[:username] if args.key?(:username)
        end
      end
      
      # A speed limit whose value can change based on road, traffic, and weather
      # conditions.
      class GeostoreVariableSpeedProto
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # A set of vehicle attribute conditionals (ex: weight >= 20T && num_trailers = 2)
      # used to define a slice of all possible vehicles. This can be useful for
      # filtering one or more vehicles by a predicate.
      class GeostoreVehicleAttributeFilterProto
        include Google::Apis::Core::Hashable
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "count < 4" AND "count >= 2" means "2 <=
        # count < 4").
        # Corresponds to the JSON property `axleCount`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreCountComparisonProto>]
        attr_accessor :axle_count
      
        # Whether the applied vehicle types have a trailer attached to them.
        # Corresponds to the JSON property `hasTrailer`
        # @return [Boolean]
        attr_accessor :has_trailer
        alias_method :has_trailer?, :has_trailer
      
        # List of prohibited hazardous goods for a vehicle to carry. A repeated value
        # here is treated as an OR operation, meaning that they may not carry ANY of the
        # goods listed.
        # Corresponds to the JSON property `hazardousGoods`
        # @return [Array<String>]
        attr_accessor :hazardous_goods
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "count <= 4" AND "count > 2" means "2 <
        # count <= 4").
        # Corresponds to the JSON property `numTrailers`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreCountComparisonProto>]
        attr_accessor :num_trailers
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "length <= 53ft" AND "length > 48ft"
        # means "48ft < length <= 53ft").
        # Corresponds to the JSON property `trailerLength`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreDimensionComparisonProto>]
        attr_accessor :trailer_length
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "height > 3m" AND "height <= 5m" means "
        # 3m < height <= 5m").
        # Corresponds to the JSON property `vehicleHeight`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreDimensionComparisonProto>]
        attr_accessor :vehicle_height
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "length <= 40m" AND "length > 35m" means "
        # 35m < length <= 40m").
        # Corresponds to the JSON property `vehicleLength`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreDimensionComparisonProto>]
        attr_accessor :vehicle_length
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "weight < 8T" AND "weight >= 3T" means "
        # 3T <= weight < 8T").
        # Corresponds to the JSON property `vehicleWeight`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreWeightComparisonProto>]
        attr_accessor :vehicle_weight
      
        # A repeated value here is treated as an AND operation. This allows for ranges
        # to be represented by two values (ex: "width < 4m" AND "width >= 2m" means "2m <
        # = width < 4m").
        # Corresponds to the JSON property `vehicleWidth`
        # @return [Array<Google::Apis::ContentwarehouseV1::GeostoreDimensionComparisonProto>]
        attr_accessor :vehicle_width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @axle_count = args[:axle_count] if args.key?(:axle_count)
          @has_trailer = args[:has_trailer] if args.key?(:has_trailer)
          @hazardous_goods = args[:hazardous_goods] if args.key?(:hazardous_goods)
          @num_trailers = args[:num_trailers] if args.key?(:num_trailers)
          @trailer_length = args[:trailer_length] if args.key?(:trailer_length)
          @vehicle_height = args[:vehicle_height] if args.key?(:vehicle_height)
          @vehicle_length = args[:vehicle_length] if args.key?(:vehicle_length)
          @vehicle_weight = args[:vehicle_weight] if args.key?(:vehicle_weight)
          @vehicle_width = args[:vehicle_width] if args.key?(:vehicle_width)
        end
      end
      
      # A proto representing a vertical ordering of a feature. NOTE: This shouldn’t be
      # used if a more specific field can be used instead. E.g., for TYPE_SEGMENT
      # features grade_level field should be preferred. For indoor features
      # RELATION_ON_LEVEL should be preferred. See go/aboutgrades for comparison of
      # various types of levels available.
      class GeostoreVerticalOrderingProto
        include Google::Apis::Core::Hashable
      
        # The level represents the relative vertical ordering of a feature among all
        # overlapping features. For example, we may have features along freeway surface
        # have level = 0, and features on an overpass have level = 1. NOTE: It’s assumed
        # that all features have level 0 by default, so that it’s not necessary for all
        # overlapping features to have this set.
        # Corresponds to the JSON property `level`
        # @return [Float]
        attr_accessor :level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @level = args[:level] if args.key?(:level)
        end
      end
      
      # A weight value tagged with a comparison operator.
      class GeostoreWeightComparisonProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `comparison`
        # @return [String]
        attr_accessor :comparison
      
        # 
        # Corresponds to the JSON property `comparisonOperator`
        # @return [String]
        attr_accessor :comparison_operator
      
        # A weight with a numerical value and unit.
        # Corresponds to the JSON property `weightWithUnit`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreWeightProto]
        attr_accessor :weight_with_unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @comparison = args[:comparison] if args.key?(:comparison)
          @comparison_operator = args[:comparison_operator] if args.key?(:comparison_operator)
          @weight_with_unit = args[:weight_with_unit] if args.key?(:weight_with_unit)
        end
      end
      
      # A weight with a numerical value and unit.
      class GeostoreWeightProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # 
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @unit = args[:unit] if args.key?(:unit)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # An anchor label can be attached to any element to give it a reference address.
      # LogicalEntity links (see goodoc-semantics.proto) may use anchor labels to
      # point to goodoc elements (they may also use indices to locate the element, but
      # the indices could become invalid if the goodocs are allowed to mutate).
      # Multiple elements may have the same anchor.
      class GoodocAnchorLabel
        include Google::Apis::Core::Hashable
      
        # There is a generic method for composing such strings. Please take a look at
        # GoodocUtils::GenerateUniqueAnchorName(...) in ocr/goodoc/goodoc-utils.h.
        # Corresponds to the JSON property `Anchor`
        # @return [String]
        attr_accessor :anchor
      
        # 
        # Corresponds to the JSON property `anchorScope`
        # @return [Fixnum]
        attr_accessor :anchor_scope
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor = args[:anchor] if args.key?(:anchor)
          @anchor_scope = args[:anchor_scope] if args.key?(:anchor_scope)
        end
      end
      
      # Bounding box for page structural elements: pictures, paragraphs, characters,
      # etc.
      class GoodocBoundingBox
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Optional magic label, so objects can be sorted on bounding box dimensions
        # easily
        # Corresponds to the JSON property `Label`
        # @return [Fixnum]
        attr_accessor :label
      
        # BoundingBox coordinates and sizes are expressed in pixels
        # Corresponds to the JSON property `Left`
        # @return [Fixnum]
        attr_accessor :left
      
        # 
        # Corresponds to the JSON property `Top`
        # @return [Fixnum]
        attr_accessor :top
      
        # 
        # Corresponds to the JSON property `Width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @label = args[:label] if args.key?(:label)
          @left = args[:left] if args.key?(:left)
          @top = args[:top] if args.key?(:top)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # A way to specify a simple partitioning of a BoundingBox into a sequence of sub-
      # boxes. +----------------------------------------------------+ | | | | | | |
      # span(0) | (1) | (2) | (3) | (4) | | | | | | | +--------------------------------
      # --------------------+ This representation can, for example, be used to store
      # coarse Symbol boundaries within a Word (see Word.CompactSymbolBoxes below)
      # instead of per-Symbol BoundingBoxes, for saving space.
      class GoodocBoxPartitions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `direction`
        # @return [Fixnum]
        attr_accessor :direction
      
        # "span" is width or height, determined by "direction". If there are k
        # partitions, then there are k - 1 "span" values, one for each except the last
        # symbol (which is redundant).
        # Corresponds to the JSON property `span`
        # @return [Array<Fixnum>]
        attr_accessor :span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @direction = args[:direction] if args.key?(:direction)
          @span = args[:span] if args.key?(:span)
        end
      end
      
      # Break label
      class GoodocBreakLabel
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `BreakLabelType`
        # @return [Fixnum]
        attr_accessor :break_label_type
      
        # True if break prepends the element
        # Corresponds to the JSON property `isPrefix`
        # @return [Boolean]
        attr_accessor :is_prefix
        alias_method :is_prefix?, :is_prefix
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @break_label_type = args[:break_label_type] if args.key?(:break_label_type)
          @is_prefix = args[:is_prefix] if args.key?(:is_prefix)
        end
      end
      
      # Font label
      class GoodocCharLabel
        include Google::Apis::Core::Hashable
      
        # The shift of a character from the base line of the string in pixels
        # Corresponds to the JSON property `BaseLine`
        # @return [Fixnum]
        attr_accessor :base_line
      
        # Height of small characters in pixels on the source image
        # Corresponds to the JSON property `CharacterHeight`
        # @return [Fixnum]
        attr_accessor :character_height
      
        # The foreground color of the symbol; the default color is 0 (black)
        # Corresponds to the JSON property `Color`
        # @return [Fixnum]
        attr_accessor :color
      
        # Symbol recognition confidence from OCR. Range depends upon OCR Engine.
        # Corresponds to the JSON property `Confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # The font ID refers to the fonts table in the document header
        # Corresponds to the JSON property `FontId`
        # @return [Fixnum]
        attr_accessor :font_id
      
        # Size in points (JFYI: point is 1/72"). This is rounded to the nearest whole
        # number.
        # Corresponds to the JSON property `FontSize`
        # @return [Fixnum]
        attr_accessor :font_size
      
        # Size in points represented as float.
        # Corresponds to the JSON property `FontSizeFloat`
        # @return [Float]
        attr_accessor :font_size_float
      
        # 
        # Corresponds to the JSON property `FontType`
        # @return [Fixnum]
        attr_accessor :font_type
      
        # If CharacterHeight is defined uncertainly
        # Corresponds to the JSON property `HasUncertainHeight`
        # @return [Boolean]
        attr_accessor :has_uncertain_height
        alias_method :has_uncertain_height?, :has_uncertain_height
      
        # The horizontal scaling for a character, in percents. The default value for
        # this property is 100, which corresponds to no scaling.
        # Corresponds to the JSON property `HorizontalScale`
        # @return [Fixnum]
        attr_accessor :horizontal_scale
      
        # 
        # Corresponds to the JSON property `IsBold`
        # @return [Boolean]
        attr_accessor :is_bold
        alias_method :is_bold?, :is_bold
      
        # 
        # Corresponds to the JSON property `IsItalic`
        # @return [Boolean]
        attr_accessor :is_italic
        alias_method :is_italic?, :is_italic
      
        # 
        # Corresponds to the JSON property `IsSmallCaps`
        # @return [Boolean]
        attr_accessor :is_small_caps
        alias_method :is_small_caps?, :is_small_caps
      
        # 
        # Corresponds to the JSON property `IsStrikeout`
        # @return [Boolean]
        attr_accessor :is_strikeout
        alias_method :is_strikeout?, :is_strikeout
      
        # 
        # Corresponds to the JSON property `IsSubscript`
        # @return [Boolean]
        attr_accessor :is_subscript
        alias_method :is_subscript?, :is_subscript
      
        # 
        # Corresponds to the JSON property `IsSuperscript`
        # @return [Boolean]
        attr_accessor :is_superscript
        alias_method :is_superscript?, :is_superscript
      
        # If OCR Engine marked the character as "suspicious" (this character is likely
        # to be recognized incorrectly).
        # Corresponds to the JSON property `IsSuspicious`
        # @return [Boolean]
        attr_accessor :is_suspicious
        alias_method :is_suspicious?, :is_suspicious
      
        # 
        # Corresponds to the JSON property `IsUnderlined`
        # @return [Boolean]
        attr_accessor :is_underlined
        alias_method :is_underlined?, :is_underlined
      
        # True if a QA operator has marked this as not OCRable. This is used for complex
        # equations, scripts that the operator can't type, or handwriting.
        # Corresponds to the JSON property `NotOcrablePerQA`
        # @return [Boolean]
        attr_accessor :not_ocrable_per_qa
        alias_method :not_ocrable_per_qa?, :not_ocrable_per_qa
      
        # Symbol-level penalty from the garbage text detector. Lower is better; range = [
        # 0,100].
        # Corresponds to the JSON property `Penalty`
        # @return [Fixnum]
        attr_accessor :penalty
      
        # The probability that a character is written with a Serif font
        # Corresponds to the JSON property `SerifProbability`
        # @return [Fixnum]
        attr_accessor :serif_probability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_line = args[:base_line] if args.key?(:base_line)
          @character_height = args[:character_height] if args.key?(:character_height)
          @color = args[:color] if args.key?(:color)
          @confidence = args[:confidence] if args.key?(:confidence)
          @font_id = args[:font_id] if args.key?(:font_id)
          @font_size = args[:font_size] if args.key?(:font_size)
          @font_size_float = args[:font_size_float] if args.key?(:font_size_float)
          @font_type = args[:font_type] if args.key?(:font_type)
          @has_uncertain_height = args[:has_uncertain_height] if args.key?(:has_uncertain_height)
          @horizontal_scale = args[:horizontal_scale] if args.key?(:horizontal_scale)
          @is_bold = args[:is_bold] if args.key?(:is_bold)
          @is_italic = args[:is_italic] if args.key?(:is_italic)
          @is_small_caps = args[:is_small_caps] if args.key?(:is_small_caps)
          @is_strikeout = args[:is_strikeout] if args.key?(:is_strikeout)
          @is_subscript = args[:is_subscript] if args.key?(:is_subscript)
          @is_superscript = args[:is_superscript] if args.key?(:is_superscript)
          @is_suspicious = args[:is_suspicious] if args.key?(:is_suspicious)
          @is_underlined = args[:is_underlined] if args.key?(:is_underlined)
          @not_ocrable_per_qa = args[:not_ocrable_per_qa] if args.key?(:not_ocrable_per_qa)
          @penalty = args[:penalty] if args.key?(:penalty)
          @serif_probability = args[:serif_probability] if args.key?(:serif_probability)
        end
      end
      
      # Top-level representation of OCRed document
      class GoodocDocument
        include Google::Apis::Core::Hashable
      
        # Debug info, recording the history of any editing done through the interface in
        # goodoc-editing.h. The strings look like "MoveParagraph(page_index = 0,
        # source_block_index = 3, ...);
        # Corresponds to the JSON property `EditingHistory`
        # @return [Array<String>]
        attr_accessor :editing_history
      
        # Logical entities are stored as blobs. Depending on the kind of thing this is a
        # goodoc of, a separate .proto file is expected to define the logical entity
        # structure. Hence we can still parse this as a goodoc for people who dont care
        # about this, and people who care about this can parse it specifically. ocr/
        # goodoc/logical-entity-utils.h has methods to read and write these. See Goodoc++
        # doc
        # Corresponds to the JSON property `LogicalEntity`
        # @return [Array<String>]
        attr_accessor :logical_entity
      
        # The names of the proto messages serialized in LogicalEntity, one for each
        # LogicalEntity. The repetitions should number 0 to leave this unspecified, or
        # they should equal the number of LogicalEntity strings.
        # Corresponds to the JSON property `LogicalEntityMessageName`
        # @return [Array<String>]
        attr_accessor :logical_entity_message_name
      
        # For multi-goodoc documents
        # Corresponds to the JSON property `SubDocuments`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocDocument>]
        attr_accessor :sub_documents
      
        # 
        # Corresponds to the JSON property `header`
        # @return [Google::Apis::ContentwarehouseV1::GoodocDocumentHeader]
        attr_accessor :header
      
        # 
        # Corresponds to the JSON property `page`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocDocumentPage>]
        attr_accessor :page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @editing_history = args[:editing_history] if args.key?(:editing_history)
          @logical_entity = args[:logical_entity] if args.key?(:logical_entity)
          @logical_entity_message_name = args[:logical_entity_message_name] if args.key?(:logical_entity_message_name)
          @sub_documents = args[:sub_documents] if args.key?(:sub_documents)
          @header = args[:header] if args.key?(:header)
          @page = args[:page] if args.key?(:page)
        end
      end
      
      # 
      class GoodocDocumentHeader
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `OcrEngineId`
        # @return [String]
        attr_accessor :ocr_engine_id
      
        # 
        # Corresponds to the JSON property `OcrEngineVersion`
        # @return [String]
        attr_accessor :ocr_engine_version
      
        # 
        # Corresponds to the JSON property `font`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocDocumentHeaderFont>]
        attr_accessor :font
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ocr_engine_id = args[:ocr_engine_id] if args.key?(:ocr_engine_id)
          @ocr_engine_version = args[:ocr_engine_version] if args.key?(:ocr_engine_version)
          @font = args[:font] if args.key?(:font)
        end
      end
      
      # 
      class GoodocDocumentHeaderFont
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `FontId`
        # @return [Fixnum]
        attr_accessor :font_id
      
        # 
        # Corresponds to the JSON property `FontName`
        # @return [String]
        attr_accessor :font_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @font_id = args[:font_id] if args.key?(:font_id)
          @font_name = args[:font_name] if args.key?(:font_name)
        end
      end
      
      # 
      class GoodocDocumentPage
        include Google::Apis::Core::Hashable
      
        # If the garbage text detector was run, the changelist that the binary was sync'
        # ed to (or -1 if unknown), and whether the settings had their production values
        # (or false if unknown).
        # Corresponds to the JSON property `GarbageDetectorChangeList`
        # @return [Fixnum]
        attr_accessor :garbage_detector_change_list
      
        # 
        # Corresponds to the JSON property `GarbageDetectorWasProduction`
        # @return [Boolean]
        attr_accessor :garbage_detector_was_production
        alias_method :garbage_detector_was_production?, :garbage_detector_was_production
      
        # Height in pixels
        # Corresponds to the JSON property `Height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Horizontal resolution in DPI.
        # Corresponds to the JSON property `HorizontalDpi`
        # @return [Fixnum]
        attr_accessor :horizontal_dpi
      
        # Label aggregates all kinds of optional characteristics of page elements.
        # Corresponds to the JSON property `Label`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLabel]
        attr_accessor :label
      
        # Score of porn classifier from analyzing images on page. Note: This should be
        # named porn_score, but we use PornScore as the name in order to be consistent
        # with the rest of this proto.
        # Corresponds to the JSON property `PornScore`
        # @return [Float]
        attr_accessor :porn_score
      
        # Page text recognition confidence. Range depends on the algorithm but should be
        # consistent in a given volume. 0 is bad, 100 is good.
        # Corresponds to the JSON property `TextConfidence`
        # @return [Fixnum]
        attr_accessor :text_confidence
      
        # Vertical resolution in DPI.
        # Corresponds to the JSON property `VerticalDpi`
        # @return [Fixnum]
        attr_accessor :vertical_dpi
      
        # Width in pixels
        # Corresponds to the JSON property `Width`
        # @return [Fixnum]
        attr_accessor :width
      
        # 
        # Corresponds to the JSON property `block`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocDocumentPageBlock>]
        attr_accessor :block
      
        # 
        # Corresponds to the JSON property `mergedpageinfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocDocumentPageMergedPageInfo>]
        attr_accessor :mergedpageinfo
      
        # Whether page-level text confidences and other summary data were computed by
        # PostOcrUtils instead of the now-obsolete GarbageTextDetector
        # Corresponds to the JSON property `postOcrConfidence`
        # @return [Boolean]
        attr_accessor :post_ocr_confidence
        alias_method :post_ocr_confidence?, :post_ocr_confidence
      
        # Goodoc stats for a range of elements, such as one page or a whole book. These
        # stats can be computed using the SummaryStatsCollector class. Some range stats
        # are pre-computed and stored in goodocs/volumes (eg., Page.stats below, and
        # Ocean's CA_VolumeResult.goodoc_stats).
        # Corresponds to the JSON property `stats`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSummaryStats]
        attr_accessor :stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @garbage_detector_change_list = args[:garbage_detector_change_list] if args.key?(:garbage_detector_change_list)
          @garbage_detector_was_production = args[:garbage_detector_was_production] if args.key?(:garbage_detector_was_production)
          @height = args[:height] if args.key?(:height)
          @horizontal_dpi = args[:horizontal_dpi] if args.key?(:horizontal_dpi)
          @label = args[:label] if args.key?(:label)
          @porn_score = args[:porn_score] if args.key?(:porn_score)
          @text_confidence = args[:text_confidence] if args.key?(:text_confidence)
          @vertical_dpi = args[:vertical_dpi] if args.key?(:vertical_dpi)
          @width = args[:width] if args.key?(:width)
          @block = args[:block] if args.key?(:block)
          @mergedpageinfo = args[:mergedpageinfo] if args.key?(:mergedpageinfo)
          @post_ocr_confidence = args[:post_ocr_confidence] if args.key?(:post_ocr_confidence)
          @stats = args[:stats] if args.key?(:stats)
        end
      end
      
      # 
      class GoodocDocumentPageBlock
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `BlockType`
        # @return [Fixnum]
        attr_accessor :block_type
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `Box`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :box
      
        # Label aggregates all kinds of optional characteristics of page elements.
        # Corresponds to the JSON property `Label`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLabel]
        attr_accessor :label
      
        # OrientationLabel groups the details about orientation and reading order.
        # Corresponds to the JSON property `OrientationLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocOrientationLabel]
        attr_accessor :orientation_label
      
        # 
        # Corresponds to the JSON property `Paragraph`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocParagraph>]
        attr_accessor :paragraph
      
        # Similar to goodoc.BoundingBox, but containing an angle of rotation, thus able
        # to represent non-axis-aligned boxes. RotatedBoundingBox can be used in
        # combination with BoundingBox to better represent non-axis-aligned page
        # structural elements. In such case, two bounding boxes can be used per element.
        # A RotatedBoundingBox that is rotated to tightly encompass the element;
        # embedded (as tightly as possible) inside an axis-aligned BoundingBox. Note
        # that there is some amount of ambiguity regarding what angle and vertex to use.
        # Consider a square with axis-aligned diagonals: B / \ A C \ / D This can either
        # be represented as a -45 degree rotation around A, a 45 degree rotation around
        # B, a 135 degree rotation around C, or a -135 degree rotation around D. Which
        # one you use depends on your use case, but one recommendation is to use the
        # vertex that would be top left if the reader was reading it in the 'natural'
        # orientation.
        # Corresponds to the JSON property `RotatedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRotatedBoundingBox]
        attr_accessor :rotated_box
      
        # Block text recognition confidence. Range depends on the algorithm but should
        # be consistent in a given volume. 0 is bad, 100 is good.
        # Corresponds to the JSON property `TextConfidence`
        # @return [Fixnum]
        attr_accessor :text_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @block_type = args[:block_type] if args.key?(:block_type)
          @box = args[:box] if args.key?(:box)
          @label = args[:label] if args.key?(:label)
          @orientation_label = args[:orientation_label] if args.key?(:orientation_label)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @rotated_box = args[:rotated_box] if args.key?(:rotated_box)
          @text_confidence = args[:text_confidence] if args.key?(:text_confidence)
        end
      end
      
      # If we have merged text from another goodoc into this one (for example, from a
      # PDF text layer goodoc into an OCR'd goodoc), we record some source goodoc info
      # here.
      class GoodocDocumentPageMergedPageInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `OcrEngineId`
        # @return [String]
        attr_accessor :ocr_engine_id
      
        # 
        # Corresponds to the JSON property `OcrEngineVersion`
        # @return [String]
        attr_accessor :ocr_engine_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ocr_engine_id = args[:ocr_engine_id] if args.key?(:ocr_engine_id)
          @ocr_engine_version = args[:ocr_engine_version] if args.key?(:ocr_engine_version)
        end
      end
      
      # Statistics about a particular font size (from CharLabel.FontSize) aggregated
      # over a range of symbols
      class GoodocFontSizeStats
        include Google::Apis::Core::Hashable
      
        # CharLabel.FontId and FontSize
        # Corresponds to the JSON property `fontId`
        # @return [Fixnum]
        attr_accessor :font_id
      
        # 
        # Corresponds to the JSON property `fontSize`
        # @return [Fixnum]
        attr_accessor :font_size
      
        # The measurements are in pixels
        # Corresponds to the JSON property `medianHeight`
        # @return [Fixnum]
        attr_accessor :median_height
      
        # top to bottom
        # Corresponds to the JSON property `medianLineHeight`
        # @return [Fixnum]
        attr_accessor :median_line_height
      
        # bottom to next top in para
        # Corresponds to the JSON property `medianLineSpace`
        # @return [Fixnum]
        attr_accessor :median_line_space
      
        # top to next top in para
        # Corresponds to the JSON property `medianLineSpan`
        # @return [Fixnum]
        attr_accessor :median_line_span
      
        # 
        # Corresponds to the JSON property `medianWidth`
        # @return [Fixnum]
        attr_accessor :median_width
      
        # Lines (out of num_lines) that have a successor line within their para
        # Corresponds to the JSON property `numLineSpaces`
        # @return [Fixnum]
        attr_accessor :num_line_spaces
      
        # Line stats for this font. "top" corresponds to the highest ascender and "
        # bottom" to the lowest descender. num_lines = # lines with > 50% symbols having
        # this font
        # Corresponds to the JSON property `numLines`
        # @return [Fixnum]
        attr_accessor :num_lines
      
        # 
        # Corresponds to the JSON property `numSymbols`
        # @return [Fixnum]
        attr_accessor :num_symbols
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @font_id = args[:font_id] if args.key?(:font_id)
          @font_size = args[:font_size] if args.key?(:font_size)
          @median_height = args[:median_height] if args.key?(:median_height)
          @median_line_height = args[:median_line_height] if args.key?(:median_line_height)
          @median_line_space = args[:median_line_space] if args.key?(:median_line_space)
          @median_line_span = args[:median_line_span] if args.key?(:median_line_span)
          @median_width = args[:median_width] if args.key?(:median_width)
          @num_line_spaces = args[:num_line_spaces] if args.key?(:num_line_spaces)
          @num_lines = args[:num_lines] if args.key?(:num_lines)
          @num_symbols = args[:num_symbols] if args.key?(:num_symbols)
        end
      end
      
      # Label aggregates all kinds of optional characteristics of page elements.
      class GoodocLabel
        include Google::Apis::Core::Hashable
      
        # AnchorLabel identifies a link target.
        # Corresponds to the JSON property `AnchorLabel`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocAnchorLabel>]
        attr_accessor :anchor_label
      
        # Break label
        # Corresponds to the JSON property `BreakLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBreakLabel]
        attr_accessor :break_label
      
        # Font label
        # Corresponds to the JSON property `CharLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocCharLabel]
        attr_accessor :char_label
      
        # Languages used in the element (page, block, paragraph or word). Ordered by
        # dominant-language first. Note: content scanjobs processed by the
        # garbage_text_detector before CL 9223538 (Dec. 2008) have LanguageLabels in
        # arbitrary order (within Page and Block elements) -- the confidence value
        # should be inspected to find the dominant language guess for these, rather than
        # just taking the first.
        # Corresponds to the JSON property `LanguageLabel`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocLanguageLabel>]
        attr_accessor :language_label
      
        # Label identifying a logical part of the page content. This applies mostly at
        # Block level or Paragraph level (but can apply to Words or to arbitrary spans
        # if needed).
        # Corresponds to the JSON property `SemanticLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabel]
        attr_accessor :semantic_label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_label = args[:anchor_label] if args.key?(:anchor_label)
          @break_label = args[:break_label] if args.key?(:break_label)
          @char_label = args[:char_label] if args.key?(:char_label)
          @language_label = args[:language_label] if args.key?(:language_label)
          @semantic_label = args[:semantic_label] if args.key?(:semantic_label)
        end
      end
      
      # Weighted language
      class GoodocLanguageCombinationLanguage
        include Google::Apis::Core::Hashable
      
        # Bcp47 language code. Note, this is not the same as OceanCode used by goodoc::
        # Document.
        # Corresponds to the JSON property `bcp47Tag`
        # @return [String]
        attr_accessor :bcp47_tag
      
        # Weight of language. This specifies how likely it is to see the language in the
        # input text. The values don't have to add up to 1.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bcp47_tag = args[:bcp47_tag] if args.key?(:bcp47_tag)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # Language label
      class GoodocLanguageLabel
        include Google::Apis::Core::Hashable
      
        # Closest id from i18n/languages/proto/languages.proto; caveat: may not
        # accurately capture the language. GoodocLanguageCodeToLanguage() declared in
        # ocr/goodoc/goodoc-utils.h may be used to convert a Language enum (i18n/
        # languages/proto/languages.proto) to a string suitable for this field.
        # Corresponds to the JSON property `ClosestLanguageId`
        # @return [Fixnum]
        attr_accessor :closest_language_id
      
        # Confidence level on that language, between 0 and 100
        # Corresponds to the JSON property `Confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # Old (Ocean) Language Code Usage: The language code is inferred during the
        # running of the Garbage Text Detector and gets set at the paragraph, block and
        # page level. Language code is a string of 3 or more characters. The first 3
        # letters specify the language, according to ISO 639. Optionally, the 3-letter
        # code can be extended with an underscore and a language variant specifier.
        # Specifiers exist for regional variants or for different forms of language
        # spelling. The regional variants are specified as 2-letter country code,
        # according to ISO 3166. Some examples: Standard "por" - Portuguese, standard "
        # rus" - Russian, standard Regional variants: "por_br" - Portuguese, Brazilian "
        # eng_us" - English, United States Variants of spelling: "rus_old" - Russian,
        # old spelling "chi_tra" - Chinese, traditional "ger_new" - German, new spelling
        # LanguageToGoodocLanguageCode() declared in ocr/goodoc/goodoc-utils.h may be
        # used to convert a Language enum (i18n/languages/proto/languages.proto) to a
        # string suitable for this field. New Language Code Usage: Most of the usages
        # described above were standardized in BCP 47, and these codes are the new
        # stanadard to be used in this field. To load either new or old language codes
        # to form LanguageCode objects, use the function FromOceanCode() in ocr/quality/
        # lang_util.h Note that the function ocr::FromOceanCode is capable of
        # transforming either version of the LanguageCode to a C++ i18n_identifiers::
        # LanguageCode.
        # Corresponds to the JSON property `LanguageCode`
        # @return [String]
        attr_accessor :language_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @closest_language_id = args[:closest_language_id] if args.key?(:closest_language_id)
          @confidence = args[:confidence] if args.key?(:confidence)
          @language_code = args[:language_code] if args.key?(:language_code)
        end
      end
      
      # A logical entity in the abstract is just a group of links to the goodoc.
      # Depending on the kind of item, a separate proto file should extend this to
      # define the logical structure for that kind. For example. newspapers.proto
      # defines the logical entity for newspapers. LogicalEntity is also used within
      # some SemanticLabels, for example, for a table-of-contents link.
      class GoodocLogicalEntity
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Metadata`
        # @return [String]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `link`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocLogicalEntityLink>]
        attr_accessor :link
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @link = args[:link] if args.key?(:link)
        end
      end
      
      # NOTE(gponcin) 2008/11 This is repeated for articles where we may have multiple
      # links in one entity. From Vivek (Atlantis): "The block segmenter outputs a
      # list of headlines on a page as a single logical entity that we attach to the
      # logicalentity(1) for the goodoc."
      class GoodocLogicalEntityLink
        include Google::Apis::Core::Hashable
      
        # The preferred way to link to an element is to create an AnchorLabel in the
        # target element and name it here. Multiple elements may contain the same Anchor
        # string.
        # Corresponds to the JSON property `Anchor`
        # @return [String]
        attr_accessor :anchor
      
        # 
        # Corresponds to the JSON property `BlockId`
        # @return [Fixnum]
        attr_accessor :block_id
      
        # Links may also specifically locate the target element with the following
        # indices. Note that during the course of layout analysis, goodoc elements may
        # move around, so such hard links should be created only very late (or not at
        # all -- Anchors would be more reliable target addresses).
        # Corresponds to the JSON property `DocId`
        # @return [Fixnum]
        attr_accessor :doc_id
      
        # 
        # Corresponds to the JSON property `PageId`
        # @return [Fixnum]
        attr_accessor :page_id
      
        # 
        # Corresponds to the JSON property `ParagraphId`
        # @return [Fixnum]
        attr_accessor :paragraph_id
      
        # 
        # Corresponds to the JSON property `RouteId`
        # @return [Fixnum]
        attr_accessor :route_id
      
        # 
        # Corresponds to the JSON property `SymbolId`
        # @return [Fixnum]
        attr_accessor :symbol_id
      
        # If not defined, link points to the current doc
        # Corresponds to the JSON property `Url`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `WordId`
        # @return [Fixnum]
        attr_accessor :word_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor = args[:anchor] if args.key?(:anchor)
          @block_id = args[:block_id] if args.key?(:block_id)
          @doc_id = args[:doc_id] if args.key?(:doc_id)
          @page_id = args[:page_id] if args.key?(:page_id)
          @paragraph_id = args[:paragraph_id] if args.key?(:paragraph_id)
          @route_id = args[:route_id] if args.key?(:route_id)
          @symbol_id = args[:symbol_id] if args.key?(:symbol_id)
          @url = args[:url] if args.key?(:url)
          @word_id = args[:word_id] if args.key?(:word_id)
        end
      end
      
      # An Ordinal message represents a single ordinal component of a page number. It
      # encodes the printed or inferred numbering style (Roman, ASCII, etc.) and the
      # ordinal value of the component. An optional set of variable is defined in
      # order to express a sectioned ordinal. A sectioned ordinal may appear in
      # certain page numbering styles, for example "12-1" where "12" identifies a
      # chapter and "1" identifies the page within it. This case will be encoded with
      # value 1 and section_value 12 both of type ASCII.
      class GoodocOrdinal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `implicit`
        # @return [String]
        attr_accessor :implicit
      
        # 
        # Corresponds to the JSON property `sectionStringValue`
        # @return [String]
        attr_accessor :section_string_value
      
        # 
        # Corresponds to the JSON property `sectionValue`
        # @return [Fixnum]
        attr_accessor :section_value
      
        # The following vars describe the section component of an ordinal (if exists).
        # They are used to express situation where a page number has a section component,
        # usually denoating the chapter number. For example pages 5-14, 5-15 will both
        # have the common section 5. (If exists). The semantcis of the section variables
        # correspond to that of the primary part of the ordinal. (Described above).
        # Corresponds to the JSON property `sectionValueType`
        # @return [String]
        attr_accessor :section_value_type
      
        # The string page value.
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # The numeric page value.
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        # The delta in which the value increases between pages.
        # Corresponds to the JSON property `valueDelta`
        # @return [String]
        attr_accessor :value_delta
      
        # A value type from the Type enum above.
        # Corresponds to the JSON property `valueType`
        # @return [String]
        attr_accessor :value_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @implicit = args[:implicit] if args.key?(:implicit)
          @section_string_value = args[:section_string_value] if args.key?(:section_string_value)
          @section_value = args[:section_value] if args.key?(:section_value)
          @section_value_type = args[:section_value_type] if args.key?(:section_value_type)
          @string_value = args[:string_value] if args.key?(:string_value)
          @value = args[:value] if args.key?(:value)
          @value_delta = args[:value_delta] if args.key?(:value_delta)
          @value_type = args[:value_type] if args.key?(:value_type)
        end
      end
      
      # OrientationLabel groups the details about orientation and reading order.
      class GoodocOrientationLabel
        include Google::Apis::Core::Hashable
      
        # After rotating so that the text orientation is upright, how many radians does
        # one have to rotate the block anti-clockwise for it to be level? We guarantee: -
        # Pi/4 <= deskew_angle <= Pi/4
        # Corresponds to the JSON property `deskewAngle`
        # @return [Float]
        attr_accessor :deskew_angle
      
        # Whether a text line is mirrored (e.g. reflected in a shiny surface or seen
        # through the opposite side of a storefront window). The intent is that this is
        # a quality of the text line image. It needs to be reflected according to a
        # vertical axis along the direction of upright characters to make it readable.
        # This does not affect the shape of the bounding box. A mirrored line with top
        # to bottom writing remains top to bottom. A mirrored horizontal line will flip
        # left to right. However any child entities (symbols) will remain in the same
        # order, and the writing direction imposed by the language (ltr or rtl) will
        # remain the same.
        # Corresponds to the JSON property `mirrored`
        # @return [Boolean]
        attr_accessor :mirrored
        alias_method :mirrored?, :mirrored
      
        # 
        # Corresponds to the JSON property `orientation`
        # @return [String]
        attr_accessor :orientation
      
        # 
        # Corresponds to the JSON property `textlineOrder`
        # @return [String]
        attr_accessor :textline_order
      
        # 
        # Corresponds to the JSON property `writingDirection`
        # @return [String]
        attr_accessor :writing_direction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deskew_angle = args[:deskew_angle] if args.key?(:deskew_angle)
          @mirrored = args[:mirrored] if args.key?(:mirrored)
          @orientation = args[:orientation] if args.key?(:orientation)
          @textline_order = args[:textline_order] if args.key?(:textline_order)
          @writing_direction = args[:writing_direction] if args.key?(:writing_direction)
        end
      end
      
      # This message specifies structure "overrides" to apply: it can be used to force
      # certain kinds of GoodocToHTML renderings of elements.
      class GoodocOverrides
        include Google::Apis::Core::Hashable
      
        # For text blocks only: do not allow this block to be turned into an image when
        # rendering, even if your algorithms want to do so:
        # Corresponds to the JSON property `blockImagination`
        # @return [String]
        attr_accessor :block_imagination
      
        # For graphic blocks, we often expand the block a bit for rendering, to
        # compensate for bad image segmentation. do_not_expand_graphic_box forces this
        # behavior to be turned off.
        # Corresponds to the JSON property `doNotExpandGraphicBox`
        # @return [Boolean]
        attr_accessor :do_not_expand_graphic_box
        alias_method :do_not_expand_graphic_box?, :do_not_expand_graphic_box
      
        # For Pages only: explicitly specify whether or not this page should be rendered
        # fully as an image
        # Corresponds to the JSON property `fullPageAsImage`
        # @return [String]
        attr_accessor :full_page_as_image
      
        # For Pages only: explicitly specify whether or not all text on this page should
        # be treated as "LINEATED"
        # Corresponds to the JSON property `fullPageLineated`
        # @return [String]
        attr_accessor :full_page_lineated
      
        # For Pages only: explicitly specify whether or not this page should be skipped.
        # Corresponds to the JSON property `fullPageSkipped`
        # @return [String]
        attr_accessor :full_page_skipped
      
        # This GRAPHIC block's image can be shown even when GoodocToHTMLOptions.
        # suppress_photos_with_this is specified.
        # Corresponds to the JSON property `needNotSuppressPhoto`
        # @return [Boolean]
        attr_accessor :need_not_suppress_photo
        alias_method :need_not_suppress_photo?, :need_not_suppress_photo
      
        # For blocks: explicitly specify whether or not this block should get a page-
        # break before it.
        # Corresponds to the JSON property `pageBreakBefore`
        # @return [String]
        attr_accessor :page_break_before
      
        # 
        # Corresponds to the JSON property `style`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocOverridesStyle>]
        attr_accessor :style
      
        # For Words only: replace the rendered HTML by this:
        # Corresponds to the JSON property `wordHtml`
        # @return [String]
        attr_accessor :word_html
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @block_imagination = args[:block_imagination] if args.key?(:block_imagination)
          @do_not_expand_graphic_box = args[:do_not_expand_graphic_box] if args.key?(:do_not_expand_graphic_box)
          @full_page_as_image = args[:full_page_as_image] if args.key?(:full_page_as_image)
          @full_page_lineated = args[:full_page_lineated] if args.key?(:full_page_lineated)
          @full_page_skipped = args[:full_page_skipped] if args.key?(:full_page_skipped)
          @need_not_suppress_photo = args[:need_not_suppress_photo] if args.key?(:need_not_suppress_photo)
          @page_break_before = args[:page_break_before] if args.key?(:page_break_before)
          @style = args[:style] if args.key?(:style)
          @word_html = args[:word_html] if args.key?(:word_html)
        end
      end
      
      # Extra css styles to apply
      class GoodocOverridesStyle
        include Google::Apis::Core::Hashable
      
        # css attribute name: "margin-left", for eg.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # css attribute vale: "1em", for eg.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Represents a paragraph of text in OCRed content.
      class GoodocParagraph
        include Google::Apis::Core::Hashable
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `Box`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :box
      
        # 
        # Corresponds to the JSON property `FirstLineIndent`
        # @return [Fixnum]
        attr_accessor :first_line_indent
      
        # Label aggregates all kinds of optional characteristics of page elements.
        # Corresponds to the JSON property `Label`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLabel]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `LeftIndent`
        # @return [Fixnum]
        attr_accessor :left_indent
      
        # 
        # Corresponds to the JSON property `LineSpacing`
        # @return [Fixnum]
        attr_accessor :line_spacing
      
        # OrientationLabel groups the details about orientation and reading order.
        # Corresponds to the JSON property `OrientationLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocOrientationLabel]
        attr_accessor :orientation_label
      
        # 
        # Corresponds to the JSON property `RightIndent`
        # @return [Fixnum]
        attr_accessor :right_indent
      
        # Similar to goodoc.BoundingBox, but containing an angle of rotation, thus able
        # to represent non-axis-aligned boxes. RotatedBoundingBox can be used in
        # combination with BoundingBox to better represent non-axis-aligned page
        # structural elements. In such case, two bounding boxes can be used per element.
        # A RotatedBoundingBox that is rotated to tightly encompass the element;
        # embedded (as tightly as possible) inside an axis-aligned BoundingBox. Note
        # that there is some amount of ambiguity regarding what angle and vertex to use.
        # Consider a square with axis-aligned diagonals: B / \ A C \ / D This can either
        # be represented as a -45 degree rotation around A, a 45 degree rotation around
        # B, a 135 degree rotation around C, or a -135 degree rotation around D. Which
        # one you use depends on your use case, but one recommendation is to use the
        # vertex that would be top left if the reader was reading it in the 'natural'
        # orientation.
        # Corresponds to the JSON property `RotatedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRotatedBoundingBox]
        attr_accessor :rotated_box
      
        # 
        # Corresponds to the JSON property `SpaceAfter`
        # @return [Fixnum]
        attr_accessor :space_after
      
        # 
        # Corresponds to the JSON property `SpaceBefore`
        # @return [Fixnum]
        attr_accessor :space_before
      
        # If we merge any paragraphs into this one (through the MergeParagraphWithNext()
        # interface in goodoc-editing.h), then we append the properties of the merged
        # paragraph here, for debugging and to avoid losing any info. Note that the
        # SubsumedParagraphProperties Paragraphs do not contain Routes.
        # Corresponds to the JSON property `SubsumedParagraphProperties`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocParagraph>]
        attr_accessor :subsumed_paragraph_properties
      
        # Paragraph text recognition confidence. Range depends on the algorithm but
        # should be consistent in a given volume. 0 is bad, 100 is good.
        # Corresponds to the JSON property `TextConfidence`
        # @return [Fixnum]
        attr_accessor :text_confidence
      
        # 
        # Corresponds to the JSON property `Width`
        # @return [Fixnum]
        attr_accessor :width
      
        # 
        # Corresponds to the JSON property `alignment`
        # @return [Fixnum]
        attr_accessor :alignment
      
        # Information about the paragraph's dropped capital letter
        # Corresponds to the JSON property `droppedcap`
        # @return [Google::Apis::ContentwarehouseV1::GoodocParagraphDroppedCap]
        attr_accessor :droppedcap
      
        # 
        # Corresponds to the JSON property `route`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocParagraphRoute>]
        attr_accessor :route
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @first_line_indent = args[:first_line_indent] if args.key?(:first_line_indent)
          @label = args[:label] if args.key?(:label)
          @left_indent = args[:left_indent] if args.key?(:left_indent)
          @line_spacing = args[:line_spacing] if args.key?(:line_spacing)
          @orientation_label = args[:orientation_label] if args.key?(:orientation_label)
          @right_indent = args[:right_indent] if args.key?(:right_indent)
          @rotated_box = args[:rotated_box] if args.key?(:rotated_box)
          @space_after = args[:space_after] if args.key?(:space_after)
          @space_before = args[:space_before] if args.key?(:space_before)
          @subsumed_paragraph_properties = args[:subsumed_paragraph_properties] if args.key?(:subsumed_paragraph_properties)
          @text_confidence = args[:text_confidence] if args.key?(:text_confidence)
          @width = args[:width] if args.key?(:width)
          @alignment = args[:alignment] if args.key?(:alignment)
          @droppedcap = args[:droppedcap] if args.key?(:droppedcap)
          @route = args[:route] if args.key?(:route)
        end
      end
      
      # Information about the paragraph's dropped capital letter
      class GoodocParagraphDroppedCap
        include Google::Apis::Core::Hashable
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `Box`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :box
      
        # 
        # Corresponds to the JSON property `LettersCount`
        # @return [Fixnum]
        attr_accessor :letters_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @letters_count = args[:letters_count] if args.key?(:letters_count)
        end
      end
      
      # 
      class GoodocParagraphRoute
        include Google::Apis::Core::Hashable
      
        # Route end point
        # Corresponds to the JSON property `EndPoint`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRoutePoint]
        attr_accessor :end_point
      
        # Route start point
        # Corresponds to the JSON property `StartPoint`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRoutePoint]
        attr_accessor :start_point
      
        # Route weight, i.e. route
        # Corresponds to the JSON property `Weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        # The array of words on this route
        # Corresponds to the JSON property `Word`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocWord>]
        attr_accessor :word
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_point = args[:end_point] if args.key?(:end_point)
          @start_point = args[:start_point] if args.key?(:start_point)
          @weight = args[:weight] if args.key?(:weight)
          @word = args[:word] if args.key?(:word)
        end
      end
      
      # Similar to goodoc.BoundingBox, but containing an angle of rotation, thus able
      # to represent non-axis-aligned boxes. RotatedBoundingBox can be used in
      # combination with BoundingBox to better represent non-axis-aligned page
      # structural elements. In such case, two bounding boxes can be used per element.
      # A RotatedBoundingBox that is rotated to tightly encompass the element;
      # embedded (as tightly as possible) inside an axis-aligned BoundingBox. Note
      # that there is some amount of ambiguity regarding what angle and vertex to use.
      # Consider a square with axis-aligned diagonals: B / \ A C \ / D This can either
      # be represented as a -45 degree rotation around A, a 45 degree rotation around
      # B, a 135 degree rotation around C, or a -135 degree rotation around D. Which
      # one you use depends on your use case, but one recommendation is to use the
      # vertex that would be top left if the reader was reading it in the 'natural'
      # orientation.
      class GoodocRotatedBoundingBox
        include Google::Apis::Core::Hashable
      
        # Angle of rotation of the original non-rotated box around the top left corner
        # of the original non-rotated box, in clockwise degrees from the horizontal.
        # Corresponds to the JSON property `Angle`
        # @return [Float]
        attr_accessor :angle
      
        # 
        # Corresponds to the JSON property `Height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Coordinates and sizes are expressed in pixels, where the top-left pixel is (0,
        # 0). The coordinates refer to the corner of the top-left vertex of the
        # unrotated version of the box.
        # Corresponds to the JSON property `Left`
        # @return [Fixnum]
        attr_accessor :left
      
        # 
        # Corresponds to the JSON property `Top`
        # @return [Fixnum]
        attr_accessor :top
      
        # 
        # Corresponds to the JSON property `Width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @angle = args[:angle] if args.key?(:angle)
          @height = args[:height] if args.key?(:height)
          @left = args[:left] if args.key?(:left)
          @top = args[:top] if args.key?(:top)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class GoodocRoutePoint
        include Google::Apis::Core::Hashable
      
        # The sequential route number, starts at 0
        # Corresponds to the JSON property `RouteIndex`
        # @return [Fixnum]
        attr_accessor :route_index
      
        # The sequential word number, starts at 0
        # Corresponds to the JSON property `WordIndex`
        # @return [Fixnum]
        attr_accessor :word_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @route_index = args[:route_index] if args.key?(:route_index)
          @word_index = args[:word_index] if args.key?(:word_index)
        end
      end
      
      # Label identifying a logical part of the page content. This applies mostly at
      # Block level or Paragraph level (but can apply to Words or to arbitrary spans
      # if needed).
      class GoodocSemanticLabel
        include Google::Apis::Core::Hashable
      
        # Alternate text for a sequence of the Goodoc, just for the element containing
        # this label, or for a sequence starting from this element to the
        # EndOfSpanningLabel. Typically this is inserted by automatic or manual OCR
        # correction. We use text instead of editing the Goodoc directly since we dont
        # usually have accurate symbol level bboxes for the alternate text. Also the
        # original values from OCR are preserved. It is upto the application to do
        # anything more intelligent like mapping words and finding potential symbol/word
        # bboxes.
        # Corresponds to the JSON property `AlternateText`
        # @return [String]
        attr_accessor :alternate_text
      
        # Page elements can be given Attributes refining meaning/role. We keep this
        # flexible by using strings instead of pre-determined enum values. But it is
        # useful to list all such Attributes in use in ocr/goodoc/goodoc-semantics-
        # attributes.h
        # Corresponds to the JSON property `Attribute`
        # @return [Array<String>]
        attr_accessor :attribute
      
        # Blocks that are at the beginning of chapters have this set:
        # Corresponds to the JSON property `ChapterStart`
        # @return [Boolean]
        attr_accessor :chapter_start
        alias_method :chapter_start?, :chapter_start
      
        # 
        # Corresponds to the JSON property `CleanupAnnotation`
        # @return [Array<Fixnum>]
        attr_accessor :cleanup_annotation
      
        # 
        # Corresponds to the JSON property `ContinuesFromPreviousPage`
        # @return [Boolean]
        attr_accessor :continues_from_previous_page
        alias_method :continues_from_previous_page?, :continues_from_previous_page
      
        # When ContinuesFromPreviousPage=true, this bit can be set to note that the word
        # fragment on the previous page ends in a hyphen.
        # Corresponds to the JSON property `ContinuesFromPreviousPageHyphenated`
        # @return [Boolean]
        attr_accessor :continues_from_previous_page_hyphenated
        alias_method :continues_from_previous_page_hyphenated?, :continues_from_previous_page_hyphenated
      
        # Paragraphs that span across pages can be identified with the following flags.
        # Note that flows just connect Blocks across pages. These continuation flags
        # imply something more specific -- the case of a single logical paragraph split
        # over pages. Only the last Paragraph in the last Block within a given
        # FlowThread() on a page can have ContinuesOnNextPage set. Similarly, only the
        # first Paragraph in the first Block with a given FlowThread() on a page may
        # have ContinuesFromPreviousPage set.
        # Corresponds to the JSON property `ContinuesOnNextPage`
        # @return [Boolean]
        attr_accessor :continues_on_next_page
        alias_method :continues_on_next_page?, :continues_on_next_page
      
        # A logical entity in the abstract is just a group of links to the goodoc.
        # Depending on the kind of item, a separate proto file should extend this to
        # define the logical structure for that kind. For example. newspapers.proto
        # defines the logical entity for newspapers. LogicalEntity is also used within
        # some SemanticLabels, for example, for a table-of-contents link.
        # Corresponds to the JSON property `EndOfSpanningLabel`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLogicalEntity]
        attr_accessor :end_of_spanning_label
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `ExperimentalData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :experimental_data
      
        # Flow identifies a single sequential unit of text (or other content). It is
        # only set on Blocks -- a flow identifies a sequence of Blocks. The default,
        # main flow is just the empty string. The "FlowThread" of a block is the flow (
        # if non-empty), suffixed with the block appearance. This is computed by
        # GoodocUtils::FlowThread(). Paragraphs may be split over blocks in the same
        # FlowThread, across pages. The following table shows how FlowThread gets
        # computed: ## Flow Appearance FlowThread (empty) UNSPECIFIED "UNSPECIFIED" foo
        # BODY "foo:BODY" Please use lower-case strings for flows (such as article-33-
        # box). One useful way to think of flows is this: A logical unit of interest in
        # a a Document (for example, an article) would be identified by a starting block,
        # an ending block, and a list of flows of interest within the [start, end) span.
        # message Article ` (page#, block#): article_start; (page#, block#):
        # article_end; repeated string flows; ` The reading order of blocks, paragraphs/
        # etc within this article would be the same order as present in the goodoc
        # itself. Some applications (such as rendering) may want to process the article
        # by running over all the flows together, others (such as indexing) may want to
        # deal with the FlowThreads one after the other.
        # Corresponds to the JSON property `Flow`
        # @return [String]
        attr_accessor :flow
      
        # This field can be used to record the steps by which AlternateText for a
        # sequence of the Goodoc is generated.
        # Corresponds to the JSON property `ModificationRecord`
        # @return [String]
        attr_accessor :modification_record
      
        # An Ordinal message represents a single ordinal component of a page number. It
        # encodes the printed or inferred numbering style (Roman, ASCII, etc.) and the
        # ordinal value of the component. An optional set of variable is defined in
        # order to express a sectioned ordinal. A sectioned ordinal may appear in
        # certain page numbering styles, for example "12-1" where "12" identifies a
        # chapter and "1" identifies the page within it. This case will be encoded with
        # value 1 and section_value 12 both of type ASCII.
        # Corresponds to the JSON property `PageNumberOrdinal`
        # @return [Google::Apis::ContentwarehouseV1::GoodocOrdinal]
        attr_accessor :page_number_ordinal
      
        # 
        # Corresponds to the JSON property `appearance`
        # @return [Fixnum]
        attr_accessor :appearance
      
        # If Appearance is COLUMN:
        # Corresponds to the JSON property `columndetails`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelColumnDetails]
        attr_accessor :columndetails
      
        # If the label is for something that links to another piece of content (in this
        # volume, outside, a url, a citation, etc.).
        # Corresponds to the JSON property `contentlink`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelContentLink]
        attr_accessor :contentlink
      
        # 
        # Corresponds to the JSON property `editcorrectioncandidate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocSemanticLabelEditCorrectionCandidate>]
        attr_accessor :editcorrectioncandidate
      
        # This message specifies structure "overrides" to apply: it can be used to force
        # certain kinds of GoodocToHTML renderings of elements.
        # Corresponds to the JSON property `overrides`
        # @return [Google::Apis::ContentwarehouseV1::GoodocOverrides]
        attr_accessor :overrides
      
        # 
        # Corresponds to the JSON property `snippetfilter`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocSemanticLabelSnippetFilter>]
        attr_accessor :snippetfilter
      
        # If Appearance is TABLE_CELL:
        # Corresponds to the JSON property `tablecelldetails`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelTableCellDetails]
        attr_accessor :tablecelldetails
      
        # If Appearance is TABLE:
        # Corresponds to the JSON property `tabledetails`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelTableDetails]
        attr_accessor :tabledetails
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternate_text = args[:alternate_text] if args.key?(:alternate_text)
          @attribute = args[:attribute] if args.key?(:attribute)
          @chapter_start = args[:chapter_start] if args.key?(:chapter_start)
          @cleanup_annotation = args[:cleanup_annotation] if args.key?(:cleanup_annotation)
          @continues_from_previous_page = args[:continues_from_previous_page] if args.key?(:continues_from_previous_page)
          @continues_from_previous_page_hyphenated = args[:continues_from_previous_page_hyphenated] if args.key?(:continues_from_previous_page_hyphenated)
          @continues_on_next_page = args[:continues_on_next_page] if args.key?(:continues_on_next_page)
          @end_of_spanning_label = args[:end_of_spanning_label] if args.key?(:end_of_spanning_label)
          @experimental_data = args[:experimental_data] if args.key?(:experimental_data)
          @flow = args[:flow] if args.key?(:flow)
          @modification_record = args[:modification_record] if args.key?(:modification_record)
          @page_number_ordinal = args[:page_number_ordinal] if args.key?(:page_number_ordinal)
          @appearance = args[:appearance] if args.key?(:appearance)
          @columndetails = args[:columndetails] if args.key?(:columndetails)
          @contentlink = args[:contentlink] if args.key?(:contentlink)
          @editcorrectioncandidate = args[:editcorrectioncandidate] if args.key?(:editcorrectioncandidate)
          @overrides = args[:overrides] if args.key?(:overrides)
          @snippetfilter = args[:snippetfilter] if args.key?(:snippetfilter)
          @tablecelldetails = args[:tablecelldetails] if args.key?(:tablecelldetails)
          @tabledetails = args[:tabledetails] if args.key?(:tabledetails)
        end
      end
      
      # If Appearance is COLUMN:
      class GoodocSemanticLabelColumnDetails
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Column`
        # @return [Fixnum]
        attr_accessor :column
      
        # 
        # Corresponds to the JSON property `Columns`
        # @return [Fixnum]
        attr_accessor :columns
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @column = args[:column] if args.key?(:column)
          @columns = args[:columns] if args.key?(:columns)
        end
      end
      
      # If the label is for something that links to another piece of content (in this
      # volume, outside, a url, a citation, etc.).
      class GoodocSemanticLabelContentLink
        include Google::Apis::Core::Hashable
      
        # For URL labels, we note the url here directly (it's also available by grabbing
        # all text symbols within the labeled span). SCHOLARLY_CITATION labels or even
        # CAPTION labels may occasionally contain URLs.
        # Corresponds to the JSON property `UrlTarget`
        # @return [String]
        attr_accessor :url_target
      
        # For SCHOLARLY_CITATION labels:
        # Corresponds to the JSON property `citationtarget`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelContentLinkCitationTarget]
        attr_accessor :citationtarget
      
        # For CAPTION or FOOTNOTE_POINTER or TOC_ENTRY or INDEX_ENTRY or CONTINUATION
        # labels:
        # Corresponds to the JSON property `involumetarget`
        # @return [Google::Apis::ContentwarehouseV1::GoodocSemanticLabelContentLinkInVolumeTarget]
        attr_accessor :involumetarget
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url_target = args[:url_target] if args.key?(:url_target)
          @citationtarget = args[:citationtarget] if args.key?(:citationtarget)
          @involumetarget = args[:involumetarget] if args.key?(:involumetarget)
        end
      end
      
      # For SCHOLARLY_CITATION labels:
      class GoodocSemanticLabelContentLinkCitationTarget
        include Google::Apis::Core::Hashable
      
        # separated by semicolons
        # Corresponds to the JSON property `Authors`
        # @return [String]
        attr_accessor :authors
      
        # 
        # Corresponds to the JSON property `BibKey`
        # @return [String]
        attr_accessor :bib_key
      
        # 
        # Corresponds to the JSON property `Confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `Title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `Year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @authors = args[:authors] if args.key?(:authors)
          @bib_key = args[:bib_key] if args.key?(:bib_key)
          @confidence = args[:confidence] if args.key?(:confidence)
          @title = args[:title] if args.key?(:title)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # For CAPTION or FOOTNOTE_POINTER or TOC_ENTRY or INDEX_ENTRY or CONTINUATION
      # labels:
      class GoodocSemanticLabelContentLinkInVolumeTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # A logical entity in the abstract is just a group of links to the goodoc.
        # Depending on the kind of item, a separate proto file should extend this to
        # define the logical structure for that kind. For example. newspapers.proto
        # defines the logical entity for newspapers. LogicalEntity is also used within
        # some SemanticLabels, for example, for a table-of-contents link.
        # Corresponds to the JSON property `LogicalEntity`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLogicalEntity]
        attr_accessor :logical_entity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @logical_entity = args[:logical_entity] if args.key?(:logical_entity)
        end
      end
      
      # If there is more than one edit correction candidate, store all the candidates
      # here. This helps a manual correction utility fire the right kind of question
      # with the relevant options.
      class GoodocSemanticLabelEditCorrectionCandidate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `EditedWord`
        # @return [String]
        attr_accessor :edited_word
      
        # 
        # Corresponds to the JSON property `Probability`
        # @return [Float]
        attr_accessor :probability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @edited_word = args[:edited_word] if args.key?(:edited_word)
          @probability = args[:probability] if args.key?(:probability)
        end
      end
      
      # Recording the output of the snippet filter. We run through a series of snippet
      # filters and store all the conditions that this article passed. A condition is
      # denoted by the "badword_fraction_allowed" in a running window of size - "
      # window_size". If ARTICLE_SNIPPET_NOT_CLEAN annotation is set, this group has 0
      # items. It can be a part of article logicalentity, but keeping it here for
      # consistency and coherence as SemanticLabel holds all other article metadata.
      class GoodocSemanticLabelSnippetFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `badwordFraction`
        # @return [Float]
        attr_accessor :badword_fraction
      
        # 
        # Corresponds to the JSON property `windowSize`
        # @return [Fixnum]
        attr_accessor :window_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @badword_fraction = args[:badword_fraction] if args.key?(:badword_fraction)
          @window_size = args[:window_size] if args.key?(:window_size)
        end
      end
      
      # If Appearance is TABLE_CELL:
      class GoodocSemanticLabelTableCellDetails
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Column`
        # @return [Fixnum]
        attr_accessor :column
      
        # 
        # Corresponds to the JSON property `ColumnSpan`
        # @return [Fixnum]
        attr_accessor :column_span
      
        # Row and Column are 0-based
        # Corresponds to the JSON property `Row`
        # @return [Fixnum]
        attr_accessor :row
      
        # 
        # Corresponds to the JSON property `RowSpan`
        # @return [Fixnum]
        attr_accessor :row_span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @column = args[:column] if args.key?(:column)
          @column_span = args[:column_span] if args.key?(:column_span)
          @row = args[:row] if args.key?(:row)
          @row_span = args[:row_span] if args.key?(:row_span)
        end
      end
      
      # If Appearance is TABLE:
      class GoodocSemanticLabelTableDetails
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Columns`
        # @return [Fixnum]
        attr_accessor :columns
      
        # 
        # Corresponds to the JSON property `Rows`
        # @return [Fixnum]
        attr_accessor :rows
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @columns = args[:columns] if args.key?(:columns)
          @rows = args[:rows] if args.key?(:rows)
        end
      end
      
      # Goodoc stats for a range of elements, such as one page or a whole book. These
      # stats can be computed using the SummaryStatsCollector class. Some range stats
      # are pre-computed and stored in goodocs/volumes (eg., Page.stats below, and
      # Ocean's CA_VolumeResult.goodoc_stats).
      class GoodocSummaryStats
        include Google::Apis::Core::Hashable
      
        # This flag is set if the histogram above has been derived by estimating font
        # sizes from CharLabel.CharacterHeight; that happens if the FontSize field is
        # constant, as has happened with Abbyy 9.
        # Corresponds to the JSON property `estimatedFontSizes`
        # @return [Boolean]
        attr_accessor :estimated_font_sizes
        alias_method :estimated_font_sizes?, :estimated_font_sizes
      
        # Symbol counts (and other attributes) for each distinct CharLabel.FontId and
        # FontSize; histogram is in decreasing order of symbol count
        # Corresponds to the JSON property `fontSizeHistogram`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocFontSizeStats>]
        attr_accessor :font_size_histogram
      
        # 
        # Corresponds to the JSON property `meanSymbolsPerBlock`
        # @return [Fixnum]
        attr_accessor :mean_symbols_per_block
      
        # 
        # Corresponds to the JSON property `meanSymbolsPerLine`
        # @return [Fixnum]
        attr_accessor :mean_symbols_per_line
      
        # 
        # Corresponds to the JSON property `meanSymbolsPerParagraph`
        # @return [Fixnum]
        attr_accessor :mean_symbols_per_paragraph
      
        # 
        # Corresponds to the JSON property `meanSymbolsPerWord`
        # @return [Fixnum]
        attr_accessor :mean_symbols_per_word
      
        # 
        # Corresponds to the JSON property `meanWordsPerBlock`
        # @return [Fixnum]
        attr_accessor :mean_words_per_block
      
        # 
        # Corresponds to the JSON property `meanWordsPerLine`
        # @return [Fixnum]
        attr_accessor :mean_words_per_line
      
        # 
        # Corresponds to the JSON property `meanWordsPerParagraph`
        # @return [Fixnum]
        attr_accessor :mean_words_per_paragraph
      
        # bottom to next top in flow on page
        # Corresponds to the JSON property `medianBlockSpace`
        # @return [Fixnum]
        attr_accessor :median_block_space
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianEvenPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_even_printed_box
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianFullEvenPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_full_even_printed_box
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianFullOddPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_full_odd_printed_box
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianFullPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_full_printed_box
      
        # 
        # Corresponds to the JSON property `medianHeight`
        # @return [Fixnum]
        attr_accessor :median_height
      
        # 
        # Corresponds to the JSON property `medianHorizontalDpi`
        # @return [Fixnum]
        attr_accessor :median_horizontal_dpi
      
        # top to bottom
        # Corresponds to the JSON property `medianLineHeight`
        # @return [Fixnum]
        attr_accessor :median_line_height
      
        # bottom to next top in para
        # Corresponds to the JSON property `medianLineSpace`
        # @return [Fixnum]
        attr_accessor :median_line_space
      
        # top to next top in para
        # Corresponds to the JSON property `medianLineSpan`
        # @return [Fixnum]
        attr_accessor :median_line_span
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianOddPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_odd_printed_box
      
        # leading space on first line
        # Corresponds to the JSON property `medianParagraphIndent`
        # @return [Fixnum]
        attr_accessor :median_paragraph_indent
      
        # bottom to next top in block
        # Corresponds to the JSON property `medianParagraphSpace`
        # @return [Fixnum]
        attr_accessor :median_paragraph_space
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `medianPrintedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :median_printed_box
      
        # 
        # Corresponds to the JSON property `medianSymbolsPerBlock`
        # @return [Fixnum]
        attr_accessor :median_symbols_per_block
      
        # 
        # Corresponds to the JSON property `medianSymbolsPerLine`
        # @return [Fixnum]
        attr_accessor :median_symbols_per_line
      
        # 
        # Corresponds to the JSON property `medianSymbolsPerParagraph`
        # @return [Fixnum]
        attr_accessor :median_symbols_per_paragraph
      
        # 
        # Corresponds to the JSON property `medianSymbolsPerWord`
        # @return [Fixnum]
        attr_accessor :median_symbols_per_word
      
        # 
        # Corresponds to the JSON property `medianVerticalDpi`
        # @return [Fixnum]
        attr_accessor :median_vertical_dpi
      
        # 
        # Corresponds to the JSON property `medianWidth`
        # @return [Fixnum]
        attr_accessor :median_width
      
        # 
        # Corresponds to the JSON property `medianWordsPerBlock`
        # @return [Fixnum]
        attr_accessor :median_words_per_block
      
        # 
        # Corresponds to the JSON property `medianWordsPerLine`
        # @return [Fixnum]
        attr_accessor :median_words_per_line
      
        # 
        # Corresponds to the JSON property `medianWordsPerParagraph`
        # @return [Fixnum]
        attr_accessor :median_words_per_paragraph
      
        # blocks that have a successor block within their flow on their page
        # Corresponds to the JSON property `numBlockSpaces`
        # @return [Fixnum]
        attr_accessor :num_block_spaces
      
        # ------ Block stats Median symbols and words omit junk, header and footer
        # blocks; they are intended to be a measure of the typical "content" block.
        # There can still be substantial differences between means and medians; however,
        # block values will generally exceed paragraph values (not the case when headers
        # and footers are included).
        # Corresponds to the JSON property `numBlocks`
        # @return [Fixnum]
        attr_accessor :num_blocks
      
        # Lines (out of num_lines) that have a successor line within their para
        # Corresponds to the JSON property `numLineSpaces`
        # @return [Fixnum]
        attr_accessor :num_line_spaces
      
        # ------ Line stats "top" corresponds to the highest ascender and "bottom" to
        # the lowest descender.
        # Corresponds to the JSON property `numLines`
        # @return [Fixnum]
        attr_accessor :num_lines
      
        # 
        # Corresponds to the JSON property `numNonGraphicBlocks`
        # @return [Fixnum]
        attr_accessor :num_non_graphic_blocks
      
        # ------ Page stats.
        # Corresponds to the JSON property `numPages`
        # @return [Fixnum]
        attr_accessor :num_pages
      
        # paras that have a successor para within their block
        # Corresponds to the JSON property `numParagraphSpaces`
        # @return [Fixnum]
        attr_accessor :num_paragraph_spaces
      
        # ------ Paragraph stats Median symbols and words omit junk, header and footer
        # blocks; they are intended to be a measure of the typical "content" paragraph.
        # There can still be substantial differences between means and medians,
        # particularly if a table is present (every cell is a paragraph).
        # Corresponds to the JSON property `numParagraphs`
        # @return [Fixnum]
        attr_accessor :num_paragraphs
      
        # ------ Symbol stats
        # Corresponds to the JSON property `numSymbols`
        # @return [Fixnum]
        attr_accessor :num_symbols
      
        # ------ Word stats
        # Corresponds to the JSON property `numWords`
        # @return [Fixnum]
        attr_accessor :num_words
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @estimated_font_sizes = args[:estimated_font_sizes] if args.key?(:estimated_font_sizes)
          @font_size_histogram = args[:font_size_histogram] if args.key?(:font_size_histogram)
          @mean_symbols_per_block = args[:mean_symbols_per_block] if args.key?(:mean_symbols_per_block)
          @mean_symbols_per_line = args[:mean_symbols_per_line] if args.key?(:mean_symbols_per_line)
          @mean_symbols_per_paragraph = args[:mean_symbols_per_paragraph] if args.key?(:mean_symbols_per_paragraph)
          @mean_symbols_per_word = args[:mean_symbols_per_word] if args.key?(:mean_symbols_per_word)
          @mean_words_per_block = args[:mean_words_per_block] if args.key?(:mean_words_per_block)
          @mean_words_per_line = args[:mean_words_per_line] if args.key?(:mean_words_per_line)
          @mean_words_per_paragraph = args[:mean_words_per_paragraph] if args.key?(:mean_words_per_paragraph)
          @median_block_space = args[:median_block_space] if args.key?(:median_block_space)
          @median_even_printed_box = args[:median_even_printed_box] if args.key?(:median_even_printed_box)
          @median_full_even_printed_box = args[:median_full_even_printed_box] if args.key?(:median_full_even_printed_box)
          @median_full_odd_printed_box = args[:median_full_odd_printed_box] if args.key?(:median_full_odd_printed_box)
          @median_full_printed_box = args[:median_full_printed_box] if args.key?(:median_full_printed_box)
          @median_height = args[:median_height] if args.key?(:median_height)
          @median_horizontal_dpi = args[:median_horizontal_dpi] if args.key?(:median_horizontal_dpi)
          @median_line_height = args[:median_line_height] if args.key?(:median_line_height)
          @median_line_space = args[:median_line_space] if args.key?(:median_line_space)
          @median_line_span = args[:median_line_span] if args.key?(:median_line_span)
          @median_odd_printed_box = args[:median_odd_printed_box] if args.key?(:median_odd_printed_box)
          @median_paragraph_indent = args[:median_paragraph_indent] if args.key?(:median_paragraph_indent)
          @median_paragraph_space = args[:median_paragraph_space] if args.key?(:median_paragraph_space)
          @median_printed_box = args[:median_printed_box] if args.key?(:median_printed_box)
          @median_symbols_per_block = args[:median_symbols_per_block] if args.key?(:median_symbols_per_block)
          @median_symbols_per_line = args[:median_symbols_per_line] if args.key?(:median_symbols_per_line)
          @median_symbols_per_paragraph = args[:median_symbols_per_paragraph] if args.key?(:median_symbols_per_paragraph)
          @median_symbols_per_word = args[:median_symbols_per_word] if args.key?(:median_symbols_per_word)
          @median_vertical_dpi = args[:median_vertical_dpi] if args.key?(:median_vertical_dpi)
          @median_width = args[:median_width] if args.key?(:median_width)
          @median_words_per_block = args[:median_words_per_block] if args.key?(:median_words_per_block)
          @median_words_per_line = args[:median_words_per_line] if args.key?(:median_words_per_line)
          @median_words_per_paragraph = args[:median_words_per_paragraph] if args.key?(:median_words_per_paragraph)
          @num_block_spaces = args[:num_block_spaces] if args.key?(:num_block_spaces)
          @num_blocks = args[:num_blocks] if args.key?(:num_blocks)
          @num_line_spaces = args[:num_line_spaces] if args.key?(:num_line_spaces)
          @num_lines = args[:num_lines] if args.key?(:num_lines)
          @num_non_graphic_blocks = args[:num_non_graphic_blocks] if args.key?(:num_non_graphic_blocks)
          @num_pages = args[:num_pages] if args.key?(:num_pages)
          @num_paragraph_spaces = args[:num_paragraph_spaces] if args.key?(:num_paragraph_spaces)
          @num_paragraphs = args[:num_paragraphs] if args.key?(:num_paragraphs)
          @num_symbols = args[:num_symbols] if args.key?(:num_symbols)
          @num_words = args[:num_words] if args.key?(:num_words)
        end
      end
      
      # A single symbol representation
      class GoodocSymbol
        include Google::Apis::Core::Hashable
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `Box`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :box
      
        # The unicode character code in UTF-32
        # Corresponds to the JSON property `Code`
        # @return [Fixnum]
        attr_accessor :code
      
        # Label aggregates all kinds of optional characteristics of page elements.
        # Corresponds to the JSON property `Label`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLabel]
        attr_accessor :label
      
        # Similar to goodoc.BoundingBox, but containing an angle of rotation, thus able
        # to represent non-axis-aligned boxes. RotatedBoundingBox can be used in
        # combination with BoundingBox to better represent non-axis-aligned page
        # structural elements. In such case, two bounding boxes can be used per element.
        # A RotatedBoundingBox that is rotated to tightly encompass the element;
        # embedded (as tightly as possible) inside an axis-aligned BoundingBox. Note
        # that there is some amount of ambiguity regarding what angle and vertex to use.
        # Consider a square with axis-aligned diagonals: B / \ A C \ / D This can either
        # be represented as a -45 degree rotation around A, a 45 degree rotation around
        # B, a 135 degree rotation around C, or a -135 degree rotation around D. Which
        # one you use depends on your use case, but one recommendation is to use the
        # vertex that would be top left if the reader was reading it in the 'natural'
        # orientation.
        # Corresponds to the JSON property `RotatedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRotatedBoundingBox]
        attr_accessor :rotated_box
      
        # 
        # Corresponds to the JSON property `symbolvariant`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocSymbolSymbolVariant>]
        attr_accessor :symbolvariant
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @code = args[:code] if args.key?(:code)
          @label = args[:label] if args.key?(:label)
          @rotated_box = args[:rotated_box] if args.key?(:rotated_box)
          @symbolvariant = args[:symbolvariant] if args.key?(:symbolvariant)
        end
      end
      
      # 
      class GoodocSymbolSymbolVariant
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Code`
        # @return [Fixnum]
        attr_accessor :code
      
        # 
        # Corresponds to the JSON property `Confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @confidence = args[:confidence] if args.key?(:confidence)
        end
      end
      
      # A word representation
      class GoodocWord
        include Google::Apis::Core::Hashable
      
        # The baseline's y-axis offset from the bottom of the word's bounding box, given
        # in pixels. (A value of 2, for instance, indicates the baseline is 2px above
        # the bottom of the box.)
        # Corresponds to the JSON property `Baseline`
        # @return [Fixnum]
        attr_accessor :baseline
      
        # Bounding box for page structural elements: pictures, paragraphs, characters,
        # etc.
        # Corresponds to the JSON property `Box`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoundingBox]
        attr_accessor :box
      
        # The capline is the y-axis offset from the top of the word bounding box. A
        # positive value n indicates that capline is n-pixels above the top of this word.
        # Corresponds to the JSON property `Capline`
        # @return [Fixnum]
        attr_accessor :capline
      
        # A way to specify a simple partitioning of a BoundingBox into a sequence of sub-
        # boxes. +----------------------------------------------------+ | | | | | | |
        # span(0) | (1) | (2) | (3) | (4) | | | | | | | +--------------------------------
        # --------------------+ This representation can, for example, be used to store
        # coarse Symbol boundaries within a Word (see Word.CompactSymbolBoxes below)
        # instead of per-Symbol BoundingBoxes, for saving space.
        # Corresponds to the JSON property `CompactSymbolBoxes`
        # @return [Google::Apis::ContentwarehouseV1::GoodocBoxPartitions]
        attr_accessor :compact_symbol_boxes
      
        # Word recognition confidence. Range depends upon OCR Engine.
        # Corresponds to the JSON property `Confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # word. The meaning and range depends on the OCR engine or subsequent processing.
        # Specifies whether the word was found
        # Corresponds to the JSON property `IsFromDictionary`
        # @return [Boolean]
        attr_accessor :is_from_dictionary
        alias_method :is_from_dictionary?, :is_from_dictionary
      
        # a number True if word represents
        # Corresponds to the JSON property `IsIdentifier`
        # @return [Boolean]
        attr_accessor :is_identifier
        alias_method :is_identifier?, :is_identifier
      
        # True if the word is the last word in any sub-paragraph unit that functions at
        # the same level of granularity as a sentence. Examples: "She hit the ball." (
        # regular sentence) "Dewey defeats Truman" (heading) "The more, the merrier." (
        # no verb) Note: not currently used. Code to set this was introduced in CL
        # 7038338 and removed in OCL=10678722.
        # Corresponds to the JSON property `IsLastInSentence`
        # @return [Boolean]
        attr_accessor :is_last_in_sentence
        alias_method :is_last_in_sentence?, :is_last_in_sentence
      
        # in the dictionary True if the word represents
        # Corresponds to the JSON property `IsNumeric`
        # @return [Boolean]
        attr_accessor :is_numeric
        alias_method :is_numeric?, :is_numeric
      
        # Label aggregates all kinds of optional characteristics of page elements.
        # Corresponds to the JSON property `Label`
        # @return [Google::Apis::ContentwarehouseV1::GoodocLabel]
        attr_accessor :label
      
        # Penalty for discordance of characters in a
        # Corresponds to the JSON property `Penalty`
        # @return [Fixnum]
        attr_accessor :penalty
      
        # Similar to goodoc.BoundingBox, but containing an angle of rotation, thus able
        # to represent non-axis-aligned boxes. RotatedBoundingBox can be used in
        # combination with BoundingBox to better represent non-axis-aligned page
        # structural elements. In such case, two bounding boxes can be used per element.
        # A RotatedBoundingBox that is rotated to tightly encompass the element;
        # embedded (as tightly as possible) inside an axis-aligned BoundingBox. Note
        # that there is some amount of ambiguity regarding what angle and vertex to use.
        # Consider a square with axis-aligned diagonals: B / \ A C \ / D This can either
        # be represented as a -45 degree rotation around A, a 45 degree rotation around
        # B, a 135 degree rotation around C, or a -135 degree rotation around D. Which
        # one you use depends on your use case, but one recommendation is to use the
        # vertex that would be top left if the reader was reading it in the 'natural'
        # orientation.
        # Corresponds to the JSON property `RotatedBox`
        # @return [Google::Apis::ContentwarehouseV1::GoodocRotatedBoundingBox]
        attr_accessor :rotated_box
      
        # Word characters, the text may
        # Corresponds to the JSON property `Symbol`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocSymbol>]
        attr_accessor :symbol
      
        # Alternate OCR words for Ptolemy OCR Correction. This is the output of the
        # Ptolemy error estimator. See http://go/Ptolemy.
        # Corresponds to the JSON property `alternates`
        # @return [Google::Apis::ContentwarehouseV1::GoodocWordAlternates]
        attr_accessor :alternates
      
        # As a shortcut, the content API provides the text of words instead of
        # individual symbols (NOTE: this is experimental). This is UTF8. And the main
        # font for the word is stored in Label.CharLabel.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Writing direction for this word.
        # Corresponds to the JSON property `writingDirection`
        # @return [String]
        attr_accessor :writing_direction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @baseline = args[:baseline] if args.key?(:baseline)
          @box = args[:box] if args.key?(:box)
          @capline = args[:capline] if args.key?(:capline)
          @compact_symbol_boxes = args[:compact_symbol_boxes] if args.key?(:compact_symbol_boxes)
          @confidence = args[:confidence] if args.key?(:confidence)
          @is_from_dictionary = args[:is_from_dictionary] if args.key?(:is_from_dictionary)
          @is_identifier = args[:is_identifier] if args.key?(:is_identifier)
          @is_last_in_sentence = args[:is_last_in_sentence] if args.key?(:is_last_in_sentence)
          @is_numeric = args[:is_numeric] if args.key?(:is_numeric)
          @label = args[:label] if args.key?(:label)
          @penalty = args[:penalty] if args.key?(:penalty)
          @rotated_box = args[:rotated_box] if args.key?(:rotated_box)
          @symbol = args[:symbol] if args.key?(:symbol)
          @alternates = args[:alternates] if args.key?(:alternates)
          @text = args[:text] if args.key?(:text)
          @writing_direction = args[:writing_direction] if args.key?(:writing_direction)
        end
      end
      
      # Alternate OCR words for Ptolemy OCR Correction. This is the output of the
      # Ptolemy error estimator. See http://go/Ptolemy.
      class GoodocWordAlternates
        include Google::Apis::Core::Hashable
      
        # The probability that the main OCR engine (Abbyy) string is incorrect; range is
        # 0 (definitely correct) to 100 (definitely incorrect).
        # Corresponds to the JSON property `ErrorProbability`
        # @return [Fixnum]
        attr_accessor :error_probability
      
        # 
        # Corresponds to the JSON property `alternate`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocWordAlternatesAlternate>]
        attr_accessor :alternate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @error_probability = args[:error_probability] if args.key?(:error_probability)
          @alternate = args[:alternate] if args.key?(:alternate)
        end
      end
      
      # An alternate word provided by another OCR engine, used for OCR Correction.
      # This iteration only supports simple substitution errors (exhanging one word
      # for another), but with minor modifications (e.g. adding a word count for each
      # alternate), it could support repairing word segmentation and text detection
      # errors.
      class GoodocWordAlternatesAlternate
        include Google::Apis::Core::Hashable
      
        # See Document.Header
        # Corresponds to the JSON property `OcrEngineId`
        # @return [String]
        attr_accessor :ocr_engine_id
      
        # See Document.Header
        # Corresponds to the JSON property `OcrEngineVersion`
        # @return [String]
        attr_accessor :ocr_engine_version
      
        # A word representation
        # Corresponds to the JSON property `Word`
        # @return [Google::Apis::ContentwarehouseV1::GoodocWord]
        attr_accessor :word
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ocr_engine_id = args[:ocr_engine_id] if args.key?(:ocr_engine_id)
          @ocr_engine_version = args[:ocr_engine_version] if args.key?(:ocr_engine_version)
          @word = args[:word] if args.key?(:word)
        end
      end
      
      # Specifies the desired format for the server to use when it returns `audio_out`
      # messages.
      class GoogleAssistantAccessoryV1AudioOutConfig
        include Google::Apis::Core::Hashable
      
        # Current audio mode on the device while issuing the query.
        # Corresponds to the JSON property `audioMode`
        # @return [String]
        attr_accessor :audio_mode
      
        # Current audio routing on the device while issuing the query.
        # Corresponds to the JSON property `audioRoutingMode`
        # @return [String]
        attr_accessor :audio_routing_mode
      
        # *Required* The encoding of audio data to be returned in all `audio_out`
        # messages.
        # Corresponds to the JSON property `encoding`
        # @return [String]
        attr_accessor :encoding
      
        # *Optional* Specifies preferred encoding bitrate (bits-per-second). Currently
        # this is only implemented for OGG_OPUS for bitrates of 12000, 16000, 24000,
        # 32000. If not specified, OGG_OPUS defaults to 32000.
        # Corresponds to the JSON property `preferredBitrateBps`
        # @return [Fixnum]
        attr_accessor :preferred_bitrate_bps
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_mode = args[:audio_mode] if args.key?(:audio_mode)
          @audio_routing_mode = args[:audio_routing_mode] if args.key?(:audio_routing_mode)
          @encoding = args[:encoding] if args.key?(:encoding)
          @preferred_bitrate_bps = args[:preferred_bitrate_bps] if args.key?(:preferred_bitrate_bps)
        end
      end
      
      # *Required* Fields that identify the device to the Assistant. See also: * [
      # Register a Device - REST API](https: //developers.google.com/assistant/sdk/re /
      # / ference/device-registration/register-device-manual) * [Device Model and
      # Instance Schemas](https: //developers.google.com/assistant/sdk/re // ference/
      # device-registration/model-and-instance-schemas) * [Device Proto](https: //
      # developers.google.com/assistant/sdk/re // ference/rpc/google.assistant.devices.
      # v1#device)
      class GoogleAssistantAccessoryV1DeviceConfig
        include Google::Apis::Core::Hashable
      
        # Contains fields to identify the device which sent the request.
        # Corresponds to the JSON property `deviceBuild`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1DeviceBuild]
        attr_accessor :device_build
      
        # Device model capabilities override from client.
        # Corresponds to the JSON property `deviceModelCapabilitiesOverride`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1DeviceModelCapabilitiesOverride]
        attr_accessor :device_model_capabilities_override
      
        # *Optional* An encrypted heterodyne_experiment_token containing the list of
        # experiment_ids (go/ph-server-tokens).
        # Corresponds to the JSON property `heterodyneToken`
        # @return [String]
        attr_accessor :heterodyne_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_build = args[:device_build] if args.key?(:device_build)
          @device_model_capabilities_override = args[:device_model_capabilities_override] if args.key?(:device_model_capabilities_override)
          @heterodyne_token = args[:heterodyne_token] if args.key?(:heterodyne_token)
        end
      end
      
      # Information about the state of the device. This contains any state that
      # Assistant may need to know about in order to fulfill requests, for example
      # which timers and alarms are set. Next ID: 9
      class GoogleAssistantAccessoryV1DeviceState
        include Google::Apis::Core::Hashable
      
        # Contains information about on-device alarms for devices that support alarms.
        # Corresponds to the JSON property `alarmState`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1Alarms]
        attr_accessor :alarm_state
      
        # Other context params to be sent to Assistant. This is a assistant.embedded.v1.
        # ContextParams message in serialized binary proto format.
        # Corresponds to the JSON property `contextParams`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :context_params
      
        # A timestamp of the current device time when the request was made. This field
        # is required if your device supports alarms or timers. This ensures that
        # requests are fulfilled relative to the current device time and regardless of
        # any clock skew between the client and the server.
        # Corresponds to the JSON property `deviceTime`
        # @return [String]
        attr_accessor :device_time
      
        # Represents a time zone from the [IANA Time Zone Database](https://www.iana.org/
        # time-zones).
        # Corresponds to the JSON property `deviceTimeZone`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeZone]
        attr_accessor :device_time_zone
      
        # Indicate whether do not disturb mode is turned on.
        # Corresponds to the JSON property `doNotDisturb`
        # @return [Boolean]
        attr_accessor :do_not_disturb
        alias_method :do_not_disturb?, :do_not_disturb
      
        # Contains information about on-device fitness activities for devices that
        # support fitness.
        # Corresponds to the JSON property `fitnessActivitiesState`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1FitnessActivities]
        attr_accessor :fitness_activities_state
      
        # Contains information about on-device timers for devices that support timers.
        # Corresponds to the JSON property `timerState`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1Timers]
        attr_accessor :timer_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alarm_state = args[:alarm_state] if args.key?(:alarm_state)
          @context_params = args[:context_params] if args.key?(:context_params)
          @device_time = args[:device_time] if args.key?(:device_time)
          @device_time_zone = args[:device_time_zone] if args.key?(:device_time_zone)
          @do_not_disturb = args[:do_not_disturb] if args.key?(:do_not_disturb)
          @fitness_activities_state = args[:fitness_activities_state] if args.key?(:fitness_activities_state)
          @timer_state = args[:timer_state] if args.key?(:timer_state)
        end
      end
      
      # Configuration for the response. Next Id: 11
      class GoogleAssistantAccessoryV1ResponseConfig
        include Google::Apis::Core::Hashable
      
        # Specifies the desired format for the server to use when it returns `audio_out`
        # messages.
        # Corresponds to the JSON property `audioOutConfig`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1AudioOutConfig]
        attr_accessor :audio_out_config
      
        # *Required* Fields that identify the device to the Assistant. See also: * [
        # Register a Device - REST API](https: //developers.google.com/assistant/sdk/re /
        # / ference/device-registration/register-device-manual) * [Device Model and
        # Instance Schemas](https: //developers.google.com/assistant/sdk/re // ference/
        # device-registration/model-and-instance-schemas) * [Device Proto](https: //
        # developers.google.com/assistant/sdk/re // ference/rpc/google.assistant.devices.
        # v1#device)
        # Corresponds to the JSON property `deviceConfig`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1DeviceConfig]
        attr_accessor :device_config
      
        # The client interaction to be sent to Assistant. This is a assistant.embedded.
        # v1.DeviceInteraction message in serialized binary proto format.
        # Corresponds to the JSON property `deviceInteraction`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :device_interaction
      
        # Information about the state of the device. This contains any state that
        # Assistant may need to know about in order to fulfill requests, for example
        # which timers and alarms are set. Next ID: 9
        # Corresponds to the JSON property `deviceState`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1DeviceState]
        attr_accessor :device_state
      
        # Specifies the initial bytes of TTS audio to send.
        # Corresponds to the JSON property `initialAudioBytes`
        # @return [Fixnum]
        attr_accessor :initial_audio_bytes
      
        # If true, the server will treat the request as a new conversation and not use
        # state from the prior request. Set this field to true when the conversation
        # should be restarted, such as after a device reboot, or after a significant
        # lapse of time since the prior query.
        # Corresponds to the JSON property `isNewConversation`
        # @return [Boolean]
        attr_accessor :is_new_conversation
        alias_method :is_new_conversation?, :is_new_conversation
      
        # Specifies the desired audio sample rate of the output TTS stream in Hz.
        # Corresponds to the JSON property `outputSampleRateHz`
        # @return [Fixnum]
        attr_accessor :output_sample_rate_hz
      
        # Specifies the requested response type.
        # Corresponds to the JSON property `responseType`
        # @return [String]
        attr_accessor :response_type
      
        # Specifies the desired format for the server to use when it returns `screen_out`
        # response.
        # Corresponds to the JSON property `screenOutConfig`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1ScreenOutConfig]
        attr_accessor :screen_out_config
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_out_config = args[:audio_out_config] if args.key?(:audio_out_config)
          @device_config = args[:device_config] if args.key?(:device_config)
          @device_interaction = args[:device_interaction] if args.key?(:device_interaction)
          @device_state = args[:device_state] if args.key?(:device_state)
          @initial_audio_bytes = args[:initial_audio_bytes] if args.key?(:initial_audio_bytes)
          @is_new_conversation = args[:is_new_conversation] if args.key?(:is_new_conversation)
          @output_sample_rate_hz = args[:output_sample_rate_hz] if args.key?(:output_sample_rate_hz)
          @response_type = args[:response_type] if args.key?(:response_type)
          @screen_out_config = args[:screen_out_config] if args.key?(:screen_out_config)
        end
      end
      
      # Specifies the desired format for the server to use when it returns `screen_out`
      # response.
      class GoogleAssistantAccessoryV1ScreenOutConfig
        include Google::Apis::Core::Hashable
      
        # This contains physical and logical characteristics about the device (e.g.
        # screen size and DPI, etc).
        # Corresponds to the JSON property `dimensions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantAccessoryV1ScreenOutConfigDimensions]
        attr_accessor :dimensions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dimensions = args[:dimensions] if args.key?(:dimensions)
        end
      end
      
      # This contains physical and logical characteristics about the device (e.g.
      # screen size and DPI, etc).
      class GoogleAssistantAccessoryV1ScreenOutConfigDimensions
        include Google::Apis::Core::Hashable
      
        # Dots (pixels) per inch of the screen.
        # Corresponds to the JSON property `screenDpi`
        # @return [Float]
        attr_accessor :screen_dpi
      
        # Height of the device's screen in pixels. If 0 or not specified, it's assumed
        # to be the same as screen_width_px. For a square or round screen, it's
        # recommended to leave this field empty as a bandwidth optimization.
        # Corresponds to the JSON property `screenHeightPx`
        # @return [Fixnum]
        attr_accessor :screen_height_px
      
        # The shape of the device's screen
        # Corresponds to the JSON property `screenShape`
        # @return [String]
        attr_accessor :screen_shape
      
        # Width of the device's screen in pixels.
        # Corresponds to the JSON property `screenWidthPx`
        # @return [Fixnum]
        attr_accessor :screen_width_px
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @screen_dpi = args[:screen_dpi] if args.key?(:screen_dpi)
          @screen_height_px = args[:screen_height_px] if args.key?(:screen_height_px)
          @screen_shape = args[:screen_shape] if args.key?(:screen_shape)
          @screen_width_px = args[:screen_width_px] if args.key?(:screen_width_px)
        end
      end
      
      # Alarms are clocks that ring at a specified time on one or more days. The
      # client schedules a time to ring based on the date/time pattern. When it rings,
      # it may be rescheduled off the original time by snoozing or it may be replaced
      # by the next occurrence.
      class GoogleAssistantEmbeddedV1Alarm
        include Google::Apis::Core::Hashable
      
        # A string key used as an identifier to this alarm. This key needs to be unique
        # amongst all alarms on the device. The client can choose a mechanism of its
        # choice to ensure this. If the server suggests an alarm_id, the client can
        # either use the suggestion or create a new unique alarm_id of its choosing.
        # Corresponds to the JSON property `alarmId`
        # @return [String]
        attr_accessor :alarm_id
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `datePattern`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :date_pattern
      
        # A user-provided name for this alarm.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # A description of the dates when an alarm should recur.
        # Corresponds to the JSON property `recurrencePattern`
        # @return [Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1AlarmRecurrence]
        attr_accessor :recurrence_pattern
      
        # When SCHEDULED or SNOOZED, the absolute time the alarm will fire next. When
        # SNOOZED, this time includes the additional time added by snoozing the alarm.
        # When FIRING, the absolute time the alarm had been scheduled to fire. When
        # DISABLED, this field is undefined and should be ignored.
        # Corresponds to the JSON property `scheduledTime`
        # @return [String]
        attr_accessor :scheduled_time
      
        # Describes the part of the lifecycle that an alarm is in.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # Represents a time of day. The date and time zone are either not significant or
        # are specified elsewhere. An API may choose to allow leap seconds. Related
        # types are google.type.Date and `google.protobuf.Timestamp`.
        # Corresponds to the JSON property `timePattern`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeOfDay]
        attr_accessor :time_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alarm_id = args[:alarm_id] if args.key?(:alarm_id)
          @date_pattern = args[:date_pattern] if args.key?(:date_pattern)
          @label = args[:label] if args.key?(:label)
          @recurrence_pattern = args[:recurrence_pattern] if args.key?(:recurrence_pattern)
          @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time)
          @status = args[:status] if args.key?(:status)
          @time_pattern = args[:time_pattern] if args.key?(:time_pattern)
        end
      end
      
      # A description of the dates when an alarm should recur.
      class GoogleAssistantEmbeddedV1AlarmRecurrence
        include Google::Apis::Core::Hashable
      
        # Specifies a weekly or daily recurrence. Constraint: The date falls on one of
        # these days of the week, in 0...6 (Sunday...Saturday). Should not be empty.
        # Corresponds to the JSON property `dayOfWeek`
        # @return [Array<String>]
        attr_accessor :day_of_week
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
        end
      end
      
      # Contains information about on-device alarms for devices that support alarms.
      class GoogleAssistantEmbeddedV1Alarms
        include Google::Apis::Core::Hashable
      
        # Information about all on-device alarms.
        # Corresponds to the JSON property `alarms`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1Alarm>]
        attr_accessor :alarms
      
        # The amount of time for which alarms should be snoozed. If not specified, the
        # productivity vertical applies a default snooze duration, which may be seen
        # here: http://google3/assistant/verticals/productivity/utils/alarm_utils.cc;l=
        # 2734;rcl=415933085
        # Corresponds to the JSON property `snoozeDuration`
        # @return [String]
        attr_accessor :snooze_duration
      
        # Indicates if an error occurred while fetching alarm state. If this value is
        # missing, it can be assumed that the state fetch was successful.
        # Corresponds to the JSON property `stateFetchError`
        # @return [String]
        attr_accessor :state_fetch_error
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alarms = args[:alarms] if args.key?(:alarms)
          @snooze_duration = args[:snooze_duration] if args.key?(:snooze_duration)
          @state_fetch_error = args[:state_fetch_error] if args.key?(:state_fetch_error)
        end
      end
      
      # Contains fields to identify the device which sent the request.
      class GoogleAssistantEmbeddedV1DeviceBuild
        include Google::Apis::Core::Hashable
      
        # * Fully formed user agent suffix string.
        # Corresponds to the JSON property `userAgentSuffix`
        # @return [String]
        attr_accessor :user_agent_suffix
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @user_agent_suffix = args[:user_agent_suffix] if args.key?(:user_agent_suffix)
        end
      end
      
      # Device model capabilities override from client.
      class GoogleAssistantEmbeddedV1DeviceModelCapabilitiesOverride
        include Google::Apis::Core::Hashable
      
        # Device model capabilities from client.
        # Corresponds to the JSON property `deviceModelCapabilities`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :device_model_capabilities
      
        # If present, overrides only fields specified in the mask. When doing so,
        # selected message and repeated fields will be replaced rather than merged.
        # Performs a regular proto MergeFrom if no mask is specified.
        # Corresponds to the JSON property `updateMask`
        # @return [String]
        attr_accessor :update_mask
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_model_capabilities = args[:device_model_capabilities] if args.key?(:device_model_capabilities)
          @update_mask = args[:update_mask] if args.key?(:update_mask)
        end
      end
      
      # Contains information about on-device fitness activities for devices that
      # support fitness.
      class GoogleAssistantEmbeddedV1FitnessActivities
        include Google::Apis::Core::Hashable
      
        # Information about all on-device activities.
        # Corresponds to the JSON property `fitnessActivities`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1FitnessActivity>]
        attr_accessor :fitness_activities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fitness_activities = args[:fitness_activities] if args.key?(:fitness_activities)
        end
      end
      
      # Describes a particular fitness activity, its current state, and other data
      # fields associated with that activity (e.g. elapsed time). LINT.IfChange
      class GoogleAssistantEmbeddedV1FitnessActivity
        include Google::Apis::Core::Hashable
      
        # Required A string key used as an identifier for this activity. This key needs
        # to be unique amongst all activities on the device. The client can choose a
        # mechanism of its choice to ensure this. If the server suggests an activity_id,
        # the client can either use the suggestion or create a new unique activity_id of
        # its choosing.
        # Corresponds to the JSON property `activityId`
        # @return [String]
        attr_accessor :activity_id
      
        # DEPRECATED: The most recent time this activity was switched to the ACTIVE
        # state.
        # Corresponds to the JSON property `mostRecentStartTime`
        # @return [String]
        attr_accessor :most_recent_start_time
      
        # DEPRECATED: The total amount of time this activity has spent in the ACTIVE
        # state until the most recent start time. The total time spent active may be
        # computed by summing (now - most_recent_start_time) with
        # previously_accumulated_duration.
        # Corresponds to the JSON property `previouslyAccumulatedDuration`
        # @return [String]
        attr_accessor :previously_accumulated_duration
      
        # The current state of this activity.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # The type of activity being done.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @activity_id = args[:activity_id] if args.key?(:activity_id)
          @most_recent_start_time = args[:most_recent_start_time] if args.key?(:most_recent_start_time)
          @previously_accumulated_duration = args[:previously_accumulated_duration] if args.key?(:previously_accumulated_duration)
          @state = args[:state] if args.key?(:state)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Conceptually, timers are clocks that count down from an initial duration and
      # ring when they reach 0. In practice, as a timer is running, it holds a stable
      # expiration time and computes the remaining duration using the current time.
      # When a timer is paused, it holds a stable remaining duration.
      class GoogleAssistantEmbeddedV1Timer
        include Google::Apis::Core::Hashable
      
        # The time the timer is scheduled to expire. google.protobuf.Timestamp is a Unix
        # epoch time with a granularity of 1 nanosecond.
        # Corresponds to the JSON property `expireTime`
        # @return [String]
        attr_accessor :expire_time
      
        # A user-provided name for this timer.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # The duration of the timer when it was started. For the ADD_TIME action, this
        # field contains the amount of time to add to the timer with the given timer_id.
        # Corresponds to the JSON property `originalDuration`
        # @return [String]
        attr_accessor :original_duration
      
        # The remaining duration for the timer.
        # Corresponds to the JSON property `remainingDuration`
        # @return [String]
        attr_accessor :remaining_duration
      
        # Describes the part of the lifecycle a timer is in.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # A string key used as an identifier to this timer. This key needs to be unique
        # amongst all timers on the device. The client can choose a mechanism of its
        # choice to ensure this. If the server suggests a timer_id, the client can
        # either use the suggestion or create a new unique timer_id of its choosing.
        # Corresponds to the JSON property `timerId`
        # @return [String]
        attr_accessor :timer_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expire_time = args[:expire_time] if args.key?(:expire_time)
          @label = args[:label] if args.key?(:label)
          @original_duration = args[:original_duration] if args.key?(:original_duration)
          @remaining_duration = args[:remaining_duration] if args.key?(:remaining_duration)
          @status = args[:status] if args.key?(:status)
          @timer_id = args[:timer_id] if args.key?(:timer_id)
        end
      end
      
      # Contains information about on-device timers for devices that support timers.
      class GoogleAssistantEmbeddedV1Timers
        include Google::Apis::Core::Hashable
      
        # Indicates if an error occurred while fetching timer state. If this value is
        # missing, it can be assumed that the state fetch was successful.
        # Corresponds to the JSON property `stateFetchError`
        # @return [String]
        attr_accessor :state_fetch_error
      
        # Information about all on-device timers.
        # Corresponds to the JSON property `timers`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleAssistantEmbeddedV1Timer>]
        attr_accessor :timers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state_fetch_error = args[:state_fetch_error] if args.key?(:state_fetch_error)
          @timers = args[:timers] if args.key?(:timers)
        end
      end
      
      # Represents the action responsible for access control list management
      # operations.
      class GoogleCloudContentwarehouseV1AccessControlAction
        include Google::Apis::Core::Hashable
      
        # Identifies the type of operation.
        # Corresponds to the JSON property `operationType`
        # @return [String]
        attr_accessor :operation_type
      
        # An Identity and Access Management (IAM) policy, which specifies access
        # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
        # A `binding` binds one or more `members`, or principals, to a single `role`.
        # Principals can be user accounts, service accounts, Google groups, and domains (
        # such as G Suite). A `role` is a named list of permissions; each `role` can be
        # an IAM predefined role or a user-created custom role. For some types of Google
        # Cloud resources, a `binding` can also specify a `condition`, which is a
        # logical expression that allows access to a resource only if the expression
        # evaluates to `true`. A condition can add constraints based on attributes of
        # the request, the resource, or both. To learn which resources support
        # conditions in their IAM policies, see the [IAM documentation](https://cloud.
        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
        # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
        # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
        # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
        # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
        # ], "condition": ` "title": "expirable access", "description": "Does not grant
        # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
        # bindings: - members: - user:mike@example.com - group:admins@example.com -
        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
        # access description: Does not grant access after Sep 2020 expression: request.
        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
        # a description of IAM and its features, see the [IAM documentation](https://
        # cloud.google.com/iam/docs/).
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleIamV1Policy]
        attr_accessor :policy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @operation_type = args[:operation_type] if args.key?(:operation_type)
          @policy = args[:policy] if args.key?(:policy)
        end
      end
      
      # Represents the action triggered by Rule Engine when the rule is true.
      class GoogleCloudContentwarehouseV1Action
        include Google::Apis::Core::Hashable
      
        # Represents the action responsible for access control list management
        # operations.
        # Corresponds to the JSON property `accessControl`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AccessControlAction]
        attr_accessor :access_control
      
        # ID of the action. Managed internally.
        # Corresponds to the JSON property `actionId`
        # @return [String]
        attr_accessor :action_id
      
        # Represents the action responsible for adding document under a folder.
        # Corresponds to the JSON property `addToFolder`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AddToFolderAction]
        attr_accessor :add_to_folder
      
        # Represents the action responsible for properties update operations.
        # Corresponds to the JSON property `dataUpdate`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataUpdateAction]
        attr_accessor :data_update
      
        # Represents the action responsible for data validation operations.
        # Corresponds to the JSON property `dataValidation`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataValidationAction]
        attr_accessor :data_validation
      
        # Represents the action responsible for deleting the document.
        # Corresponds to the JSON property `deleteDocumentAction`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentAction]
        attr_accessor :delete_document_action
      
        # Represents the action responsible for publishing messages to a Pub/Sub topic.
        # Corresponds to the JSON property `publishToPubSub`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PublishAction]
        attr_accessor :publish_to_pub_sub
      
        # Represents the action responsible for remove a document from a specific folder.
        # Corresponds to the JSON property `removeFromFolderAction`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RemoveFromFolderAction]
        attr_accessor :remove_from_folder_action
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_control = args[:access_control] if args.key?(:access_control)
          @action_id = args[:action_id] if args.key?(:action_id)
          @add_to_folder = args[:add_to_folder] if args.key?(:add_to_folder)
          @data_update = args[:data_update] if args.key?(:data_update)
          @data_validation = args[:data_validation] if args.key?(:data_validation)
          @delete_document_action = args[:delete_document_action] if args.key?(:delete_document_action)
          @publish_to_pub_sub = args[:publish_to_pub_sub] if args.key?(:publish_to_pub_sub)
          @remove_from_folder_action = args[:remove_from_folder_action] if args.key?(:remove_from_folder_action)
        end
      end
      
      # Represents the output of the Action Executor.
      class GoogleCloudContentwarehouseV1ActionExecutorOutput
        include Google::Apis::Core::Hashable
      
        # List of rule and corresponding actions result.
        # Corresponds to the JSON property `ruleActionsPairs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleActionsPair>]
        attr_accessor :rule_actions_pairs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @rule_actions_pairs = args[:rule_actions_pairs] if args.key?(:rule_actions_pairs)
        end
      end
      
      # Represents the result of executing an action.
      class GoogleCloudContentwarehouseV1ActionOutput
        include Google::Apis::Core::Hashable
      
        # ID of the action.
        # Corresponds to the JSON property `actionId`
        # @return [String]
        attr_accessor :action_id
      
        # State of an action.
        # Corresponds to the JSON property `actionState`
        # @return [String]
        attr_accessor :action_state
      
        # Action execution output message.
        # Corresponds to the JSON property `outputMessage`
        # @return [String]
        attr_accessor :output_message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_id = args[:action_id] if args.key?(:action_id)
          @action_state = args[:action_state] if args.key?(:action_state)
          @output_message = args[:output_message] if args.key?(:output_message)
        end
      end
      
      # Represents the action responsible for adding document under a folder.
      class GoogleCloudContentwarehouseV1AddToFolderAction
        include Google::Apis::Core::Hashable
      
        # Names of the folder under which new document is to be added. Format: projects/`
        # project_number`/locations/`location`/documents/`document_id`.
        # Corresponds to the JSON property `folders`
        # @return [Array<String>]
        attr_accessor :folders
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @folders = args[:folders] if args.key?(:folders)
        end
      end
      
      # Request Option for processing Cloud AI Document in CW Document.
      class GoogleCloudContentwarehouseV1CloudAiDocumentOption
        include Google::Apis::Core::Hashable
      
        # If set, only selected entities will be converted to properties.
        # Corresponds to the JSON property `customizedEntitiesPropertiesConversions`
        # @return [Hash<String,String>]
        attr_accessor :customized_entities_properties_conversions
      
        # Whether to convert all the entities to properties.
        # Corresponds to the JSON property `enableEntitiesConversions`
        # @return [Boolean]
        attr_accessor :enable_entities_conversions
        alias_method :enable_entities_conversions?, :enable_entities_conversions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @customized_entities_properties_conversions = args[:customized_entities_properties_conversions] if args.key?(:customized_entities_properties_conversions)
          @enable_entities_conversions = args[:enable_entities_conversions] if args.key?(:enable_entities_conversions)
        end
      end
      
      # Request message for DocumentLinkService.CreateDocumentLink.
      class GoogleCloudContentwarehouseV1CreateDocumentLinkRequest
        include Google::Apis::Core::Hashable
      
        # A document-link between source and target document.
        # Corresponds to the JSON property `documentLink`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink]
        attr_accessor :document_link
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_link = args[:document_link] if args.key?(:document_link)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Metadata object for CreateDocument request (currently empty).
      class GoogleCloudContentwarehouseV1CreateDocumentMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Request message for DocumentService.CreateDocument.
      class GoogleCloudContentwarehouseV1CreateDocumentRequest
        include Google::Apis::Core::Hashable
      
        # Request Option for processing Cloud AI Document in CW Document.
        # Corresponds to the JSON property `cloudAiDocumentOption`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CloudAiDocumentOption]
        attr_accessor :cloud_ai_document_option
      
        # Field mask for creating Document fields. If mask path is empty, it means all
        # fields are masked. For the `FieldMask` definition, see https://developers.
        # google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
        # Corresponds to the JSON property `createMask`
        # @return [String]
        attr_accessor :create_mask
      
        # Defines the structure for content warehouse document proto. Next ID: 20
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document]
        attr_accessor :document
      
        # An Identity and Access Management (IAM) policy, which specifies access
        # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
        # A `binding` binds one or more `members`, or principals, to a single `role`.
        # Principals can be user accounts, service accounts, Google groups, and domains (
        # such as G Suite). A `role` is a named list of permissions; each `role` can be
        # an IAM predefined role or a user-created custom role. For some types of Google
        # Cloud resources, a `binding` can also specify a `condition`, which is a
        # logical expression that allows access to a resource only if the expression
        # evaluates to `true`. A condition can add constraints based on attributes of
        # the request, the resource, or both. To learn which resources support
        # conditions in their IAM policies, see the [IAM documentation](https://cloud.
        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
        # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
        # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
        # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
        # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
        # ], "condition": ` "title": "expirable access", "description": "Does not grant
        # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
        # bindings: - members: - user:mike@example.com - group:admins@example.com -
        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
        # access description: Does not grant access after Sep 2020 expression: request.
        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
        # a description of IAM and its features, see the [IAM documentation](https://
        # cloud.google.com/iam/docs/).
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleIamV1Policy]
        attr_accessor :policy
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_ai_document_option = args[:cloud_ai_document_option] if args.key?(:cloud_ai_document_option)
          @create_mask = args[:create_mask] if args.key?(:create_mask)
          @document = args[:document] if args.key?(:document)
          @policy = args[:policy] if args.key?(:policy)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Response message for DocumentService.CreateDocument.
      class GoogleCloudContentwarehouseV1CreateDocumentResponse
        include Google::Apis::Core::Hashable
      
        # Defines the structure for content warehouse document proto. Next ID: 20
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document]
        attr_accessor :document
      
        # Additional information returned to client, such as debugging information.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata]
        attr_accessor :metadata
      
        # Records the output of Rule Engine including rule evaluation and actions result.
        # Corresponds to the JSON property `ruleEngineOutput`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput]
        attr_accessor :rule_engine_output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document = args[:document] if args.key?(:document)
          @metadata = args[:metadata] if args.key?(:metadata)
          @rule_engine_output = args[:rule_engine_output] if args.key?(:rule_engine_output)
        end
      end
      
      # Represents the action responsible for properties update operations.
      class GoogleCloudContentwarehouseV1DataUpdateAction
        include Google::Apis::Core::Hashable
      
        # Map of (K, V) -> (valid name of the field, new value of the field) E.g., ("age"
        # , "60") entry triggers update of field age with a value of 60. If the field is
        # not present then new entry is added. During update action execution, value
        # strings will be casted to appropriate types.
        # Corresponds to the JSON property `entries`
        # @return [Hash<String,String>]
        attr_accessor :entries
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entries = args[:entries] if args.key?(:entries)
        end
      end
      
      # Represents the action responsible for data validation operations.
      class GoogleCloudContentwarehouseV1DataValidationAction
        include Google::Apis::Core::Hashable
      
        # Map of (K, V) -> (field, string condition to be evaluated on the field) E.g., (
        # "age", "age > 18 && age < 60") entry triggers validation of field age with the
        # given condition. Map entries will be ANDed during validation.
        # Corresponds to the JSON property `conditions`
        # @return [Hash<String,String>]
        attr_accessor :conditions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conditions = args[:conditions] if args.key?(:conditions)
        end
      end
      
      # DateTime values.
      class GoogleCloudContentwarehouseV1DateTimeArray
        include Google::Apis::Core::Hashable
      
        # List of datetime values. Both OffsetDateTime and ZonedDateTime are supported.
        # Corresponds to the JSON property `values`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleTypeDateTime>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for a date time property.
      class GoogleCloudContentwarehouseV1DateTimeTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Represents the action responsible for deleting the document.
      class GoogleCloudContentwarehouseV1DeleteDocumentAction
        include Google::Apis::Core::Hashable
      
        # Boolean field to select between hard vs soft delete options. Set 'true' for '
        # hard delete' and 'false' for 'soft delete'.
        # Corresponds to the JSON property `enableHardDelete`
        # @return [Boolean]
        attr_accessor :enable_hard_delete
        alias_method :enable_hard_delete?, :enable_hard_delete
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enable_hard_delete = args[:enable_hard_delete] if args.key?(:enable_hard_delete)
        end
      end
      
      # Request message for DocumentLinkService.DeleteDocumentLink.
      class GoogleCloudContentwarehouseV1DeleteDocumentLinkRequest
        include Google::Apis::Core::Hashable
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Request message for DocumentService.DeleteDocument.
      class GoogleCloudContentwarehouseV1DeleteDocumentRequest
        include Google::Apis::Core::Hashable
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Defines the structure for content warehouse document proto. Next ID: 20
      class GoogleCloudContentwarehouseV1Document
        include Google::Apis::Core::Hashable
      
        # If true, makes the document visible to asynchronous policies and rules.
        # Corresponds to the JSON property `asyncEnabled`
        # @return [Boolean]
        attr_accessor :async_enabled
        alias_method :async_enabled?, :async_enabled
      
        # Document represents the canonical document resource in Document AI. It is an
        # interchange format that provides insights into documents and allows for
        # collaboration between users and Document AI to iterate and optimize for
        # quality.
        # Corresponds to the JSON property `cloudAiDocument`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Document]
        attr_accessor :cloud_ai_document
      
        # Output only. The time when the document is created.
        # Corresponds to the JSON property `createTime`
        # @return [String]
        attr_accessor :create_time
      
        # The user who creates the document.
        # Corresponds to the JSON property `creator`
        # @return [String]
        attr_accessor :creator
      
        # Required. Display name of the document given by the user. This name will be
        # displayed in the UI. Customer can populate this field with the name of the
        # document. This differs from the 'title' field as 'title' is optional and
        # stores the top heading in the document.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Uri to display the document, for example, in the UI.
        # Corresponds to the JSON property `displayUri`
        # @return [String]
        attr_accessor :display_uri
      
        # The Document schema name. Format: projects/`project_number`/locations/`
        # location`/documentSchemas/`document_schema_id`.
        # Corresponds to the JSON property `documentSchemaName`
        # @return [String]
        attr_accessor :document_schema_name
      
        # Raw document content.
        # Corresponds to the JSON property `inlineRawDocument`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :inline_raw_document
      
        # The resource name of the document. Format: projects/`project_number`/locations/
        # `location`/documents/`document_id`. The name is ignored when creating a
        # document.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Other document format, such as PPTX, XLXS
        # Corresponds to the JSON property `plainText`
        # @return [String]
        attr_accessor :plain_text
      
        # List of values that are user supplied metadata.
        # Corresponds to the JSON property `properties`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Property>]
        attr_accessor :properties
      
        # This is used when DocAI was not used to load the document and parsing/
        # extracting is needed for the inline_raw_document. For example, if
        # inline_raw_document is the byte representation of a PDF file, then this should
        # be set to: RAW_DOCUMENT_FILE_TYPE_PDF.
        # Corresponds to the JSON property `rawDocumentFileType`
        # @return [String]
        attr_accessor :raw_document_file_type
      
        # Raw document file in Cloud Storage path.
        # Corresponds to the JSON property `rawDocumentPath`
        # @return [String]
        attr_accessor :raw_document_path
      
        # The reference ID set by customers. Must be unique per project and location.
        # Corresponds to the JSON property `referenceId`
        # @return [String]
        attr_accessor :reference_id
      
        # A path linked to structured content file.
        # Corresponds to the JSON property `structuredContentUri`
        # @return [String]
        attr_accessor :structured_content_uri
      
        # If true, text extraction will not be performed.
        # Corresponds to the JSON property `textExtractionDisabled`
        # @return [Boolean]
        attr_accessor :text_extraction_disabled
        alias_method :text_extraction_disabled?, :text_extraction_disabled
      
        # Title that describes the document. This is usually present in the top section
        # of the document, and is a mandatory field for the question-answering feature.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Output only. The time when the document is last updated.
        # Corresponds to the JSON property `updateTime`
        # @return [String]
        attr_accessor :update_time
      
        # The user who lastly updates the document.
        # Corresponds to the JSON property `updater`
        # @return [String]
        attr_accessor :updater
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @async_enabled = args[:async_enabled] if args.key?(:async_enabled)
          @cloud_ai_document = args[:cloud_ai_document] if args.key?(:cloud_ai_document)
          @create_time = args[:create_time] if args.key?(:create_time)
          @creator = args[:creator] if args.key?(:creator)
          @display_name = args[:display_name] if args.key?(:display_name)
          @display_uri = args[:display_uri] if args.key?(:display_uri)
          @document_schema_name = args[:document_schema_name] if args.key?(:document_schema_name)
          @inline_raw_document = args[:inline_raw_document] if args.key?(:inline_raw_document)
          @name = args[:name] if args.key?(:name)
          @plain_text = args[:plain_text] if args.key?(:plain_text)
          @properties = args[:properties] if args.key?(:properties)
          @raw_document_file_type = args[:raw_document_file_type] if args.key?(:raw_document_file_type)
          @raw_document_path = args[:raw_document_path] if args.key?(:raw_document_path)
          @reference_id = args[:reference_id] if args.key?(:reference_id)
          @structured_content_uri = args[:structured_content_uri] if args.key?(:structured_content_uri)
          @text_extraction_disabled = args[:text_extraction_disabled] if args.key?(:text_extraction_disabled)
          @title = args[:title] if args.key?(:title)
          @update_time = args[:update_time] if args.key?(:update_time)
          @updater = args[:updater] if args.key?(:updater)
        end
      end
      
      # A document-link between source and target document.
      class GoogleCloudContentwarehouseV1DocumentLink
        include Google::Apis::Core::Hashable
      
        # Output only. The time when the documentLink is created.
        # Corresponds to the JSON property `createTime`
        # @return [String]
        attr_accessor :create_time
      
        # Description of this document-link.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Name of this document-link. It is required that the parent derived form the
        # name to be consistent with the source document reference. Otherwise an
        # exception will be thrown. Format: projects/`project_number`/locations/`
        # location`/documents/`source_document_id`/documentLinks/`document_link_id`.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # References to the documents.
        # Corresponds to the JSON property `sourceDocumentReference`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentReference]
        attr_accessor :source_document_reference
      
        # The state of the documentlink. If target node has been deleted, the link is
        # marked as invalid. Removing a source node will result in removal of all
        # associated links.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # References to the documents.
        # Corresponds to the JSON property `targetDocumentReference`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentReference]
        attr_accessor :target_document_reference
      
        # Output only. The time when the documentLink is last updated.
        # Corresponds to the JSON property `updateTime`
        # @return [String]
        attr_accessor :update_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @create_time = args[:create_time] if args.key?(:create_time)
          @description = args[:description] if args.key?(:description)
          @name = args[:name] if args.key?(:name)
          @source_document_reference = args[:source_document_reference] if args.key?(:source_document_reference)
          @state = args[:state] if args.key?(:state)
          @target_document_reference = args[:target_document_reference] if args.key?(:target_document_reference)
          @update_time = args[:update_time] if args.key?(:update_time)
        end
      end
      
      # NEXT_ID: 13
      class GoogleCloudContentwarehouseV1DocumentQuery
        include Google::Apis::Core::Hashable
      
        # This filter specifies a structured syntax to match against the [
        # PropertyDefinition].is_filterable marked as `true`. The syntax for this
        # expression is a subset of SQL syntax. Supported operators are: `=`, `!=`, `<`,
        # `<=`, `>`, and `>=` where the left of the operator is a property name and the
        # right of the operator is a number or a quoted string. You must escape
        # backslash (\\) and quote (\") characters. Supported functions are `LOWER([
        # property_name])` to perform a case insensitive match and `EMPTY([property_name]
        # )` to filter on the existence of a key. Boolean expressions (AND/OR/NOT) are
        # supported up to 3 levels of nesting (for example, "((A AND B AND C) OR NOT D)
        # AND E"), a maximum of 100 comparisons or functions are allowed in the
        # expression. The expression must be < 6000 bytes in length. Sample Query: `(
        # LOWER(driving_license)="class \"a\"" OR EMPTY(driving_license)) AND
        # driving_years > 10`
        # Corresponds to the JSON property `customPropertyFilter`
        # @return [String]
        attr_accessor :custom_property_filter
      
        # The exact creator(s) of the documents to search against. If a value isn't
        # specified, documents within the search results are associated with any creator.
        # If multiple values are specified, documents within the search results may be
        # associated with any of the specified creators.
        # Corresponds to the JSON property `documentCreatorFilter`
        # @return [Array<String>]
        attr_accessor :document_creator_filter
      
        # This filter specifies the exact document schema Document.document_schema_name
        # of the documents to search against. If a value isn't specified, documents
        # within the search results are associated with any schema. If multiple values
        # are specified, documents within the search results may be associated with any
        # of the specified schemas. At most 20 document schema names are allowed.
        # Corresponds to the JSON property `documentSchemaNames`
        # @return [Array<String>]
        attr_accessor :document_schema_names
      
        # Filter for the specific types of documents returned.
        # Corresponds to the JSON property `fileTypeFilter`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FileTypeFilter]
        attr_accessor :file_type_filter
      
        # Search all the documents under this specified folder. Format: projects/`
        # project_number`/locations/`location`/documents/`document_id`.
        # Corresponds to the JSON property `folderNameFilter`
        # @return [String]
        attr_accessor :folder_name_filter
      
        # Experimental, do not use. If the query is a natural language question. False
        # by default. If true, then the question-answering feature will be used instead
        # of search, and `result_count` in SearchDocumentsRequest must be set. In
        # addition, all other input fields related to search (pagination, histograms,
        # etc.) will be ignored.
        # Corresponds to the JSON property `isNlQuery`
        # @return [Boolean]
        attr_accessor :is_nl_query
        alias_method :is_nl_query?, :is_nl_query
      
        # This filter specifies a structured syntax to match against the
        # PropertyDefinition.is_filterable marked as `true`. The relationship between
        # the PropertyFilters is OR.
        # Corresponds to the JSON property `propertyFilter`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyFilter>]
        attr_accessor :property_filter
      
        # The query string that matches against the full text of the document and the
        # searchable properties. The maximum number of allowed characters is 255.
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        # For custom synonyms. Customers provide the synonyms based on context. One
        # customer can provide multiple set of synonyms based on different context. The
        # search query will be expanded based on the custom synonyms of the query
        # context set. By default, no custom synonyms wll be applied if no query context
        # is provided. It is not supported for CMEK compliant deployment.
        # Corresponds to the JSON property `queryContext`
        # @return [Array<String>]
        attr_accessor :query_context
      
        # Documents created/updated within a range specified by this filter are searched
        # against.
        # Corresponds to the JSON property `timeFilters`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimeFilter>]
        attr_accessor :time_filters
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @custom_property_filter = args[:custom_property_filter] if args.key?(:custom_property_filter)
          @document_creator_filter = args[:document_creator_filter] if args.key?(:document_creator_filter)
          @document_schema_names = args[:document_schema_names] if args.key?(:document_schema_names)
          @file_type_filter = args[:file_type_filter] if args.key?(:file_type_filter)
          @folder_name_filter = args[:folder_name_filter] if args.key?(:folder_name_filter)
          @is_nl_query = args[:is_nl_query] if args.key?(:is_nl_query)
          @property_filter = args[:property_filter] if args.key?(:property_filter)
          @query = args[:query] if args.key?(:query)
          @query_context = args[:query_context] if args.key?(:query_context)
          @time_filters = args[:time_filters] if args.key?(:time_filters)
        end
      end
      
      # References to the documents.
      class GoogleCloudContentwarehouseV1DocumentReference
        include Google::Apis::Core::Hashable
      
        # Output only. The time when the document is created.
        # Corresponds to the JSON property `createTime`
        # @return [String]
        attr_accessor :create_time
      
        # Output only. The time when the document is deleted.
        # Corresponds to the JSON property `deleteTime`
        # @return [String]
        attr_accessor :delete_time
      
        # display_name of the referenced document; this name does not need to be
        # consistent to the display_name in the Document proto, depending on the ACL
        # constraint.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # The document type of the document being referenced.
        # Corresponds to the JSON property `documentIsFolder`
        # @return [Boolean]
        attr_accessor :document_is_folder
        alias_method :document_is_folder?, :document_is_folder
      
        # Required. Name of the referenced document.
        # Corresponds to the JSON property `documentName`
        # @return [String]
        attr_accessor :document_name
      
        # Stores the subset of the referenced document's content. This is useful to
        # allow user peek the information of the referenced document.
        # Corresponds to the JSON property `snippet`
        # @return [String]
        attr_accessor :snippet
      
        # Output only. The time when the document is last updated.
        # Corresponds to the JSON property `updateTime`
        # @return [String]
        attr_accessor :update_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @create_time = args[:create_time] if args.key?(:create_time)
          @delete_time = args[:delete_time] if args.key?(:delete_time)
          @display_name = args[:display_name] if args.key?(:display_name)
          @document_is_folder = args[:document_is_folder] if args.key?(:document_is_folder)
          @document_name = args[:document_name] if args.key?(:document_name)
          @snippet = args[:snippet] if args.key?(:snippet)
          @update_time = args[:update_time] if args.key?(:update_time)
        end
      end
      
      # A document schema used to define document structure.
      class GoogleCloudContentwarehouseV1DocumentSchema
        include Google::Apis::Core::Hashable
      
        # Output only. The time when the document schema is created.
        # Corresponds to the JSON property `createTime`
        # @return [String]
        attr_accessor :create_time
      
        # Schema description.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Required. Name of the schema given by the user. Must be unique per customer.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Document Type, true refers the document is a folder, otherwise it is a typical
        # document.
        # Corresponds to the JSON property `documentIsFolder`
        # @return [Boolean]
        attr_accessor :document_is_folder
        alias_method :document_is_folder?, :document_is_folder
      
        # The resource name of the document schema. Format: projects/`project_number`/
        # locations/`location`/documentSchemas/`document_schema_id`. The name is ignored
        # when creating a document schema.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Document details.
        # Corresponds to the JSON property `propertyDefinitions`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition>]
        attr_accessor :property_definitions
      
        # Output only. The time when the document schema is last updated.
        # Corresponds to the JSON property `updateTime`
        # @return [String]
        attr_accessor :update_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @create_time = args[:create_time] if args.key?(:create_time)
          @description = args[:description] if args.key?(:description)
          @display_name = args[:display_name] if args.key?(:display_name)
          @document_is_folder = args[:document_is_folder] if args.key?(:document_is_folder)
          @name = args[:name] if args.key?(:name)
          @property_definitions = args[:property_definitions] if args.key?(:property_definitions)
          @update_time = args[:update_time] if args.key?(:update_time)
        end
      end
      
      # Enum values.
      class GoogleCloudContentwarehouseV1EnumArray
        include Google::Apis::Core::Hashable
      
        # List of enum values.
        # Corresponds to the JSON property `values`
        # @return [Array<String>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for an enum/categorical property.
      class GoogleCloudContentwarehouseV1EnumTypeOptions
        include Google::Apis::Core::Hashable
      
        # Required. List of possible enum values.
        # Corresponds to the JSON property `possibleValues`
        # @return [Array<String>]
        attr_accessor :possible_values
      
        # Make sure the Enum property value provided in the document is in the possile
        # value list during document creation. The validation check runs by default.
        # Corresponds to the JSON property `validationCheckDisabled`
        # @return [Boolean]
        attr_accessor :validation_check_disabled
        alias_method :validation_check_disabled?, :validation_check_disabled
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @possible_values = args[:possible_values] if args.key?(:possible_values)
          @validation_check_disabled = args[:validation_check_disabled] if args.key?(:validation_check_disabled)
        end
      end
      
      # Represents the string value of the enum field.
      class GoogleCloudContentwarehouseV1EnumValue
        include Google::Apis::Core::Hashable
      
        # String value of the enum field. This must match defined set of enums in
        # document schema using EnumTypeOptions.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Request message for DocumentService.FetchAcl
      class GoogleCloudContentwarehouseV1FetchAclRequest
        include Google::Apis::Core::Hashable
      
        # For Get Project ACL only. Authorization check for end user will be ignored
        # when project_owner=true.
        # Corresponds to the JSON property `projectOwner`
        # @return [Boolean]
        attr_accessor :project_owner
        alias_method :project_owner?, :project_owner
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @project_owner = args[:project_owner] if args.key?(:project_owner)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Response message for DocumentService.FetchAcl.
      class GoogleCloudContentwarehouseV1FetchAclResponse
        include Google::Apis::Core::Hashable
      
        # Additional information returned to client, such as debugging information.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata]
        attr_accessor :metadata
      
        # An Identity and Access Management (IAM) policy, which specifies access
        # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
        # A `binding` binds one or more `members`, or principals, to a single `role`.
        # Principals can be user accounts, service accounts, Google groups, and domains (
        # such as G Suite). A `role` is a named list of permissions; each `role` can be
        # an IAM predefined role or a user-created custom role. For some types of Google
        # Cloud resources, a `binding` can also specify a `condition`, which is a
        # logical expression that allows access to a resource only if the expression
        # evaluates to `true`. A condition can add constraints based on attributes of
        # the request, the resource, or both. To learn which resources support
        # conditions in their IAM policies, see the [IAM documentation](https://cloud.
        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
        # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
        # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
        # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
        # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
        # ], "condition": ` "title": "expirable access", "description": "Does not grant
        # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
        # bindings: - members: - user:mike@example.com - group:admins@example.com -
        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
        # access description: Does not grant access after Sep 2020 expression: request.
        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
        # a description of IAM and its features, see the [IAM documentation](https://
        # cloud.google.com/iam/docs/).
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleIamV1Policy]
        attr_accessor :policy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @policy = args[:policy] if args.key?(:policy)
        end
      end
      
      # Filter for the specific types of documents returned.
      class GoogleCloudContentwarehouseV1FileTypeFilter
        include Google::Apis::Core::Hashable
      
        # The type of files to return.
        # Corresponds to the JSON property `fileType`
        # @return [String]
        attr_accessor :file_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @file_type = args[:file_type] if args.key?(:file_type)
        end
      end
      
      # Float values.
      class GoogleCloudContentwarehouseV1FloatArray
        include Google::Apis::Core::Hashable
      
        # List of float values.
        # Corresponds to the JSON property `values`
        # @return [Array<Float>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for a float property.
      class GoogleCloudContentwarehouseV1FloatTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Request message for DocumentService.GetDocument. Next ID: 4
      class GoogleCloudContentwarehouseV1GetDocumentRequest
        include Google::Apis::Core::Hashable
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # The histogram request.
      class GoogleCloudContentwarehouseV1HistogramQuery
        include Google::Apis::Core::Hashable
      
        # Optional. Filter the result of histogram query by the property names. It only
        # works with histogram query count('FilterableProperties'). It is an optional.
        # It will perform histogram on all the property names for all the document
        # schemas. Setting this field will have a better performance.
        # Corresponds to the JSON property `filters`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter]
        attr_accessor :filters
      
        # An expression specifies a histogram request against matching documents for
        # searches. See SearchDocumentsRequest.histogram_queries for details about
        # syntax.
        # Corresponds to the JSON property `histogramQuery`
        # @return [String]
        attr_accessor :histogram_query
      
        # Controls if the histogram query requires the return of a precise count. Enable
        # this flag may adversely impact performance. Defaults to true.
        # Corresponds to the JSON property `requirePreciseResultSize`
        # @return [Boolean]
        attr_accessor :require_precise_result_size
        alias_method :require_precise_result_size?, :require_precise_result_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @filters = args[:filters] if args.key?(:filters)
          @histogram_query = args[:histogram_query] if args.key?(:histogram_query)
          @require_precise_result_size = args[:require_precise_result_size] if args.key?(:require_precise_result_size)
        end
      end
      
      # 
      class GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
        include Google::Apis::Core::Hashable
      
        # This filter specifies the exact document schema(s) Document.
        # document_schema_name to run histogram query against. It is optional. It will
        # perform histogram for property names for all the document schemas if it is not
        # set. At most 10 document schema names are allowed. Format: projects/`
        # project_number`/locations/`location`/documentSchemas/`document_schema_id`.
        # Corresponds to the JSON property `documentSchemas`
        # @return [Array<String>]
        attr_accessor :document_schemas
      
        # It is optional. It will perform histogram for all the property names if it is
        # not set. The properties need to be defined with the is_filterable flag set to
        # true and the name of the property should be in the format: "schemaId.
        # propertyName". The property needs to be defined in the schema. Example: the
        # schema id is abc. Then the name of property for property MORTGAGE_TYPE will be
        # "abc.MORTGAGE_TYPE".
        # Corresponds to the JSON property `propertyNames`
        # @return [Array<String>]
        attr_accessor :property_names
      
        # By default, the y_axis is HISTOGRAM_YAXIS_DOCUMENT if this field is not set.
        # Corresponds to the JSON property `yAxis`
        # @return [String]
        attr_accessor :y_axis
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_schemas = args[:document_schemas] if args.key?(:document_schemas)
          @property_names = args[:property_names] if args.key?(:property_names)
          @y_axis = args[:y_axis] if args.key?(:y_axis)
        end
      end
      
      # Histogram result that matches HistogramQuery specified in searches.
      class GoogleCloudContentwarehouseV1HistogramQueryResult
        include Google::Apis::Core::Hashable
      
        # A map from the values of the facet associated with distinct values to the
        # number of matching entries with corresponding value. The key format is: * (for
        # string histogram) string values stored in the field.
        # Corresponds to the JSON property `histogram`
        # @return [Hash<String,Fixnum>]
        attr_accessor :histogram
      
        # Requested histogram expression.
        # Corresponds to the JSON property `histogramQuery`
        # @return [String]
        attr_accessor :histogram_query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @histogram = args[:histogram] if args.key?(:histogram)
          @histogram_query = args[:histogram_query] if args.key?(:histogram_query)
        end
      end
      
      # Request message for projectService.InitializeProject
      class GoogleCloudContentwarehouseV1InitializeProjectRequest
        include Google::Apis::Core::Hashable
      
        # Required. The access control mode for accessing the customer data
        # Corresponds to the JSON property `accessControlMode`
        # @return [String]
        attr_accessor :access_control_mode
      
        # Required. The type of database used to store customer data
        # Corresponds to the JSON property `databaseType`
        # @return [String]
        attr_accessor :database_type
      
        # Optional. The KMS key used for CMEK encryption. It is required that the kms
        # key is in the same region as the endpoint. The same key will be used for all
        # provisioned resources, if encryption is available. If the kms_key is left
        # empty, no encryption will be enforced.
        # Corresponds to the JSON property `kmsKey`
        # @return [String]
        attr_accessor :kms_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_control_mode = args[:access_control_mode] if args.key?(:access_control_mode)
          @database_type = args[:database_type] if args.key?(:database_type)
          @kms_key = args[:kms_key] if args.key?(:kms_key)
        end
      end
      
      # Response message for projectService.InitializeProject
      class GoogleCloudContentwarehouseV1InitializeProjectResponse
        include Google::Apis::Core::Hashable
      
        # The message of the project initialization process.
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        # The state of the project initialization process.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message = args[:message] if args.key?(:message)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Integer values.
      class GoogleCloudContentwarehouseV1IntegerArray
        include Google::Apis::Core::Hashable
      
        # List of integer values.
        # Corresponds to the JSON property `values`
        # @return [Array<Fixnum>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for an integer property.
      class GoogleCloudContentwarehouseV1IntegerTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # A triggered rule that failed the validation check(s) after parsing.
      class GoogleCloudContentwarehouseV1InvalidRule
        include Google::Apis::Core::Hashable
      
        # Validation error on a parsed expression.
        # Corresponds to the JSON property `error`
        # @return [String]
        attr_accessor :error
      
        # Represents the rule for a content warehouse trigger.
        # Corresponds to the JSON property `rule`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule]
        attr_accessor :rule
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @error = args[:error] if args.key?(:error)
          @rule = args[:rule] if args.key?(:rule)
        end
      end
      
      # Response message for DocumentSchemaService.ListDocumentSchemas.
      class GoogleCloudContentwarehouseV1ListDocumentSchemasResponse
        include Google::Apis::Core::Hashable
      
        # The document schemas from the specified parent.
        # Corresponds to the JSON property `documentSchemas`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema>]
        attr_accessor :document_schemas
      
        # A token, which can be sent as `page_token` to retrieve the next page. If this
        # field is omitted, there are no subsequent pages.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_schemas = args[:document_schemas] if args.key?(:document_schemas)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
        end
      end
      
      # Response message for DocumentLinkService.ListLinkedSources.
      class GoogleCloudContentwarehouseV1ListLinkedSourcesRequest
        include Google::Apis::Core::Hashable
      
        # The maximum number of document-links to return. The service may return fewer
        # than this value. If unspecified, at most 50 document-links will be returned.
        # The maximum value is 1000; values above 1000 will be coerced to 1000.
        # Corresponds to the JSON property `pageSize`
        # @return [Fixnum]
        attr_accessor :page_size
      
        # A page token, received from a previous `ListLinkedSources` call. Provide this
        # to retrieve the subsequent page. When paginating, all other parameters
        # provided to `ListLinkedSources` must match the call that provided the page
        # token.
        # Corresponds to the JSON property `pageToken`
        # @return [String]
        attr_accessor :page_token
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @page_size = args[:page_size] if args.key?(:page_size)
          @page_token = args[:page_token] if args.key?(:page_token)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Response message for DocumentLinkService.ListLinkedSources.
      class GoogleCloudContentwarehouseV1ListLinkedSourcesResponse
        include Google::Apis::Core::Hashable
      
        # Source document-links.
        # Corresponds to the JSON property `documentLinks`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink>]
        attr_accessor :document_links
      
        # A token, which can be sent as `page_token` to retrieve the next page. If this
        # field is omitted, there are no subsequent pages.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_links = args[:document_links] if args.key?(:document_links)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
        end
      end
      
      # Request message for DocumentLinkService.ListLinkedTargets.
      class GoogleCloudContentwarehouseV1ListLinkedTargetsRequest
        include Google::Apis::Core::Hashable
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Response message for DocumentLinkService.ListLinkedTargets.
      class GoogleCloudContentwarehouseV1ListLinkedTargetsResponse
        include Google::Apis::Core::Hashable
      
        # Target document-links.
        # Corresponds to the JSON property `documentLinks`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink>]
        attr_accessor :document_links
      
        # A token, which can be sent as `page_token` to retrieve the next page. If this
        # field is omitted, there are no subsequent pages.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_links = args[:document_links] if args.key?(:document_links)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
        end
      end
      
      # Response message for RuleSetService.ListRuleSets.
      class GoogleCloudContentwarehouseV1ListRuleSetsResponse
        include Google::Apis::Core::Hashable
      
        # A token, which can be sent as `page_token` to retrieve the next page. If this
        # field is omitted, there are no subsequent pages.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        # The rule sets from the specified parent.
        # Corresponds to the JSON property `ruleSets`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet>]
        attr_accessor :rule_sets
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
          @rule_sets = args[:rule_sets] if args.key?(:rule_sets)
        end
      end
      
      # Response message for SynonymSetService.ListSynonymSets.
      class GoogleCloudContentwarehouseV1ListSynonymSetsResponse
        include Google::Apis::Core::Hashable
      
        # A page token, received from a previous `ListSynonymSets` call. Provide this to
        # retrieve the subsequent page.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        # The synonymSets from the specified parent.
        # Corresponds to the JSON property `synonymSets`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet>]
        attr_accessor :synonym_sets
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
          @synonym_sets = args[:synonym_sets] if args.key?(:synonym_sets)
        end
      end
      
      # Map property value. Represents a structured entries of key value pairs,
      # consisting of field names which map to dynamically typed values.
      class GoogleCloudContentwarehouseV1MapProperty
        include Google::Apis::Core::Hashable
      
        # Unordered map of dynamically typed values.
        # Corresponds to the JSON property `fields`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Value>]
        attr_accessor :fields
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fields = args[:fields] if args.key?(:fields)
        end
      end
      
      # Configurations for a Map property.
      class GoogleCloudContentwarehouseV1MapTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Options for merging updated fields.
      class GoogleCloudContentwarehouseV1MergeFieldsOptions
        include Google::Apis::Core::Hashable
      
        # When merging message fields, the default behavior is to merge the content of
        # two message fields together. If you instead want to use the field from the
        # source message to replace the corresponding field in the destination message,
        # set this flag to true. When this flag is set, specified submessage fields that
        # are missing in source will be cleared in destination.
        # Corresponds to the JSON property `replaceMessageFields`
        # @return [Boolean]
        attr_accessor :replace_message_fields
        alias_method :replace_message_fields?, :replace_message_fields
      
        # When merging repeated fields, the default behavior is to append entries from
        # the source repeated field to the destination repeated field. If you instead
        # want to keep only the entries from the source repeated field, set this flag to
        # true. If you want to replace a repeated field within a message field on the
        # destination message, you must set both replace_repeated_fields and
        # replace_message_fields to true, otherwise the repeated fields will be appended.
        # Corresponds to the JSON property `replaceRepeatedFields`
        # @return [Boolean]
        attr_accessor :replace_repeated_fields
        alias_method :replace_repeated_fields?, :replace_repeated_fields
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @replace_message_fields = args[:replace_message_fields] if args.key?(:replace_message_fields)
          @replace_repeated_fields = args[:replace_repeated_fields] if args.key?(:replace_repeated_fields)
        end
      end
      
      # Property of a document.
      class GoogleCloudContentwarehouseV1Property
        include Google::Apis::Core::Hashable
      
        # DateTime values.
        # Corresponds to the JSON property `dateTimeValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DateTimeArray]
        attr_accessor :date_time_values
      
        # Enum values.
        # Corresponds to the JSON property `enumValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumArray]
        attr_accessor :enum_values
      
        # Float values.
        # Corresponds to the JSON property `floatValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FloatArray]
        attr_accessor :float_values
      
        # Integer values.
        # Corresponds to the JSON property `integerValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IntegerArray]
        attr_accessor :integer_values
      
        # Map property value. Represents a structured entries of key value pairs,
        # consisting of field names which map to dynamically typed values.
        # Corresponds to the JSON property `mapProperty`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapProperty]
        attr_accessor :map_property
      
        # Required. Must match the name of a PropertyDefinition in the DocumentSchema.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Property values.
        # Corresponds to the JSON property `propertyValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyArray]
        attr_accessor :property_values
      
        # String/text values.
        # Corresponds to the JSON property `textValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TextArray]
        attr_accessor :text_values
      
        # Timestamp values.
        # Corresponds to the JSON property `timestampValues`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampArray]
        attr_accessor :timestamp_values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_time_values = args[:date_time_values] if args.key?(:date_time_values)
          @enum_values = args[:enum_values] if args.key?(:enum_values)
          @float_values = args[:float_values] if args.key?(:float_values)
          @integer_values = args[:integer_values] if args.key?(:integer_values)
          @map_property = args[:map_property] if args.key?(:map_property)
          @name = args[:name] if args.key?(:name)
          @property_values = args[:property_values] if args.key?(:property_values)
          @text_values = args[:text_values] if args.key?(:text_values)
          @timestamp_values = args[:timestamp_values] if args.key?(:timestamp_values)
        end
      end
      
      # Property values.
      class GoogleCloudContentwarehouseV1PropertyArray
        include Google::Apis::Core::Hashable
      
        # List of property values.
        # Corresponds to the JSON property `properties`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Property>]
        attr_accessor :properties
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @properties = args[:properties] if args.key?(:properties)
        end
      end
      
      # Defines the metadata for a schema property. Next ID: 18
      class GoogleCloudContentwarehouseV1PropertyDefinition
        include Google::Apis::Core::Hashable
      
        # Configurations for a date time property.
        # Corresponds to the JSON property `dateTimeTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DateTimeTypeOptions]
        attr_accessor :date_time_type_options
      
        # The display-name for the property, used for front-end.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # Configurations for an enum/categorical property.
        # Corresponds to the JSON property `enumTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumTypeOptions]
        attr_accessor :enum_type_options
      
        # Configurations for a float property.
        # Corresponds to the JSON property `floatTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FloatTypeOptions]
        attr_accessor :float_type_options
      
        # Configurations for an integer property.
        # Corresponds to the JSON property `integerTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IntegerTypeOptions]
        attr_accessor :integer_type_options
      
        # Whether the property can be filtered. If this is a sub-property, all the
        # parent properties must be marked filterable.
        # Corresponds to the JSON property `isFilterable`
        # @return [Boolean]
        attr_accessor :is_filterable
        alias_method :is_filterable?, :is_filterable
      
        # Whether the property is user supplied metadata.
        # Corresponds to the JSON property `isMetadata`
        # @return [Boolean]
        attr_accessor :is_metadata
        alias_method :is_metadata?, :is_metadata
      
        # Whether the property can have multiple values.
        # Corresponds to the JSON property `isRepeatable`
        # @return [Boolean]
        attr_accessor :is_repeatable
        alias_method :is_repeatable?, :is_repeatable
      
        # Whether the property is mandatory. Default is 'false', i.e. populating
        # property value can be skipped. If 'true' then user must populate the value for
        # this property.
        # Corresponds to the JSON property `isRequired`
        # @return [Boolean]
        attr_accessor :is_required
        alias_method :is_required?, :is_required
      
        # Indicates that the property should be included in a global search.
        # Corresponds to the JSON property `isSearchable`
        # @return [Boolean]
        attr_accessor :is_searchable
        alias_method :is_searchable?, :is_searchable
      
        # Configurations for a Map property.
        # Corresponds to the JSON property `mapTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapTypeOptions]
        attr_accessor :map_type_options
      
        # Required. The name of the metadata property. Must be unique within a document
        # schema and is case insensitive. Names must be non-blank, start with a letter,
        # and can contain alphanumeric characters and: /, :, -, _, and .
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Configurations for a nested structured data property.
        # Corresponds to the JSON property `propertyTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyTypeOptions]
        attr_accessor :property_type_options
      
        # Configurations for a text property.
        # Corresponds to the JSON property `textTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TextTypeOptions]
        attr_accessor :text_type_options
      
        # Configurations for a timestamp property.
        # Corresponds to the JSON property `timestampTypeOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampTypeOptions]
        attr_accessor :timestamp_type_options
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_time_type_options = args[:date_time_type_options] if args.key?(:date_time_type_options)
          @display_name = args[:display_name] if args.key?(:display_name)
          @enum_type_options = args[:enum_type_options] if args.key?(:enum_type_options)
          @float_type_options = args[:float_type_options] if args.key?(:float_type_options)
          @integer_type_options = args[:integer_type_options] if args.key?(:integer_type_options)
          @is_filterable = args[:is_filterable] if args.key?(:is_filterable)
          @is_metadata = args[:is_metadata] if args.key?(:is_metadata)
          @is_repeatable = args[:is_repeatable] if args.key?(:is_repeatable)
          @is_required = args[:is_required] if args.key?(:is_required)
          @is_searchable = args[:is_searchable] if args.key?(:is_searchable)
          @map_type_options = args[:map_type_options] if args.key?(:map_type_options)
          @name = args[:name] if args.key?(:name)
          @property_type_options = args[:property_type_options] if args.key?(:property_type_options)
          @text_type_options = args[:text_type_options] if args.key?(:text_type_options)
          @timestamp_type_options = args[:timestamp_type_options] if args.key?(:timestamp_type_options)
        end
      end
      
      # 
      class GoogleCloudContentwarehouseV1PropertyFilter
        include Google::Apis::Core::Hashable
      
        # The filter condition. The syntax for this expression is a subset of SQL syntax.
        # Supported operators are: `=`, `!=`, `<`, `<=`, `>`, `>=`, and `~~` where the
        # left of the operator is a property name and the right of the operator is a
        # number or a quoted string. You must escape backslash (\\) and quote (\")
        # characters. `~~` is the LIKE operator. The right of the operator must be a
        # string. The only supported property data type for LIKE is text_values. It
        # provides semantic search functionality by parsing, stemming and doing synonyms
        # expansion against the input query. It matches if the property contains
        # semantic similar content to the query. It is not regex matching or wildcard
        # matching. For example, "property.company ~~ \"google\"" will match records
        # whose property `property.compnay` have values like "Google Inc.", "Google LLC"
        # or "Google Company". Supported functions are `LOWER([property_name])` to
        # perform a case insensitive match and `EMPTY([property_name])` to filter on the
        # existence of a key. Boolean expressions (AND/OR/NOT) are supported up to 3
        # levels of nesting (for example, "((A AND B AND C) OR NOT D) AND E"), a maximum
        # of 100 comparisons or functions are allowed in the expression. The expression
        # must be < 6000 bytes in length. Only properties that are marked filterable are
        # allowed (PropertyDefinition.is_filterable). Property names do not need to be
        # prefixed by the document schema id (as is the case with histograms), however
        # property names will need to be prefixed by its parent hierarchy, if any. For
        # example: top_property_name.sub_property_name. Sample Query: `(LOWER(
        # driving_license)="class \"a\"" OR EMPTY(driving_license)) AND driving_years >
        # 10` CMEK compliant deployment only supports: * Operators: `=`, `<`, `<=`, `>`,
        # and `>=`. * Boolean expressions: AND and OR.
        # Corresponds to the JSON property `condition`
        # @return [String]
        attr_accessor :condition
      
        # The Document schema name Document.document_schema_name. Format: projects/`
        # project_number`/locations/`location`/documentSchemas/`document_schema_id`.
        # Corresponds to the JSON property `documentSchemaName`
        # @return [String]
        attr_accessor :document_schema_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @condition = args[:condition] if args.key?(:condition)
          @document_schema_name = args[:document_schema_name] if args.key?(:document_schema_name)
        end
      end
      
      # Configurations for a nested structured data property.
      class GoogleCloudContentwarehouseV1PropertyTypeOptions
        include Google::Apis::Core::Hashable
      
        # Required. List of property definitions.
        # Corresponds to the JSON property `propertyDefinitions`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition>]
        attr_accessor :property_definitions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @property_definitions = args[:property_definitions] if args.key?(:property_definitions)
        end
      end
      
      # Represents the action responsible for publishing messages to a Pub/Sub topic.
      class GoogleCloudContentwarehouseV1PublishAction
        include Google::Apis::Core::Hashable
      
        # Messages to be published.
        # Corresponds to the JSON property `messages`
        # @return [Array<String>]
        attr_accessor :messages
      
        # The topic id in the Pub/Sub service for which messages will be published to.
        # Corresponds to the JSON property `topicId`
        # @return [String]
        attr_accessor :topic_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @messages = args[:messages] if args.key?(:messages)
          @topic_id = args[:topic_id] if args.key?(:topic_id)
        end
      end
      
      # Additional result info for the question-answering feature.
      class GoogleCloudContentwarehouseV1QaResult
        include Google::Apis::Core::Hashable
      
        # The calibrated confidence score for this document, in the range [0., 1.]. This
        # represents the confidence level for whether the returned document and snippet
        # answers the user's query.
        # Corresponds to the JSON property `confidenceScore`
        # @return [Float]
        attr_accessor :confidence_score
      
        # Highlighted sections in the snippet.
        # Corresponds to the JSON property `highlights`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1QaResultHighlight>]
        attr_accessor :highlights
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
          @highlights = args[:highlights] if args.key?(:highlights)
        end
      end
      
      # A text span in the search text snippet that represents a highlighted section (
      # answer context, highly relevant sentence, etc.).
      class GoogleCloudContentwarehouseV1QaResultHighlight
        include Google::Apis::Core::Hashable
      
        # End index of the highlight, exclusive.
        # Corresponds to the JSON property `endIndex`
        # @return [Fixnum]
        attr_accessor :end_index
      
        # Start index of the highlight.
        # Corresponds to the JSON property `startIndex`
        # @return [Fixnum]
        attr_accessor :start_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_index = args[:end_index] if args.key?(:end_index)
          @start_index = args[:start_index] if args.key?(:start_index)
        end
      end
      
      # Represents the action responsible for remove a document from a specific folder.
      class GoogleCloudContentwarehouseV1RemoveFromFolderAction
        include Google::Apis::Core::Hashable
      
        # Condition of the action to be executed.
        # Corresponds to the JSON property `condition`
        # @return [String]
        attr_accessor :condition
      
        # Name of the folder under which new document is to be added. Format: projects/`
        # project_number`/locations/`location`/documents/`document_id`.
        # Corresponds to the JSON property `folder`
        # @return [String]
        attr_accessor :folder
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @condition = args[:condition] if args.key?(:condition)
          @folder = args[:folder] if args.key?(:folder)
        end
      end
      
      # Meta information is used to improve the performance of the service.
      class GoogleCloudContentwarehouseV1RequestMetadata
        include Google::Apis::Core::Hashable
      
        # Provides user unique identification and groups information.
        # Corresponds to the JSON property `userInfo`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UserInfo]
        attr_accessor :user_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @user_info = args[:user_info] if args.key?(:user_info)
        end
      end
      
      # Additional information returned to client, such as debugging information.
      class GoogleCloudContentwarehouseV1ResponseMetadata
        include Google::Apis::Core::Hashable
      
        # A unique id associated with this call. This id is logged for tracking purpose.
        # Corresponds to the JSON property `requestId`
        # @return [String]
        attr_accessor :request_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @request_id = args[:request_id] if args.key?(:request_id)
        end
      end
      
      # Represents the rule for a content warehouse trigger.
      class GoogleCloudContentwarehouseV1Rule
        include Google::Apis::Core::Hashable
      
        # List of actions that are executed when the rule is satisfied.
        # Corresponds to the JSON property `actions`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Action>]
        attr_accessor :actions
      
        # Represents the conditional expression to be evaluated. Expression should
        # evaluate to a boolean result. When the condition is true actions are executed.
        # Example: user_role = "hsbc_role_1" AND doc.salary > 20000
        # Corresponds to the JSON property `condition`
        # @return [String]
        attr_accessor :condition
      
        # Short description of the rule and its context.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # ID of the rule. It has to be unique across all the examples. This is managed
        # internally.
        # Corresponds to the JSON property `ruleId`
        # @return [String]
        attr_accessor :rule_id
      
        # Identifies the trigger type for running the policy.
        # Corresponds to the JSON property `triggerType`
        # @return [String]
        attr_accessor :trigger_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @actions = args[:actions] if args.key?(:actions)
          @condition = args[:condition] if args.key?(:condition)
          @description = args[:description] if args.key?(:description)
          @rule_id = args[:rule_id] if args.key?(:rule_id)
          @trigger_type = args[:trigger_type] if args.key?(:trigger_type)
        end
      end
      
      # Represents a rule and outputs of associated actions.
      class GoogleCloudContentwarehouseV1RuleActionsPair
        include Google::Apis::Core::Hashable
      
        # Outputs of executing the actions associated with the above rule.
        # Corresponds to the JSON property `actionOutputs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionOutput>]
        attr_accessor :action_outputs
      
        # Represents the rule for a content warehouse trigger.
        # Corresponds to the JSON property `rule`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule]
        attr_accessor :rule
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_outputs = args[:action_outputs] if args.key?(:action_outputs)
          @rule = args[:rule] if args.key?(:rule)
        end
      end
      
      # Records the output of Rule Engine including rule evaluation and actions result.
      class GoogleCloudContentwarehouseV1RuleEngineOutput
        include Google::Apis::Core::Hashable
      
        # Represents the output of the Action Executor.
        # Corresponds to the JSON property `actionExecutorOutput`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionExecutorOutput]
        attr_accessor :action_executor_output
      
        # Name of the document against which the rules and actions were evaluated.
        # Corresponds to the JSON property `documentName`
        # @return [String]
        attr_accessor :document_name
      
        # Represents the output of the Rule Evaluator.
        # Corresponds to the JSON property `ruleEvaluatorOutput`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEvaluatorOutput]
        attr_accessor :rule_evaluator_output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_executor_output = args[:action_executor_output] if args.key?(:action_executor_output)
          @document_name = args[:document_name] if args.key?(:document_name)
          @rule_evaluator_output = args[:rule_evaluator_output] if args.key?(:rule_evaluator_output)
        end
      end
      
      # Represents the output of the Rule Evaluator.
      class GoogleCloudContentwarehouseV1RuleEvaluatorOutput
        include Google::Apis::Core::Hashable
      
        # A subset of triggered rules that failed the validation check(s) after parsing.
        # Corresponds to the JSON property `invalidRules`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1InvalidRule>]
        attr_accessor :invalid_rules
      
        # A subset of triggered rules that are evaluated true for a given request.
        # Corresponds to the JSON property `matchedRules`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>]
        attr_accessor :matched_rules
      
        # List of rules fetched from database for the given request trigger type.
        # Corresponds to the JSON property `triggeredRules`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>]
        attr_accessor :triggered_rules
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @invalid_rules = args[:invalid_rules] if args.key?(:invalid_rules)
          @matched_rules = args[:matched_rules] if args.key?(:matched_rules)
          @triggered_rules = args[:triggered_rules] if args.key?(:triggered_rules)
        end
      end
      
      # Represents a set of rules from a single customer. Next id: 9
      class GoogleCloudContentwarehouseV1RuleSet
        include Google::Apis::Core::Hashable
      
        # Short description of the rule-set.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The resource name of the rule set. Managed internally. Format: projects/`
        # project_number`/locations/`location`/ruleSet/`rule_set_id`. The name is
        # ignored when creating a rule set.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # List of rules given by the customer.
        # Corresponds to the JSON property `rules`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>]
        attr_accessor :rules
      
        # Source of the rules i.e., customer name.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @name = args[:name] if args.key?(:name)
          @rules = args[:rules] if args.key?(:rules)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class GoogleCloudContentwarehouseV1SearchDocumentsRequest
        include Google::Apis::Core::Hashable
      
        # NEXT_ID: 13
        # Corresponds to the JSON property `documentQuery`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentQuery]
        attr_accessor :document_query
      
        # An expression specifying a histogram request against matching documents.
        # Expression syntax is an aggregation function call with histogram facets and
        # other options. The following aggregation functions are supported: * `count(
        # string_histogram_facet)`: Count the number of matching entities for each
        # distinct attribute value. Data types: * Histogram facet (aka filterable
        # properties): Facet names with format <schema id>.<facet>. Facets will have the
        # format of: a-zA-Z. If the facet is a child facet, then the parent hierarchy
        # needs to be specified separated by dots in the prefix after the schema id.
        # Thus, the format for a multi- level facet is: <schema id>.<parent facet name>.
        # <child facet name>. Example: schema123.root_parent_facet.middle_facet.
        # child_facet * DocumentSchemaId: (with no schema id prefix) to get histograms
        # for each document type (returns the schema id path, e.g. projects/12345/
        # locations/us-west/documentSchemas/abc123). Example expression: * Document type
        # counts: count('DocumentSchemaId') * For schema id, abc123, get the counts for
        # MORTGAGE_TYPE: count('abc123.MORTGAGE_TYPE')
        # Corresponds to the JSON property `histogramQueries`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQuery>]
        attr_accessor :histogram_queries
      
        # An integer that specifies the current offset (that is, starting result
        # location, amongst the documents deemed by the API as relevant) in search
        # results. This field is only considered if page_token is unset. The maximum
        # allowed value is 5000. Otherwise an error is thrown. For example, 0 means to
        # return results starting from the first matching document, and 10 means to
        # return from the 11th document. This can be used for pagination, (for example,
        # pageSize = 10 and offset = 10 means to return from the second page).
        # Corresponds to the JSON property `offset`
        # @return [Fixnum]
        attr_accessor :offset
      
        # The criteria determining how search results are sorted. For non-empty query,
        # default is `"relevance desc"`. For empty query, default is `"upload_date desc"`
        # . Supported options are: * `"relevance desc"`: By relevance descending, as
        # determined by the API algorithms. * `"upload_date desc"`: By upload date
        # descending. * `"upload_date"`: By upload date ascending. * `"update_date desc"`
        # : By last updated date descending. * `"update_date"`: By last updated date
        # ascending.
        # Corresponds to the JSON property `orderBy`
        # @return [String]
        attr_accessor :order_by
      
        # A limit on the number of documents returned in the search results. Increasing
        # this value above the default value of 10 can increase search response time.
        # The value can be between 1 and 100.
        # Corresponds to the JSON property `pageSize`
        # @return [Fixnum]
        attr_accessor :page_size
      
        # The token specifying the current offset within search results. See
        # SearchDocumentsResponse.next_page_token for an explanation of how to obtain
        # the next set of query results.
        # Corresponds to the JSON property `pageToken`
        # @return [String]
        attr_accessor :page_token
      
        # Experimental, do not use. The limit on the number of documents returned for
        # the question-answering feature. To enable the question-answering feature, set [
        # DocumentQuery].is_nl_query to true.
        # Corresponds to the JSON property `qaSizeLimit`
        # @return [Fixnum]
        attr_accessor :qa_size_limit
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        # Optional. Controls if the search document request requires the return of a
        # total size of matched documents. See SearchDocumentsResponse.total_size.
        # Enabling this flag may adversely impact performance. Defaults to false.
        # Corresponds to the JSON property `requireTotalSize`
        # @return [Boolean]
        attr_accessor :require_total_size
        alias_method :require_total_size?, :require_total_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_query = args[:document_query] if args.key?(:document_query)
          @histogram_queries = args[:histogram_queries] if args.key?(:histogram_queries)
          @offset = args[:offset] if args.key?(:offset)
          @order_by = args[:order_by] if args.key?(:order_by)
          @page_size = args[:page_size] if args.key?(:page_size)
          @page_token = args[:page_token] if args.key?(:page_token)
          @qa_size_limit = args[:qa_size_limit] if args.key?(:qa_size_limit)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
          @require_total_size = args[:require_total_size] if args.key?(:require_total_size)
        end
      end
      
      # Response message for DocumentService.SearchDocuments.
      class GoogleCloudContentwarehouseV1SearchDocumentsResponse
        include Google::Apis::Core::Hashable
      
        # The histogram results that match with the specified SearchDocumentsRequest.
        # histogram_queries.
        # Corresponds to the JSON property `histogramQueryResults`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryResult>]
        attr_accessor :histogram_query_results
      
        # The document entities that match the specified SearchDocumentsRequest.
        # Corresponds to the JSON property `matchingDocuments`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument>]
        attr_accessor :matching_documents
      
        # Additional information returned to client, such as debugging information.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata]
        attr_accessor :metadata
      
        # The token that specifies the starting position of the next page of results.
        # This field is empty if there are no more results.
        # Corresponds to the JSON property `nextPageToken`
        # @return [String]
        attr_accessor :next_page_token
      
        # The total number of matched documents which is available only if the client
        # set SearchDocumentsRequest.require_total_size to `true`. Otherwise, the value
        # will be `-1`.
        # Corresponds to the JSON property `totalSize`
        # @return [Fixnum]
        attr_accessor :total_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @histogram_query_results = args[:histogram_query_results] if args.key?(:histogram_query_results)
          @matching_documents = args[:matching_documents] if args.key?(:matching_documents)
          @metadata = args[:metadata] if args.key?(:metadata)
          @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
          @total_size = args[:total_size] if args.key?(:total_size)
        end
      end
      
      # Document entry with metadata inside SearchDocumentsResponse
      class GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument
        include Google::Apis::Core::Hashable
      
        # Defines the structure for content warehouse document proto. Next ID: 20
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document]
        attr_accessor :document
      
        # Additional result info for the question-answering feature.
        # Corresponds to the JSON property `qaResult`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1QaResult]
        attr_accessor :qa_result
      
        # Contains snippets of text from the document full raw text that most closely
        # match a search query's keywords, if available. All HTML tags in the original
        # fields are stripped when returned in this field, and matching query keywords
        # are enclosed in HTML bold tags. If the question-answering feature is enabled,
        # this field will instead contain a snippet that answers the user's natural-
        # language query. No HTML bold tags will be present, and highlights in the
        # answer snippet can be found in QAResult.highlights.
        # Corresponds to the JSON property `searchTextSnippet`
        # @return [String]
        attr_accessor :search_text_snippet
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document = args[:document] if args.key?(:document)
          @qa_result = args[:qa_result] if args.key?(:qa_result)
          @search_text_snippet = args[:search_text_snippet] if args.key?(:search_text_snippet)
        end
      end
      
      # Request message for DocumentService.SetAcl.
      class GoogleCloudContentwarehouseV1SetAclRequest
        include Google::Apis::Core::Hashable
      
        # An Identity and Access Management (IAM) policy, which specifies access
        # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
        # A `binding` binds one or more `members`, or principals, to a single `role`.
        # Principals can be user accounts, service accounts, Google groups, and domains (
        # such as G Suite). A `role` is a named list of permissions; each `role` can be
        # an IAM predefined role or a user-created custom role. For some types of Google
        # Cloud resources, a `binding` can also specify a `condition`, which is a
        # logical expression that allows access to a resource only if the expression
        # evaluates to `true`. A condition can add constraints based on attributes of
        # the request, the resource, or both. To learn which resources support
        # conditions in their IAM policies, see the [IAM documentation](https://cloud.
        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
        # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
        # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
        # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
        # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
        # ], "condition": ` "title": "expirable access", "description": "Does not grant
        # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
        # bindings: - members: - user:mike@example.com - group:admins@example.com -
        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
        # access description: Does not grant access after Sep 2020 expression: request.
        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
        # a description of IAM and its features, see the [IAM documentation](https://
        # cloud.google.com/iam/docs/).
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleIamV1Policy]
        attr_accessor :policy
      
        # For Set Project ACL only. Authorization check for end user will be ignored
        # when project_owner=true.
        # Corresponds to the JSON property `projectOwner`
        # @return [Boolean]
        attr_accessor :project_owner
        alias_method :project_owner?, :project_owner
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @policy = args[:policy] if args.key?(:policy)
          @project_owner = args[:project_owner] if args.key?(:project_owner)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
        end
      end
      
      # Response message for DocumentService.SetAcl.
      class GoogleCloudContentwarehouseV1SetAclResponse
        include Google::Apis::Core::Hashable
      
        # Additional information returned to client, such as debugging information.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata]
        attr_accessor :metadata
      
        # An Identity and Access Management (IAM) policy, which specifies access
        # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
        # A `binding` binds one or more `members`, or principals, to a single `role`.
        # Principals can be user accounts, service accounts, Google groups, and domains (
        # such as G Suite). A `role` is a named list of permissions; each `role` can be
        # an IAM predefined role or a user-created custom role. For some types of Google
        # Cloud resources, a `binding` can also specify a `condition`, which is a
        # logical expression that allows access to a resource only if the expression
        # evaluates to `true`. A condition can add constraints based on attributes of
        # the request, the resource, or both. To learn which resources support
        # conditions in their IAM policies, see the [IAM documentation](https://cloud.
        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
        # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
        # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
        # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
        # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
        # ], "condition": ` "title": "expirable access", "description": "Does not grant
        # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
        # bindings: - members: - user:mike@example.com - group:admins@example.com -
        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
        # access description: Does not grant access after Sep 2020 expression: request.
        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
        # a description of IAM and its features, see the [IAM documentation](https://
        # cloud.google.com/iam/docs/).
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleIamV1Policy]
        attr_accessor :policy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @policy = args[:policy] if args.key?(:policy)
        end
      end
      
      # Represents a list of synonyms for a given context. For example a context "
      # sales" could contain: Synonym 1: sale, invoice, bill, order Synonym 2: money,
      # credit, finance, payment Synonym 3: shipping, freight, transport Each
      # SynonymSets should be disjoint
      class GoogleCloudContentwarehouseV1SynonymSet
        include Google::Apis::Core::Hashable
      
        # This is a freeform field. Example contexts can be "sales," "engineering," "
        # real estate," "accounting," etc. The context can be supplied during search
        # requests.
        # Corresponds to the JSON property `context`
        # @return [String]
        attr_accessor :context
      
        # The resource name of the SynonymSet This is mandatory for google.api.resource.
        # Format: projects/`project_number`/locations/`location`/synonymSets/`context`.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # List of Synonyms for the context.
        # Corresponds to the JSON property `synonyms`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSetSynonym>]
        attr_accessor :synonyms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @context = args[:context] if args.key?(:context)
          @name = args[:name] if args.key?(:name)
          @synonyms = args[:synonyms] if args.key?(:synonyms)
        end
      end
      
      # Represents a list of words given by the customer All these words are synonyms
      # of each other.
      class GoogleCloudContentwarehouseV1SynonymSetSynonym
        include Google::Apis::Core::Hashable
      
        # For example: sale, invoice, bill, order
        # Corresponds to the JSON property `words`
        # @return [Array<String>]
        attr_accessor :words
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @words = args[:words] if args.key?(:words)
        end
      end
      
      # String/text values.
      class GoogleCloudContentwarehouseV1TextArray
        include Google::Apis::Core::Hashable
      
        # List of text values.
        # Corresponds to the JSON property `values`
        # @return [Array<String>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for a text property.
      class GoogleCloudContentwarehouseV1TextTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Filter on create timestamp or update timestamp of documents.
      class GoogleCloudContentwarehouseV1TimeFilter
        include Google::Apis::Core::Hashable
      
        # Specifies which time field to filter documents on. Defaults to TimeField.
        # UPLOAD_TIME.
        # Corresponds to the JSON property `timeField`
        # @return [String]
        attr_accessor :time_field
      
        # Represents a time interval, encoded as a Timestamp start (inclusive) and a
        # Timestamp end (exclusive). The start must be less than or equal to the end.
        # When the start equals the end, the interval is empty (matches no time). When
        # both start and end are unspecified, the interval matches any time.
        # Corresponds to the JSON property `timeRange`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeInterval]
        attr_accessor :time_range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @time_field = args[:time_field] if args.key?(:time_field)
          @time_range = args[:time_range] if args.key?(:time_range)
        end
      end
      
      # Timestamp values.
      class GoogleCloudContentwarehouseV1TimestampArray
        include Google::Apis::Core::Hashable
      
        # List of timestamp values.
        # Corresponds to the JSON property `values`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Configurations for a timestamp property.
      class GoogleCloudContentwarehouseV1TimestampTypeOptions
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Timestamp value type.
      class GoogleCloudContentwarehouseV1TimestampValue
        include Google::Apis::Core::Hashable
      
        # The string must represent a valid instant in UTC and is parsed using java.time.
        # format.DateTimeFormatter.ISO_INSTANT. e.g. "2013-09-29T18:46:19Z"
        # Corresponds to the JSON property `textValue`
        # @return [String]
        attr_accessor :text_value
      
        # Timestamp value
        # Corresponds to the JSON property `timestampValue`
        # @return [String]
        attr_accessor :timestamp_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text_value = args[:text_value] if args.key?(:text_value)
          @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
        end
      end
      
      # Metadata object for UpdateDocument request (currently empty).
      class GoogleCloudContentwarehouseV1UpdateDocumentMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Request message for DocumentService.UpdateDocument.
      class GoogleCloudContentwarehouseV1UpdateDocumentRequest
        include Google::Apis::Core::Hashable
      
        # Request Option for processing Cloud AI Document in CW Document.
        # Corresponds to the JSON property `cloudAiDocumentOption`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CloudAiDocumentOption]
        attr_accessor :cloud_ai_document_option
      
        # Defines the structure for content warehouse document proto. Next ID: 20
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document]
        attr_accessor :document
      
        # Meta information is used to improve the performance of the service.
        # Corresponds to the JSON property `requestMetadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata]
        attr_accessor :request_metadata
      
        # Options for Update operations.
        # Corresponds to the JSON property `updateOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateOptions]
        attr_accessor :update_options
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_ai_document_option = args[:cloud_ai_document_option] if args.key?(:cloud_ai_document_option)
          @document = args[:document] if args.key?(:document)
          @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
          @update_options = args[:update_options] if args.key?(:update_options)
        end
      end
      
      # Response message for DocumentService.UpdateDocument.
      class GoogleCloudContentwarehouseV1UpdateDocumentResponse
        include Google::Apis::Core::Hashable
      
        # Defines the structure for content warehouse document proto. Next ID: 20
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document]
        attr_accessor :document
      
        # Additional information returned to client, such as debugging information.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata]
        attr_accessor :metadata
      
        # Records the output of Rule Engine including rule evaluation and actions result.
        # Corresponds to the JSON property `ruleEngineOutput`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput]
        attr_accessor :rule_engine_output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document = args[:document] if args.key?(:document)
          @metadata = args[:metadata] if args.key?(:metadata)
          @rule_engine_output = args[:rule_engine_output] if args.key?(:rule_engine_output)
        end
      end
      
      # Request message for DocumentSchemaService.UpdateDocumentSchema.
      class GoogleCloudContentwarehouseV1UpdateDocumentSchemaRequest
        include Google::Apis::Core::Hashable
      
        # A document schema used to define document structure.
        # Corresponds to the JSON property `documentSchema`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema]
        attr_accessor :document_schema
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_schema = args[:document_schema] if args.key?(:document_schema)
        end
      end
      
      # Options for Update operations.
      class GoogleCloudContentwarehouseV1UpdateOptions
        include Google::Apis::Core::Hashable
      
        # Options for merging updated fields.
        # Corresponds to the JSON property `mergeFieldsOptions`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MergeFieldsOptions]
        attr_accessor :merge_fields_options
      
        # Field mask for merging Document fields. For the `FieldMask` definition, see
        # https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#
        # fieldmask
        # Corresponds to the JSON property `updateMask`
        # @return [String]
        attr_accessor :update_mask
      
        # Type for update.
        # Corresponds to the JSON property `updateType`
        # @return [String]
        attr_accessor :update_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @merge_fields_options = args[:merge_fields_options] if args.key?(:merge_fields_options)
          @update_mask = args[:update_mask] if args.key?(:update_mask)
          @update_type = args[:update_type] if args.key?(:update_type)
        end
      end
      
      # Request message for RuleSetService.UpdateRuleSet.
      class GoogleCloudContentwarehouseV1UpdateRuleSetRequest
        include Google::Apis::Core::Hashable
      
        # Represents a set of rules from a single customer. Next id: 9
        # Corresponds to the JSON property `ruleSet`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet]
        attr_accessor :rule_set
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @rule_set = args[:rule_set] if args.key?(:rule_set)
        end
      end
      
      # 
      class GoogleCloudContentwarehouseV1UserInfo
        include Google::Apis::Core::Hashable
      
        # The unique group identifications which the user is belong to. The format is "
        # group:yyyy@example.com";
        # Corresponds to the JSON property `groupIds`
        # @return [Array<String>]
        attr_accessor :group_ids
      
        # A unique user identification string, as determined by the client. The maximum
        # number of allowed characters is 255. Allowed characters include numbers 0 to 9,
        # uppercase and lowercase letters, and restricted special symbols (:, @, +, -,
        # _, ~) The format is "user:xxxx@example.com";
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @group_ids = args[:group_ids] if args.key?(:group_ids)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # `Value` represents a dynamically typed value which can be either be a float, a
      # integer, a string, or a datetime value. A producer of value is expected to set
      # one of these variants. Absence of any variant indicates an error.
      class GoogleCloudContentwarehouseV1Value
        include Google::Apis::Core::Hashable
      
        # Represents a boolean value.
        # Corresponds to the JSON property `booleanValue`
        # @return [Boolean]
        attr_accessor :boolean_value
        alias_method :boolean_value?, :boolean_value
      
        # Represents civil time (or occasionally physical time). This type can represent
        # a civil time in one of a few possible ways: * When utc_offset is set and
        # time_zone is unset: a civil time on a calendar day with a particular offset
        # from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
        # calendar day in a particular time zone. * When neither time_zone nor
        # utc_offset is set: a civil time on a calendar day in local time. The date is
        # relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
        # the DateTime is considered not to have a specific year, month, or day
        # respectively. This type may also be used to represent a physical time if all
        # the date and time fields are set and either case of the `time_offset` oneof is
        # set. Consider using `Timestamp` message for physical time instead. If your use
        # case also would like to store the user's timezone, that can be done in another
        # field. This type is more flexible than some applications may want. Make sure
        # to document and validate your application's limitations.
        # Corresponds to the JSON property `datetimeValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDateTime]
        attr_accessor :datetime_value
      
        # Represents the string value of the enum field.
        # Corresponds to the JSON property `enumValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumValue]
        attr_accessor :enum_value
      
        # Represents a float value.
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # Represents a integer value.
        # Corresponds to the JSON property `intValue`
        # @return [Fixnum]
        attr_accessor :int_value
      
        # Represents a string value.
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # Timestamp value type.
        # Corresponds to the JSON property `timestampValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue]
        attr_accessor :timestamp_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
          @datetime_value = args[:datetime_value] if args.key?(:datetime_value)
          @enum_value = args[:enum_value] if args.key?(:enum_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @int_value = args[:int_value] if args.key?(:int_value)
          @string_value = args[:string_value] if args.key?(:string_value)
          @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
        end
      end
      
      # Metadata object for CreateDocument request (currently empty).
      class GoogleCloudContentwarehouseV1beta1CreateDocumentMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Response message for projectService.InitializeProject
      class GoogleCloudContentwarehouseV1beta1InitializeProjectResponse
        include Google::Apis::Core::Hashable
      
        # The message of the project initialization process.
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        # The state of the project initialization process.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message = args[:message] if args.key?(:message)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Metadata object for UpdateDocument request (currently empty).
      class GoogleCloudContentwarehouseV1beta1UpdateDocumentMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Encodes the detailed information of a barcode.
      class GoogleCloudDocumentaiV1Barcode
        include Google::Apis::Core::Hashable
      
        # Format of a barcode. The supported formats are: CODE_128: Code 128 type.
        # CODE_39: Code 39 type. CODE_93: Code 93 type. CODABAR: Codabar type.
        # DATA_MATRIX: 2D Data Matrix type. ITF: ITF type. EAN_13: EAN-13 type. EAN_8:
        # EAN-8 type. QR_CODE: 2D QR code type. UPC_A: UPC-A type. UPC_E: UPC-E type.
        # PDF417: PDF417 type. AZTEC: 2D Aztec code type. DATABAR: GS1 DataBar code type.
        # Corresponds to the JSON property `format`
        # @return [String]
        attr_accessor :format
      
        # Raw value encoded in the barcode. For example, 'MEBKM:TITLE:Google;URL:https://
        # www.google.com;;'.
        # Corresponds to the JSON property `rawValue`
        # @return [String]
        attr_accessor :raw_value
      
        # Value format describes the format of the value that a barcode encodes. The
        # supported formats are: CONTACT_INFO: Contact information. EMAIL: Email address.
        # ISBN: ISBN identifier. PHONE: Phone number. PRODUCT: Product. SMS: SMS
        # message. TEXT: Text string. URL: URL address. WIFI: Wifi information. GEO: Geo-
        # localization. CALENDAR_EVENT: Calendar event. DRIVER_LICENSE: Driver's license.
        # Corresponds to the JSON property `valueFormat`
        # @return [String]
        attr_accessor :value_format
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @format = args[:format] if args.key?(:format)
          @raw_value = args[:raw_value] if args.key?(:raw_value)
          @value_format = args[:value_format] if args.key?(:value_format)
        end
      end
      
      # A bounding polygon for the detected image annotation.
      class GoogleCloudDocumentaiV1BoundingPoly
        include Google::Apis::Core::Hashable
      
        # The bounding polygon normalized vertices.
        # Corresponds to the JSON property `normalizedVertices`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1NormalizedVertex>]
        attr_accessor :normalized_vertices
      
        # The bounding polygon vertices.
        # Corresponds to the JSON property `vertices`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Vertex>]
        attr_accessor :vertices
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized_vertices = args[:normalized_vertices] if args.key?(:normalized_vertices)
          @vertices = args[:vertices] if args.key?(:vertices)
        end
      end
      
      # Document represents the canonical document resource in Document AI. It is an
      # interchange format that provides insights into documents and allows for
      # collaboration between users and Document AI to iterate and optimize for
      # quality.
      class GoogleCloudDocumentaiV1Document
        include Google::Apis::Core::Hashable
      
        # Optional. Inline document content, represented as a stream of bytes. Note: As
        # with all `bytes` fields, protobuffers use a pure binary representation,
        # whereas JSON representations use base64.
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # A list of entities detected on Document.text. For document shards, entities in
        # this list may cross shard boundaries.
        # Corresponds to the JSON property `entities`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity>]
        attr_accessor :entities
      
        # Placeholder. Relationship among Document.entities.
        # Corresponds to the JSON property `entityRelations`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntityRelation>]
        attr_accessor :entity_relations
      
        # The `Status` type defines a logical error model that is suitable for different
        # programming environments, including REST APIs and RPC APIs. It is used by [
        # gRPC](https://github.com/grpc). Each `Status` message contains three pieces of
        # data: error code, error message, and error details. You can find out more
        # about this error model and how to work with it in the [API Design Guide](https:
        # //cloud.google.com/apis/design/errors).
        # Corresponds to the JSON property `error`
        # @return [Google::Apis::ContentwarehouseV1::GoogleRpcStatus]
        attr_accessor :error
      
        # An IANA published MIME type (also referred to as media type). For more
        # information, see https://www.iana.org/assignments/media-types/media-types.
        # xhtml.
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # Visual page layout for the Document.
        # Corresponds to the JSON property `pages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPage>]
        attr_accessor :pages
      
        # Placeholder. Revision history of this document.
        # Corresponds to the JSON property `revisions`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevision>]
        attr_accessor :revisions
      
        # For a large document, sharding may be performed to produce several document
        # shards. Each document shard contains this field to detail which shard it is.
        # Corresponds to the JSON property `shardInfo`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentShardInfo]
        attr_accessor :shard_info
      
        # Optional. UTF-8 encoded text in reading order from the document.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Placeholder. A list of text corrections made to [Document.text]. This is
        # usually used for annotating corrections to OCR mistakes. Text changes for a
        # given revision may not overlap with each other.
        # Corresponds to the JSON property `textChanges`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextChange>]
        attr_accessor :text_changes
      
        # Placeholder. Styles for the Document.text.
        # Corresponds to the JSON property `textStyles`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentStyle>]
        attr_accessor :text_styles
      
        # Optional. Currently supports Google Cloud Storage URI of the form `gs://
        # bucket_name/object_name`. Object versioning is not supported. See [Google
        # Cloud Storage Request URIs](https://cloud.google.com/storage/docs/reference-
        # uris) for more info.
        # Corresponds to the JSON property `uri`
        # @return [String]
        attr_accessor :uri
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @entities = args[:entities] if args.key?(:entities)
          @entity_relations = args[:entity_relations] if args.key?(:entity_relations)
          @error = args[:error] if args.key?(:error)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @pages = args[:pages] if args.key?(:pages)
          @revisions = args[:revisions] if args.key?(:revisions)
          @shard_info = args[:shard_info] if args.key?(:shard_info)
          @text = args[:text] if args.key?(:text)
          @text_changes = args[:text_changes] if args.key?(:text_changes)
          @text_styles = args[:text_styles] if args.key?(:text_styles)
          @uri = args[:uri] if args.key?(:uri)
        end
      end
      
      # An entity that could be a phrase in the text or a property that belongs to the
      # document. It is a known entity type, such as a person, an organization, or
      # location.
      class GoogleCloudDocumentaiV1DocumentEntity
        include Google::Apis::Core::Hashable
      
        # Optional. Confidence of detected Schema entity. Range [0, 1].
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Optional. Canonical id. This will be a unique value in the entity list for
        # this document.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Optional. Deprecated. Use `id` field instead.
        # Corresponds to the JSON property `mentionId`
        # @return [String]
        attr_accessor :mention_id
      
        # Optional. Text value of the entity e.g. `1600 Amphitheatre Pkwy`.
        # Corresponds to the JSON property `mentionText`
        # @return [String]
        attr_accessor :mention_text
      
        # Parsed and normalized entity value.
        # Corresponds to the JSON property `normalizedValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue]
        attr_accessor :normalized_value
      
        # Referencing the visual context of the entity in the Document.pages. Page
        # anchors can be cross-page, consist of multiple bounding polygons and
        # optionally reference specific layout element types.
        # Corresponds to the JSON property `pageAnchor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageAnchor]
        attr_accessor :page_anchor
      
        # Optional. Entities can be nested to form a hierarchical data structure
        # representing the content in the document.
        # Corresponds to the JSON property `properties`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity>]
        attr_accessor :properties
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        # Optional. Whether the entity will be redacted for de-identification purposes.
        # Corresponds to the JSON property `redacted`
        # @return [Boolean]
        attr_accessor :redacted
        alias_method :redacted?, :redacted
      
        # Text reference indexing into the Document.text.
        # Corresponds to the JSON property `textAnchor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor]
        attr_accessor :text_anchor
      
        # Required. Entity type from a schema e.g. `Address`.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @id = args[:id] if args.key?(:id)
          @mention_id = args[:mention_id] if args.key?(:mention_id)
          @mention_text = args[:mention_text] if args.key?(:mention_text)
          @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
          @page_anchor = args[:page_anchor] if args.key?(:page_anchor)
          @properties = args[:properties] if args.key?(:properties)
          @provenance = args[:provenance] if args.key?(:provenance)
          @redacted = args[:redacted] if args.key?(:redacted)
          @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Parsed and normalized entity value.
      class GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
        include Google::Apis::Core::Hashable
      
        # Represents a postal address, e.g. for postal delivery or payments addresses.
        # Given a postal address, a postal service can deliver items to a premise, P.O.
        # Box or similar. It is not intended to model geographical locations (roads,
        # towns, mountains). In typical usage an address would be created via user input
        # or from importing existing data, depending on the type of process. Advice on
        # address input / editing: - Use an internationalization-ready address widget
        # such as https://github.com/google/libaddressinput) - Users should not be
        # presented with UI elements for input or editing of fields outside countries
        # where that field is used. For more guidance on how to use this schema, please
        # see: https://support.google.com/business/answer/6397478
        # Corresponds to the JSON property `addressValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypePostalAddress]
        attr_accessor :address_value
      
        # Boolean value. Can be used for entities with binary values, or for checkboxes.
        # Corresponds to the JSON property `booleanValue`
        # @return [Boolean]
        attr_accessor :boolean_value
        alias_method :boolean_value?, :boolean_value
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `dateValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :date_value
      
        # Represents civil time (or occasionally physical time). This type can represent
        # a civil time in one of a few possible ways: * When utc_offset is set and
        # time_zone is unset: a civil time on a calendar day with a particular offset
        # from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
        # calendar day in a particular time zone. * When neither time_zone nor
        # utc_offset is set: a civil time on a calendar day in local time. The date is
        # relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
        # the DateTime is considered not to have a specific year, month, or day
        # respectively. This type may also be used to represent a physical time if all
        # the date and time fields are set and either case of the `time_offset` oneof is
        # set. Consider using `Timestamp` message for physical time instead. If your use
        # case also would like to store the user's timezone, that can be done in another
        # field. This type is more flexible than some applications may want. Make sure
        # to document and validate your application's limitations.
        # Corresponds to the JSON property `datetimeValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDateTime]
        attr_accessor :datetime_value
      
        # Float value.
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # Integer value.
        # Corresponds to the JSON property `integerValue`
        # @return [Fixnum]
        attr_accessor :integer_value
      
        # Represents an amount of money with its currency type.
        # Corresponds to the JSON property `moneyValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeMoney]
        attr_accessor :money_value
      
        # Optional. An optional field to store a normalized string. For some entity
        # types, one of respective `structured_value` fields may also be populated. Also
        # not all the types of `structured_value` will be normalized. For example, some
        # processors may not generate float or int normalized text by default. Below are
        # sample formats mapped to structured values. - Money/Currency type (`
        # money_value`) is in the ISO 4217 text format. - Date type (`date_value`) is in
        # the ISO 8601 text format. - Datetime type (`datetime_value`) is in the ISO
        # 8601 text format.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address_value = args[:address_value] if args.key?(:address_value)
          @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
          @date_value = args[:date_value] if args.key?(:date_value)
          @datetime_value = args[:datetime_value] if args.key?(:datetime_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @integer_value = args[:integer_value] if args.key?(:integer_value)
          @money_value = args[:money_value] if args.key?(:money_value)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Relationship between Entities.
      class GoogleCloudDocumentaiV1DocumentEntityRelation
        include Google::Apis::Core::Hashable
      
        # Object entity id.
        # Corresponds to the JSON property `objectId`
        # @return [String]
        attr_accessor :object_id_prop
      
        # Relationship description.
        # Corresponds to the JSON property `relation`
        # @return [String]
        attr_accessor :relation
      
        # Subject entity id.
        # Corresponds to the JSON property `subjectId`
        # @return [String]
        attr_accessor :subject_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
          @relation = args[:relation] if args.key?(:relation)
          @subject_id = args[:subject_id] if args.key?(:subject_id)
        end
      end
      
      # A page in a Document.
      class GoogleCloudDocumentaiV1DocumentPage
        include Google::Apis::Core::Hashable
      
        # A list of visually detected text blocks on the page. A block has a set of
        # lines (collected into paragraphs) that have a common line-spacing and
        # orientation.
        # Corresponds to the JSON property `blocks`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageBlock>]
        attr_accessor :blocks
      
        # A list of detected barcodes.
        # Corresponds to the JSON property `detectedBarcodes`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedBarcode>]
        attr_accessor :detected_barcodes
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Dimension for the page.
        # Corresponds to the JSON property `dimension`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDimension]
        attr_accessor :dimension
      
        # A list of visually detected form fields on the page.
        # Corresponds to the JSON property `formFields`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageFormField>]
        attr_accessor :form_fields
      
        # Rendered image contents for this page.
        # Corresponds to the JSON property `image`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageImage]
        attr_accessor :image
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # A list of visually detected text lines on the page. A collection of tokens
        # that a human would perceive as a line.
        # Corresponds to the JSON property `lines`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLine>]
        attr_accessor :lines
      
        # 1-based index for current Page in a parent Document. Useful when a page is
        # taken out of a Document for individual processing.
        # Corresponds to the JSON property `pageNumber`
        # @return [Fixnum]
        attr_accessor :page_number
      
        # A list of visually detected text paragraphs on the page. A collection of lines
        # that a human would perceive as a paragraph.
        # Corresponds to the JSON property `paragraphs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageParagraph>]
        attr_accessor :paragraphs
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        # A list of visually detected symbols on the page.
        # Corresponds to the JSON property `symbols`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageSymbol>]
        attr_accessor :symbols
      
        # A list of visually detected tables on the page.
        # Corresponds to the JSON property `tables`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTable>]
        attr_accessor :tables
      
        # A list of visually detected tokens on the page.
        # Corresponds to the JSON property `tokens`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageToken>]
        attr_accessor :tokens
      
        # Transformation matrices that were applied to the original document image to
        # produce Page.image.
        # Corresponds to the JSON property `transforms`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageMatrix>]
        attr_accessor :transforms
      
        # A list of detected non-text visual elements e.g. checkbox, signature etc. on
        # the page.
        # Corresponds to the JSON property `visualElements`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageVisualElement>]
        attr_accessor :visual_elements
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blocks = args[:blocks] if args.key?(:blocks)
          @detected_barcodes = args[:detected_barcodes] if args.key?(:detected_barcodes)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @dimension = args[:dimension] if args.key?(:dimension)
          @form_fields = args[:form_fields] if args.key?(:form_fields)
          @image = args[:image] if args.key?(:image)
          @layout = args[:layout] if args.key?(:layout)
          @lines = args[:lines] if args.key?(:lines)
          @page_number = args[:page_number] if args.key?(:page_number)
          @paragraphs = args[:paragraphs] if args.key?(:paragraphs)
          @provenance = args[:provenance] if args.key?(:provenance)
          @symbols = args[:symbols] if args.key?(:symbols)
          @tables = args[:tables] if args.key?(:tables)
          @tokens = args[:tokens] if args.key?(:tokens)
          @transforms = args[:transforms] if args.key?(:transforms)
          @visual_elements = args[:visual_elements] if args.key?(:visual_elements)
        end
      end
      
      # Referencing the visual context of the entity in the Document.pages. Page
      # anchors can be cross-page, consist of multiple bounding polygons and
      # optionally reference specific layout element types.
      class GoogleCloudDocumentaiV1DocumentPageAnchor
        include Google::Apis::Core::Hashable
      
        # One or more references to visual page elements
        # Corresponds to the JSON property `pageRefs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageAnchorPageRef>]
        attr_accessor :page_refs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @page_refs = args[:page_refs] if args.key?(:page_refs)
        end
      end
      
      # Represents a weak reference to a page element within a document.
      class GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
        include Google::Apis::Core::Hashable
      
        # A bounding polygon for the detected image annotation.
        # Corresponds to the JSON property `boundingPoly`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1BoundingPoly]
        attr_accessor :bounding_poly
      
        # Optional. Confidence of detected page element, if applicable. Range [0, 1].
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Optional. Deprecated. Use PageRef.bounding_poly instead.
        # Corresponds to the JSON property `layoutId`
        # @return [String]
        attr_accessor :layout_id
      
        # Optional. The type of the layout element that is being referenced if any.
        # Corresponds to the JSON property `layoutType`
        # @return [String]
        attr_accessor :layout_type
      
        # Required. Index into the Document.pages element, for example using Document.
        # pages to locate the related page element. This field is skipped when its value
        # is the default 0. See https://developers.google.com/protocol-buffers/docs/
        # proto3#json.
        # Corresponds to the JSON property `page`
        # @return [Fixnum]
        attr_accessor :page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
          @confidence = args[:confidence] if args.key?(:confidence)
          @layout_id = args[:layout_id] if args.key?(:layout_id)
          @layout_type = args[:layout_type] if args.key?(:layout_type)
          @page = args[:page] if args.key?(:page)
        end
      end
      
      # A block has a set of lines (collected into paragraphs) that have a common line-
      # spacing and orientation.
      class GoogleCloudDocumentaiV1DocumentPageBlock
        include Google::Apis::Core::Hashable
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # A detected barcode.
      class GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
        include Google::Apis::Core::Hashable
      
        # Encodes the detailed information of a barcode.
        # Corresponds to the JSON property `barcode`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Barcode]
        attr_accessor :barcode
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @barcode = args[:barcode] if args.key?(:barcode)
          @layout = args[:layout] if args.key?(:layout)
        end
      end
      
      # Detected language for a structural component.
      class GoogleCloudDocumentaiV1DocumentPageDetectedLanguage
        include Google::Apis::Core::Hashable
      
        # Confidence of detected language. Range [0, 1].
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # The BCP-47 language code, such as "en-US" or "sr-Latn". For more information,
        # see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @language_code = args[:language_code] if args.key?(:language_code)
        end
      end
      
      # Dimension for the page.
      class GoogleCloudDocumentaiV1DocumentPageDimension
        include Google::Apis::Core::Hashable
      
        # Page height.
        # Corresponds to the JSON property `height`
        # @return [Float]
        attr_accessor :height
      
        # Dimension unit.
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # Page width.
        # Corresponds to the JSON property `width`
        # @return [Float]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @unit = args[:unit] if args.key?(:unit)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # A form field detected on the page.
      class GoogleCloudDocumentaiV1DocumentPageFormField
        include Google::Apis::Core::Hashable
      
        # Created for Labeling UI to export key text. If corrections were made to the
        # text identified by the `field_name.text_anchor`, this field will contain the
        # correction.
        # Corresponds to the JSON property `correctedKeyText`
        # @return [String]
        attr_accessor :corrected_key_text
      
        # Created for Labeling UI to export value text. If corrections were made to the
        # text identified by the `field_value.text_anchor`, this field will contain the
        # correction.
        # Corresponds to the JSON property `correctedValueText`
        # @return [String]
        attr_accessor :corrected_value_text
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `fieldName`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :field_name
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `fieldValue`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :field_value
      
        # A list of detected languages for name together with confidence.
        # Corresponds to the JSON property `nameDetectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :name_detected_languages
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        # A list of detected languages for value together with confidence.
        # Corresponds to the JSON property `valueDetectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :value_detected_languages
      
        # If the value is non-textual, this field represents the type. Current valid
        # values are: - blank (this indicates the field_value is normal text) - "
        # unfilled_checkbox" - "filled_checkbox"
        # Corresponds to the JSON property `valueType`
        # @return [String]
        attr_accessor :value_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @corrected_key_text = args[:corrected_key_text] if args.key?(:corrected_key_text)
          @corrected_value_text = args[:corrected_value_text] if args.key?(:corrected_value_text)
          @field_name = args[:field_name] if args.key?(:field_name)
          @field_value = args[:field_value] if args.key?(:field_value)
          @name_detected_languages = args[:name_detected_languages] if args.key?(:name_detected_languages)
          @provenance = args[:provenance] if args.key?(:provenance)
          @value_detected_languages = args[:value_detected_languages] if args.key?(:value_detected_languages)
          @value_type = args[:value_type] if args.key?(:value_type)
        end
      end
      
      # Rendered image contents for this page.
      class GoogleCloudDocumentaiV1DocumentPageImage
        include Google::Apis::Core::Hashable
      
        # Raw byte content of the image.
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # Height of the image in pixels.
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Encoding mime type for the image.
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # Width of the image in pixels.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @height = args[:height] if args.key?(:height)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Visual element describing a layout unit on a page.
      class GoogleCloudDocumentaiV1DocumentPageLayout
        include Google::Apis::Core::Hashable
      
        # A bounding polygon for the detected image annotation.
        # Corresponds to the JSON property `boundingPoly`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1BoundingPoly]
        attr_accessor :bounding_poly
      
        # Confidence of the current Layout within context of the object this layout is
        # for. e.g. confidence can be for a single token, a table, a visual element, etc.
        # depending on context. Range [0, 1].
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Detected orientation for the Layout.
        # Corresponds to the JSON property `orientation`
        # @return [String]
        attr_accessor :orientation
      
        # Text reference indexing into the Document.text.
        # Corresponds to the JSON property `textAnchor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor]
        attr_accessor :text_anchor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
          @confidence = args[:confidence] if args.key?(:confidence)
          @orientation = args[:orientation] if args.key?(:orientation)
          @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
        end
      end
      
      # A collection of tokens that a human would perceive as a line. Does not cross
      # column boundaries, can be horizontal, vertical, etc.
      class GoogleCloudDocumentaiV1DocumentPageLine
        include Google::Apis::Core::Hashable
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # Representation for transformation matrix, intended to be compatible and used
      # with OpenCV format for image manipulation.
      class GoogleCloudDocumentaiV1DocumentPageMatrix
        include Google::Apis::Core::Hashable
      
        # Number of columns in the matrix.
        # Corresponds to the JSON property `cols`
        # @return [Fixnum]
        attr_accessor :cols
      
        # The matrix data.
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # Number of rows in the matrix.
        # Corresponds to the JSON property `rows`
        # @return [Fixnum]
        attr_accessor :rows
      
        # This encodes information about what data type the matrix uses. For example, 0 (
        # CV_8U) is an unsigned 8-bit image. For the full list of OpenCV primitive data
        # types, please refer to https://docs.opencv.org/4.3.0/d1/d1b/
        # group__core__hal__interface.html
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cols = args[:cols] if args.key?(:cols)
          @data = args[:data] if args.key?(:data)
          @rows = args[:rows] if args.key?(:rows)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A collection of lines that a human would perceive as a paragraph.
      class GoogleCloudDocumentaiV1DocumentPageParagraph
        include Google::Apis::Core::Hashable
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # A detected symbol.
      class GoogleCloudDocumentaiV1DocumentPageSymbol
        include Google::Apis::Core::Hashable
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
        end
      end
      
      # A table representation similar to HTML table structure.
      class GoogleCloudDocumentaiV1DocumentPageTable
        include Google::Apis::Core::Hashable
      
        # Body rows of the table.
        # Corresponds to the JSON property `bodyRows`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>]
        attr_accessor :body_rows
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Header rows of the table.
        # Corresponds to the JSON property `headerRows`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>]
        attr_accessor :header_rows
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @body_rows = args[:body_rows] if args.key?(:body_rows)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @header_rows = args[:header_rows] if args.key?(:header_rows)
          @layout = args[:layout] if args.key?(:layout)
        end
      end
      
      # A cell representation inside the table.
      class GoogleCloudDocumentaiV1DocumentPageTableTableCell
        include Google::Apis::Core::Hashable
      
        # How many columns this cell spans.
        # Corresponds to the JSON property `colSpan`
        # @return [Fixnum]
        attr_accessor :col_span
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # How many rows this cell spans.
        # Corresponds to the JSON property `rowSpan`
        # @return [Fixnum]
        attr_accessor :row_span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @col_span = args[:col_span] if args.key?(:col_span)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @row_span = args[:row_span] if args.key?(:row_span)
        end
      end
      
      # A row of table cells.
      class GoogleCloudDocumentaiV1DocumentPageTableTableRow
        include Google::Apis::Core::Hashable
      
        # Cells that make up this row.
        # Corresponds to the JSON property `cells`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTableTableCell>]
        attr_accessor :cells
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cells = args[:cells] if args.key?(:cells)
        end
      end
      
      # A detected token.
      class GoogleCloudDocumentaiV1DocumentPageToken
        include Google::Apis::Core::Hashable
      
        # Detected break at the end of a Token.
        # Corresponds to the JSON property `detectedBreak`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak]
        attr_accessor :detected_break
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # Structure to identify provenance relationships between annotations in
        # different revisions.
        # Corresponds to the JSON property `provenance`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_break = args[:detected_break] if args.key?(:detected_break)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # Detected break at the end of a Token.
      class GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak
        include Google::Apis::Core::Hashable
      
        # Detected break type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Detected non-text visual elements e.g. checkbox, signature etc. on the page.
      class GoogleCloudDocumentaiV1DocumentPageVisualElement
        include Google::Apis::Core::Hashable
      
        # A list of detected languages together with confidence.
        # Corresponds to the JSON property `detectedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>]
        attr_accessor :detected_languages
      
        # Visual element describing a layout unit on a page.
        # Corresponds to the JSON property `layout`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout]
        attr_accessor :layout
      
        # Type of the VisualElement.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
          @layout = args[:layout] if args.key?(:layout)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Structure to identify provenance relationships between annotations in
      # different revisions.
      class GoogleCloudDocumentaiV1DocumentProvenance
        include Google::Apis::Core::Hashable
      
        # The Id of this operation. Needs to be unique within the scope of the revision.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # References to the original elements that are replaced.
        # Corresponds to the JSON property `parents`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenanceParent>]
        attr_accessor :parents
      
        # The index of the revision that produced this element.
        # Corresponds to the JSON property `revision`
        # @return [Fixnum]
        attr_accessor :revision
      
        # The type of provenance operation.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @parents = args[:parents] if args.key?(:parents)
          @revision = args[:revision] if args.key?(:revision)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # The parent element the current element is based on. Used for referencing/
      # aligning, removal and replacement operations.
      class GoogleCloudDocumentaiV1DocumentProvenanceParent
        include Google::Apis::Core::Hashable
      
        # The id of the parent provenance.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # The index of the parent item in the corresponding item list (eg. list of
        # entities, properties within entities, etc.) in the parent revision.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # The index of the index into current revision's parent_ids list.
        # Corresponds to the JSON property `revision`
        # @return [Fixnum]
        attr_accessor :revision
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @index = args[:index] if args.key?(:index)
          @revision = args[:revision] if args.key?(:revision)
        end
      end
      
      # Contains past or forward revisions of this document.
      class GoogleCloudDocumentaiV1DocumentRevision
        include Google::Apis::Core::Hashable
      
        # If the change was made by a person specify the name or id of that person.
        # Corresponds to the JSON property `agent`
        # @return [String]
        attr_accessor :agent
      
        # The time that the revision was created.
        # Corresponds to the JSON property `createTime`
        # @return [String]
        attr_accessor :create_time
      
        # Human Review information of the document.
        # Corresponds to the JSON property `humanReview`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview]
        attr_accessor :human_review
      
        # Id of the revision. Unique within the context of the document.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The revisions that this revision is based on. This can include one or more
        # parent (when documents are merged.) This field represents the index into the `
        # revisions` field.
        # Corresponds to the JSON property `parent`
        # @return [Array<Fixnum>]
        attr_accessor :parent
      
        # The revisions that this revision is based on. Must include all the ids that
        # have anything to do with this revision - eg. there are `provenance.parent.
        # revision` fields that index into this field.
        # Corresponds to the JSON property `parentIds`
        # @return [Array<String>]
        attr_accessor :parent_ids
      
        # If the annotation was made by processor identify the processor by its resource
        # name.
        # Corresponds to the JSON property `processor`
        # @return [String]
        attr_accessor :processor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent = args[:agent] if args.key?(:agent)
          @create_time = args[:create_time] if args.key?(:create_time)
          @human_review = args[:human_review] if args.key?(:human_review)
          @id = args[:id] if args.key?(:id)
          @parent = args[:parent] if args.key?(:parent)
          @parent_ids = args[:parent_ids] if args.key?(:parent_ids)
          @processor = args[:processor] if args.key?(:processor)
        end
      end
      
      # Human Review information of the document.
      class GoogleCloudDocumentaiV1DocumentRevisionHumanReview
        include Google::Apis::Core::Hashable
      
        # Human review state. e.g. `requested`, `succeeded`, `rejected`.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # A message providing more details about the current state of processing. For
        # example, the rejection reason when the state is `rejected`.
        # Corresponds to the JSON property `stateMessage`
        # @return [String]
        attr_accessor :state_message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @state = args[:state] if args.key?(:state)
          @state_message = args[:state_message] if args.key?(:state_message)
        end
      end
      
      # For a large document, sharding may be performed to produce several document
      # shards. Each document shard contains this field to detail which shard it is.
      class GoogleCloudDocumentaiV1DocumentShardInfo
        include Google::Apis::Core::Hashable
      
        # Total number of shards.
        # Corresponds to the JSON property `shardCount`
        # @return [Fixnum]
        attr_accessor :shard_count
      
        # The 0-based index of this shard.
        # Corresponds to the JSON property `shardIndex`
        # @return [Fixnum]
        attr_accessor :shard_index
      
        # The index of the first character in Document.text in the overall document
        # global text.
        # Corresponds to the JSON property `textOffset`
        # @return [Fixnum]
        attr_accessor :text_offset
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @shard_count = args[:shard_count] if args.key?(:shard_count)
          @shard_index = args[:shard_index] if args.key?(:shard_index)
          @text_offset = args[:text_offset] if args.key?(:text_offset)
        end
      end
      
      # Annotation for common text style attributes. This adheres to CSS conventions
      # as much as possible.
      class GoogleCloudDocumentaiV1DocumentStyle
        include Google::Apis::Core::Hashable
      
        # Represents a color in the RGBA color space. This representation is designed
        # for simplicity of conversion to/from color representations in various
        # languages over compactness. For example, the fields of this representation can
        # be trivially provided to the constructor of `java.awt.Color` in Java; it can
        # also be trivially provided to UIColor's `+colorWithRed:green:blue:alpha`
        # method in iOS; and, with just a little work, it can be easily formatted into a
        # CSS `rgba()` string in JavaScript. This reference page doesn't carry
        # information about the absolute color space that should be used to interpret
        # the RGB value (e.g. sRGB, Adobe RGB, DCI-P3, BT.2020, etc.). By default,
        # applications should assume the sRGB color space. When color equality needs to
        # be decided, implementations, unless documented otherwise, treat two colors as
        # equal if all their red, green, blue, and alpha values each differ by at most
        # 1e-5. Example (Java): import com.google.type.Color; // ... public static java.
        # awt.Color fromProto(Color protocolor) ` float alpha = protocolor.hasAlpha() ?
        # protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
        # getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); ` public static
        # Color toProto(java.awt.Color color) ` float red = (float) color.getRed();
        # float green = (float) color.getGreen(); float blue = (float) color.getBlue();
        # float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
        # setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
        # denominator); int alpha = color.getAlpha(); if (alpha != 255) ` result.
        # setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
        # build()); ` return resultBuilder.build(); ` // ... Example (iOS / Obj-C): // ..
        # . static UIColor* fromProto(Color* protocolor) ` float red = [protocolor red];
        # float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
        # alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
        # nil) ` alpha = [alpha_wrapper value]; ` return [UIColor colorWithRed:red green:
        # green blue:blue alpha:alpha]; ` static Color* toProto(UIColor* color) `
        # CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
        # blue alpha:&alpha]) ` return nil; ` Color* result = [[Color alloc] init]; [
        # result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
        # = 0.9999) ` [result setAlpha:floatWrapperWithValue(alpha)]; ` [result
        # autorelease]; return result; ` // ... Example (JavaScript): // ... var
        # protoToCssColor = function(rgb_color) ` var redFrac = rgb_color.red || 0.0;
        # var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
        # var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
        # var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) ` return
        # rgbToCssColor(red, green, blue); ` var alphaFrac = rgb_color.alpha.value || 0.
        # 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
        # ', alphaFrac, ')'].join(''); `; var rgbToCssColor = function(red, green, blue)
        # ` var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
        # = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
        # resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) ` resultBuilder.
        # push('0'); ` resultBuilder.push(hexString); return resultBuilder.join(''); `; /
        # / ...
        # Corresponds to the JSON property `backgroundColor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeColor]
        attr_accessor :background_color
      
        # Represents a color in the RGBA color space. This representation is designed
        # for simplicity of conversion to/from color representations in various
        # languages over compactness. For example, the fields of this representation can
        # be trivially provided to the constructor of `java.awt.Color` in Java; it can
        # also be trivially provided to UIColor's `+colorWithRed:green:blue:alpha`
        # method in iOS; and, with just a little work, it can be easily formatted into a
        # CSS `rgba()` string in JavaScript. This reference page doesn't carry
        # information about the absolute color space that should be used to interpret
        # the RGB value (e.g. sRGB, Adobe RGB, DCI-P3, BT.2020, etc.). By default,
        # applications should assume the sRGB color space. When color equality needs to
        # be decided, implementations, unless documented otherwise, treat two colors as
        # equal if all their red, green, blue, and alpha values each differ by at most
        # 1e-5. Example (Java): import com.google.type.Color; // ... public static java.
        # awt.Color fromProto(Color protocolor) ` float alpha = protocolor.hasAlpha() ?
        # protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
        # getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); ` public static
        # Color toProto(java.awt.Color color) ` float red = (float) color.getRed();
        # float green = (float) color.getGreen(); float blue = (float) color.getBlue();
        # float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
        # setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
        # denominator); int alpha = color.getAlpha(); if (alpha != 255) ` result.
        # setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
        # build()); ` return resultBuilder.build(); ` // ... Example (iOS / Obj-C): // ..
        # . static UIColor* fromProto(Color* protocolor) ` float red = [protocolor red];
        # float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
        # alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
        # nil) ` alpha = [alpha_wrapper value]; ` return [UIColor colorWithRed:red green:
        # green blue:blue alpha:alpha]; ` static Color* toProto(UIColor* color) `
        # CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
        # blue alpha:&alpha]) ` return nil; ` Color* result = [[Color alloc] init]; [
        # result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
        # = 0.9999) ` [result setAlpha:floatWrapperWithValue(alpha)]; ` [result
        # autorelease]; return result; ` // ... Example (JavaScript): // ... var
        # protoToCssColor = function(rgb_color) ` var redFrac = rgb_color.red || 0.0;
        # var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
        # var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
        # var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) ` return
        # rgbToCssColor(red, green, blue); ` var alphaFrac = rgb_color.alpha.value || 0.
        # 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
        # ', alphaFrac, ')'].join(''); `; var rgbToCssColor = function(red, green, blue)
        # ` var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
        # = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
        # resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) ` resultBuilder.
        # push('0'); ` resultBuilder.push(hexString); return resultBuilder.join(''); `; /
        # / ...
        # Corresponds to the JSON property `color`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeColor]
        attr_accessor :color
      
        # Font family such as "Arial", "Times New Roman". https://www.w3schools.com/
        # cssref/pr_font_font-family.asp
        # Corresponds to the JSON property `fontFamily`
        # @return [String]
        attr_accessor :font_family
      
        # Font size with unit.
        # Corresponds to the JSON property `fontSize`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentStyleFontSize]
        attr_accessor :font_size
      
        # Font weight. Possible values are normal, bold, bolder, and lighter. https://
        # www.w3schools.com/cssref/pr_font_weight.asp
        # Corresponds to the JSON property `fontWeight`
        # @return [String]
        attr_accessor :font_weight
      
        # Text reference indexing into the Document.text.
        # Corresponds to the JSON property `textAnchor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor]
        attr_accessor :text_anchor
      
        # Text decoration. Follows CSS standard. https://www.w3schools.com/cssref/
        # pr_text_text-decoration.asp
        # Corresponds to the JSON property `textDecoration`
        # @return [String]
        attr_accessor :text_decoration
      
        # Text style. Possible values are normal, italic, and oblique. https://www.
        # w3schools.com/cssref/pr_font_font-style.asp
        # Corresponds to the JSON property `textStyle`
        # @return [String]
        attr_accessor :text_style
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @background_color = args[:background_color] if args.key?(:background_color)
          @color = args[:color] if args.key?(:color)
          @font_family = args[:font_family] if args.key?(:font_family)
          @font_size = args[:font_size] if args.key?(:font_size)
          @font_weight = args[:font_weight] if args.key?(:font_weight)
          @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
          @text_decoration = args[:text_decoration] if args.key?(:text_decoration)
          @text_style = args[:text_style] if args.key?(:text_style)
        end
      end
      
      # Font size with unit.
      class GoogleCloudDocumentaiV1DocumentStyleFontSize
        include Google::Apis::Core::Hashable
      
        # Font size for the text.
        # Corresponds to the JSON property `size`
        # @return [Float]
        attr_accessor :size
      
        # Unit for the font size. Follows CSS naming (in, px, pt, etc.).
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @size = args[:size] if args.key?(:size)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # Text reference indexing into the Document.text.
      class GoogleCloudDocumentaiV1DocumentTextAnchor
        include Google::Apis::Core::Hashable
      
        # Contains the content of the text span so that users do not have to look it up
        # in the text_segments. It is always populated for formFields.
        # Corresponds to the JSON property `content`
        # @return [String]
        attr_accessor :content
      
        # The text segments from the Document.text.
        # Corresponds to the JSON property `textSegments`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment>]
        attr_accessor :text_segments
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @text_segments = args[:text_segments] if args.key?(:text_segments)
        end
      end
      
      # A text segment in the Document.text. The indices may be out of bounds which
      # indicate that the text extends into another document shard for large sharded
      # documents. See ShardInfo.text_offset
      class GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment
        include Google::Apis::Core::Hashable
      
        # TextSegment half open end UTF-8 char index in the Document.text.
        # Corresponds to the JSON property `endIndex`
        # @return [Fixnum]
        attr_accessor :end_index
      
        # TextSegment start UTF-8 char index in the Document.text.
        # Corresponds to the JSON property `startIndex`
        # @return [Fixnum]
        attr_accessor :start_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_index = args[:end_index] if args.key?(:end_index)
          @start_index = args[:start_index] if args.key?(:start_index)
        end
      end
      
      # This message is used for text changes aka. OCR corrections.
      class GoogleCloudDocumentaiV1DocumentTextChange
        include Google::Apis::Core::Hashable
      
        # The text that replaces the text identified in the `text_anchor`.
        # Corresponds to the JSON property `changedText`
        # @return [String]
        attr_accessor :changed_text
      
        # The history of this annotation.
        # Corresponds to the JSON property `provenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance>]
        attr_accessor :provenance
      
        # Text reference indexing into the Document.text.
        # Corresponds to the JSON property `textAnchor`
        # @return [Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor]
        attr_accessor :text_anchor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @changed_text = args[:changed_text] if args.key?(:changed_text)
          @provenance = args[:provenance] if args.key?(:provenance)
          @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
        end
      end
      
      # A vertex represents a 2D point in the image. NOTE: the normalized vertex
      # coordinates are relative to the original image and range from 0 to 1.
      class GoogleCloudDocumentaiV1NormalizedVertex
        include Google::Apis::Core::Hashable
      
        # X coordinate.
        # Corresponds to the JSON property `x`
        # @return [Float]
        attr_accessor :x
      
        # Y coordinate (starts from the top of the image).
        # Corresponds to the JSON property `y`
        # @return [Float]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # A vertex represents a 2D point in the image. NOTE: the vertex coordinates are
      # in the same scale as the original image.
      class GoogleCloudDocumentaiV1Vertex
        include Google::Apis::Core::Hashable
      
        # X coordinate.
        # Corresponds to the JSON property `x`
        # @return [Fixnum]
        attr_accessor :x
      
        # Y coordinate (starts from the top of the image).
        # Corresponds to the JSON property `y`
        # @return [Fixnum]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # Specifies the audit configuration for a service. The configuration determines
      # which permission types are logged, and what identities, if any, are exempted
      # from logging. An AuditConfig must have one or more AuditLogConfigs. If there
      # are AuditConfigs for both `allServices` and a specific service, the union of
      # the two AuditConfigs is used for that service: the log_types specified in each
      # AuditConfig are enabled, and the exempted_members in each AuditLogConfig are
      # exempted. Example Policy with multiple AuditConfigs: ` "audit_configs": [ ` "
      # service": "allServices", "audit_log_configs": [ ` "log_type": "DATA_READ", "
      # exempted_members": [ "user:jose@example.com" ] `, ` "log_type": "DATA_WRITE" `,
      # ` "log_type": "ADMIN_READ" ` ] `, ` "service": "sampleservice.googleapis.com",
      # "audit_log_configs": [ ` "log_type": "DATA_READ" `, ` "log_type": "DATA_WRITE"
      # , "exempted_members": [ "user:aliya@example.com" ] ` ] ` ] ` For sampleservice,
      # this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also
      # exempts `jose@example.com` from DATA_READ logging, and `aliya@example.com`
      # from DATA_WRITE logging.
      class GoogleIamV1AuditConfig
        include Google::Apis::Core::Hashable
      
        # The configuration for logging of each type of permission.
        # Corresponds to the JSON property `auditLogConfigs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleIamV1AuditLogConfig>]
        attr_accessor :audit_log_configs
      
        # Specifies a service that will be enabled for audit logging. For example, `
        # storage.googleapis.com`, `cloudsql.googleapis.com`. `allServices` is a special
        # value that covers all services.
        # Corresponds to the JSON property `service`
        # @return [String]
        attr_accessor :service
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audit_log_configs = args[:audit_log_configs] if args.key?(:audit_log_configs)
          @service = args[:service] if args.key?(:service)
        end
      end
      
      # Provides the configuration for logging a type of permissions. Example: ` "
      # audit_log_configs": [ ` "log_type": "DATA_READ", "exempted_members": [ "user:
      # jose@example.com" ] `, ` "log_type": "DATA_WRITE" ` ] ` This enables '
      # DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from
      # DATA_READ logging.
      class GoogleIamV1AuditLogConfig
        include Google::Apis::Core::Hashable
      
        # Specifies the identities that do not cause logging for this type of permission.
        # Follows the same format of Binding.members.
        # Corresponds to the JSON property `exemptedMembers`
        # @return [Array<String>]
        attr_accessor :exempted_members
      
        # The log type that this config enables.
        # Corresponds to the JSON property `logType`
        # @return [String]
        attr_accessor :log_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @exempted_members = args[:exempted_members] if args.key?(:exempted_members)
          @log_type = args[:log_type] if args.key?(:log_type)
        end
      end
      
      # Associates `members`, or principals, with a `role`.
      class GoogleIamV1Binding
        include Google::Apis::Core::Hashable
      
        # Represents a textual expression in the Common Expression Language (CEL) syntax.
        # CEL is a C-like expression language. The syntax and semantics of CEL are
        # documented at https://github.com/google/cel-spec. Example (Comparison): title:
        # "Summary size limit" description: "Determines if a summary is less than 100
        # chars" expression: "document.summary.size() < 100" Example (Equality): title: "
        # Requestor is owner" description: "Determines if requestor is the document
        # owner" expression: "document.owner == request.auth.claims.email" Example (
        # Logic): title: "Public documents" description: "Determine whether the document
        # should be publicly visible" expression: "document.type != 'private' &&
        # document.type != 'internal'" Example (Data Manipulation): title: "Notification
        # string" description: "Create a notification string with a timestamp."
        # expression: "'New message received at ' + string(document.create_time)" The
        # exact variables and functions that may be referenced within an expression are
        # determined by the service that evaluates it. See the service documentation for
        # additional information.
        # Corresponds to the JSON property `condition`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeExpr]
        attr_accessor :condition
      
        # Specifies the principals requesting access for a Google Cloud resource. `
        # members` can have the following values: * `allUsers`: A special identifier
        # that represents anyone who is on the internet; with or without a Google
        # account. * `allAuthenticatedUsers`: A special identifier that represents
        # anyone who is authenticated with a Google account or a service account. Does
        # not include identities that come from external identity providers (IdPs)
        # through identity federation. * `user:`emailid``: An email address that
        # represents a specific Google account. For example, `alice@example.com` . * `
        # serviceAccount:`emailid``: An email address that represents a Google service
        # account. For example, `my-other-app@appspot.gserviceaccount.com`. * `
        # serviceAccount:`projectid`.svc.id.goog[`namespace`/`kubernetes-sa`]`: An
        # identifier for a [Kubernetes service account](https://cloud.google.com/
        # kubernetes-engine/docs/how-to/kubernetes-service-accounts). For example, `my-
        # project.svc.id.goog[my-namespace/my-kubernetes-sa]`. * `group:`emailid``: An
        # email address that represents a Google group. For example, `admins@example.com`
        # . * `deleted:user:`emailid`?uid=`uniqueid``: An email address (plus unique
        # identifier) representing a user that has been recently deleted. For example, `
        # alice@example.com?uid=123456789012345678901`. If the user is recovered, this
        # value reverts to `user:`emailid`` and the recovered user retains the role in
        # the binding. * `deleted:serviceAccount:`emailid`?uid=`uniqueid``: An email
        # address (plus unique identifier) representing a service account that has been
        # recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=
        # 123456789012345678901`. If the service account is undeleted, this value
        # reverts to `serviceAccount:`emailid`` and the undeleted service account
        # retains the role in the binding. * `deleted:group:`emailid`?uid=`uniqueid``:
        # An email address (plus unique identifier) representing a Google group that has
        # been recently deleted. For example, `admins@example.com?uid=
        # 123456789012345678901`. If the group is recovered, this value reverts to `
        # group:`emailid`` and the recovered group retains the role in the binding. * `
        # domain:`domain``: The G Suite domain (primary) that represents all the users
        # of that domain. For example, `google.com` or `example.com`.
        # Corresponds to the JSON property `members`
        # @return [Array<String>]
        attr_accessor :members
      
        # Role that is assigned to the list of `members`, or principals. For example, `
        # roles/viewer`, `roles/editor`, or `roles/owner`.
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @condition = args[:condition] if args.key?(:condition)
          @members = args[:members] if args.key?(:members)
          @role = args[:role] if args.key?(:role)
        end
      end
      
      # An Identity and Access Management (IAM) policy, which specifies access
      # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
      # A `binding` binds one or more `members`, or principals, to a single `role`.
      # Principals can be user accounts, service accounts, Google groups, and domains (
      # such as G Suite). A `role` is a named list of permissions; each `role` can be
      # an IAM predefined role or a user-created custom role. For some types of Google
      # Cloud resources, a `binding` can also specify a `condition`, which is a
      # logical expression that allows access to a resource only if the expression
      # evaluates to `true`. A condition can add constraints based on attributes of
      # the request, the resource, or both. To learn which resources support
      # conditions in their IAM policies, see the [IAM documentation](https://cloud.
      # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
      # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
      # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
      # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
      # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
      # ], "condition": ` "title": "expirable access", "description": "Does not grant
      # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
      # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
      # bindings: - members: - user:mike@example.com - group:admins@example.com -
      # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
      # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
      # com role: roles/resourcemanager.organizationViewer condition: title: expirable
      # access description: Does not grant access after Sep 2020 expression: request.
      # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
      # a description of IAM and its features, see the [IAM documentation](https://
      # cloud.google.com/iam/docs/).
      class GoogleIamV1Policy
        include Google::Apis::Core::Hashable
      
        # Specifies cloud audit logging configuration for this policy.
        # Corresponds to the JSON property `auditConfigs`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleIamV1AuditConfig>]
        attr_accessor :audit_configs
      
        # Associates a list of `members`, or principals, with a `role`. Optionally, may
        # specify a `condition` that determines how and when the `bindings` are applied.
        # Each of the `bindings` must contain at least one principal. The `bindings` in
        # a `Policy` can refer to up to 1,500 principals; up to 250 of these principals
        # can be Google groups. Each occurrence of a principal counts towards these
        # limits. For example, if the `bindings` grant 50 different roles to `user:alice@
        # example.com`, and not to any other principal, then you can add another 1,450
        # principals to the `bindings` in the `Policy`.
        # Corresponds to the JSON property `bindings`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleIamV1Binding>]
        attr_accessor :bindings
      
        # `etag` is used for optimistic concurrency control as a way to help prevent
        # simultaneous updates of a policy from overwriting each other. It is strongly
        # suggested that systems make use of the `etag` in the read-modify-write cycle
        # to perform policy updates in order to avoid race conditions: An `etag` is
        # returned in the response to `getIamPolicy`, and systems are expected to put
        # that etag in the request to `setIamPolicy` to ensure that their change will be
        # applied to the same version of the policy. **Important:** If you use IAM
        # Conditions, you must include the `etag` field whenever you call `setIamPolicy`.
        # If you omit this field, then IAM allows you to overwrite a version `3` policy
        # with a version `1` policy, and all of the conditions in the version `3` policy
        # are lost.
        # Corresponds to the JSON property `etag`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :etag
      
        # Specifies the format of the policy. Valid values are `0`, `1`, and `3`.
        # Requests that specify an invalid value are rejected. Any operation that
        # affects conditional role bindings must specify version `3`. This requirement
        # applies to the following operations: * Getting a policy that includes a
        # conditional role binding * Adding a conditional role binding to a policy *
        # Changing a conditional role binding in a policy * Removing any role binding,
        # with or without a condition, from a policy that includes conditions **
        # Important:** If you use IAM Conditions, you must include the `etag` field
        # whenever you call `setIamPolicy`. If you omit this field, then IAM allows you
        # to overwrite a version `3` policy with a version `1` policy, and all of the
        # conditions in the version `3` policy are lost. If a policy does not include
        # any conditions, operations on that policy may specify any valid version or
        # leave the field unset. To learn which resources support conditions in their
        # IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/
        # conditions/resource-policies).
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audit_configs = args[:audit_configs] if args.key?(:audit_configs)
          @bindings = args[:bindings] if args.key?(:bindings)
          @etag = args[:etag] if args.key?(:etag)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Represents the information about user's working hours during one day. Note
      # that a period on Monday from 18:00 - 00:00 is represented as a triplet (1,
      # 1080, 1440).
      class GoogleInternalAppsWaldoV1alphaAvailabilityPeriod
        include Google::Apis::Core::Hashable
      
        # Day of week, 0 for Sunday, 1 for Monday, ...
        # Corresponds to the JSON property `dayOfWeek`
        # @return [Fixnum]
        attr_accessor :day_of_week
      
        # Period end, in minutes from the start of the day, exclusive.
        # Corresponds to the JSON property `periodEndMinutes`
        # @return [Fixnum]
        attr_accessor :period_end_minutes
      
        # Period start, in minutes from the start of the day, inclusive.
        # Corresponds to the JSON property `periodStartMinutes`
        # @return [Fixnum]
        attr_accessor :period_start_minutes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
          @period_end_minutes = args[:period_end_minutes] if args.key?(:period_end_minutes)
          @period_start_minutes = args[:period_start_minutes] if args.key?(:period_start_minutes)
        end
      end
      
      # The status indicating the user is temporarily busy and there is not a more
      # specific status derived from calendar that applies (e.g., InMeeting or
      # DoNotDisturb).
      class GoogleInternalAppsWaldoV1alphaCalendarBusy
        include Google::Apis::Core::Hashable
      
        # The summary of the corresponding event in Calendar.
        # Corresponds to the JSON property `eventSummary`
        # @return [String]
        attr_accessor :event_summary
      
        # The next time when the user will be available, i.e., when their status will be
        # neither InMeeting, CalendarBusy, DoNotDisturb, OutsideWorkingHours, nor
        # OutOfOffice.
        # Corresponds to the JSON property `nextAvailable`
        # @return [String]
        attr_accessor :next_available
      
        # The time when the user will stop being occupied, i.e., when their status will
        # be neither inMeeting, Busy nor DoNotDisturb.
        # Corresponds to the JSON property `occupiedUntil`
        # @return [String]
        attr_accessor :occupied_until
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event_summary = args[:event_summary] if args.key?(:event_summary)
          @next_available = args[:next_available] if args.key?(:next_available)
          @occupied_until = args[:occupied_until] if args.key?(:occupied_until)
        end
      end
      
      # Custom location specified by the user.
      class GoogleInternalAppsWaldoV1alphaCustomLocation
        include Google::Apis::Core::Hashable
      
        # An object that represents a latitude/longitude pair. This is expressed as a
        # pair of doubles to represent degrees latitude and degrees longitude. Unless
        # specified otherwise, this object must conform to the WGS84 standard. Values
        # must be within normalized ranges.
        # Corresponds to the JSON property `geoCoordinates`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeLatLng]
        attr_accessor :geo_coordinates
      
        # The custom location label as a string entered manually by the user.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # Geographic location as free-form text.
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @geo_coordinates = args[:geo_coordinates] if args.key?(:geo_coordinates)
          @label = args[:label] if args.key?(:label)
          @location = args[:location] if args.key?(:location)
        end
      end
      
      # The status indicating the user should not be disturbed.
      class GoogleInternalAppsWaldoV1alphaDoNotDisturb
        include Google::Apis::Core::Hashable
      
        # The next time when the user will be available, i.e., when their status will be
        # neither InMeeting, CalendarBusy, DoNotDisturb, OutsideWorkingHours, nor
        # OutOfOffice.
        # Corresponds to the JSON property `nextAvailable`
        # @return [String]
        attr_accessor :next_available
      
        # The time when the user will stop being occupied, i.e., when their status will
        # be neither inMeeting, Busy nor DoNotDisturb.
        # Corresponds to the JSON property `occupiedUntil`
        # @return [String]
        attr_accessor :occupied_until
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @next_available = args[:next_available] if args.key?(:next_available)
          @occupied_until = args[:occupied_until] if args.key?(:occupied_until)
        end
      end
      
      # Home location.
      class GoogleInternalAppsWaldoV1alphaHomeLocation
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The status indicating the user is in a meeting.
      class GoogleInternalAppsWaldoV1alphaInMeeting
        include Google::Apis::Core::Hashable
      
        # The summary of the corresponding event in Calendar.
        # Corresponds to the JSON property `eventSummary`
        # @return [String]
        attr_accessor :event_summary
      
        # The time when the user will stop being in a meeting.
        # Corresponds to the JSON property `inMeetingsUntil`
        # @return [String]
        attr_accessor :in_meetings_until
      
        # The next time when the user will be available, i.e., when their status will be
        # neither InMeeting, CalendarBusy, DoNotDisturb, OutsideWorkingHours, nor
        # OutOfOffice.
        # Corresponds to the JSON property `nextAvailable`
        # @return [String]
        attr_accessor :next_available
      
        # The time when the user will stop being occupied, i.e., when their status will
        # be neither inMeeting, Busy nor DoNotDisturb.
        # Corresponds to the JSON property `occupiedUntil`
        # @return [String]
        attr_accessor :occupied_until
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event_summary = args[:event_summary] if args.key?(:event_summary)
          @in_meetings_until = args[:in_meetings_until] if args.key?(:in_meetings_until)
          @next_available = args[:next_available] if args.key?(:next_available)
          @occupied_until = args[:occupied_until] if args.key?(:occupied_until)
        end
      end
      
      # The status indicating that no other status applies.
      class GoogleInternalAppsWaldoV1alphaInactive
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Context which helps to determine the user's local time.
      class GoogleInternalAppsWaldoV1alphaLocalTimeContext
        include Google::Apis::Core::Hashable
      
        # The current time zone of the user. Represented as a valid time zone ID from
        # Olson database, like "Europe/Zurich" (see http://google3/i18n/identifiers/data/
        # timezones.txt).
        # Corresponds to the JSON property `timeZone`
        # @return [String]
        attr_accessor :time_zone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @time_zone = args[:time_zone] if args.key?(:time_zone)
        end
      end
      
      # Office location.
      class GoogleInternalAppsWaldoV1alphaOfficeLocation
        include Google::Apis::Core::Hashable
      
        # Experimental. Can change or disappear without warning or notice. References a
        # building from http://google3/ccc/hosted/api/rosy/resources/calendar/building.
        # proto For example "US-NYC-9TH".
        # Corresponds to the JSON property `experimentalBuildingId`
        # @return [String]
        attr_accessor :experimental_building_id
      
        # Experimental. Can change or disappear without warning or notice. The desk id.
        # For example "11E358K".
        # Corresponds to the JSON property `experimentalDeskId`
        # @return [String]
        attr_accessor :experimental_desk_id
      
        # Experimental. Can change or disappear without warning or notice. The floor id.
        # For example "11".
        # Corresponds to the JSON property `experimentalFloorId`
        # @return [String]
        attr_accessor :experimental_floor_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experimental_building_id = args[:experimental_building_id] if args.key?(:experimental_building_id)
          @experimental_desk_id = args[:experimental_desk_id] if args.key?(:experimental_desk_id)
          @experimental_floor_id = args[:experimental_floor_id] if args.key?(:experimental_floor_id)
        end
      end
      
      # The status indicating the user is out of office.
      class GoogleInternalAppsWaldoV1alphaOutOfOffice
        include Google::Apis::Core::Hashable
      
        # The closest time when the user will be available after this OOO block. This
        # might be different from the end of the OOO block in Calendar, since the OOO
        # block might end on Friday evening, and then the user is outside working hours.
        # Corresponds to the JSON property `comeBackTime`
        # @return [String]
        attr_accessor :come_back_time
      
        # The summary of the corresponding OOO block in Calendar. This is entered by the
        # user, so we return it "as is" - no i18n.
        # Corresponds to the JSON property `eventSummary`
        # @return [String]
        attr_accessor :event_summary
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @come_back_time = args[:come_back_time] if args.key?(:come_back_time)
          @event_summary = args[:event_summary] if args.key?(:event_summary)
        end
      end
      
      # The status indicating the user doesn't work at this time.
      class GoogleInternalAppsWaldoV1alphaOutsideWorkingHours
        include Google::Apis::Core::Hashable
      
        # The closest time when the user will be available after this block. This might
        # be different from the start of the working hours in Calendar, because the
        # given OutsideWorkingHours interval might be followed by OOO.
        # Corresponds to the JSON property `comeBackTime`
        # @return [String]
        attr_accessor :come_back_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @come_back_time = args[:come_back_time] if args.key?(:come_back_time)
        end
      end
      
      # A time range, which includes the start and excludes the end.
      class GoogleInternalAppsWaldoV1alphaTimeRange
        include Google::Apis::Core::Hashable
      
        # End point of the range, exclusive.
        # Corresponds to the JSON property `endTime`
        # @return [String]
        attr_accessor :end_time
      
        # Starting point of the range, inclusive.
        # Corresponds to the JSON property `startTime`
        # @return [String]
        attr_accessor :start_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_time = args[:end_time] if args.key?(:end_time)
          @start_time = args[:start_time] if args.key?(:start_time)
        end
      end
      
      # The context indicating the user's upcoming Out of Office event.
      class GoogleInternalAppsWaldoV1alphaUpcomingOooContext
        include Google::Apis::Core::Hashable
      
        # A time range, which includes the start and excludes the end.
        # Corresponds to the JSON property `timeRange`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaTimeRange]
        attr_accessor :time_range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @time_range = args[:time_range] if args.key?(:time_range)
        end
      end
      
      # The current and future availabilities of a user. The response contains a
      # timeline, which starts before or at the request time, and the timeline is
      # split into a set of disjoint intervals (without gaps), where the first range
      # always contains the request time. Each range represents what should be
      # displayed in the UI during this time range. The time range might be different
      # from the actual time range of the underlying status. For example, if the user
      # is OOO from 09:00 to 10:00, and a request is made at 8:00, the response might
      # contain two intervals: [08:00, 09:00) - "User is INACTIVE, but leaving the
      # office soon" [09:00, 10:00) - "User is OOO till 10:00" For intervals that don'
      # t have a clear availability signal coming from Calendar (e.g. OOO), we return
      # INACTIVE. For more details, please see https://docs.google.com/presentation/d/
      # 1ADCTxGawjF9UqMnfuVrVNxGvdyjeiV8h4D7p0a9zYgw/edit#slide=id.g3e2824ac6c_12_94
      # The service returns availabilities for some short period of time - likely one
      # day, but the client should stick to the "next_poll_time" to decide when to
      # query the server again at the latest. Below there is an example response from
      # the server. Let's assume the client calls the service at 17:59:45. The client
      # receives the message and, assuming its current time is between [17:59:45, 18:
      # 00:00), it displays "inactive". When the current time becomes 18:00:00 it
      # displays "outside working hours". At 18:00:40 the client issues another rpc
      # which will return the availabilities for the next minute. The original
      # response looks like availabilities ` time_range ` start_time: 17:59:45
      # end_time: 18:00:00 ` status ` inactive `` ` ` availabilities ` time_range `
      # start_time: 18:00:00 end_time: 18:00:45 ` status ` outside_working_hours ` ` `
      # ` next_poll_time: 18:00:40
      class GoogleInternalAppsWaldoV1alphaUserAvailabilities
        include Google::Apis::Core::Hashable
      
        # A list of user availabilities having contiguous time ranges which are ordered
        # chronologically. The first one starts at the time of the request or before,
        # and is guaranteed to contain the request time. That means the first element
        # always indicates the current status of a user. A client that wants to display
        # a user's availability in real time should display the availability whose time
        # range contains the current time.
        # Corresponds to the JSON property `availabilities`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUserAvailability>]
        attr_accessor :availabilities
      
        # The time at which the client should issue the next availability query for this
        # user. This field should only be used to control the polling frequency. This
        # time is always before the end of the time range of the last availability so
        # that the client always knows the current availability.
        # Corresponds to the JSON property `nextPollTime`
        # @return [String]
        attr_accessor :next_poll_time
      
        # Information about the user's working hours.
        # Corresponds to the JSON property `workingHours`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaWorkingHours]
        attr_accessor :working_hours
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @availabilities = args[:availabilities] if args.key?(:availabilities)
          @next_poll_time = args[:next_poll_time] if args.key?(:next_poll_time)
          @working_hours = args[:working_hours] if args.key?(:working_hours)
        end
      end
      
      # A single availability range. The displayed status should be the same during
      # the entire time range.
      class GoogleInternalAppsWaldoV1alphaUserAvailability
        include Google::Apis::Core::Hashable
      
        # Additional context about the user's current and/or future availability to give
        # a better understanding of the status ("Working from Zurich").
        # Corresponds to the JSON property `contexts`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUserContext]
        attr_accessor :contexts
      
        # The actual status of the user. The message contains everything needed for
        # visualisation of this status.
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUserStatus]
        attr_accessor :status
      
        # A time range, which includes the start and excludes the end.
        # Corresponds to the JSON property `timeRange`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaTimeRange]
        attr_accessor :time_range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contexts = args[:contexts] if args.key?(:contexts)
          @status = args[:status] if args.key?(:status)
          @time_range = args[:time_range] if args.key?(:time_range)
        end
      end
      
      # Additional context about the user's current and/or future availability to give
      # a better understanding of the status ("Working from Zurich").
      class GoogleInternalAppsWaldoV1alphaUserContext
        include Google::Apis::Core::Hashable
      
        # Context which helps to determine the user's local time.
        # Corresponds to the JSON property `localTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaLocalTimeContext]
        attr_accessor :local_time
      
        # The context indicating the user's upcoming Out of Office event.
        # Corresponds to the JSON property `upcomingOoo`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUpcomingOooContext]
        attr_accessor :upcoming_ooo
      
        # The context indicating the user is working remotely (from home / from a
        # different office).
        # Corresponds to the JSON property `workingElsewhere`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaWorkingElsewhereContext]
        attr_accessor :working_elsewhere
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @local_time = args[:local_time] if args.key?(:local_time)
          @upcoming_ooo = args[:upcoming_ooo] if args.key?(:upcoming_ooo)
          @working_elsewhere = args[:working_elsewhere] if args.key?(:working_elsewhere)
        end
      end
      
      # Location of the user, which might be "home", for example, or another office
      # building, as well as a custom location specified by the user.
      class GoogleInternalAppsWaldoV1alphaUserLocation
        include Google::Apis::Core::Hashable
      
        # Custom location specified by the user.
        # Corresponds to the JSON property `customLocation`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaCustomLocation]
        attr_accessor :custom_location
      
        # Home location.
        # Corresponds to the JSON property `homeLocation`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaHomeLocation]
        attr_accessor :home_location
      
        # Office location.
        # Corresponds to the JSON property `officeLocation`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaOfficeLocation]
        attr_accessor :office_location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @custom_location = args[:custom_location] if args.key?(:custom_location)
          @home_location = args[:home_location] if args.key?(:home_location)
          @office_location = args[:office_location] if args.key?(:office_location)
        end
      end
      
      # The actual status of the user. The message contains everything needed for
      # visualisation of this status.
      class GoogleInternalAppsWaldoV1alphaUserStatus
        include Google::Apis::Core::Hashable
      
        # The status indicating the user is temporarily busy and there is not a more
        # specific status derived from calendar that applies (e.g., InMeeting or
        # DoNotDisturb).
        # Corresponds to the JSON property `calendarBusy`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaCalendarBusy]
        attr_accessor :calendar_busy
      
        # The status indicating the user should not be disturbed.
        # Corresponds to the JSON property `doNotDisturb`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaDoNotDisturb]
        attr_accessor :do_not_disturb
      
        # The status indicating the user is in a meeting.
        # Corresponds to the JSON property `inMeeting`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaInMeeting]
        attr_accessor :in_meeting
      
        # The status indicating that no other status applies.
        # Corresponds to the JSON property `inactive`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaInactive]
        attr_accessor :inactive
      
        # The status indicating the user is out of office.
        # Corresponds to the JSON property `outOfOffice`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaOutOfOffice]
        attr_accessor :out_of_office
      
        # The status indicating the user doesn't work at this time.
        # Corresponds to the JSON property `outsideWorkingHours`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaOutsideWorkingHours]
        attr_accessor :outside_working_hours
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calendar_busy = args[:calendar_busy] if args.key?(:calendar_busy)
          @do_not_disturb = args[:do_not_disturb] if args.key?(:do_not_disturb)
          @in_meeting = args[:in_meeting] if args.key?(:in_meeting)
          @inactive = args[:inactive] if args.key?(:inactive)
          @out_of_office = args[:out_of_office] if args.key?(:out_of_office)
          @outside_working_hours = args[:outside_working_hours] if args.key?(:outside_working_hours)
        end
      end
      
      # The context indicating the user is working remotely (from home / from a
      # different office).
      class GoogleInternalAppsWaldoV1alphaWorkingElsewhereContext
        include Google::Apis::Core::Hashable
      
        # Location of the user, which might be "home", for example, or another office
        # building, as well as a custom location specified by the user.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUserLocation]
        attr_accessor :location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @location = args[:location] if args.key?(:location)
        end
      end
      
      # Information about the user's working hours.
      class GoogleInternalAppsWaldoV1alphaWorkingHours
        include Google::Apis::Core::Hashable
      
        # A list of availability periods representing the user's working hours as
        # configured in calendar.
        # Corresponds to the JSON property `availableTime`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaAvailabilityPeriod>]
        attr_accessor :available_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @available_time = args[:available_time] if args.key?(:available_time)
        end
      end
      
      # Id for message recipients, e.g. users, groups etc.
      class GoogleInternalCommunicationsInstantmessagingV1Id
        include Google::Apis::Core::Hashable
      
        # app is the tachyon client application that generated or is to receive a
        # message.
        # Corresponds to the JSON property `app`
        # @return [String]
        attr_accessor :app
      
        # country_code is the E164_COUNTRY_CODE format country code for this id, used as
        # a hint for its region. E.g, "+1" will be used for North America, "+86" will be
        # used for China, etc. Should be filled only for RCS group id.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # id is a unique (for this type and app) identifier of a message source or
        # recipient.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # LocationHint is used to specify a location as well as format.
        # Corresponds to the JSON property `locationHint`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalCommunicationsInstantmessagingV1LocationHint]
        attr_accessor :location_hint
      
        # Raw byte array containing encoded routing information. Clients of Tachyon are
        # expected to include the most recent routing_info_cookie that they have
        # received from the server in the requests that they make. Its format is
        # purposely opaque so that clients do not need to concern themselves with the
        # content of this field. This field is expected to be used primarily by
        # Tachygram clients for go/tachygram-groups to simplify the API contract for
        # group operations while reducing the need for unnecessary lookups.
        # Corresponds to the JSON property `routingInfoToken`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :routing_info_token
      
        # type defines what the id field contains, e.g. phone number, Fi-number, Gaia ID
        # etc.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app = args[:app] if args.key?(:app)
          @country_code = args[:country_code] if args.key?(:country_code)
          @id = args[:id] if args.key?(:id)
          @location_hint = args[:location_hint] if args.key?(:location_hint)
          @routing_info_token = args[:routing_info_token] if args.key?(:routing_info_token)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # LocationHint is used to specify a location as well as format.
      class GoogleInternalCommunicationsInstantmessagingV1LocationHint
        include Google::Apis::Core::Hashable
      
        # the format of location.
        # Corresponds to the JSON property `format`
        # @return [String]
        attr_accessor :format
      
        # Location is the location, provided in the format specified by format.
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @format = args[:format] if args.key?(:format)
          @location = args[:location] if args.key?(:location)
        end
      end
      
      # This resource represents a long-running operation that is the result of a
      # network API call.
      class GoogleLongrunningOperation
        include Google::Apis::Core::Hashable
      
        # If the value is `false`, it means the operation is still in progress. If `true`
        # , the operation is completed, and either `error` or `response` is available.
        # Corresponds to the JSON property `done`
        # @return [Boolean]
        attr_accessor :done
        alias_method :done?, :done
      
        # The `Status` type defines a logical error model that is suitable for different
        # programming environments, including REST APIs and RPC APIs. It is used by [
        # gRPC](https://github.com/grpc). Each `Status` message contains three pieces of
        # data: error code, error message, and error details. You can find out more
        # about this error model and how to work with it in the [API Design Guide](https:
        # //cloud.google.com/apis/design/errors).
        # Corresponds to the JSON property `error`
        # @return [Google::Apis::ContentwarehouseV1::GoogleRpcStatus]
        attr_accessor :error
      
        # Service-specific metadata associated with the operation. It typically contains
        # progress information and common metadata such as create time. Some services
        # might not provide such metadata. Any method that returns a long-running
        # operation should document the metadata type, if any.
        # Corresponds to the JSON property `metadata`
        # @return [Hash<String,Object>]
        attr_accessor :metadata
      
        # The server-assigned name, which is only unique within the same service that
        # originally returns it. If you use the default HTTP mapping, the `name` should
        # be a resource name ending with `operations/`unique_id``.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The normal response of the operation in case of success. If the original
        # method returns no data on success, such as `Delete`, the response is `google.
        # protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`,
        # the response should be the resource. For other methods, the response should
        # have the type `XxxResponse`, where `Xxx` is the original method name. For
        # example, if the original method name is `TakeSnapshot()`, the inferred
        # response type is `TakeSnapshotResponse`.
        # Corresponds to the JSON property `response`
        # @return [Hash<String,Object>]
        attr_accessor :response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @done = args[:done] if args.key?(:done)
          @error = args[:error] if args.key?(:error)
          @metadata = args[:metadata] if args.key?(:metadata)
          @name = args[:name] if args.key?(:name)
          @response = args[:response] if args.key?(:response)
        end
      end
      
      # A generic empty message that you can re-use to avoid defining duplicated empty
      # messages in your APIs. A typical example is to use it as the request or the
      # response type of an API method. For instance: service Foo ` rpc Bar(google.
      # protobuf.Empty) returns (google.protobuf.Empty); `
      class GoogleProtobufEmpty
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The `Status` type defines a logical error model that is suitable for different
      # programming environments, including REST APIs and RPC APIs. It is used by [
      # gRPC](https://github.com/grpc). Each `Status` message contains three pieces of
      # data: error code, error message, and error details. You can find out more
      # about this error model and how to work with it in the [API Design Guide](https:
      # //cloud.google.com/apis/design/errors).
      class GoogleRpcStatus
        include Google::Apis::Core::Hashable
      
        # The status code, which should be an enum value of google.rpc.Code.
        # Corresponds to the JSON property `code`
        # @return [Fixnum]
        attr_accessor :code
      
        # A list of messages that carry the error details. There is a common set of
        # message types for APIs to use.
        # Corresponds to the JSON property `details`
        # @return [Array<Hash<String,Object>>]
        attr_accessor :details
      
        # A developer-facing error message, which should be in English. Any user-facing
        # error message should be localized and sent in the google.rpc.Status.details
        # field, or localized by the client.
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @details = args[:details] if args.key?(:details)
          @message = args[:message] if args.key?(:message)
        end
      end
      
      # Represents a color in the RGBA color space. This representation is designed
      # for simplicity of conversion to/from color representations in various
      # languages over compactness. For example, the fields of this representation can
      # be trivially provided to the constructor of `java.awt.Color` in Java; it can
      # also be trivially provided to UIColor's `+colorWithRed:green:blue:alpha`
      # method in iOS; and, with just a little work, it can be easily formatted into a
      # CSS `rgba()` string in JavaScript. This reference page doesn't carry
      # information about the absolute color space that should be used to interpret
      # the RGB value (e.g. sRGB, Adobe RGB, DCI-P3, BT.2020, etc.). By default,
      # applications should assume the sRGB color space. When color equality needs to
      # be decided, implementations, unless documented otherwise, treat two colors as
      # equal if all their red, green, blue, and alpha values each differ by at most
      # 1e-5. Example (Java): import com.google.type.Color; // ... public static java.
      # awt.Color fromProto(Color protocolor) ` float alpha = protocolor.hasAlpha() ?
      # protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
      # getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); ` public static
      # Color toProto(java.awt.Color color) ` float red = (float) color.getRed();
      # float green = (float) color.getGreen(); float blue = (float) color.getBlue();
      # float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
      # setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
      # denominator); int alpha = color.getAlpha(); if (alpha != 255) ` result.
      # setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
      # build()); ` return resultBuilder.build(); ` // ... Example (iOS / Obj-C): // ..
      # . static UIColor* fromProto(Color* protocolor) ` float red = [protocolor red];
      # float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
      # alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
      # nil) ` alpha = [alpha_wrapper value]; ` return [UIColor colorWithRed:red green:
      # green blue:blue alpha:alpha]; ` static Color* toProto(UIColor* color) `
      # CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
      # blue alpha:&alpha]) ` return nil; ` Color* result = [[Color alloc] init]; [
      # result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
      # = 0.9999) ` [result setAlpha:floatWrapperWithValue(alpha)]; ` [result
      # autorelease]; return result; ` // ... Example (JavaScript): // ... var
      # protoToCssColor = function(rgb_color) ` var redFrac = rgb_color.red || 0.0;
      # var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
      # var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
      # var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) ` return
      # rgbToCssColor(red, green, blue); ` var alphaFrac = rgb_color.alpha.value || 0.
      # 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
      # ', alphaFrac, ')'].join(''); `; var rgbToCssColor = function(red, green, blue)
      # ` var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
      # = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
      # resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) ` resultBuilder.
      # push('0'); ` resultBuilder.push(hexString); return resultBuilder.join(''); `; /
      # / ...
      class GoogleTypeColor
        include Google::Apis::Core::Hashable
      
        # The fraction of this color that should be applied to the pixel. That is, the
        # final pixel color is defined by the equation: `pixel color = alpha * (this
        # color) + (1.0 - alpha) * (background color)` This means that a value of 1.0
        # corresponds to a solid color, whereas a value of 0.0 corresponds to a
        # completely transparent color. This uses a wrapper message rather than a simple
        # float scalar so that it is possible to distinguish between a default value and
        # the value being unset. If omitted, this color object is rendered as a solid
        # color (as if the alpha value had been explicitly given a value of 1.0).
        # Corresponds to the JSON property `alpha`
        # @return [Float]
        attr_accessor :alpha
      
        # The amount of blue in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `blue`
        # @return [Float]
        attr_accessor :blue
      
        # The amount of green in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `green`
        # @return [Float]
        attr_accessor :green
      
        # The amount of red in the color as a value in the interval [0, 1].
        # Corresponds to the JSON property `red`
        # @return [Float]
        attr_accessor :red
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alpha = args[:alpha] if args.key?(:alpha)
          @blue = args[:blue] if args.key?(:blue)
          @green = args[:green] if args.key?(:green)
          @red = args[:red] if args.key?(:red)
        end
      end
      
      # Represents a whole or partial calendar date, such as a birthday. The time of
      # day and time zone are either specified elsewhere or are insignificant. The
      # date is relative to the Gregorian Calendar. This can represent one of the
      # following: * A full date, with non-zero year, month, and day values. * A month
      # and day, with a zero year (for example, an anniversary). * A year on its own,
      # with a zero month and a zero day. * A year and month, with a zero day (for
      # example, a credit card expiration date). Related types: * google.type.
      # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
      class GoogleTypeDate
        include Google::Apis::Core::Hashable
      
        # Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to
        # specify a year by itself or a year and month where the day isn't significant.
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # Month of a year. Must be from 1 to 12, or 0 to specify a year without a month
        # and day.
        # Corresponds to the JSON property `month`
        # @return [Fixnum]
        attr_accessor :month
      
        # Year of the date. Must be from 1 to 9999, or 0 to specify a date without a
        # year.
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @month = args[:month] if args.key?(:month)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # Represents civil time (or occasionally physical time). This type can represent
      # a civil time in one of a few possible ways: * When utc_offset is set and
      # time_zone is unset: a civil time on a calendar day with a particular offset
      # from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
      # calendar day in a particular time zone. * When neither time_zone nor
      # utc_offset is set: a civil time on a calendar day in local time. The date is
      # relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
      # the DateTime is considered not to have a specific year, month, or day
      # respectively. This type may also be used to represent a physical time if all
      # the date and time fields are set and either case of the `time_offset` oneof is
      # set. Consider using `Timestamp` message for physical time instead. If your use
      # case also would like to store the user's timezone, that can be done in another
      # field. This type is more flexible than some applications may want. Make sure
      # to document and validate your application's limitations.
      class GoogleTypeDateTime
        include Google::Apis::Core::Hashable
      
        # Optional. Day of month. Must be from 1 to 31 and valid for the year and month,
        # or 0 if specifying a datetime without a day.
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults to
        # 0 (midnight). An API may choose to allow the value "24:00:00" for scenarios
        # like business closing time.
        # Corresponds to the JSON property `hours`
        # @return [Fixnum]
        attr_accessor :hours
      
        # Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0.
        # Corresponds to the JSON property `minutes`
        # @return [Fixnum]
        attr_accessor :minutes
      
        # Optional. Month of year. Must be from 1 to 12, or 0 if specifying a datetime
        # without a month.
        # Corresponds to the JSON property `month`
        # @return [Fixnum]
        attr_accessor :month
      
        # Optional. Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999,
        # defaults to 0.
        # Corresponds to the JSON property `nanos`
        # @return [Fixnum]
        attr_accessor :nanos
      
        # Optional. Seconds of minutes of the time. Must normally be from 0 to 59,
        # defaults to 0. An API may allow the value 60 if it allows leap-seconds.
        # Corresponds to the JSON property `seconds`
        # @return [Fixnum]
        attr_accessor :seconds
      
        # Represents a time zone from the [IANA Time Zone Database](https://www.iana.org/
        # time-zones).
        # Corresponds to the JSON property `timeZone`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeZone]
        attr_accessor :time_zone
      
        # UTC offset. Must be whole seconds, between -18 hours and +18 hours. For
        # example, a UTC offset of -4:00 would be represented as ` seconds: -14400 `.
        # Corresponds to the JSON property `utcOffset`
        # @return [String]
        attr_accessor :utc_offset
      
        # Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a datetime
        # without a year.
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @hours = args[:hours] if args.key?(:hours)
          @minutes = args[:minutes] if args.key?(:minutes)
          @month = args[:month] if args.key?(:month)
          @nanos = args[:nanos] if args.key?(:nanos)
          @seconds = args[:seconds] if args.key?(:seconds)
          @time_zone = args[:time_zone] if args.key?(:time_zone)
          @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # Represents a textual expression in the Common Expression Language (CEL) syntax.
      # CEL is a C-like expression language. The syntax and semantics of CEL are
      # documented at https://github.com/google/cel-spec. Example (Comparison): title:
      # "Summary size limit" description: "Determines if a summary is less than 100
      # chars" expression: "document.summary.size() < 100" Example (Equality): title: "
      # Requestor is owner" description: "Determines if requestor is the document
      # owner" expression: "document.owner == request.auth.claims.email" Example (
      # Logic): title: "Public documents" description: "Determine whether the document
      # should be publicly visible" expression: "document.type != 'private' &&
      # document.type != 'internal'" Example (Data Manipulation): title: "Notification
      # string" description: "Create a notification string with a timestamp."
      # expression: "'New message received at ' + string(document.create_time)" The
      # exact variables and functions that may be referenced within an expression are
      # determined by the service that evaluates it. See the service documentation for
      # additional information.
      class GoogleTypeExpr
        include Google::Apis::Core::Hashable
      
        # Optional. Description of the expression. This is a longer text which describes
        # the expression, e.g. when hovered over it in a UI.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Textual representation of an expression in Common Expression Language syntax.
        # Corresponds to the JSON property `expression`
        # @return [String]
        attr_accessor :expression
      
        # Optional. String indicating the location of the expression for error reporting,
        # e.g. a file name and a position in the file.
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        # Optional. Title for the expression, i.e. a short string describing its purpose.
        # This can be used e.g. in UIs which allow to enter the expression.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @expression = args[:expression] if args.key?(:expression)
          @location = args[:location] if args.key?(:location)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Represents a time interval, encoded as a Timestamp start (inclusive) and a
      # Timestamp end (exclusive). The start must be less than or equal to the end.
      # When the start equals the end, the interval is empty (matches no time). When
      # both start and end are unspecified, the interval matches any time.
      class GoogleTypeInterval
        include Google::Apis::Core::Hashable
      
        # Optional. Exclusive end of the interval. If specified, a Timestamp matching
        # this interval will have to be before the end.
        # Corresponds to the JSON property `endTime`
        # @return [String]
        attr_accessor :end_time
      
        # Optional. Inclusive start of the interval. If specified, a Timestamp matching
        # this interval will have to be the same or after the start.
        # Corresponds to the JSON property `startTime`
        # @return [String]
        attr_accessor :start_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_time = args[:end_time] if args.key?(:end_time)
          @start_time = args[:start_time] if args.key?(:start_time)
        end
      end
      
      # An object that represents a latitude/longitude pair. This is expressed as a
      # pair of doubles to represent degrees latitude and degrees longitude. Unless
      # specified otherwise, this object must conform to the WGS84 standard. Values
      # must be within normalized ranges.
      class GoogleTypeLatLng
        include Google::Apis::Core::Hashable
      
        # The latitude in degrees. It must be in the range [-90.0, +90.0].
        # Corresponds to the JSON property `latitude`
        # @return [Float]
        attr_accessor :latitude
      
        # The longitude in degrees. It must be in the range [-180.0, +180.0].
        # Corresponds to the JSON property `longitude`
        # @return [Float]
        attr_accessor :longitude
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @latitude = args[:latitude] if args.key?(:latitude)
          @longitude = args[:longitude] if args.key?(:longitude)
        end
      end
      
      # Represents an amount of money with its currency type.
      class GoogleTypeMoney
        include Google::Apis::Core::Hashable
      
        # The three-letter currency code defined in ISO 4217.
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        # Number of nano (10^-9) units of the amount. The value must be between -999,999,
        # 999 and +999,999,999 inclusive. If `units` is positive, `nanos` must be
        # positive or zero. If `units` is zero, `nanos` can be positive, zero, or
        # negative. If `units` is negative, `nanos` must be negative or zero. For
        # example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.
        # Corresponds to the JSON property `nanos`
        # @return [Fixnum]
        attr_accessor :nanos
      
        # The whole units of the amount. For example if `currencyCode` is `"USD"`, then
        # 1 unit is one US dollar.
        # Corresponds to the JSON property `units`
        # @return [Fixnum]
        attr_accessor :units
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
          @nanos = args[:nanos] if args.key?(:nanos)
          @units = args[:units] if args.key?(:units)
        end
      end
      
      # Represents a postal address, e.g. for postal delivery or payments addresses.
      # Given a postal address, a postal service can deliver items to a premise, P.O.
      # Box or similar. It is not intended to model geographical locations (roads,
      # towns, mountains). In typical usage an address would be created via user input
      # or from importing existing data, depending on the type of process. Advice on
      # address input / editing: - Use an internationalization-ready address widget
      # such as https://github.com/google/libaddressinput) - Users should not be
      # presented with UI elements for input or editing of fields outside countries
      # where that field is used. For more guidance on how to use this schema, please
      # see: https://support.google.com/business/answer/6397478
      class GoogleTypePostalAddress
        include Google::Apis::Core::Hashable
      
        # Unstructured address lines describing the lower levels of an address. Because
        # values in address_lines do not have type information and may sometimes contain
        # multiple values in a single field (e.g. "Austin, TX"), it is important that
        # the line order is clear. The order of address lines should be "envelope order"
        # for the country/region of the address. In places where this can vary (e.g.
        # Japan), address_language is used to make it explicit (e.g. "ja" for large-to-
        # small ordering and "ja-Latn" or "en" for small-to-large). This way, the most
        # specific line of an address can be selected based on the language. The minimum
        # permitted structural representation of an address consists of a region_code
        # with all remaining information placed in the address_lines. It would be
        # possible to format such an address very approximately without geocoding, but
        # no semantic reasoning could be made about any of the address components until
        # it was at least partially resolved. Creating an address only containing a
        # region_code and address_lines, and then geocoding is the recommended way to
        # handle completely unstructured addresses (as opposed to guessing which parts
        # of the address should be localities or administrative areas).
        # Corresponds to the JSON property `addressLines`
        # @return [Array<String>]
        attr_accessor :address_lines
      
        # Optional. Highest administrative subdivision which is used for postal
        # addresses of a country or region. For example, this can be a state, a province,
        # an oblast, or a prefecture. Specifically, for Spain this is the province and
        # not the autonomous community (e.g. "Barcelona" and not "Catalonia"). Many
        # countries don't use an administrative area in postal addresses. E.g. in
        # Switzerland this should be left unpopulated.
        # Corresponds to the JSON property `administrativeArea`
        # @return [String]
        attr_accessor :administrative_area
      
        # Optional. BCP-47 language code of the contents of this address (if known).
        # This is often the UI language of the input form or is expected to match one of
        # the languages used in the address' country/region, or their transliterated
        # equivalents. This can affect formatting in certain countries, but is not
        # critical to the correctness of the data and will never affect any validation
        # or other non-formatting related operations. If this value is not known, it
        # should be omitted (rather than specifying a possibly incorrect default).
        # Examples: "zh-Hant", "ja", "ja-Latn", "en".
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # Optional. Generally refers to the city/town portion of the address. Examples:
        # US city, IT comune, UK post town. In regions of the world where localities are
        # not well defined or do not fit into this structure well, leave locality empty
        # and use address_lines.
        # Corresponds to the JSON property `locality`
        # @return [String]
        attr_accessor :locality
      
        # Optional. The name of the organization at the address.
        # Corresponds to the JSON property `organization`
        # @return [String]
        attr_accessor :organization
      
        # Optional. Postal code of the address. Not all countries use or require postal
        # codes to be present, but where they are used, they may trigger additional
        # validation with other parts of the address (e.g. state/zip validation in the U.
        # S.A.).
        # Corresponds to the JSON property `postalCode`
        # @return [String]
        attr_accessor :postal_code
      
        # Optional. The recipient at the address. This field may, under certain
        # circumstances, contain multiline information. For example, it might contain "
        # care of" information.
        # Corresponds to the JSON property `recipients`
        # @return [Array<String>]
        attr_accessor :recipients
      
        # Required. CLDR region code of the country/region of the address. This is never
        # inferred and it is up to the user to ensure the value is correct. See https://
        # cldr.unicode.org/ and https://www.unicode.org/cldr/charts/30/supplemental/
        # territory_information.html for details. Example: "CH" for Switzerland.
        # Corresponds to the JSON property `regionCode`
        # @return [String]
        attr_accessor :region_code
      
        # The schema revision of the `PostalAddress`. This must be set to 0, which is
        # the latest revision. All new revisions **must** be backward compatible with
        # old revisions.
        # Corresponds to the JSON property `revision`
        # @return [Fixnum]
        attr_accessor :revision
      
        # Optional. Additional, country-specific, sorting code. This is not used in most
        # regions. Where it is used, the value is either a string like "CEDEX",
        # optionally followed by a number (e.g. "CEDEX 7"), or just a number alone,
        # representing the "sector code" (Jamaica), "delivery area indicator" (Malawi)
        # or "post office indicator" (e.g. Côte d'Ivoire).
        # Corresponds to the JSON property `sortingCode`
        # @return [String]
        attr_accessor :sorting_code
      
        # Optional. Sublocality of the address. For example, this can be neighborhoods,
        # boroughs, districts.
        # Corresponds to the JSON property `sublocality`
        # @return [String]
        attr_accessor :sublocality
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address_lines = args[:address_lines] if args.key?(:address_lines)
          @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
          @language_code = args[:language_code] if args.key?(:language_code)
          @locality = args[:locality] if args.key?(:locality)
          @organization = args[:organization] if args.key?(:organization)
          @postal_code = args[:postal_code] if args.key?(:postal_code)
          @recipients = args[:recipients] if args.key?(:recipients)
          @region_code = args[:region_code] if args.key?(:region_code)
          @revision = args[:revision] if args.key?(:revision)
          @sorting_code = args[:sorting_code] if args.key?(:sorting_code)
          @sublocality = args[:sublocality] if args.key?(:sublocality)
        end
      end
      
      # Represents a time of day. The date and time zone are either not significant or
      # are specified elsewhere. An API may choose to allow leap seconds. Related
      # types are google.type.Date and `google.protobuf.Timestamp`.
      class GoogleTypeTimeOfDay
        include Google::Apis::Core::Hashable
      
        # Hours of day in 24 hour format. Should be from 0 to 23. An API may choose to
        # allow the value "24:00:00" for scenarios like business closing time.
        # Corresponds to the JSON property `hours`
        # @return [Fixnum]
        attr_accessor :hours
      
        # Minutes of hour of day. Must be from 0 to 59.
        # Corresponds to the JSON property `minutes`
        # @return [Fixnum]
        attr_accessor :minutes
      
        # Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.
        # Corresponds to the JSON property `nanos`
        # @return [Fixnum]
        attr_accessor :nanos
      
        # Seconds of minutes of the time. Must normally be from 0 to 59. An API may
        # allow the value 60 if it allows leap-seconds.
        # Corresponds to the JSON property `seconds`
        # @return [Fixnum]
        attr_accessor :seconds
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hours = args[:hours] if args.key?(:hours)
          @minutes = args[:minutes] if args.key?(:minutes)
          @nanos = args[:nanos] if args.key?(:nanos)
          @seconds = args[:seconds] if args.key?(:seconds)
        end
      end
      
      # Represents a time zone from the [IANA Time Zone Database](https://www.iana.org/
      # time-zones).
      class GoogleTypeTimeZone
        include Google::Apis::Core::Hashable
      
        # IANA Time Zone Database time zone, e.g. "America/New_York".
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Optional. IANA Time Zone Database version number, e.g. "2019a".
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class GroupsPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AuthorId`
        # @return [Fixnum]
        attr_accessor :author_id
      
        # 
        # Corresponds to the JSON property `GroupGaiaId`
        # @return [Fixnum]
        attr_accessor :group_gaia_id
      
        # Legacy group mysql id.
        # Corresponds to the JSON property `GroupId`
        # @return [Fixnum]
        attr_accessor :group_id
      
        # 
        # Corresponds to the JSON property `ThreadId`
        # @return [Fixnum]
        attr_accessor :thread_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author_id = args[:author_id] if args.key?(:author_id)
          @group_gaia_id = args[:group_gaia_id] if args.key?(:group_gaia_id)
          @group_id = args[:group_id] if args.key?(:group_id)
          @thread_id = args[:thread_id] if args.key?(:thread_id)
        end
      end
      
      # 
      class HomeGraphCommonRoute
        include Google::Apis::Core::Hashable
      
        # The device ID defined by the agent.
        # Corresponds to the JSON property `agentDeviceId`
        # @return [String]
        attr_accessor :agent_device_id
      
        # The agent's ID. Generally it is the agent's Google cloud project id.
        # Corresponds to the JSON property `agentId`
        # @return [String]
        attr_accessor :agent_id
      
        # chip endpoint index (if the target is CHIP). Set packed = true to handle error
        # caused by b/32953375 when exporting this data. Note that we should never
        # change this to non-repeated: a packed field will not work properly if you
        # change the field to non-repeated later.
        # Corresponds to the JSON property `chipEndpoint`
        # @return [Array<Fixnum>]
        attr_accessor :chip_endpoint
      
        # Execution routing target.
        # Corresponds to the JSON property `targetType`
        # @return [String]
        attr_accessor :target_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agent_device_id = args[:agent_device_id] if args.key?(:agent_device_id)
          @agent_id = args[:agent_id] if args.key?(:agent_id)
          @chip_endpoint = args[:chip_endpoint] if args.key?(:chip_endpoint)
          @target_type = args[:target_type] if args.key?(:target_type)
        end
      end
      
      # Defines execution routing information for Traits, which will be used to be
      # mapped for each Trait as following: map traits_to_routing_table_map = X; We'll
      # use this for CHIP first. And expect to migrate the existing routing logic to
      # this gradually.
      class HomeGraphCommonRoutingTable
        include Google::Apis::Core::Hashable
      
        # List of supported execution route.
        # Corresponds to the JSON property `supportedRoutes`
        # @return [Array<Google::Apis::ContentwarehouseV1::HomeGraphCommonRoute>]
        attr_accessor :supported_routes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @supported_routes = args[:supported_routes] if args.key?(:supported_routes)
        end
      end
      
      # LINT.IfChange go/shed-per-trait-routing. Making it object to allow for
      # extendible design, where we can add attributes in future.
      class HomeGraphCommonTraitRoutingHints
        include Google::Apis::Core::Hashable
      
        # Set to true for a non-local trait.
        # Corresponds to the JSON property `cloudFulfillmentOnly`
        # @return [Boolean]
        attr_accessor :cloud_fulfillment_only
        alias_method :cloud_fulfillment_only?, :cloud_fulfillment_only
      
        # Trait name, e.g., "action.devices.traits.MediaInitiation". See [device traits](
        # https://developers.google.com/assistant/smarthome/traits). See java/com/google/
        # home/graph/common/devices/config/protoconf.pi for the exhaustive list of trait-
        # strings.
        # Corresponds to the JSON property `trait`
        # @return [String]
        attr_accessor :trait
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_fulfillment_only = args[:cloud_fulfillment_only] if args.key?(:cloud_fulfillment_only)
          @trait = args[:trait] if args.key?(:trait)
        end
      end
      
      # TimingStatPair message stores a timing period name and a time value. This is
      # intentionally vague for doing fine level timing of rendering as what we
      # measure is likely to change as we iterate. The intention is also that these
      # values will just be dumped to varzs for evaluation purposed and not used
      # programmatically.
      class HtmlrenderWebkitHeadlessProtoAnonTimingStatPair
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `timeS`
        # @return [Float]
        attr_accessor :time_s
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @time_s = args[:time_s] if args.key?(:time_s)
        end
      end
      
      # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
      # Coordinates are in pixels.
      class HtmlrenderWebkitHeadlessProtoBox
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        # on horizontal axis
        # Corresponds to the JSON property `x`
        # @return [Fixnum]
        attr_accessor :x
      
        # on vertical axis
        # Corresponds to the JSON property `y`
        # @return [Fixnum]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @width = args[:width] if args.key?(:width)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # A message to describe the trace events returned by Chromium.
      class HtmlrenderWebkitHeadlessProtoChromiumTrace
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `chromiumTrace`
        # @return [String]
        attr_accessor :chromium_trace
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chromium_trace = args[:chromium_trace] if args.key?(:chromium_trace)
        end
      end
      
      # ConsoleLogEntry message stores messages logged by the renderer to the console.
      # Typically error messages related to JS execution, parsing, any CSS errors, etc
      # are logged by the renderer to the console. Next id: 7.
      class HtmlrenderWebkitHeadlessProtoConsoleLogEntry
        include Google::Apis::Core::Hashable
      
        # Line number of the document which caused an error.
        # Corresponds to the JSON property `lineNumber`
        # @return [Fixnum]
        attr_accessor :line_number
      
        # Message which indicates the nature of the error. e.g. parse error, reference
        # error (happens when javascript functions or variables are not resolvable) etc.
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        # message level
        # Corresponds to the JSON property `messageLevel`
        # @return [String]
        attr_accessor :message_level
      
        # The url of the document which has the error.
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # Stack trace which functions were called when generating the console log. The
        # first frame is the innermost one.
        # Corresponds to the JSON property `stackTrace`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoScriptStackFrame>]
        attr_accessor :stack_trace
      
        # Wall time (s) when the log entry was recorded
        # Corresponds to the JSON property `timestamp`
        # @return [Float]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @line_number = args[:line_number] if args.key?(:line_number)
          @message = args[:message] if args.key?(:message)
          @message_level = args[:message_level] if args.key?(:message_level)
          @source_url = args[:source_url] if args.key?(:source_url)
          @stack_trace = args[:stack_trace] if args.key?(:stack_trace)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoCookie
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `expiration`
        # @return [Float]
        attr_accessor :expiration
      
        # 
        # Corresponds to the JSON property `httpOnly`
        # @return [Boolean]
        attr_accessor :http_only
        alias_method :http_only?, :http_only
      
        # 
        # Corresponds to the JSON property `name`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `path`
        # @return [String]
        attr_accessor :path
      
        # 
        # Corresponds to the JSON property `sameSite`
        # @return [String]
        attr_accessor :same_site
      
        # 
        # Corresponds to the JSON property `secure`
        # @return [Boolean]
        attr_accessor :secure
        alias_method :secure?, :secure
      
        # 
        # Corresponds to the JSON property `value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
          @expiration = args[:expiration] if args.key?(:expiration)
          @http_only = args[:http_only] if args.key?(:http_only)
          @name = args[:name] if args.key?(:name)
          @path = args[:path] if args.key?(:path)
          @same_site = args[:same_site] if args.key?(:same_site)
          @secure = args[:secure] if args.key?(:secure)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoDomStorageItem
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # 
        # Corresponds to the JSON property `securityOrigin`
        # @return [String]
        attr_accessor :security_origin
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @security_origin = args[:security_origin] if args.key?(:security_origin)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # DOMTreeNode Defines a DOM Node. An instance can contain references to one or
      # more children (of type DOMTreeNode) and one or more attributes. The
      # DOMTreeNode also encapsulates rendering information (if applicable) in the
      # form of references to one or more RenderTreeNodes. Next tag available: 16
      class HtmlrenderWebkitHeadlessProtoDomTreeNode
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attribute`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDomTreeNodeAttribute>]
        attr_accessor :attribute
      
        # An index per child. Indexes can be used to fetch the DOMTreeNodes from the
        # list maintained by the Document.
        # Corresponds to the JSON property `childDomTreeNodeIndex`
        # @return [Array<Fixnum>]
        attr_accessor :child_dom_tree_node_index
      
        # For elements, the actual url that was used to fetch the image. Note that this
        # field is set only if it is different from the 'src' attribute value.
        # Corresponds to the JSON property `currentSourceUrl`
        # @return [String]
        attr_accessor :current_source_url
      
        # Next available tag: 24
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDocument]
        attr_accessor :document
      
        # Identifies the HTML tag type (IMG, P, DIV, etc). Applicable only for DOM nodes
        # that are representative of html elements. For a list of possible types refer
        # HtmlTagEnum defined in webutil/html/htmltagenum.h.
        # Corresponds to the JSON property `htmlTagType`
        # @return [Fixnum]
        attr_accessor :html_tag_type
      
        # Whether this DOM node responds to mouse clicks. This includes e.g. nodes that
        # have had click event listeners attached via JavaScript as well as e.g. anchor
        # tags that naturally navigate when clicked.
        # Corresponds to the JSON property `isClickable`
        # @return [Boolean]
        attr_accessor :is_clickable
        alias_method :is_clickable?, :is_clickable
      
        # Name of the node (document, text, comment, div, etc).
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # URL of the script, if any, which created or populated this node.
        # Corresponds to the JSON property `originUrl`
        # @return [String]
        attr_accessor :origin_url
      
        # List of referenced resource indexes for any resources that this DOM tree node
        # references.
        # Corresponds to the JSON property `referencedResourceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :referenced_resource_index
      
        # RenderTreeNode can be looked up from the list of RenderTreeNodes stored in the
        # Document using render_tree_node_index. RenderTreeNode gives rendering
        # information (bounding box, style that was applied, etc). Note: 1. If a
        # DOMTreeNode does not have a RenderTreeNode then it is safe to assume that the
        # DOMTreeNode has no effect on the rendering. DOMTreeNodes for a ,
        # Corresponds to the JSON property `renderTreeNodeIndex`
        # @return [Array<Fixnum>]
        attr_accessor :render_tree_node_index
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The node value is applicable for TEXT_NODEs, DOCUMENT_TYPE_NODEs, and user
        # input elements such as , and <option>. For DOCUMENT_TYPE_NODEs, the value
        # contains the publicId and SystemId. For input elements, the value reflects the
        # current value in the element at the time the snapshot was taken.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute = args[:attribute] if args.key?(:attribute)
          @child_dom_tree_node_index = args[:child_dom_tree_node_index] if args.key?(:child_dom_tree_node_index)
          @current_source_url = args[:current_source_url] if args.key?(:current_source_url)
          @document = args[:document] if args.key?(:document)
          @html_tag_type = args[:html_tag_type] if args.key?(:html_tag_type)
          @is_clickable = args[:is_clickable] if args.key?(:is_clickable)
          @name = args[:name] if args.key?(:name)
          @origin_url = args[:origin_url] if args.key?(:origin_url)
          @referenced_resource_index = args[:referenced_resource_index] if args.key?(:referenced_resource_index)
          @render_tree_node_index = args[:render_tree_node_index] if args.key?(:render_tree_node_index)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Zero or more attributes for the node.
      class HtmlrenderWebkitHeadlessProtoDomTreeNodeAttribute
        include Google::Apis::Core::Hashable
      
        # Identifies the HTML attribute type (src, width, height, etc). For a list of
        # possible types refer HtmlAttributeEnum defined in webutil/html/htmlattrenum.h.
        # Corresponds to the JSON property `htmlAttributeType`
        # @return [Fixnum]
        attr_accessor :html_attribute_type
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @html_attribute_type = args[:html_attribute_type] if args.key?(:html_attribute_type)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Next available tag: 24
      class HtmlrenderWebkitHeadlessProtoDocument
        include Google::Apis::Core::Hashable
      
        # Document's base uri.
        # Corresponds to the JSON property `baseUri`
        # @return [String]
        attr_accessor :base_uri
      
        # Document's charset.
        # Corresponds to the JSON property `charset`
        # @return [String]
        attr_accessor :charset
      
        # 
        # Corresponds to the JSON property `contentHeight`
        # @return [Fixnum]
        attr_accessor :content_height
      
        # Document's language.
        # Corresponds to the JSON property `contentLanguage`
        # @return [String]
        attr_accessor :content_language
      
        # These fields contain the actual width and height of the document content,
        # which may exceed the size of the rendering viewport. *DEPRECATED* Use
        # rendered_content_area instead. These two fields always assume the content area
        # begins at viewport coordinates (0,0).
        # Corresponds to the JSON property `contentWidth`
        # @return [Fixnum]
        attr_accessor :content_width
      
        # A flat list of all the DOMTreeNodes in the DOM. A flat list is preferred to a
        # tree to avoid recursion and potential stack overflows. Note that the first
        # node in this list will always be the root node.
        # Corresponds to the JSON property `domTreeNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDomTreeNode>]
        attr_accessor :dom_tree_node
      
        # A unique identifier for the frame (browser window of iframe) this document is
        # loaded in. This identifier matches the identifiers used in the timeline data
        # to identify frames and therefore only set if the record_timeline field of the
        # RenderRequest message was set to true. frame_id is not supported on Chromium.
        # Corresponds to the JSON property `frameId`
        # @return [String]
        attr_accessor :frame_id
      
        # The name of the frame (browser window of iframe) this document is loaded in.
        # May not be set if the frame name was empty.
        # Corresponds to the JSON property `frameName`
        # @return [String]
        attr_accessor :frame_name
      
        # --------------------------------------------------------------------------
        # Input context. These fields are copied from RenderRequest so that Document can
        # be a self contained protobuf. We would've liked to place them in a ## nested
        # InputContext message but it's too late now. ## Time specified to RenderRequest.
        # JavaScriptOptions.time_of_day, if any. ## End of input context. Output-only
        # fields below.
        # Corresponds to the JSON property `javascriptTimeOfDay`
        # @return [Float]
        attr_accessor :javascript_time_of_day
      
        # The chain of redirects (and redirect methods) used to get to the final
        # resource for this Document. Deprecated: Use the redirect events in the
        # render_event field instead.
        # Corresponds to the JSON property `redirectHop`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRedirectHop>]
        attr_accessor :redirect_hop
      
        # Contains a list of Resources which the renderer requested -- both those that
        # were found and those that were not. Resources are returned in the order that
        # they were requested.
        # Corresponds to the JSON property `referencedResource`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoReferencedResource>]
        attr_accessor :referenced_resource
      
        # Different types of events which happened during rendering. All events for this
        # document's frame are included, so for example if a confirmation dialog is
        # created before a client redirect to this document the ConfirmationDialogEvent
        # will still be included even though the dialog was created by a different
        # document. See render_event.proto for the types of events which are recorded.
        # Note that this is present regardless of whether record_timeline was set in the
        # RenderRequest.
        # Corresponds to the JSON property `renderEvent`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderEvent>]
        attr_accessor :render_event
      
        # See htmlrender_webkit_headless_utils::SerializeRenderStyle() if a serialized
        # css string is wanted.
        # Corresponds to the JSON property `renderStyle`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoStyle>]
        attr_accessor :render_style
      
        # A flat list of all the RenderTreeNodes from the render tree. A flat list is
        # preferred to a tree to avoid recursion and potential stack overflows. Note
        # that the first node in this list will always be the RenderTreeNode for the #
        # document node (aka root).
        # Corresponds to the JSON property `renderTreeNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderTreeNode>]
        attr_accessor :render_tree_node
      
        # DEPRECATED - This field to be removed mid-2011. If you need this, use the
        # library directly: //google3/htmlrender/webkit_headless/snapshot_quality
        # Indicates how good or bad the rendering is from the perspective of the render
        # tree. This is different from snapshot_quality_score in that the quality
        # analysis examines everything that can be rendered, not just the portion within
        # the document's viewport. It also ignores missing resouces with fixed width/
        # height specified in the tag. A score of 1 (100%) implies the entire document
        # can be rendered at the best quality and a score of 0 implies the entire
        # document is unusable.
        # Corresponds to the JSON property `renderTreeQualityScore`
        # @return [Float]
        attr_accessor :render_tree_quality_score
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `renderedContentArea`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :rendered_content_area
      
        # Scroll offset of this document within the frame. Note that if
        # expand_frame_to_content_height or expand_frame_to_content_width is true, this
        # field reflects the final scroll offset after frame expansion.
        # Corresponds to the JSON property `scrollX`
        # @return [Fixnum]
        attr_accessor :scroll_x
      
        # 
        # Corresponds to the JSON property `scrollY`
        # @return [Fixnum]
        attr_accessor :scroll_y
      
        # DEPRECATED - This field to be removed mid-2011. If you need this, use the
        # library directly: //google3/htmlrender/webkit_headless/snapshot_quality
        # Indicates how good or bad the rendered snapshot is within the rendered content
        # area within the document's viewport. A score of 1 (100%) implies the snapshot
        # is of best quality and a score of 0 implies the snapshot is unusable.
        # Corresponds to the JSON property `snapshotQualityScore`
        # @return [Float]
        attr_accessor :snapshot_quality_score
      
        # Document's title.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Document uri is the URL that this document was fetched from. The displayed URL
        # and base URL may be different. If this document was not fetched from any URL (
        # e.g. iframe with no src, populated by script) uri will be "about:blank".
        # Corresponds to the JSON property `uri`
        # @return [String]
        attr_accessor :uri
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `viewport`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :viewport
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_uri = args[:base_uri] if args.key?(:base_uri)
          @charset = args[:charset] if args.key?(:charset)
          @content_height = args[:content_height] if args.key?(:content_height)
          @content_language = args[:content_language] if args.key?(:content_language)
          @content_width = args[:content_width] if args.key?(:content_width)
          @dom_tree_node = args[:dom_tree_node] if args.key?(:dom_tree_node)
          @frame_id = args[:frame_id] if args.key?(:frame_id)
          @frame_name = args[:frame_name] if args.key?(:frame_name)
          @javascript_time_of_day = args[:javascript_time_of_day] if args.key?(:javascript_time_of_day)
          @redirect_hop = args[:redirect_hop] if args.key?(:redirect_hop)
          @referenced_resource = args[:referenced_resource] if args.key?(:referenced_resource)
          @render_event = args[:render_event] if args.key?(:render_event)
          @render_style = args[:render_style] if args.key?(:render_style)
          @render_tree_node = args[:render_tree_node] if args.key?(:render_tree_node)
          @render_tree_quality_score = args[:render_tree_quality_score] if args.key?(:render_tree_quality_score)
          @rendered_content_area = args[:rendered_content_area] if args.key?(:rendered_content_area)
          @scroll_x = args[:scroll_x] if args.key?(:scroll_x)
          @scroll_y = args[:scroll_y] if args.key?(:scroll_y)
          @snapshot_quality_score = args[:snapshot_quality_score] if args.key?(:snapshot_quality_score)
          @title = args[:title] if args.key?(:title)
          @uri = args[:uri] if args.key?(:uri)
          @viewport = args[:viewport] if args.key?(:viewport)
        end
      end
      
      # Event for frame resize. Currently we only record resize events caused by
      # automatic frame expansion.
      class HtmlrenderWebkitHeadlessProtoFrameResizeEvent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `resizeType`
        # @return [String]
        attr_accessor :resize_type
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `visibleRectAfterResize`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :visible_rect_after_resize
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `visibleRectBeforeResize`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :visible_rect_before_resize
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @resize_type = args[:resize_type] if args.key?(:resize_type)
          @visible_rect_after_resize = args[:visible_rect_after_resize] if args.key?(:visible_rect_after_resize)
          @visible_rect_before_resize = args[:visible_rect_before_resize] if args.key?(:visible_rect_before_resize)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoImage
        include Google::Apis::Core::Hashable
      
        # The binary image data, stored in a format decided by the application and a
        # particular RenderService implementation.
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # The page number if this is an image of a page from a print-mode rendering.
        # Corresponds to the JSON property `pageNumber`
        # @return [Fixnum]
        attr_accessor :page_number
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `viewport`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :viewport
      
        # The width and height of the image stored in the data field.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @height = args[:height] if args.key?(:height)
          @page_number = args[:page_number] if args.key?(:page_number)
          @viewport = args[:viewport] if args.key?(:viewport)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Event for the initial load of a frame, including main frame and subframes.
      class HtmlrenderWebkitHeadlessProtoInitialLoadEvent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Event for a modal dialog created by one of window.confirm(), window.prompt(),
      # or window.alert().
      class HtmlrenderWebkitHeadlessProtoModalDialogEvent
        include Google::Apis::Core::Hashable
      
        # Whether a confirm() or prompt() dialog was confirmed. Will not be present for
        # an alert() dialog.
        # Corresponds to the JSON property `confirmed`
        # @return [Boolean]
        attr_accessor :confirmed
        alias_method :confirmed?, :confirmed
      
        # 
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        # For a prompt() dialog, the result of the prompt. Will not be present for other
        # types of dialogs. If confirmed == false and the prompt had a default value,
        # result will contain the default value.
        # Corresponds to the JSON property `result`
        # @return [String]
        attr_accessor :result
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confirmed = args[:confirmed] if args.key?(:confirmed)
          @message = args[:message] if args.key?(:message)
          @result = args[:result] if args.key?(:result)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoOffset
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @unit = args[:unit] if args.key?(:unit)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # PartialRenders can be created using the extension API to store the document
      # state and/or create an image at points before the final render.
      class HtmlrenderWebkitHeadlessProtoPartialRender
        include Google::Apis::Core::Hashable
      
        # Cookies at the time of snapshot creation.
        # Corresponds to the JSON property `cookie`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoCookie>]
        attr_accessor :cookie
      
        # Current url as would appear in the web browser's address bar at the time of
        # snapshot creation.
        # Corresponds to the JSON property `currentClientUrl`
        # @return [String]
        attr_accessor :current_client_url
      
        # Next available tag: 24
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDocument]
        attr_accessor :document
      
        # ID set by the render extension
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Image of the render, if requested
        # Corresponds to the JSON property `image`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoImage]
        attr_accessor :image
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cookie = args[:cookie] if args.key?(:cookie)
          @current_client_url = args[:current_client_url] if args.key?(:current_client_url)
          @document = args[:document] if args.key?(:document)
          @id = args[:id] if args.key?(:id)
          @image = args[:image] if args.key?(:image)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoPdf
        include Google::Apis::Core::Hashable
      
        # The binary PDF data.
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoRectangle
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `bottom`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :bottom
      
        # 
        # Corresponds to the JSON property `left`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :left
      
        # 
        # Corresponds to the JSON property `right`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :right
      
        # A missing value for any field in this message means 'auto'.
        # Corresponds to the JSON property `top`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :top
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bottom = args[:bottom] if args.key?(:bottom)
          @left = args[:left] if args.key?(:left)
          @right = args[:right] if args.key?(:right)
          @top = args[:top] if args.key?(:top)
        end
      end
      
      # A redirect event represents a change in the resource URL for a document. This
      # includes HTTP redirects, as well things which trigger client navigations such
      # as script changing window.location, tags, HTTP Refresh headers, etc.
      class HtmlrenderWebkitHeadlessProtoRedirectEvent
        include Google::Apis::Core::Hashable
      
        # The HTTP method of the request for the redirect target.
        # Corresponds to the JSON property `httpMethod`
        # @return [String]
        attr_accessor :http_method
      
        # For HTTP redirects, the HTTP status code returned in the initial HTTP response.
        # Corresponds to the JSON property `httpStatusCode`
        # @return [Fixnum]
        attr_accessor :http_status_code
      
        # 
        # Corresponds to the JSON property `refreshType`
        # @return [String]
        attr_accessor :refresh_type
      
        # True if the redirect led to a download instead of loading a new page. Note
        # that such redirects can appear anywhere in the list of redirect events.
        # Corresponds to the JSON property `targetContentDownloaded`
        # @return [Boolean]
        attr_accessor :target_content_downloaded
        alias_method :target_content_downloaded?, :target_content_downloaded
      
        # 
        # Corresponds to the JSON property `targetUrl`
        # @return [String]
        attr_accessor :target_url
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @http_method = args[:http_method] if args.key?(:http_method)
          @http_status_code = args[:http_status_code] if args.key?(:http_status_code)
          @refresh_type = args[:refresh_type] if args.key?(:refresh_type)
          @target_content_downloaded = args[:target_content_downloaded] if args.key?(:target_content_downloaded)
          @target_url = args[:target_url] if args.key?(:target_url)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoRedirectHop
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # The redirect target url.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # ReferencedResource contains an entry per url referenced by the browser while
      # rendering a document. Next tag available: 20
      class HtmlrenderWebkitHeadlessProtoReferencedResource
        include Google::Apis::Core::Hashable
      
        # True if this fetch was canceled due to render server policy. e.g. the page
        # exceeded the fetch budget or an extension canceled the fetch.
        # Corresponds to the JSON property `canceled`
        # @return [Boolean]
        attr_accessor :canceled
        alias_method :canceled?, :canceled
      
        # Content type of this resource (webutil/http/content-type.h). The content type
        # is from guess based on the file extension, any mime type in http headers at
        # the beginning of the content, any content-disposition http header, and the
        # content body itself. Note: the content type defined in webutil/http/content-
        # type.proto is incomplete. If you are interested in missing types, please
        # update the enum and the logic of content type detection.
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # DOMTreeNode index which has the url as one of its attributes specified using
        # either src, href or background attributes. src attribute applies to img,
        # script, frame and iframe nodes, href applies to link nodes and background
        # applies to body node. It is possible for a url to be referenced by multiple
        # DOM nodes. For e.g. an tag with the same src attribute can occur in multiple
        # places within a document. It is possible for a url to not have any DOM node
        # reference. For example, redirects don't have DOM tree nodes.
        # Corresponds to the JSON property `domTreeNodeIndex`
        # @return [Array<Fixnum>]
        attr_accessor :dom_tree_node_index
      
        # True when a HTTP request succeeded but the resource was not made accessible to
        # script due to a HTTP Access Control (CORS) failure. This field is not
        # implemented on Chromium.
        # Corresponds to the JSON property `failedHttpAccessControlCheck`
        # @return [Boolean]
        attr_accessor :failed_http_access_control_check
        alias_method :failed_http_access_control_check?, :failed_http_access_control_check
      
        # Where this resource comes from.
        # Corresponds to the JSON property `fetchSourceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::WirelessTranscoderFetchFetchSourceInfo>]
        attr_accessor :fetch_source_info
      
        # The FetchStatus returned by the fetcher. Values are taken from
        # wireless_transcoder_fetch.FetchConstants.FetchStatus in fetch_service.proto.
        # The default value is SUCCESS(0).
        # Corresponds to the JSON property `fetchStatus`
        # @return [String]
        attr_accessor :fetch_status
      
        # HTTP headers from the fetcher.
        # Corresponds to the JSON property `httpHeader`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoReferencedResourceHttpHeader>]
        attr_accessor :http_header
      
        # HTTP response code if we had tried to fetch the url. Absence of this field
        # indicates either we have not tried to fetch the url or the fetcher never got
        # back to us with any response.
        # Corresponds to the JSON property `httpResponseCode`
        # @return [Fixnum]
        attr_accessor :http_response_code
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::WirelessTranscoderFetchFetchMetadata>]
        attr_accessor :metadata
      
        # The post_data field is only valid when the HTTP request method is POST.
        # Corresponds to the JSON property `postData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :post_data
      
        # If the http_response_code is a HTTP redirect, the redirect target will be
        # stored here.
        # Corresponds to the JSON property `redirectTarget`
        # @return [String]
        attr_accessor :redirect_target
      
        # Indicates which referenced_resource_content (in RenderResponse) this
        # RefencedResource points to. This field will be set only when there is
        # referenced_resource_content for this RefencedResource in RenderResponse.
        # Corresponds to the JSON property `referencedResourceContentIndex`
        # @return [Fixnum]
        attr_accessor :referenced_resource_content_index
      
        # 
        # Corresponds to the JSON property `requestHeader`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoReferencedResourceHttpHeader>]
        attr_accessor :request_header
      
        # The HTTP request method (GET, HEAD, POST, etc) used for this request. Values
        # are taken from the HTTPHeaders::Protocol enum in webutil/http/httputils.h.
        # HTTPHeaders::PROTO_GET
        # Corresponds to the JSON property `requestMethod`
        # @return [Fixnum]
        attr_accessor :request_method
      
        # style index which has the url specified using either the background-image
        # property or the list-style-image property.
        # Corresponds to the JSON property `styleIndex`
        # @return [Array<Fixnum>]
        attr_accessor :style_index
      
        # Whether it is synchronously fetched.
        # Corresponds to the JSON property `synchronouslyFetched`
        # @return [Boolean]
        attr_accessor :synchronously_fetched
        alias_method :synchronously_fetched?, :synchronously_fetched
      
        # 
        # Corresponds to the JSON property `timing`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoReferencedResourceFetchTiming>]
        attr_accessor :timing
      
        # Does not have a #fragment.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # WebkKitFetchMetadata holds additional webkit-specific information for a single
        # resource fetch.
        # Corresponds to the JSON property `webkitMetadata`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoWebKitFetchMetadata]
        attr_accessor :webkit_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canceled = args[:canceled] if args.key?(:canceled)
          @content_type = args[:content_type] if args.key?(:content_type)
          @dom_tree_node_index = args[:dom_tree_node_index] if args.key?(:dom_tree_node_index)
          @failed_http_access_control_check = args[:failed_http_access_control_check] if args.key?(:failed_http_access_control_check)
          @fetch_source_info = args[:fetch_source_info] if args.key?(:fetch_source_info)
          @fetch_status = args[:fetch_status] if args.key?(:fetch_status)
          @http_header = args[:http_header] if args.key?(:http_header)
          @http_response_code = args[:http_response_code] if args.key?(:http_response_code)
          @metadata = args[:metadata] if args.key?(:metadata)
          @post_data = args[:post_data] if args.key?(:post_data)
          @redirect_target = args[:redirect_target] if args.key?(:redirect_target)
          @referenced_resource_content_index = args[:referenced_resource_content_index] if args.key?(:referenced_resource_content_index)
          @request_header = args[:request_header] if args.key?(:request_header)
          @request_method = args[:request_method] if args.key?(:request_method)
          @style_index = args[:style_index] if args.key?(:style_index)
          @synchronously_fetched = args[:synchronously_fetched] if args.key?(:synchronously_fetched)
          @timing = args[:timing] if args.key?(:timing)
          @url = args[:url] if args.key?(:url)
          @webkit_metadata = args[:webkit_metadata] if args.key?(:webkit_metadata)
        end
      end
      
      # Timing data produced by the fetcher.
      class HtmlrenderWebkitHeadlessProtoReferencedResourceFetchTiming
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `finishMsec`
        # @return [Fixnum]
        attr_accessor :finish_msec
      
        # A string identifying the fetcher that added this timing information.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # UNIX epoch timestamps in milliseconds.
        # Corresponds to the JSON property `startMsec`
        # @return [Fixnum]
        attr_accessor :start_msec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @finish_msec = args[:finish_msec] if args.key?(:finish_msec)
          @name = args[:name] if args.key?(:name)
          @start_msec = args[:start_msec] if args.key?(:start_msec)
        end
      end
      
      # HTTP Headers included with the resource request.
      class HtmlrenderWebkitHeadlessProtoReferencedResourceHttpHeader
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoRenderEvent
        include Google::Apis::Core::Hashable
      
        # Event for frame resize. Currently we only record resize events caused by
        # automatic frame expansion.
        # Corresponds to the JSON property `frameResize`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoFrameResizeEvent]
        attr_accessor :frame_resize
      
        # Event for the initial load of a frame, including main frame and subframes.
        # Corresponds to the JSON property `initialLoad`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoInitialLoadEvent]
        attr_accessor :initial_load
      
        # Event for a modal dialog created by one of window.confirm(), window.prompt(),
        # or window.alert().
        # Corresponds to the JSON property `modalDialog`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoModalDialogEvent]
        attr_accessor :modal_dialog
      
        # A redirect event represents a change in the resource URL for a document. This
        # includes HTTP redirects, as well things which trigger client navigations such
        # as script changing window.location, tags, HTTP Refresh headers, etc.
        # Corresponds to the JSON property `redirect`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRedirectEvent]
        attr_accessor :redirect
      
        # The URL of the script which caused this event, if any. Analogous to origin_url
        # in DOMTreeNode.
        # Corresponds to the JSON property `scriptOriginUrl`
        # @return [String]
        attr_accessor :script_origin_url
      
        # Virtual time of the event, as an offset from the beginning of the render in
        # seconds.
        # Corresponds to the JSON property `virtualTimeOffset`
        # @return [Float]
        attr_accessor :virtual_time_offset
      
        # Corresponds to a call to window.open(). Note that a WindowOpenEvent will be
        # present whether or not the call was successful.
        # Corresponds to the JSON property `windowOpen`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoWindowOpenEvent]
        attr_accessor :window_open
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_resize = args[:frame_resize] if args.key?(:frame_resize)
          @initial_load = args[:initial_load] if args.key?(:initial_load)
          @modal_dialog = args[:modal_dialog] if args.key?(:modal_dialog)
          @redirect = args[:redirect] if args.key?(:redirect)
          @script_origin_url = args[:script_origin_url] if args.key?(:script_origin_url)
          @virtual_time_offset = args[:virtual_time_offset] if args.key?(:virtual_time_offset)
          @window_open = args[:window_open] if args.key?(:window_open)
        end
      end
      
      # Results returned by a render server extension. Next id: 3
      class HtmlrenderWebkitHeadlessProtoRenderExtensionResult
        include Google::Apis::Core::Hashable
      
        # Log messages and errors generated by extension script.
        # Corresponds to the JSON property `consoleLogEntry`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoConsoleLogEntry>]
        attr_accessor :console_log_entry
      
        # 
        # Corresponds to the JSON property `result`
        # @return [String]
        attr_accessor :result
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @console_log_entry = args[:console_log_entry] if args.key?(:console_log_entry)
          @result = args[:result] if args.key?(:result)
        end
      end
      
      # See go/wrs-render-quality for how to evaluate the results. Next id: 24
      class HtmlrenderWebkitHeadlessProtoRenderResponse
        include Google::Apis::Core::Hashable
      
        # A message to describe the trace events returned by Chromium.
        # Corresponds to the JSON property `chromiumTrace`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoChromiumTrace]
        attr_accessor :chromium_trace
      
        # Contents of the browser's cookie jar. (if cookies_enabled was set to true in
        # the RenderRequest).
        # Corresponds to the JSON property `cookie`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoCookie>]
        attr_accessor :cookie
      
        # Next available tag: 24
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDocument]
        attr_accessor :document
      
        # Provides extra debugging details when certain exception bits are set.
        # Corresponds to the JSON property `exceptionDetail`
        # @return [String]
        attr_accessor :exception_detail
      
        # Exceptions (possibly serious conditions) that occurred during this rendering.
        # 0 means none. Bitfield encoding. See the RenderingException enum above for an
        # explanation.
        # Corresponds to the JSON property `exceptions`
        # @return [Fixnum]
        attr_accessor :exceptions
      
        # Results returned by a render server extension. Next id: 3
        # Corresponds to the JSON property `extensionResult`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderExtensionResult]
        attr_accessor :extension_result
      
        # This field contains the final url as would appear in the web browser's address
        # bar. Note that JavaScript can modify the contents of the location bar so this
        # URL may not appear on the list of referenced resources. If we fail to follow a
        # redirect this field will contain the URL that we failed to redirect to, not
        # the last one we successfully loaded.
        # Corresponds to the JSON property `finalClientUrl`
        # @return [String]
        attr_accessor :final_client_url
      
        # Contains the viewport images rendered by webkit (if generate_image was set to
        # true in the RenderRequest). Will also contain the print-mode images (if
        # generate_print_mode_images was set to true).
        # Corresponds to the JSON property `image`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoImage>]
        attr_accessor :image
      
        # Contents of the browser's local storage.
        # Corresponds to the JSON property `localStorage`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDomStorageItem>]
        attr_accessor :local_storage
      
        # Partial render snapshots (if requested by a render extension)
        # Corresponds to the JSON property `partialRender`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoPartialRender>]
        attr_accessor :partial_render
      
        # Contains the PDF document (if generate_pdf was set to true in the
        # RenderRequest)
        # Corresponds to the JSON property `pdf`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoPdf]
        attr_accessor :pdf
      
        # Contents for all the urls fetched by the render server. This field is present
        # only if generate_referenced_resource_content was set to true in the
        # RenderRequest.
        # Corresponds to the JSON property `referencedResourceContent`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoResource>]
        attr_accessor :referenced_resource_content
      
        # Next id: 17.
        # Corresponds to the JSON property `renderStats`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderStats]
        attr_accessor :render_stats
      
        # Contents of the browser's session storage.
        # Corresponds to the JSON property `sessionStorage`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoDomStorageItem>]
        attr_accessor :session_storage
      
        # Contains the page title produced by webkit, in the UTF-8 encoding.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chromium_trace = args[:chromium_trace] if args.key?(:chromium_trace)
          @cookie = args[:cookie] if args.key?(:cookie)
          @document = args[:document] if args.key?(:document)
          @exception_detail = args[:exception_detail] if args.key?(:exception_detail)
          @exceptions = args[:exceptions] if args.key?(:exceptions)
          @extension_result = args[:extension_result] if args.key?(:extension_result)
          @final_client_url = args[:final_client_url] if args.key?(:final_client_url)
          @image = args[:image] if args.key?(:image)
          @local_storage = args[:local_storage] if args.key?(:local_storage)
          @partial_render = args[:partial_render] if args.key?(:partial_render)
          @pdf = args[:pdf] if args.key?(:pdf)
          @referenced_resource_content = args[:referenced_resource_content] if args.key?(:referenced_resource_content)
          @render_stats = args[:render_stats] if args.key?(:render_stats)
          @session_storage = args[:session_storage] if args.key?(:session_storage)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Next id: 17.
      class HtmlrenderWebkitHeadlessProtoRenderStats
        include Google::Apis::Core::Hashable
      
        # Deliberately non-named fine timing stats. These are all related to each other
        # and unrelated to other timing stats in this message.
        # Corresponds to the JSON property `anonRenderFineTimingStats`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoAnonTimingStatPair>]
        attr_accessor :anon_render_fine_timing_stats
      
        # Any messages logged by the renderer to the console. Note that we capture a
        # subset of the messages logged by the renderer here to avoid explosion.
        # Corresponds to the JSON property `consoleLogEntry`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoConsoleLogEntry>]
        attr_accessor :console_log_entry
      
        # 
        # Corresponds to the JSON property `counter`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderStatsCounter>]
        attr_accessor :counter
      
        # Time to build document and render tree response data.
        # Corresponds to the JSON property `documentBuildTimeMsec`
        # @return [Fixnum]
        attr_accessor :document_build_time_msec
      
        # Number of dropped log messages. Since we capture only a subset of the messages
        # in console_log_entry this field is included just so that the consumers can get
        # an idea of how many actual attempts were made by the renderer.
        # Corresponds to the JSON property `droppedLogEntryCount`
        # @return [Fixnum]
        attr_accessor :dropped_log_entry_count
      
        # Image encoding (e.g. raw -> PNG) time.
        # Corresponds to the JSON property `imageEncodingTimeMsec`
        # @return [Fixnum]
        attr_accessor :image_encoding_time_msec
      
        # Image scaling time.
        # Corresponds to the JSON property `imageScalingTimeMsec`
        # @return [Fixnum]
        attr_accessor :image_scaling_time_msec
      
        # Time from starting render to document finished loading. This includes all
        # fetches, parsing, decoding, running JavaScript, etc.
        # Corresponds to the JSON property `layoutTimeMsec`
        # @return [Fixnum]
        attr_accessor :layout_time_msec
      
        # Time required to paint a document into our buffer.
        # Corresponds to the JSON property `paintTimeMsec`
        # @return [Fixnum]
        attr_accessor :paint_time_msec
      
        # Total cost this render spent running and RPC cost in milliGCUs.
        # Corresponds to the JSON property `renderCostMgcu`
        # @return [Fixnum]
        attr_accessor :render_cost_mgcu
      
        # Render engine used to render this document.
        # Corresponds to the JSON property `renderEngine`
        # @return [String]
        attr_accessor :render_engine
      
        # Total CPU time this render spent running in milliseconds.
        # Corresponds to the JSON property `renderRunningTimeMsec`
        # @return [Fixnum]
        attr_accessor :render_running_time_msec
      
        # The CL from which the render engine was built.
        # Corresponds to the JSON property `renderServerBaselineCl`
        # @return [Fixnum]
        attr_accessor :render_server_baseline_cl
      
        # Total wall time taken to render a document in milliseconds.
        # Corresponds to the JSON property `renderTimeMsec`
        # @return [Fixnum]
        attr_accessor :render_time_msec
      
        # Total time spent in the sandbox in milliseconds. This time includes all phases
        # measured individually below.
        # Corresponds to the JSON property `sandboxRenderTimeMsec`
        # @return [Fixnum]
        attr_accessor :sandbox_render_time_msec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anon_render_fine_timing_stats = args[:anon_render_fine_timing_stats] if args.key?(:anon_render_fine_timing_stats)
          @console_log_entry = args[:console_log_entry] if args.key?(:console_log_entry)
          @counter = args[:counter] if args.key?(:counter)
          @document_build_time_msec = args[:document_build_time_msec] if args.key?(:document_build_time_msec)
          @dropped_log_entry_count = args[:dropped_log_entry_count] if args.key?(:dropped_log_entry_count)
          @image_encoding_time_msec = args[:image_encoding_time_msec] if args.key?(:image_encoding_time_msec)
          @image_scaling_time_msec = args[:image_scaling_time_msec] if args.key?(:image_scaling_time_msec)
          @layout_time_msec = args[:layout_time_msec] if args.key?(:layout_time_msec)
          @paint_time_msec = args[:paint_time_msec] if args.key?(:paint_time_msec)
          @render_cost_mgcu = args[:render_cost_mgcu] if args.key?(:render_cost_mgcu)
          @render_engine = args[:render_engine] if args.key?(:render_engine)
          @render_running_time_msec = args[:render_running_time_msec] if args.key?(:render_running_time_msec)
          @render_server_baseline_cl = args[:render_server_baseline_cl] if args.key?(:render_server_baseline_cl)
          @render_time_msec = args[:render_time_msec] if args.key?(:render_time_msec)
          @sandbox_render_time_msec = args[:sandbox_render_time_msec] if args.key?(:sandbox_render_time_msec)
        end
      end
      
      # Render event counters.
      class HtmlrenderWebkitHeadlessProtoRenderStatsCounter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # By convention, counters may contain a "." which we use to separate a metric
        # name from a counter name in streamz.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoRenderTreeNode
        include Google::Apis::Core::Hashable
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `box`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :box
      
        # child_render_tree_node_index is an index into the list of RenderTreeNodes
        # stored in the Document. *** WARNING ***: Don't use this field. Applications
        # should not rely on the structure of the render tree. This is an internal
        # browser implementation detail and it changes from time to time. Generally,
        # applications should obtain rendering information by starting with the relevant
        # DOMTreeNode and following pointers from there to the relevant RenderTreeNodes.
        # Corresponds to the JSON property `childRenderTreeNodeIndex`
        # @return [Array<Fixnum>]
        attr_accessor :child_render_tree_node_index
      
        # Index of the DOMTreeNode for which this RenderTreeNode is applicable. This
        # index can be used to lookup a DOMTreeNode from list of DOMTreeNodes stored in
        # the Document.
        # Corresponds to the JSON property `domTreeNodeIndex`
        # @return [Fixnum]
        attr_accessor :dom_tree_node_index
      
        # 
        # Corresponds to the JSON property `inlineTextBox`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderTreeNodeInlineTextBox>]
        attr_accessor :inline_text_box
      
        # The actual text that was rendered. This is applicable only for text nodes.
        # Corresponds to the JSON property `renderedText`
        # @return [String]
        attr_accessor :rendered_text
      
        # Style index is set for rendered nodes (text nodes, image nodes, widgets, etc).
        # The style_index can be used to lookup the style from the list of styles stored
        # in the Document.
        # Corresponds to the JSON property `styleIndex`
        # @return [Fixnum]
        attr_accessor :style_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @child_render_tree_node_index = args[:child_render_tree_node_index] if args.key?(:child_render_tree_node_index)
          @dom_tree_node_index = args[:dom_tree_node_index] if args.key?(:dom_tree_node_index)
          @inline_text_box = args[:inline_text_box] if args.key?(:inline_text_box)
          @rendered_text = args[:rendered_text] if args.key?(:rendered_text)
          @style_index = args[:style_index] if args.key?(:style_index)
        end
      end
      
      # For text nodes, individual lines of text. This repeats rendered_text with more
      # specific bounding boxes.
      class HtmlrenderWebkitHeadlessProtoRenderTreeNodeInlineTextBox
        include Google::Apis::Core::Hashable
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `box`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :box
      
        # 
        # Corresponds to the JSON property `renderedText`
        # @return [String]
        attr_accessor :rendered_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @rendered_text = args[:rendered_text] if args.key?(:rendered_text)
        end
      end
      
      # Next id: 9.
      class HtmlrenderWebkitHeadlessProtoResource
        include Google::Apis::Core::Hashable
      
        # content contains a complete HTTP response message including the HTTP status
        # line, headers and body. For example: HTTP/1.1 200 OK\r\n Content-Type: text/
        # html\r\n \r\n ... content ... For inputs (RenderRequest.resource): Any HTTP
        # content encoding (e.g. gzip) and transfer encoding (e.g. chunked) MUST be
        # decoded. HTTP content and transfer encoding headers will be ignored if present.
        # For outputs (RenderResponse.referenced_resource_content): The body will be
        # decoded (no content or transfer encoding) however any content or transfer
        # encoding headers present in the original fetch response will be passed through.
        # Decoding this field requires a correct text encoding. The charset field of
        # Document proto can be a good guess but is not guaranteed to be correct.
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # Where this resource comes from.
        # Corresponds to the JSON property `fetchSourceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::WirelessTranscoderFetchFetchSourceInfo>]
        attr_accessor :fetch_source_info
      
        # The url that contributes the final content. Only existed when metadata
        # contains FetchReplyData.
        # Corresponds to the JSON property `finalContentUrl`
        # @return [String]
        attr_accessor :final_content_url
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::WirelessTranscoderFetchFetchMetadata>]
        attr_accessor :metadata
      
        # The HTTP request method (GET, HEAD, POST, etc) used for this request. Values
        # are taken from the HTTPHeaders::Protocol enum in webutil/http/httputils.h. If
        # it's not set, we will infer GET or POST based on the presence of post_data.
        # Corresponds to the JSON property `method`
        # @return [Fixnum]
        attr_accessor :method_prop
      
        # 
        # Corresponds to the JSON property `postData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :post_data
      
        # 
        # Corresponds to the JSON property `requestHeader`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoResourceHttpHeader>]
        attr_accessor :request_header
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @fetch_source_info = args[:fetch_source_info] if args.key?(:fetch_source_info)
          @final_content_url = args[:final_content_url] if args.key?(:final_content_url)
          @metadata = args[:metadata] if args.key?(:metadata)
          @method_prop = args[:method_prop] if args.key?(:method_prop)
          @post_data = args[:post_data] if args.key?(:post_data)
          @request_header = args[:request_header] if args.key?(:request_header)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class HtmlrenderWebkitHeadlessProtoResourceHttpHeader
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Describes a script stack frame.
      class HtmlrenderWebkitHeadlessProtoScriptStackFrame
        include Google::Apis::Core::Hashable
      
        # The current column number for the stack frame.
        # Corresponds to the JSON property `columnNumber`
        # @return [Fixnum]
        attr_accessor :column_number
      
        # The function name of the stack frame.
        # Corresponds to the JSON property `functionName`
        # @return [String]
        attr_accessor :function_name
      
        # The current line number for the stack frame.
        # Corresponds to the JSON property `lineNumber`
        # @return [Fixnum]
        attr_accessor :line_number
      
        # The URL of the script being executed.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @column_number = args[:column_number] if args.key?(:column_number)
          @function_name = args[:function_name] if args.key?(:function_name)
          @line_number = args[:line_number] if args.key?(:line_number)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Next id: 54
      class HtmlrenderWebkitHeadlessProtoStyle
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `backgroundAttachment`
        # @return [String]
        attr_accessor :background_attachment
      
        # Background color encoded as ARGB
        # Corresponds to the JSON property `backgroundColorArgb`
        # @return [Fixnum]
        attr_accessor :background_color_argb
      
        # 
        # Corresponds to the JSON property `backgroundGradientColorStopArgb`
        # @return [Array<Fixnum>]
        attr_accessor :background_gradient_color_stop_argb
      
        # 
        # Corresponds to the JSON property `backgroundGradientRepeat`
        # @return [Boolean]
        attr_accessor :background_gradient_repeat
        alias_method :background_gradient_repeat?, :background_gradient_repeat
      
        # 
        # Corresponds to the JSON property `backgroundGradientType`
        # @return [String]
        attr_accessor :background_gradient_type
      
        # 
        # Corresponds to the JSON property `backgroundImageRepeat`
        # @return [String]
        attr_accessor :background_image_repeat
      
        # The url of the background image in the first layer.
        # Corresponds to the JSON property `backgroundImageUrl`
        # @return [String]
        attr_accessor :background_image_url
      
        # Background image position (x, y).
        # Corresponds to the JSON property `backgroundImageXPos`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :background_image_x_pos
      
        # 
        # Corresponds to the JSON property `backgroundImageYPos`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :background_image_y_pos
      
        # 
        # Corresponds to the JSON property `backgroundSize`
        # @return [String]
        attr_accessor :background_size
      
        # 
        # Corresponds to the JSON property `backgroundSizeHeight`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :background_size_height
      
        # Only present (but may be missing) if background_size == SIZE_LENGTH.
        # Corresponds to the JSON property `backgroundSizeWidth`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :background_size_width
      
        # 
        # Corresponds to the JSON property `borderColorArgbBottom`
        # @return [Fixnum]
        attr_accessor :border_color_argb_bottom
      
        # 
        # Corresponds to the JSON property `borderColorArgbLeft`
        # @return [Fixnum]
        attr_accessor :border_color_argb_left
      
        # 
        # Corresponds to the JSON property `borderColorArgbRight`
        # @return [Fixnum]
        attr_accessor :border_color_argb_right
      
        # 
        # Corresponds to the JSON property `borderColorArgbTop`
        # @return [Fixnum]
        attr_accessor :border_color_argb_top
      
        # 
        # Corresponds to the JSON property `borderPixelWidthBottom`
        # @return [Fixnum]
        attr_accessor :border_pixel_width_bottom
      
        # 
        # Corresponds to the JSON property `borderPixelWidthLeft`
        # @return [Fixnum]
        attr_accessor :border_pixel_width_left
      
        # 
        # Corresponds to the JSON property `borderPixelWidthRight`
        # @return [Fixnum]
        attr_accessor :border_pixel_width_right
      
        # 
        # Corresponds to the JSON property `borderPixelWidthTop`
        # @return [Fixnum]
        attr_accessor :border_pixel_width_top
      
        # 
        # Corresponds to the JSON property `borderStyleBottom`
        # @return [String]
        attr_accessor :border_style_bottom
      
        # 
        # Corresponds to the JSON property `borderStyleLeft`
        # @return [String]
        attr_accessor :border_style_left
      
        # 
        # Corresponds to the JSON property `borderStyleRight`
        # @return [String]
        attr_accessor :border_style_right
      
        # 
        # Corresponds to the JSON property `borderStyleTop`
        # @return [String]
        attr_accessor :border_style_top
      
        # Default value for clip is "auto", which is represented here as !has_clip().
        # Corresponds to the JSON property `clip`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRectangle]
        attr_accessor :clip
      
        # 
        # Corresponds to the JSON property `direction`
        # @return [String]
        attr_accessor :direction
      
        # 
        # Corresponds to the JSON property `display`
        # @return [String]
        attr_accessor :display_prop
      
        # Font and text decorations:
        # Corresponds to the JSON property `fontFamily`
        # @return [String]
        attr_accessor :font_family
      
        # 
        # Corresponds to the JSON property `fontSize`
        # @return [Fixnum]
        attr_accessor :font_size
      
        # 
        # Corresponds to the JSON property `fontStyle`
        # @return [String]
        attr_accessor :font_style
      
        # 
        # Corresponds to the JSON property `fontWeight`
        # @return [Fixnum]
        attr_accessor :font_weight
      
        # Foreground color encoded as ARGB
        # Corresponds to the JSON property `foregroundColorArgb`
        # @return [Fixnum]
        attr_accessor :foreground_color_argb
      
        # Starting from Chromium, has_background is set when there is a non-empty
        # specification for background_image, whether it be a url, gradient or other
        # cases, such as cross-fade. Besides setting this field, We additionally parse
        # url and gradient cases and populate some of the following background fields.
        # Corresponds to the JSON property `hasBackground`
        # @return [Boolean]
        attr_accessor :has_background
        alias_method :has_background?, :has_background
      
        # 
        # Corresponds to the JSON property `listStyleImageUrl`
        # @return [String]
        attr_accessor :list_style_image_url
      
        # 
        # Corresponds to the JSON property `listStyleType`
        # @return [String]
        attr_accessor :list_style_type
      
        # 
        # Corresponds to the JSON property `marginBottom`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :margin_bottom
      
        # 
        # Corresponds to the JSON property `marginLeft`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :margin_left
      
        # 
        # Corresponds to the JSON property `marginRight`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :margin_right
      
        # Margin
        # Corresponds to the JSON property `marginTop`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :margin_top
      
        # 
        # Corresponds to the JSON property `opacity`
        # @return [Float]
        attr_accessor :opacity
      
        # 
        # Corresponds to the JSON property `overflowX`
        # @return [String]
        attr_accessor :overflow_x
      
        # 
        # Corresponds to the JSON property `overflowY`
        # @return [String]
        attr_accessor :overflow_y
      
        # 
        # Corresponds to the JSON property `paddingBottom`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :padding_bottom
      
        # 
        # Corresponds to the JSON property `paddingLeft`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :padding_left
      
        # 
        # Corresponds to the JSON property `paddingRight`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :padding_right
      
        # Padding
        # Corresponds to the JSON property `paddingTop`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoOffset]
        attr_accessor :padding_top
      
        # 
        # Corresponds to the JSON property `position`
        # @return [String]
        attr_accessor :position
      
        # List of referenced resource indexes for any resources that this style
        # references. (e.g. background images.) (see document.proto)
        # Corresponds to the JSON property `referencedResourceIndex`
        # @return [Array<Fixnum>]
        attr_accessor :referenced_resource_index
      
        # 
        # Corresponds to the JSON property `textAlign`
        # @return [String]
        attr_accessor :text_align
      
        # 
        # Corresponds to the JSON property `textDecoration`
        # @return [String]
        attr_accessor :text_decoration
      
        # 
        # Corresponds to the JSON property `textShadowColorArgb`
        # @return [Fixnum]
        attr_accessor :text_shadow_color_argb
      
        # 
        # Corresponds to the JSON property `visibility`
        # @return [String]
        attr_accessor :visibility
      
        # Default value for z-index is "auto" which means "inherit from parent".
        # Corresponds to the JSON property `zIndex`
        # @return [Fixnum]
        attr_accessor :z_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @background_attachment = args[:background_attachment] if args.key?(:background_attachment)
          @background_color_argb = args[:background_color_argb] if args.key?(:background_color_argb)
          @background_gradient_color_stop_argb = args[:background_gradient_color_stop_argb] if args.key?(:background_gradient_color_stop_argb)
          @background_gradient_repeat = args[:background_gradient_repeat] if args.key?(:background_gradient_repeat)
          @background_gradient_type = args[:background_gradient_type] if args.key?(:background_gradient_type)
          @background_image_repeat = args[:background_image_repeat] if args.key?(:background_image_repeat)
          @background_image_url = args[:background_image_url] if args.key?(:background_image_url)
          @background_image_x_pos = args[:background_image_x_pos] if args.key?(:background_image_x_pos)
          @background_image_y_pos = args[:background_image_y_pos] if args.key?(:background_image_y_pos)
          @background_size = args[:background_size] if args.key?(:background_size)
          @background_size_height = args[:background_size_height] if args.key?(:background_size_height)
          @background_size_width = args[:background_size_width] if args.key?(:background_size_width)
          @border_color_argb_bottom = args[:border_color_argb_bottom] if args.key?(:border_color_argb_bottom)
          @border_color_argb_left = args[:border_color_argb_left] if args.key?(:border_color_argb_left)
          @border_color_argb_right = args[:border_color_argb_right] if args.key?(:border_color_argb_right)
          @border_color_argb_top = args[:border_color_argb_top] if args.key?(:border_color_argb_top)
          @border_pixel_width_bottom = args[:border_pixel_width_bottom] if args.key?(:border_pixel_width_bottom)
          @border_pixel_width_left = args[:border_pixel_width_left] if args.key?(:border_pixel_width_left)
          @border_pixel_width_right = args[:border_pixel_width_right] if args.key?(:border_pixel_width_right)
          @border_pixel_width_top = args[:border_pixel_width_top] if args.key?(:border_pixel_width_top)
          @border_style_bottom = args[:border_style_bottom] if args.key?(:border_style_bottom)
          @border_style_left = args[:border_style_left] if args.key?(:border_style_left)
          @border_style_right = args[:border_style_right] if args.key?(:border_style_right)
          @border_style_top = args[:border_style_top] if args.key?(:border_style_top)
          @clip = args[:clip] if args.key?(:clip)
          @direction = args[:direction] if args.key?(:direction)
          @display_prop = args[:display_prop] if args.key?(:display_prop)
          @font_family = args[:font_family] if args.key?(:font_family)
          @font_size = args[:font_size] if args.key?(:font_size)
          @font_style = args[:font_style] if args.key?(:font_style)
          @font_weight = args[:font_weight] if args.key?(:font_weight)
          @foreground_color_argb = args[:foreground_color_argb] if args.key?(:foreground_color_argb)
          @has_background = args[:has_background] if args.key?(:has_background)
          @list_style_image_url = args[:list_style_image_url] if args.key?(:list_style_image_url)
          @list_style_type = args[:list_style_type] if args.key?(:list_style_type)
          @margin_bottom = args[:margin_bottom] if args.key?(:margin_bottom)
          @margin_left = args[:margin_left] if args.key?(:margin_left)
          @margin_right = args[:margin_right] if args.key?(:margin_right)
          @margin_top = args[:margin_top] if args.key?(:margin_top)
          @opacity = args[:opacity] if args.key?(:opacity)
          @overflow_x = args[:overflow_x] if args.key?(:overflow_x)
          @overflow_y = args[:overflow_y] if args.key?(:overflow_y)
          @padding_bottom = args[:padding_bottom] if args.key?(:padding_bottom)
          @padding_left = args[:padding_left] if args.key?(:padding_left)
          @padding_right = args[:padding_right] if args.key?(:padding_right)
          @padding_top = args[:padding_top] if args.key?(:padding_top)
          @position = args[:position] if args.key?(:position)
          @referenced_resource_index = args[:referenced_resource_index] if args.key?(:referenced_resource_index)
          @text_align = args[:text_align] if args.key?(:text_align)
          @text_decoration = args[:text_decoration] if args.key?(:text_decoration)
          @text_shadow_color_argb = args[:text_shadow_color_argb] if args.key?(:text_shadow_color_argb)
          @visibility = args[:visibility] if args.key?(:visibility)
          @z_index = args[:z_index] if args.key?(:z_index)
        end
      end
      
      # WebkKitFetchMetadata holds additional webkit-specific information for a single
      # resource fetch.
      class HtmlrenderWebkitHeadlessProtoWebKitFetchMetadata
        include Google::Apis::Core::Hashable
      
        # Chromium DevTools frame ID of the frame that initiated this fetch. Only
        # populated in the streaming render service with FETCH_MODE_CLIENT.
        # Corresponds to the JSON property `devtoolsFrameId`
        # @return [String]
        attr_accessor :devtools_frame_id
      
        # 
        # Corresponds to the JSON property `targetType`
        # @return [String]
        attr_accessor :target_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @devtools_frame_id = args[:devtools_frame_id] if args.key?(:devtools_frame_id)
          @target_type = args[:target_type] if args.key?(:target_type)
        end
      end
      
      # Corresponds to a call to window.open(). Note that a WindowOpenEvent will be
      # present whether or not the call was successful.
      class HtmlrenderWebkitHeadlessProtoWindowOpenEvent
        include Google::Apis::Core::Hashable
      
        # Whether or not the window was allowed to be opened by the popup blocker.
        # Unless user events are created with a render extension this should be false.
        # Corresponds to the JSON property `allowed`
        # @return [Boolean]
        attr_accessor :allowed
        alias_method :allowed?, :allowed
      
        # The URL for the new window. Note that this is the URL after it has been
        # processed by WebKit, so, for example, relative links passed to window.create()
        # will have been made absolute.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Window features passed to window.open().
        # Corresponds to the JSON property `windowFeatures`
        # @return [String]
        attr_accessor :window_features
      
        # Window name passed to window.open(). If no name is provided this defaults to "
        # _blank".
        # Corresponds to the JSON property `windowName`
        # @return [String]
        attr_accessor :window_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allowed = args[:allowed] if args.key?(:allowed)
          @url = args[:url] if args.key?(:url)
          @window_features = args[:window_features] if args.key?(:window_features)
          @window_name = args[:window_name] if args.key?(:window_name)
        end
      end
      
      # The PhoneNumber object that is used by all LibPhoneNumber API's to fully
      # represent a phone number.
      class I18nPhonenumbersPhoneNumber
        include Google::Apis::Core::Hashable
      
        # The country calling code for this number, as defined by the International
        # Telecommunication Union (ITU). For example, this would be 1 for NANPA
        # countries, and 33 for France.
        # Corresponds to the JSON property `countryCode`
        # @return [Fixnum]
        attr_accessor :country_code
      
        # The source from which the country_code is derived.
        # Corresponds to the JSON property `countryCodeSource`
        # @return [String]
        attr_accessor :country_code_source
      
        # Extension is not standardized in ITU recommendations, except for being defined
        # as a series of numbers with a maximum length of 40 digits. It is defined as a
        # string here to accommodate for the possible use of a leading zero in the
        # extension (organizations have complete freedom to do so, as there is no
        # standard defined). Other than digits, some other dialling characters such as ",
        # " (indicating a wait) may be stored here.
        # Corresponds to the JSON property `extension`
        # @return [String]
        attr_accessor :extension
      
        # In some countries, the national (significant) number starts with one or more "
        # 0"s without this being a national prefix or trunk code of some kind. For
        # example, the leading zero in the national (significant) number of an Italian
        # phone number indicates the number is a fixed-line number. There have been
        # plans to migrate fixed-line numbers to start with the digit two since December
        # 2000, but it has not happened yet. See http://en.wikipedia.org/wiki/%2B39 for
        # more details. These fields can be safely ignored (there is no need to set them)
        # for most countries. Some limited number of countries behave like Italy - for
        # these cases, if the leading zero(s) of a number would be retained even when
        # dialling internationally, set this flag to true, and also set the number of
        # leading zeros. Clients who use the parsing or conversion functionality of the
        # i18n phone number libraries (go/phonenumbers) will have these fields set if
        # necessary automatically.
        # Corresponds to the JSON property `italianLeadingZero`
        # @return [Boolean]
        attr_accessor :italian_leading_zero
        alias_method :italian_leading_zero?, :italian_leading_zero
      
        # The National (significant) Number, as defined in International
        # Telecommunication Union (ITU) Recommendation E.164, without any leading zero.
        # The leading-zero is stored separately if required, since this is an uint64 and
        # hence cannot store such information. Do not use this field directly: if you
        # want the national significant number, call the getNationalSignificantNumber
        # method of PhoneNumberUtil. For countries which have the concept of an "area
        # code" or "national destination code", this is included in the National (
        # significant) Number. Although the ITU says the maximum length should be 15, we
        # have found longer numbers in some countries e.g. Germany. Note that the
        # National (significant) Number does not contain the National (trunk) prefix.
        # Obviously, as a uint64, it will never contain any formatting (hyphens, spaces,
        # parentheses), nor any alphanumeric spellings.
        # Corresponds to the JSON property `nationalNumber`
        # @return [Fixnum]
        attr_accessor :national_number
      
        # Full description of this field in the comment for italian_leading_zero since
        # this field will only be set when italian_leading_zero is true.
        # Corresponds to the JSON property `numberOfLeadingZeros`
        # @return [Fixnum]
        attr_accessor :number_of_leading_zeros
      
        # The carrier selection code that is preferred when calling this phone number
        # domestically. This also includes codes that need to be dialed in some
        # countries when calling from landlines to mobiles or vice versa. For example,
        # in Columbia, a "3" needs to be dialed before the phone number itself when
        # calling from a mobile phone to a domestic landline phone and vice versa. Note
        # this is the "preferred" code, which means other codes may work as well.
        # Corresponds to the JSON property `preferredDomesticCarrierCode`
        # @return [String]
        attr_accessor :preferred_domestic_carrier_code
      
        # This field is used to store the raw input string containing phone numbers
        # before it was canonicalized by the library. For example, it could be used to
        # store alphanumerical numbers such as "1-800-GOOG-411".
        # Corresponds to the JSON property `rawInput`
        # @return [String]
        attr_accessor :raw_input
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @country_code_source = args[:country_code_source] if args.key?(:country_code_source)
          @extension = args[:extension] if args.key?(:extension)
          @italian_leading_zero = args[:italian_leading_zero] if args.key?(:italian_leading_zero)
          @national_number = args[:national_number] if args.key?(:national_number)
          @number_of_leading_zeros = args[:number_of_leading_zeros] if args.key?(:number_of_leading_zeros)
          @preferred_domestic_carrier_code = args[:preferred_domestic_carrier_code] if args.key?(:preferred_domestic_carrier_code)
          @raw_input = args[:raw_input] if args.key?(:raw_input)
        end
      end
      
      # Next ID: 15
      class ImageBaseThumbnailMetadata
        include Google::Apis::Core::Hashable
      
        # the size of the stored thumbnail
        # Corresponds to the JSON property `byteSize`
        # @return [Fixnum]
        attr_accessor :byte_size
      
        # SmartCrop crop-hints By default, this field is not populated.
        # Corresponds to the JSON property `crops`
        # @return [Google::Apis::ContentwarehouseV1::ContentAwareCropsIndexing]
        attr_accessor :crops
      
        # DeepCrop crop-hints. Usage in thumbnails could be deprecated in favor or
        # deep_crop_pixels (below). By default, this field is not populated.
        # Corresponds to the JSON property `deepCrop`
        # @return [Google::Apis::ContentwarehouseV1::DeepCropIndexing]
        attr_accessor :deep_crop
      
        # DeepCrop signal in pixels, equivalent to deep_crop (above) but with pixels
        # instead of percentages. By default, this field is not populated.
        # Corresponds to the JSON property `deepCropPixels`
        # @return [Google::Apis::ContentwarehouseV1::DeepCropPixels]
        attr_accessor :deep_crop_pixels
      
        # the Amarna docid of the thumbnail
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # encrypted version of docid
        # Corresponds to the JSON property `encryptedDocid`
        # @return [String]
        attr_accessor :encrypted_docid
      
        # the fprint of the thumbnail
        # Corresponds to the JSON property `fprint`
        # @return [Fixnum]
        attr_accessor :fprint
      
        # the height of the stored thumbnail
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # The mime_type of the thumbnail ("image/jpeg", "image/png", etc.).
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # 
        # Corresponds to the JSON property `originalHeight`
        # @return [Fixnum]
        attr_accessor :original_height
      
        # Not populated by Amarna/image pipelines, ever. This was apparently introduced
        # by a customer that wished to extend ThumbnailMetadata with this custom data.
        # Corresponds to the JSON property `originalWidth`
        # @return [Fixnum]
        attr_accessor :original_width
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # the width of the stored thumbnail
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte_size = args[:byte_size] if args.key?(:byte_size)
          @crops = args[:crops] if args.key?(:crops)
          @deep_crop = args[:deep_crop] if args.key?(:deep_crop)
          @deep_crop_pixels = args[:deep_crop_pixels] if args.key?(:deep_crop_pixels)
          @docid = args[:docid] if args.key?(:docid)
          @encrypted_docid = args[:encrypted_docid] if args.key?(:encrypted_docid)
          @fprint = args[:fprint] if args.key?(:fprint)
          @height = args[:height] if args.key?(:height)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @original_height = args[:original_height] if args.key?(:original_height)
          @original_width = args[:original_width] if args.key?(:original_width)
          @type = args[:type] if args.key?(:type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # This message is used internally in Amarna and is also used to store
      # information in the VideoWebAttachment portion of the websearch index. Only the
      # following fields will be used in the index: VideoPreviewType type int32 width
      # int32 height byte byte_size If more fields are added, please update this list.
      class ImageBaseVideoPreviewMetadata
        include Google::Apis::Core::Hashable
      
        # Size of the stored preview.
        # Corresponds to the JSON property `byteSize`
        # @return [Fixnum]
        attr_accessor :byte_size
      
        # 64 bit docid of the original video.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # TODO (yzliu): consider using duration_ms as field name since it is number of
        # milliseconds. Duration of the preview in ms.
        # Corresponds to the JSON property `duration`
        # @return [Fixnum]
        attr_accessor :duration
      
        # Expiration timestamp of preview in microseconds since epoch.
        # Corresponds to the JSON property `expirationTimestampMicros`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp_micros
      
        # LINT.ThenChange(//depot/google3/video/crawl/indexing/signal_combiner.cc:
        # video_preview) Fingerprint of the preview.
        # Corresponds to the JSON property `fprint`
        # @return [Fixnum]
        attr_accessor :fprint
      
        # Height of the stored preview.
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Mime type of the preview ("video/mp4").
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # Indicates the state in Venom for this preview type.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # Timestamp of start of preview in ms.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # LINT.IfChange
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Width of the stored preview.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte_size = args[:byte_size] if args.key?(:byte_size)
          @docid = args[:docid] if args.key?(:docid)
          @duration = args[:duration] if args.key?(:duration)
          @expiration_timestamp_micros = args[:expiration_timestamp_micros] if args.key?(:expiration_timestamp_micros)
          @fprint = args[:fprint] if args.key?(:fprint)
          @height = args[:height] if args.key?(:height)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @state = args[:state] if args.key?(:state)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @type = args[:type] if args.key?(:type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # The subset of FlowProto that we want to go into production AND be stored in
      # ContentSignals.
      class ImageContentFlowProtoProd
        include Google::Apis::Core::Hashable
      
        # Repeated so that multiple versions can exist in prod simultaneously.
        # Corresponds to the JSON property `starburst`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageContentStarburstVersionGroup>]
        attr_accessor :starburst
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @starburst = args[:starburst] if args.key?(:starburst)
        end
      end
      
      # Image content based multipliers. Current usage is in the pamir_section.
      class ImageContentQueryBoost
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `queryboost`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageContentQueryBoostQueryBoost>]
        attr_accessor :queryboost
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @queryboost = args[:queryboost] if args.key?(:queryboost)
        end
      end
      
      # 
      class ImageContentQueryBoostQueryBoost
        include Google::Apis::Core::Hashable
      
        # Score multiplier (fully normalized 1 is nop).
        # Corresponds to the JSON property `boost`
        # @return [Float]
        attr_accessor :boost
      
        # Canonicalized query string.
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boost = args[:boost] if args.key?(:boost)
          @query = args[:query] if args.key?(:query)
        end
      end
      
      # 
      class ImageContentStarburstVersionGroup
        include Google::Apis::Core::Hashable
      
        # Raw dense float feature vector.
        # Corresponds to the JSON property `descriptorFloat`
        # @return [Array<Float>]
        attr_accessor :descriptor_float
      
        # Short descriptor for image content features, e.g. compressed bytes. This is
        # the compressed version of descriptor_float below. It can be can be
        # decompressed to descriptor_float with a tiny bit of compression error (in most
        # cases it should be totally fine).
        # Corresponds to the JSON property `descriptorShort`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :descriptor_short
      
        # 
        # Corresponds to the JSON property `enumVersion`
        # @return [String]
        attr_accessor :enum_version
      
        # 
        # Corresponds to the JSON property `minorVersion`
        # @return [String]
        attr_accessor :minor_version
      
        # Starburst tokens.
        # Corresponds to the JSON property `starburstTokens`
        # @return [Array<Fixnum>]
        attr_accessor :starburst_tokens
      
        # The following integers are currently used: Starburst V1: 1 Starburst V2: 2
        # Starburst V3: 3 Starburst V4: 4 Starburst Visual V4: 1004 This field is
        # deprecated. Please try to use the 'enum_version' in future.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @descriptor_float = args[:descriptor_float] if args.key?(:descriptor_float)
          @descriptor_short = args[:descriptor_short] if args.key?(:descriptor_short)
          @enum_version = args[:enum_version] if args.key?(:enum_version)
          @minor_version = args[:minor_version] if args.key?(:minor_version)
          @starburst_tokens = args[:starburst_tokens] if args.key?(:starburst_tokens)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # This defines the per-doc data which is extracted from thumbnails and
      # propagated over to indexing. It contains all information that can be used for
      # restricts. Next tag id: 127
      class ImageData
        include Google::Apis::Core::Hashable
      
        # Warning: adaboost_image_feature_porn* and imageFeaturePorn fields are
        # DEPRECATED in favor of brain_porn_scores. Please do not use them. Contact
        # safesearch@ for transition advice.
        # Corresponds to the JSON property `adaboostImageFeaturePorn`
        # @return [Float]
        attr_accessor :adaboost_image_feature_porn
      
        # 
        # Corresponds to the JSON property `adaboostImageFeaturePornMinorVersion`
        # @return [Fixnum]
        attr_accessor :adaboost_image_feature_porn_minor_version
      
        # 
        # Corresponds to the JSON property `adaboostImageFeaturePornVersion`
        # @return [Fixnum]
        attr_accessor :adaboost_image_feature_porn_version
      
        # Additional animated image data stored in perdoc (ImageData); will only be
        # stored for animated images.
        # Corresponds to the JSON property `animatedImageData`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryAnimatedImagePerdocData]
        attr_accessor :animated_image_data
      
        # Don't change the field names. The names are used as sparse feature labels in
        # client projects.
        # Corresponds to the JSON property `brainPornScores`
        # @return [Google::Apis::ContentwarehouseV1::ImageSafesearchContentBrainPornAnnotation]
        attr_accessor :brain_porn_scores
      
        # A string that indicates the version of SafeSearch classifier used to compute
        # brain_porn_scores.
        # Corresponds to the JSON property `brainPornScoresVersion`
        # @return [String]
        attr_accessor :brain_porn_scores_version
      
        # This is the image docid used in image search. For ImageData protos coming from
        # Alexandria/Freshdocs, this is a 'required' field that MUST be populated.
        # Corresponds to the JSON property `canonicalDocid`
        # @return [Fixnum]
        attr_accessor :canonical_docid
      
        # A score in (0, 1] to indicate how likely this image is considered as a click
        # magnet based on clicks received from bad queries.
        # Corresponds to the JSON property `clickMagnetScore`
        # @return [Float]
        attr_accessor :click_magnet_score
      
        # Image content based classifier scores.
        # Corresponds to the JSON property `clipartDetectorScore`
        # @return [Float]
        attr_accessor :clipart_detector_score
      
        # 
        # Corresponds to the JSON property `clipartDetectorVersion`
        # @return [Fixnum]
        attr_accessor :clipart_detector_version
      
        # Like is_visible, this is a property of the (web-doc, img_url) pair not just
        # the image. A high codomain_strength indicates high confidence based on
        # collected stats that the image is hosted on a companion domain. If not enough
        # stats are available for codomain strength, this field may be absent in
        # ImageData, and hence the CompositeDoc. Do not place negative values here.
        # Permitted values range between 0 and image_quality_codomain::
        # kMaxCodomainStrength defined in //image/quality/codomain/codomain-stats-utils.
        # h.
        # Corresponds to the JSON property `codomainStrength`
        # @return [Fixnum]
        attr_accessor :codomain_strength
      
        # Colorness scores for the image. Each score represents the amount of a
        # particular color in the image. At the current time, there are 12 colors, so
        # there should always be 0 or 12 values in this array. The 12 colors are black,
        # blue, brown, gray, green, orange, pink, purple, red, teal, white, yellow. The
        # convention is that the scores are stored in alphabetical order, so the first
        # score is black, and the last score is yellow.
        # Corresponds to the JSON property `colorScore`
        # @return [Array<Float>]
        attr_accessor :color_score
      
        # 
        # Corresponds to the JSON property `colorScoreVersion`
        # @return [Fixnum]
        attr_accessor :color_score_version
      
        # Fraction of the image that contains pixels over a certain saturation threshold:
        # can be used to determine if the image is grayscale or not.
        # Corresponds to the JSON property `coloredPixelsFrac`
        # @return [Float]
        attr_accessor :colored_pixels_frac
      
        # Earliest known crawl time among all neardups of this image (go/imagecontentage)
        # .
        # Corresponds to the JSON property `contentFirstCrawlTime`
        # @return [Fixnum]
        attr_accessor :content_first_crawl_time
      
        # Corpus scoring info for images indexed through Amarna.
        # Corresponds to the JSON property `corpusSelectionInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::CorpusSelectionInfo>]
        attr_accessor :corpus_selection_info
      
        # The content-aware cropping information.
        # Corresponds to the JSON property `crops`
        # @return [Google::Apis::ContentwarehouseV1::ContentAwareCropsIndexing]
        attr_accessor :crops
      
        # DeepCrop based cropping information. See go/creatism/deepcrop for details.
        # Corresponds to the JSON property `deepCrop`
        # @return [Google::Apis::ContentwarehouseV1::DeepCropIndexing]
        attr_accessor :deep_crop
      
        # Image-level deep tags: essentially equivalent to the proto above but
        # containing tags that are computed at the image level. These image signals are
        # maintained by the Visual Shopping team (visual-shopping@). *** If you do use
        # the signals, please add an entry in go/ShoppingImageAttributeClients to be
        # notified for model upgrade. *** We recommend our clients against using the raw
        # confidence value directly. Instead, the clients should use the library, cs/ads/
        # shopping/visual/deeptags/public/single_tag.h and cs/ads/shopping/visual/
        # deeptags/public/single_scored_tag.h to specify an operating point in terms of
        # precision or recall. See the following code example: http://google3/shopping/
        # visual/explore_looks/looks_offline_pipeline.cc?l=268&rcl=304165166 *** `
        # model_outputs` is a repeated field. Please check `version` to get the model
        # you desire to use, instead of indexing the model_outputs directly e.g.
        # model_outputs(0). We will remove the old versions in the future and this will
        # lead to incorrect model. *** Models: As of Q2 2020, we have two models running
        # within Shopping: model one only has the overlay tag, which we are deprecating,
        # and model two has the tags specified in go/VisualShoppingImageAttributes.
        # Corresponds to the JSON property `deepTags`
        # @return [Google::Apis::ContentwarehouseV1::CommerceDatastoreImageDeepTags]
        attr_accessor :deep_tags
      
        # fingerprint(non-canonicalized absolute image url) This is *not* the image
        # docid. Use canonical_docid instead. For ImageData protos coming from
        # Alexandria/Freshdocs, this is a 'required' field that MUST be populated. But
        # once again, this is very likely NOT something you need. Use canonical_docid
        # instead.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # This class holds the EXIf/IPTC meta data Next Id: 104
        # Corresponds to the JSON property `embeddedMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ImageExifImageEmbeddedMetadata]
        attr_accessor :embedded_metadata
      
        # The thumbnail is guaranteed to be kept in the serving system until the
        # expiration timestamp has passed, in microseconds.
        # Corresponds to the JSON property `expirationTimestamp`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp
      
        # Next tag value: 381.
        # Corresponds to the JSON property `extendedExif`
        # @return [Google::Apis::ContentwarehouseV1::PhotosImageMetadata]
        attr_accessor :extended_exif
      
        # Properties used in featured imagesearch project. inspiration_score indicates
        # how well an image is related to products, or how inspirational it is.
        # Corresponds to the JSON property `featuredImageProp`
        # @return [Google::Apis::ContentwarehouseV1::ImageMonetizationFeaturedImageProperties]
        attr_accessor :featured_image_prop
      
        # True file format (not extension).
        # Corresponds to the JSON property `fileFormat`
        # @return [String]
        attr_accessor :file_format
      
        # A [0..1] porn score based on some image-level features (like content score,
        # referrer statistics, navboost queries, etc.). See class RiflePornScorer for
        # more details.
        # Corresponds to the JSON property `finalPornScore`
        # @return [Float]
        attr_accessor :final_porn_score
      
        # A string that indicates the version of SafeSearch classifier used to compute
        # final_porn_score.
        # Corresponds to the JSON property `finalPornScoreVersion`
        # @return [String]
        attr_accessor :final_porn_score_version
      
        # Earliest known timestamp about this image. Today, this is the timestamp when
        # the content key was generated for this image. The time is in seconds.
        # Corresponds to the JSON property `firstCrawlTime`
        # @return [Fixnum]
        attr_accessor :first_crawl_time
      
        # The first time this image URL was seen on the containing web page. Only set
        # during web indexing.
        # Corresponds to the JSON property `firstTimeSeenOnDocSec`
        # @return [Fixnum]
        attr_accessor :first_time_seen_on_doc_sec
      
        # Use image_perdoc.h to read/write 'flags'.
        # Corresponds to the JSON property `flags`
        # @return [Fixnum]
        attr_accessor :flags
      
        # The subset of FlowProto that we want to go into production AND be stored in
        # ContentSignals.
        # Corresponds to the JSON property `flowOutput`
        # @return [Google::Apis::ContentwarehouseV1::ImageContentFlowProtoProd]
        attr_accessor :flow_output
      
        # 
        # Corresponds to the JSON property `h2c`
        # @return [Float]
        attr_accessor :h2c
      
        # 'Hovers to Impressions' and 'Hovers to Clicks' ratios for an image.
        # Corresponds to the JSON property `h2i`
        # @return [Float]
        attr_accessor :h2i
      
        # Hate logo detections from the VSS logo_recognition module.
        # Corresponds to the JSON property `hateLogoDetection`
        # @return [Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingAnnotationGroup]
        attr_accessor :hate_logo_detection
      
        # Height
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Image content based multipliers. Current usage is in the pamir_section.
        # Corresponds to the JSON property `imageContentQueryBoost`
        # @return [Google::Apis::ContentwarehouseV1::ImageContentQueryBoost]
        attr_accessor :image_content_query_boost
      
        # A set of query fingerprints and confidence scores. There queries are supposed
        # to be relevant to the image with high confidence.
        # Corresponds to the JSON property `imageExactBoost`
        # @return [Google::Apis::ContentwarehouseV1::ImageExactBoost]
        attr_accessor :image_exact_boost
      
        # The image license info for licensable images(go/Licensable-Images-PRD) This
        # proto in design doc: go/licensable-images-edd
        # Corresponds to the JSON property `imageLicenseInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageSearchImageLicenseInfo]
        attr_accessor :image_license_info
      
        # An image with regions within it. NEXT_ID: 11
        # Corresponds to the JSON property `imageRegions`
        # @return [Google::Apis::ContentwarehouseV1::ImageRegionsImageRegions]
        attr_accessor :image_regions
      
        # 
        # Corresponds to the JSON property `imagerank`
        # @return [Fixnum]
        attr_accessor :imagerank
      
        # IIP in scope signal (go/iip). Set to true if the image is annotated with any
        # iip_in_scope entities (go/iukp-trust-v2).
        # Corresponds to the JSON property `isIipInScope`
        # @return [Boolean]
        attr_accessor :is_iip_in_scope
        alias_method :is_iip_in_scope?, :is_iip_in_scope
      
        # If this image was not selected for indexing by imagesearch, these fields say
        # so and explain why.
        # Corresponds to the JSON property `isIndexedByImagesearch`
        # @return [Boolean]
        attr_accessor :is_indexed_by_imagesearch
        alias_method :is_indexed_by_imagesearch?, :is_indexed_by_imagesearch
      
        # True if the original image contains multiple frames (e.g., for animated or
        # stereoscopic images).
        # Corresponds to the JSON property `isMultiframe`
        # @return [Boolean]
        attr_accessor :is_multiframe
        alias_method :is_multiframe?, :is_multiframe
      
        # Field to indicate the image is unwanted for search index. The data is
        # propagated from amarna to alexandria to be annotated in the cdoc. Refer to
        # image/repository/proto/unwanted_content.proto for more info.
        # Corresponds to the JSON property `isUnwantedContent`
        # @return [Boolean]
        attr_accessor :is_unwanted_content
        alias_method :is_unwanted_content?, :is_unwanted_content
      
        # True if the image is inlined on the page (typicially via ) or false if the
        # image is linked to (via an href).
        # Corresponds to the JSON property `isVisible`
        # @return [Boolean]
        attr_accessor :is_visible
        alias_method :is_visible?, :is_visible
      
        # Fraction of image covered by the largest face (should match
        # largestFaceFraction, but without scaling). In perdocs, is set only if
        # numberFaces > 0.
        # Corresponds to the JSON property `largestFaceFrac`
        # @return [Float]
        attr_accessor :largest_face_frac
      
        # Fraction of image covered by the largest face, scaled by 1000. Warning: Is
        # DEPRECATED in favor of largest_face_frac. Do not use.
        # Corresponds to the JSON property `largestFaceFraction`
        # @return [Fixnum]
        attr_accessor :largest_face_fraction
      
        # Most recent timestamp in seconds when this URL was crawled.
        # Corresponds to the JSON property `lastCrawlTime`
        # @return [Fixnum]
        attr_accessor :last_crawl_time
      
        # Indicates the web-master opt-in state of this image, and will be used for
        # Google products to decide usage rights like showing large previews.
        # Corresponds to the JSON property `licensedWebImagesOptInState`
        # @return [String]
        attr_accessor :licensed_web_images_opt_in_state
      
        # 
        # Corresponds to the JSON property `lineartDetectorScore`
        # @return [Float]
        attr_accessor :lineart_detector_score
      
        # 
        # Corresponds to the JSON property `lineartDetectorVersion`
        # @return [Fixnum]
        attr_accessor :lineart_detector_version
      
        # Multibang kg entities.
        # Corresponds to the JSON property `multibangKgEntities`
        # @return [Google::Apis::ContentwarehouseV1::ImageDataMultibangEntities]
        attr_accessor :multibang_kg_entities
      
        # 
        # Corresponds to the JSON property `nearDupFeatures`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :near_dup_features
      
        # 
        # Corresponds to the JSON property `nearDupFeaturesSmall`
        # @return [Array<String>]
        attr_accessor :near_dup_features_small
      
        # The following fields contain information about a smaller and less powerful
        # version of the hash, needed for neardup retrieval. A compressed and an encoded
        # version of the small hash are stored below. The smaller hash may have a few
        # variants to increase recall. NOTE: This hash is generated by V2 hash
        # computation. A compressed version of the small hash. Currently, a 4-byte
        # fingerprint.
        # Corresponds to the JSON property `nearDupFeaturesSmallVersion`
        # @return [Fixnum]
        attr_accessor :near_dup_features_small_version
      
        # Image content derived data used for finding image near dups. NOTE: This hash
        # is generated by V1 hash computation.
        # Corresponds to the JSON property `nearDupFeaturesVersion`
        # @return [Fixnum]
        attr_accessor :near_dup_features_version
      
        # Productionized Nima AVA score. Both this field and nima_vq were added on the
        # top of nima_ava_score and nima_vq_score because the signals are already
        # integrated with Batch Amarna in image/repository/schema/global_output_tags.h
        # using NimaOutput.
        # Corresponds to the JSON property `nimaAva`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryNimaOutput]
        attr_accessor :nima_ava
      
        # Productionized Nima VQ score.
        # Corresponds to the JSON property `nimaVq`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryNimaOutput]
        attr_accessor :nima_vq
      
        # 
        # Corresponds to the JSON property `noIndexReason`
        # @return [Array<String>]
        attr_accessor :no_index_reason
      
        # Number of faces detected in the image
        # Corresponds to the JSON property `numberFaces`
        # @return [Fixnum]
        attr_accessor :number_faces
      
        # Top-level representation of OCRed document
        # Corresponds to the JSON property `ocrGoodoc`
        # @return [Google::Apis::ContentwarehouseV1::GoodocDocument]
        attr_accessor :ocr_goodoc
      
        # Top-level representation of OCRed document
        # Corresponds to the JSON property `ocrTaser`
        # @return [Google::Apis::ContentwarehouseV1::GoodocDocument]
        attr_accessor :ocr_taser
      
        # Text lines detected by OCR engine.
        # Corresponds to the JSON property `ocrTextboxes`
        # @return [Array<Google::Apis::ContentwarehouseV1::OcrPhotoTextBox>]
        attr_accessor :ocr_textboxes
      
        # For an image not explicitly visible on this page, the following url is the one
        # which most closely matches it.
        # Corresponds to the JSON property `onPageAlternateUrl`
        # @return [String]
        attr_accessor :on_page_alternate_url
      
        # Encodes face number and largest face frac into a small package for storage in
        # mustang. This is calculated directly from FaceDetectionResult.
        # Corresponds to the JSON property `packedFullFaceInfo`
        # @return [Google::Apis::ContentwarehouseV1::FaceIndexing]
        attr_accessor :packed_full_face_info
      
        # This message holds person attributes from the LookNet-Person model (go/looknet-
        # person) and the Style AI Iconic Person Scorer (http://go/styleai-indexing-
        # g3doc#iconic-person-scorer) for the most iconic person in a style image. There
        # is an ongoing collaboration with the Human Sensing team on LookNet-Person v3 (
        # go/looknet-person-v3-collaboration) that deals with some of these signals
        # together. Hence, the combined proto definition. Discretization of float values
        # is recommended by CDS for cheaper and more efficient storage. Next ID: 11
        # Corresponds to the JSON property `personAttributes`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStylePersonAttributes]
        attr_accessor :person_attributes
      
        # This message holds bounding boxes of detected people in the image. Next ID: 3
        # Corresponds to the JSON property `personDetectionSignals`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStylePersonDetectionSignals]
        attr_accessor :person_detection_signals
      
        # 
        # Corresponds to the JSON property `photoDetectorScore`
        # @return [Float]
        attr_accessor :photo_detector_score
      
        # 
        # Corresponds to the JSON property `photoDetectorVersion`
        # @return [Fixnum]
        attr_accessor :photo_detector_version
      
        # A protocol buffer to store the url, referer and porn flag for a url. and an
        # optional image score. Next available tag id: 50.
        # Corresponds to the JSON property `pornFlagData`
        # @return [Google::Apis::ContentwarehouseV1::PornFlagData]
        attr_accessor :porn_flag_data
      
        # The restricts that are computed before building a Mustang index.
        # Corresponds to the JSON property `precomputedRestricts`
        # @return [Google::Apis::ContentwarehouseV1::PrecomputedRestricts]
        attr_accessor :precomputed_restricts
      
        # Rank in near-dup cluster (go/image-rank-in-neardup-cluster). The rank is 1-
        # indexed: rank 1 is the best.
        # Corresponds to the JSON property `rankInNeardupCluster`
        # @return [Fixnum]
        attr_accessor :rank_in_neardup_cluster
      
        # A string representation of all the restricts associated with this image.
        # Corresponds to the JSON property `restrictStrings`
        # @return [Array<String>]
        attr_accessor :restrict_strings
      
        # CSV list of user agents for which this image should be considered roboted.
        # Note: All images are crawled using googlebot-images, this exists for clients
        # that require additional restrictions beyond googlebot-images such as news.
        # Corresponds to the JSON property `robotedAgents`
        # @return [String]
        attr_accessor :roboted_agents
      
        # A message containing embedding information and localization scores using the
        # VSS product recognition module.
        # Corresponds to the JSON property `shoppingProductInformation`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformation]
        attr_accessor :shopping_product_information
      
        # Size in bytes of original (non-thumbnail)
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        # Web docids that correspond to high ranked smeared landing pages for this image.
        # Used for conditional retrieval of actionable landing pages for image search.
        # Corresponds to the JSON property `smearedTopWebLandingPageDocids`
        # @return [Array<Fixnum>]
        attr_accessor :smeared_top_web_landing_page_docids
      
        # 
        # Corresponds to the JSON property `smearedTopWebLandingPages`
        # @return [Array<Google::Apis::ContentwarehouseV1::SmearedWebLandingPageEntry>]
        attr_accessor :smeared_top_web_landing_pages
      
        # Aesthetics score of a style image. Check http://go/styleai-indexing-g3doc#
        # aesthetic-model for more details about the Style AI Aesthetics Model.
        # Corresponds to the JSON property `styleAestheticsScore`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStyleAestheticsScoreSignals]
        attr_accessor :style_aesthetics_score
      
        # Prediction of a style image type: Stage, Stock, Street or Outfits. Check http:/
        # /go/styleai-indexing-g3doc#style-image-type-classifier for more details about
        # the Style AI Style Image Type Classifier.
        # Corresponds to the JSON property `styleImageType`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStyleStyleImageTypeSignals]
        attr_accessor :style_image_type
      
        # This field is for testing purposes, more information in go/media-dirt-2022.
        # Corresponds to the JSON property `testingScore`
        # @return [Fixnum]
        attr_accessor :testing_score
      
        # 
        # Corresponds to the JSON property `thumbHeight`
        # @return [Fixnum]
        attr_accessor :thumb_height
      
        # 
        # Corresponds to the JSON property `thumbSize`
        # @return [Fixnum]
        attr_accessor :thumb_size
      
        # Thumbnail width.
        # Corresponds to the JSON property `thumbWidth`
        # @return [Fixnum]
        attr_accessor :thumb_width
      
        # 
        # Corresponds to the JSON property `thumbnail`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageDataThumbnail>]
        attr_accessor :thumbnail
      
        # Time in seconds since epoch after which this image should be considered
        # unavailable.
        # Corresponds to the JSON property `unavailableAfterSecs`
        # @return [Fixnum]
        attr_accessor :unavailable_after_secs
      
        # Canonicalized absolute image url.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `whiteBackgroundScore`
        # @return [Float]
        attr_accessor :white_background_score
      
        # Image is likely an object on a white background (value on [0,1]).
        # Corresponds to the JSON property `whiteBackgroundScoreVersion`
        # @return [Fixnum]
        attr_accessor :white_background_score_version
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @adaboost_image_feature_porn = args[:adaboost_image_feature_porn] if args.key?(:adaboost_image_feature_porn)
          @adaboost_image_feature_porn_minor_version = args[:adaboost_image_feature_porn_minor_version] if args.key?(:adaboost_image_feature_porn_minor_version)
          @adaboost_image_feature_porn_version = args[:adaboost_image_feature_porn_version] if args.key?(:adaboost_image_feature_porn_version)
          @animated_image_data = args[:animated_image_data] if args.key?(:animated_image_data)
          @brain_porn_scores = args[:brain_porn_scores] if args.key?(:brain_porn_scores)
          @brain_porn_scores_version = args[:brain_porn_scores_version] if args.key?(:brain_porn_scores_version)
          @canonical_docid = args[:canonical_docid] if args.key?(:canonical_docid)
          @click_magnet_score = args[:click_magnet_score] if args.key?(:click_magnet_score)
          @clipart_detector_score = args[:clipart_detector_score] if args.key?(:clipart_detector_score)
          @clipart_detector_version = args[:clipart_detector_version] if args.key?(:clipart_detector_version)
          @codomain_strength = args[:codomain_strength] if args.key?(:codomain_strength)
          @color_score = args[:color_score] if args.key?(:color_score)
          @color_score_version = args[:color_score_version] if args.key?(:color_score_version)
          @colored_pixels_frac = args[:colored_pixels_frac] if args.key?(:colored_pixels_frac)
          @content_first_crawl_time = args[:content_first_crawl_time] if args.key?(:content_first_crawl_time)
          @corpus_selection_info = args[:corpus_selection_info] if args.key?(:corpus_selection_info)
          @crops = args[:crops] if args.key?(:crops)
          @deep_crop = args[:deep_crop] if args.key?(:deep_crop)
          @deep_tags = args[:deep_tags] if args.key?(:deep_tags)
          @docid = args[:docid] if args.key?(:docid)
          @embedded_metadata = args[:embedded_metadata] if args.key?(:embedded_metadata)
          @expiration_timestamp = args[:expiration_timestamp] if args.key?(:expiration_timestamp)
          @extended_exif = args[:extended_exif] if args.key?(:extended_exif)
          @featured_image_prop = args[:featured_image_prop] if args.key?(:featured_image_prop)
          @file_format = args[:file_format] if args.key?(:file_format)
          @final_porn_score = args[:final_porn_score] if args.key?(:final_porn_score)
          @final_porn_score_version = args[:final_porn_score_version] if args.key?(:final_porn_score_version)
          @first_crawl_time = args[:first_crawl_time] if args.key?(:first_crawl_time)
          @first_time_seen_on_doc_sec = args[:first_time_seen_on_doc_sec] if args.key?(:first_time_seen_on_doc_sec)
          @flags = args[:flags] if args.key?(:flags)
          @flow_output = args[:flow_output] if args.key?(:flow_output)
          @h2c = args[:h2c] if args.key?(:h2c)
          @h2i = args[:h2i] if args.key?(:h2i)
          @hate_logo_detection = args[:hate_logo_detection] if args.key?(:hate_logo_detection)
          @height = args[:height] if args.key?(:height)
          @image_content_query_boost = args[:image_content_query_boost] if args.key?(:image_content_query_boost)
          @image_exact_boost = args[:image_exact_boost] if args.key?(:image_exact_boost)
          @image_license_info = args[:image_license_info] if args.key?(:image_license_info)
          @image_regions = args[:image_regions] if args.key?(:image_regions)
          @imagerank = args[:imagerank] if args.key?(:imagerank)
          @is_iip_in_scope = args[:is_iip_in_scope] if args.key?(:is_iip_in_scope)
          @is_indexed_by_imagesearch = args[:is_indexed_by_imagesearch] if args.key?(:is_indexed_by_imagesearch)
          @is_multiframe = args[:is_multiframe] if args.key?(:is_multiframe)
          @is_unwanted_content = args[:is_unwanted_content] if args.key?(:is_unwanted_content)
          @is_visible = args[:is_visible] if args.key?(:is_visible)
          @largest_face_frac = args[:largest_face_frac] if args.key?(:largest_face_frac)
          @largest_face_fraction = args[:largest_face_fraction] if args.key?(:largest_face_fraction)
          @last_crawl_time = args[:last_crawl_time] if args.key?(:last_crawl_time)
          @licensed_web_images_opt_in_state = args[:licensed_web_images_opt_in_state] if args.key?(:licensed_web_images_opt_in_state)
          @lineart_detector_score = args[:lineart_detector_score] if args.key?(:lineart_detector_score)
          @lineart_detector_version = args[:lineart_detector_version] if args.key?(:lineart_detector_version)
          @multibang_kg_entities = args[:multibang_kg_entities] if args.key?(:multibang_kg_entities)
          @near_dup_features = args[:near_dup_features] if args.key?(:near_dup_features)
          @near_dup_features_small = args[:near_dup_features_small] if args.key?(:near_dup_features_small)
          @near_dup_features_small_version = args[:near_dup_features_small_version] if args.key?(:near_dup_features_small_version)
          @near_dup_features_version = args[:near_dup_features_version] if args.key?(:near_dup_features_version)
          @nima_ava = args[:nima_ava] if args.key?(:nima_ava)
          @nima_vq = args[:nima_vq] if args.key?(:nima_vq)
          @no_index_reason = args[:no_index_reason] if args.key?(:no_index_reason)
          @number_faces = args[:number_faces] if args.key?(:number_faces)
          @ocr_goodoc = args[:ocr_goodoc] if args.key?(:ocr_goodoc)
          @ocr_taser = args[:ocr_taser] if args.key?(:ocr_taser)
          @ocr_textboxes = args[:ocr_textboxes] if args.key?(:ocr_textboxes)
          @on_page_alternate_url = args[:on_page_alternate_url] if args.key?(:on_page_alternate_url)
          @packed_full_face_info = args[:packed_full_face_info] if args.key?(:packed_full_face_info)
          @person_attributes = args[:person_attributes] if args.key?(:person_attributes)
          @person_detection_signals = args[:person_detection_signals] if args.key?(:person_detection_signals)
          @photo_detector_score = args[:photo_detector_score] if args.key?(:photo_detector_score)
          @photo_detector_version = args[:photo_detector_version] if args.key?(:photo_detector_version)
          @porn_flag_data = args[:porn_flag_data] if args.key?(:porn_flag_data)
          @precomputed_restricts = args[:precomputed_restricts] if args.key?(:precomputed_restricts)
          @rank_in_neardup_cluster = args[:rank_in_neardup_cluster] if args.key?(:rank_in_neardup_cluster)
          @restrict_strings = args[:restrict_strings] if args.key?(:restrict_strings)
          @roboted_agents = args[:roboted_agents] if args.key?(:roboted_agents)
          @shopping_product_information = args[:shopping_product_information] if args.key?(:shopping_product_information)
          @size = args[:size] if args.key?(:size)
          @smeared_top_web_landing_page_docids = args[:smeared_top_web_landing_page_docids] if args.key?(:smeared_top_web_landing_page_docids)
          @smeared_top_web_landing_pages = args[:smeared_top_web_landing_pages] if args.key?(:smeared_top_web_landing_pages)
          @style_aesthetics_score = args[:style_aesthetics_score] if args.key?(:style_aesthetics_score)
          @style_image_type = args[:style_image_type] if args.key?(:style_image_type)
          @testing_score = args[:testing_score] if args.key?(:testing_score)
          @thumb_height = args[:thumb_height] if args.key?(:thumb_height)
          @thumb_size = args[:thumb_size] if args.key?(:thumb_size)
          @thumb_width = args[:thumb_width] if args.key?(:thumb_width)
          @thumbnail = args[:thumbnail] if args.key?(:thumbnail)
          @unavailable_after_secs = args[:unavailable_after_secs] if args.key?(:unavailable_after_secs)
          @url = args[:url] if args.key?(:url)
          @white_background_score = args[:white_background_score] if args.key?(:white_background_score)
          @white_background_score_version = args[:white_background_score_version] if args.key?(:white_background_score_version)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Multibang kg entities.
      class ImageDataMultibangEntities
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entity`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageDataMultibangEntitiesMultibangEntity>]
        attr_accessor :entity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity = args[:entity] if args.key?(:entity)
        end
      end
      
      # 
      class ImageDataMultibangEntitiesMultibangEntity
        include Google::Apis::Core::Hashable
      
        # Entity ID.
        # Corresponds to the JSON property `entityId`
        # @return [String]
        attr_accessor :entity_id
      
        # Multibang score.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_id = args[:entity_id] if args.key?(:entity_id)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # 
      class ImageDataThumbnail
        include Google::Apis::Core::Hashable
      
        # The thumbnail is guaranteed to be kept in the serving system until the
        # expiration timestamp has passed, in microseconds.
        # Corresponds to the JSON property `expirationTimestampMicros`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp_micros
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `mimeType`
        # @return [String]
        attr_accessor :mime_type
      
        # 
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiration_timestamp_micros = args[:expiration_timestamp_micros] if args.key?(:expiration_timestamp_micros)
          @height = args[:height] if args.key?(:height)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @size = args[:size] if args.key?(:size)
          @type = args[:type] if args.key?(:type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class ImageExactBoost
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `navquery`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageExactBoostNavQuery>]
        attr_accessor :navquery
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @navquery = args[:navquery] if args.key?(:navquery)
        end
      end
      
      # Navboost query data.
      class ImageExactBoostNavQuery
        include Google::Apis::Core::Hashable
      
        # Associated confidence scores for the image for the query.
        # Corresponds to the JSON property `confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # Click-based rank of the image for this query.
        # Corresponds to the JSON property `imageClickRank`
        # @return [Fixnum]
        attr_accessor :image_click_rank
      
        # Query fingerprint.
        # Corresponds to the JSON property `navFp`
        # @return [Fixnum]
        attr_accessor :nav_fp
      
        # The normalized raw query text.
        # Corresponds to the JSON property `navQuery`
        # @return [String]
        attr_accessor :nav_query
      
        # List of all referrers, sorted by their rank (stored in Moosedog).
        # Corresponds to the JSON property `referrerDocid`
        # @return [Array<Fixnum>]
        attr_accessor :referrer_docid
      
        # Rank of the current web doc referrer (stored in docjoins).
        # Corresponds to the JSON property `referrerRank`
        # @return [Fixnum]
        attr_accessor :referrer_rank
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @image_click_rank = args[:image_click_rank] if args.key?(:image_click_rank)
          @nav_fp = args[:nav_fp] if args.key?(:nav_fp)
          @nav_query = args[:nav_query] if args.key?(:nav_query)
          @referrer_docid = args[:referrer_docid] if args.key?(:referrer_docid)
          @referrer_rank = args[:referrer_rank] if args.key?(:referrer_rank)
        end
      end
      
      # This proto holds IPTC metadata. http://www.iptc.org/cms/site/index.html?
      # channel=CH0099 Proto field name is same with IPTC property name except which
      # is clearly stated. Next Id: 63
      class ImageExifIptcMetadata
        include Google::Apis::Core::Hashable
      
        # Page URL about how to acquire this licensable image.
        # Corresponds to the JSON property `acquireLicensePage`
        # @return [String]
        attr_accessor :acquire_license_page
      
        # 
        # Corresponds to the JSON property `artwork`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageExifIptcMetadataArtwork>]
        attr_accessor :artwork
      
        # 
        # Corresponds to the JSON property `contactinfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageExifIptcMetadataContactInfo]
        attr_accessor :contactinfo
      
        # 
        # Corresponds to the JSON property `copyrightNotice`
        # @return [String]
        attr_accessor :copyright_notice
      
        # IPTC authorship & copyright related fields.
        # Corresponds to the JSON property `creator`
        # @return [Array<String>]
        attr_accessor :creator
      
        # 
        # Corresponds to the JSON property `creditLine`
        # @return [String]
        attr_accessor :credit_line
      
        # Time (in seconds)
        # Corresponds to the JSON property `dateCreated`
        # @return [Fixnum]
        attr_accessor :date_created
      
        # 
        # Corresponds to the JSON property `dateExpired`
        # @return [Fixnum]
        attr_accessor :date_expired
      
        # 
        # Corresponds to the JSON property `dateReleased`
        # @return [Fixnum]
        attr_accessor :date_released
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `event`
        # @return [String]
        attr_accessor :event
      
        # 
        # Corresponds to the JSON property `headline`
        # @return [String]
        attr_accessor :headline
      
        # PLUS field, not used.
        # Corresponds to the JSON property `imageSupplier`
        # @return [String]
        attr_accessor :image_supplier
      
        # 
        # Corresponds to the JSON property `instructions`
        # @return [String]
        attr_accessor :instructions
      
        # 
        # Corresponds to the JSON property `keywords`
        # @return [Array<String>]
        attr_accessor :keywords
      
        # License URL about how to distribute the image.
        # Corresponds to the JSON property `licenseUrl`
        # @return [String]
        attr_accessor :license_url
      
        # Location of the camera @deprecated: Use location_created instead.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::ImageExifIptcMetadataLocation]
        attr_accessor :location
      
        # Location of the camera
        # Corresponds to the JSON property `locationCreated`
        # @return [Google::Apis::ContentwarehouseV1::ImageExifIptcMetadataLocationInfo]
        attr_accessor :location_created
      
        # Location shown on the image
        # Corresponds to the JSON property `locationShown`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageExifIptcMetadataLocationInfo>]
        attr_accessor :location_shown
      
        # 
        # Corresponds to the JSON property `modelReleaseStatus`
        # @return [String]
        attr_accessor :model_release_status
      
        # 
        # Corresponds to the JSON property `propertyReleaseStatus`
        # @return [String]
        attr_accessor :property_release_status
      
        # 
        # Corresponds to the JSON property `rightsUsageTerms`
        # @return [String]
        attr_accessor :rights_usage_terms
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `supplementalCategories`
        # @return [Array<String>]
        attr_accessor :supplemental_categories
      
        # IPTC description related fields.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acquire_license_page = args[:acquire_license_page] if args.key?(:acquire_license_page)
          @artwork = args[:artwork] if args.key?(:artwork)
          @contactinfo = args[:contactinfo] if args.key?(:contactinfo)
          @copyright_notice = args[:copyright_notice] if args.key?(:copyright_notice)
          @creator = args[:creator] if args.key?(:creator)
          @credit_line = args[:credit_line] if args.key?(:credit_line)
          @date_created = args[:date_created] if args.key?(:date_created)
          @date_expired = args[:date_expired] if args.key?(:date_expired)
          @date_released = args[:date_released] if args.key?(:date_released)
          @description = args[:description] if args.key?(:description)
          @event = args[:event] if args.key?(:event)
          @headline = args[:headline] if args.key?(:headline)
          @image_supplier = args[:image_supplier] if args.key?(:image_supplier)
          @instructions = args[:instructions] if args.key?(:instructions)
          @keywords = args[:keywords] if args.key?(:keywords)
          @license_url = args[:license_url] if args.key?(:license_url)
          @location = args[:location] if args.key?(:location)
          @location_created = args[:location_created] if args.key?(:location_created)
          @location_shown = args[:location_shown] if args.key?(:location_shown)
          @model_release_status = args[:model_release_status] if args.key?(:model_release_status)
          @property_release_status = args[:property_release_status] if args.key?(:property_release_status)
          @rights_usage_terms = args[:rights_usage_terms] if args.key?(:rights_usage_terms)
          @source = args[:source] if args.key?(:source)
          @supplemental_categories = args[:supplemental_categories] if args.key?(:supplemental_categories)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Artwork or Object in the Image Details
      class ImageExifIptcMetadataArtwork
        include Google::Apis::Core::Hashable
      
        # Other fields omitted.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class ImageExifIptcMetadataContactInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `address`
        # @return [String]
        attr_accessor :address
      
        # 
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `phone`
        # @return [String]
        attr_accessor :phone
      
        # 
        # Corresponds to the JSON property `postalCode`
        # @return [String]
        attr_accessor :postal_code
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # 
        # Corresponds to the JSON property `webUrl`
        # @return [String]
        attr_accessor :web_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address = args[:address] if args.key?(:address)
          @city = args[:city] if args.key?(:city)
          @country = args[:country] if args.key?(:country)
          @email = args[:email] if args.key?(:email)
          @phone = args[:phone] if args.key?(:phone)
          @postal_code = args[:postal_code] if args.key?(:postal_code)
          @state = args[:state] if args.key?(:state)
          @web_url = args[:web_url] if args.key?(:web_url)
        end
      end
      
      # Location of the camera @deprecated: Use location_created instead.
      class ImageExifIptcMetadataLocation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # 
        # Corresponds to the JSON property `subLocation`
        # @return [String]
        attr_accessor :sub_location
      
        # 
        # Corresponds to the JSON property `worldRegion`
        # @return [String]
        attr_accessor :world_region
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @city = args[:city] if args.key?(:city)
          @country = args[:country] if args.key?(:country)
          @country_code = args[:country_code] if args.key?(:country_code)
          @state = args[:state] if args.key?(:state)
          @sub_location = args[:sub_location] if args.key?(:sub_location)
          @world_region = args[:world_region] if args.key?(:world_region)
        end
      end
      
      # 
      class ImageExifIptcMetadataLocationInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # 
        # Corresponds to the JSON property `subLocation`
        # @return [String]
        attr_accessor :sub_location
      
        # 
        # Corresponds to the JSON property `worldRegion`
        # @return [String]
        attr_accessor :world_region
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @city = args[:city] if args.key?(:city)
          @country = args[:country] if args.key?(:country)
          @country_code = args[:country_code] if args.key?(:country_code)
          @state = args[:state] if args.key?(:state)
          @sub_location = args[:sub_location] if args.key?(:sub_location)
          @world_region = args[:world_region] if args.key?(:world_region)
        end
      end
      
      # This class holds the EXIf/IPTC meta data Next Id: 104
      class ImageExifImageEmbeddedMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `altitude`
        # @return [Float]
        attr_accessor :altitude
      
        # 
        # Corresponds to the JSON property `aperture`
        # @return [Float]
        attr_accessor :aperture
      
        # Text fields EXIF_TAG_ARTIST
        # Corresponds to the JSON property `author`
        # @return [String]
        attr_accessor :author
      
        # EXIF_TAG_XP_AUTHOR
        # Corresponds to the JSON property `author2`
        # @return [String]
        attr_accessor :author2
      
        # 
        # Corresponds to the JSON property `brightness`
        # @return [Float]
        attr_accessor :brightness
      
        # Device - Camera raw text without normalization
        # Corresponds to the JSON property `cameraMaker`
        # @return [String]
        attr_accessor :camera_maker
      
        # raw text without normalization
        # Corresponds to the JSON property `cameraModel`
        # @return [String]
        attr_accessor :camera_model
      
        # This is the extracted serial number from EXIF (the source depends on camera,
        # most of the cameras store it in makers note tag).
        # Corresponds to the JSON property `cameraSerialNumber`
        # @return [String]
        attr_accessor :camera_serial_number
      
        # Capturing settings in time_t
        # Corresponds to the JSON property `captureTime`
        # @return [Fixnum]
        attr_accessor :capture_time
      
        # 
        # Corresponds to the JSON property `colorSpace`
        # @return [Fixnum]
        attr_accessor :color_space
      
        # EXIF_TAG_USER_COMMENT
        # Corresponds to the JSON property `comments`
        # @return [String]
        attr_accessor :comments
      
        # EXIF_TAG_XP_COMMENT
        # Corresponds to the JSON property `comments2`
        # @return [String]
        attr_accessor :comments2
      
        # 
        # Corresponds to the JSON property `continousDriveMode`
        # @return [Boolean]
        attr_accessor :continous_drive_mode
        alias_method :continous_drive_mode?, :continous_drive_mode
      
        # EXIF_TAG_COPYRIGHT
        # Corresponds to the JSON property `copyright`
        # @return [String]
        attr_accessor :copyright
      
        # Location from IPTC @deprecated: Use iptc.location instead.
        # Corresponds to the JSON property `deprecatedCity`
        # @return [String]
        attr_accessor :deprecated_city
      
        # 
        # Corresponds to the JSON property `deprecatedCountry`
        # @return [String]
        attr_accessor :deprecated_country
      
        # 
        # Corresponds to the JSON property `deprecatedState`
        # @return [String]
        attr_accessor :deprecated_state
      
        # EXIF_TAG_IMAGE_DESCRIPTION
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `destBearing`
        # @return [Float]
        attr_accessor :dest_bearing
      
        # Bearing and distance to destination point.
        # Corresponds to the JSON property `destBearingRef`
        # @return [Float]
        attr_accessor :dest_bearing_ref
      
        # 
        # Corresponds to the JSON property `destDistance`
        # @return [Float]
        attr_accessor :dest_distance
      
        # GPS location of destination point.
        # Corresponds to the JSON property `destLatitude`
        # @return [Float]
        attr_accessor :dest_latitude
      
        # 
        # Corresponds to the JSON property `destLongitude`
        # @return [Float]
        attr_accessor :dest_longitude
      
        # 
        # Corresponds to the JSON property `digitalZoomRatio`
        # @return [Float]
        attr_accessor :digital_zoom_ratio
      
        # 
        # Corresponds to the JSON property `exposureBias`
        # @return [Float]
        attr_accessor :exposure_bias
      
        # 1-8, see EXIF definition
        # Corresponds to the JSON property `exposureProgram`
        # @return [Fixnum]
        attr_accessor :exposure_program
      
        # 
        # Corresponds to the JSON property `exposureTime`
        # @return [Float]
        attr_accessor :exposure_time
      
        # 
        # Corresponds to the JSON property `flashUsed`
        # @return [Boolean]
        attr_accessor :flash_used
        alias_method :flash_used?, :flash_used
      
        # 
        # Corresponds to the JSON property `focalLength`
        # @return [Float]
        attr_accessor :focal_length
      
        # convert to match 35mm film camera
        # Corresponds to the JSON property `focalLength35mm`
        # @return [Float]
        attr_accessor :focal_length35mm
      
        # 
        # Corresponds to the JSON property `focalPlaneResUnit`
        # @return [Fixnum]
        attr_accessor :focal_plane_res_unit
      
        # 
        # Corresponds to the JSON property `focalPlaneXres`
        # @return [Float]
        attr_accessor :focal_plane_xres
      
        # 
        # Corresponds to the JSON property `focusMode`
        # @return [String]
        attr_accessor :focus_mode
      
        # Dilution of precision. HDOP/PDOP depends on measure mode. Find out more at
        # http://en.wikipedia.org/wiki/Dilution_of_precision_(GPS)
        # Corresponds to the JSON property `gpsDop`
        # @return [Float]
        attr_accessor :gps_dop
      
        # 
        # Corresponds to the JSON property `gpsMeasureMode`
        # @return [String]
        attr_accessor :gps_measure_mode
      
        # 
        # Corresponds to the JSON property `gpsStatus`
        # @return [String]
        attr_accessor :gps_status
      
        # in meters
        # Corresponds to the JSON property `hPositioningError`
        # @return [Float]
        attr_accessor :h_positioning_error
      
        # 
        # Corresponds to the JSON property `imageHeight`
        # @return [Fixnum]
        attr_accessor :image_height
      
        # 
        # Corresponds to the JSON property `imageWidth`
        # @return [Fixnum]
        attr_accessor :image_width
      
        # GPS Heading 0.00 to 359.99 degrees
        # Corresponds to the JSON property `imgDirection`
        # @return [Float]
        attr_accessor :img_direction
      
        # 
        # Corresponds to the JSON property `imgDirectionRef`
        # @return [String]
        attr_accessor :img_direction_ref
      
        # This proto holds IPTC metadata. http://www.iptc.org/cms/site/index.html?
        # channel=CH0099 Proto field name is same with IPTC property name except which
        # is clearly stated. Next Id: 63
        # Corresponds to the JSON property `iptc`
        # @return [Google::Apis::ContentwarehouseV1::ImageExifIptcMetadata]
        attr_accessor :iptc
      
        # 
        # Corresponds to the JSON property `iso`
        # @return [Fixnum]
        attr_accessor :iso
      
        # EXIF_TAG_XP_KEYWORDS
        # Corresponds to the JSON property `keywords`
        # @return [String]
        attr_accessor :keywords
      
        # GPS location +/- 90 inclusive
        # Corresponds to the JSON property `latitude`
        # @return [Float]
        attr_accessor :latitude
      
        # Device - Lens We use this extended id to identify a lens uniquely. Canon: "%d %
        # d %d"=.. Nikon: "%.2X %.2X %.2X %.2X %.2X %.2X %.2X %.2X" Don't change the
        # format of the internal lens id because we use them to look up the lens names.
        # Corresponds to the JSON property `lensId`
        # @return [String]
        attr_accessor :lens_id
      
        # 
        # Corresponds to the JSON property `lensMaker`
        # @return [String]
        attr_accessor :lens_maker
      
        # 
        # Corresponds to the JSON property `lightSource`
        # @return [Fixnum]
        attr_accessor :light_source
      
        # 
        # Corresponds to the JSON property `longFocal`
        # @return [Fixnum]
        attr_accessor :long_focal
      
        # +/- 180 inclusive
        # Corresponds to the JSON property `longitude`
        # @return [Float]
        attr_accessor :longitude
      
        # 
        # Corresponds to the JSON property `maxApertureAtLongFocal`
        # @return [Float]
        attr_accessor :max_aperture_at_long_focal
      
        # 
        # Corresponds to the JSON property `maxApertureAtShortFocal`
        # @return [Float]
        attr_accessor :max_aperture_at_short_focal
      
        # 1-6, see EXIF definition
        # Corresponds to the JSON property `meteringMode`
        # @return [Fixnum]
        attr_accessor :metering_mode
      
        # in time_t
        # Corresponds to the JSON property `modificationTime`
        # @return [Fixnum]
        attr_accessor :modification_time
      
        # 
        # Corresponds to the JSON property `orientation`
        # @return [String]
        attr_accessor :orientation
      
        # 
        # Corresponds to the JSON property `shortFocal`
        # @return [Fixnum]
        attr_accessor :short_focal
      
        # EXIF_TAG_SOFTWARE
        # Corresponds to the JSON property `software`
        # @return [String]
        attr_accessor :software
      
        # EXIF_TAG_XP_SUBJECT
        # Corresponds to the JSON property `subject`
        # @return [String]
        attr_accessor :subject
      
        # 
        # Corresponds to the JSON property `subjectDistance`
        # @return [Float]
        attr_accessor :subject_distance
      
        # 
        # Corresponds to the JSON property `subjectLocationX`
        # @return [Fixnum]
        attr_accessor :subject_location_x
      
        # 
        # Corresponds to the JSON property `subjectLocationY`
        # @return [Fixnum]
        attr_accessor :subject_location_y
      
        # EXIF_TAG_XP_TITLE
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # pixels per inch
        # Corresponds to the JSON property `xResolution`
        # @return [Float]
        attr_accessor :x_resolution
      
        # pixels per inch
        # Corresponds to the JSON property `yResolution`
        # @return [Float]
        attr_accessor :y_resolution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @altitude = args[:altitude] if args.key?(:altitude)
          @aperture = args[:aperture] if args.key?(:aperture)
          @author = args[:author] if args.key?(:author)
          @author2 = args[:author2] if args.key?(:author2)
          @brightness = args[:brightness] if args.key?(:brightness)
          @camera_maker = args[:camera_maker] if args.key?(:camera_maker)
          @camera_model = args[:camera_model] if args.key?(:camera_model)
          @camera_serial_number = args[:camera_serial_number] if args.key?(:camera_serial_number)
          @capture_time = args[:capture_time] if args.key?(:capture_time)
          @color_space = args[:color_space] if args.key?(:color_space)
          @comments = args[:comments] if args.key?(:comments)
          @comments2 = args[:comments2] if args.key?(:comments2)
          @continous_drive_mode = args[:continous_drive_mode] if args.key?(:continous_drive_mode)
          @copyright = args[:copyright] if args.key?(:copyright)
          @deprecated_city = args[:deprecated_city] if args.key?(:deprecated_city)
          @deprecated_country = args[:deprecated_country] if args.key?(:deprecated_country)
          @deprecated_state = args[:deprecated_state] if args.key?(:deprecated_state)
          @description = args[:description] if args.key?(:description)
          @dest_bearing = args[:dest_bearing] if args.key?(:dest_bearing)
          @dest_bearing_ref = args[:dest_bearing_ref] if args.key?(:dest_bearing_ref)
          @dest_distance = args[:dest_distance] if args.key?(:dest_distance)
          @dest_latitude = args[:dest_latitude] if args.key?(:dest_latitude)
          @dest_longitude = args[:dest_longitude] if args.key?(:dest_longitude)
          @digital_zoom_ratio = args[:digital_zoom_ratio] if args.key?(:digital_zoom_ratio)
          @exposure_bias = args[:exposure_bias] if args.key?(:exposure_bias)
          @exposure_program = args[:exposure_program] if args.key?(:exposure_program)
          @exposure_time = args[:exposure_time] if args.key?(:exposure_time)
          @flash_used = args[:flash_used] if args.key?(:flash_used)
          @focal_length = args[:focal_length] if args.key?(:focal_length)
          @focal_length35mm = args[:focal_length35mm] if args.key?(:focal_length35mm)
          @focal_plane_res_unit = args[:focal_plane_res_unit] if args.key?(:focal_plane_res_unit)
          @focal_plane_xres = args[:focal_plane_xres] if args.key?(:focal_plane_xres)
          @focus_mode = args[:focus_mode] if args.key?(:focus_mode)
          @gps_dop = args[:gps_dop] if args.key?(:gps_dop)
          @gps_measure_mode = args[:gps_measure_mode] if args.key?(:gps_measure_mode)
          @gps_status = args[:gps_status] if args.key?(:gps_status)
          @h_positioning_error = args[:h_positioning_error] if args.key?(:h_positioning_error)
          @image_height = args[:image_height] if args.key?(:image_height)
          @image_width = args[:image_width] if args.key?(:image_width)
          @img_direction = args[:img_direction] if args.key?(:img_direction)
          @img_direction_ref = args[:img_direction_ref] if args.key?(:img_direction_ref)
          @iptc = args[:iptc] if args.key?(:iptc)
          @iso = args[:iso] if args.key?(:iso)
          @keywords = args[:keywords] if args.key?(:keywords)
          @latitude = args[:latitude] if args.key?(:latitude)
          @lens_id = args[:lens_id] if args.key?(:lens_id)
          @lens_maker = args[:lens_maker] if args.key?(:lens_maker)
          @light_source = args[:light_source] if args.key?(:light_source)
          @long_focal = args[:long_focal] if args.key?(:long_focal)
          @longitude = args[:longitude] if args.key?(:longitude)
          @max_aperture_at_long_focal = args[:max_aperture_at_long_focal] if args.key?(:max_aperture_at_long_focal)
          @max_aperture_at_short_focal = args[:max_aperture_at_short_focal] if args.key?(:max_aperture_at_short_focal)
          @metering_mode = args[:metering_mode] if args.key?(:metering_mode)
          @modification_time = args[:modification_time] if args.key?(:modification_time)
          @orientation = args[:orientation] if args.key?(:orientation)
          @short_focal = args[:short_focal] if args.key?(:short_focal)
          @software = args[:software] if args.key?(:software)
          @subject = args[:subject] if args.key?(:subject)
          @subject_distance = args[:subject_distance] if args.key?(:subject_distance)
          @subject_location_x = args[:subject_location_x] if args.key?(:subject_location_x)
          @subject_location_y = args[:subject_location_y] if args.key?(:subject_location_y)
          @title = args[:title] if args.key?(:title)
          @x_resolution = args[:x_resolution] if args.key?(:x_resolution)
          @y_resolution = args[:y_resolution] if args.key?(:y_resolution)
        end
      end
      
      # 
      class ImageMonetizationFeaturedImageProperties
        include Google::Apis::Core::Hashable
      
        # How an image is inspirational, [0, 1].
        # Corresponds to the JSON property `inspirationScore`
        # @return [Float]
        attr_accessor :inspiration_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @inspiration_score = args[:inspiration_score] if args.key?(:inspiration_score)
        end
      end
      
      # 
      class ImageMoosedogCrawlState
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `code`
        # @return [String]
        attr_accessor :code
      
        # Each of the above not_crawled_reason will have a set of detailed reason
        # defined in crawler/trawler/trawler_enums.proto.
        # Corresponds to the JSON property `detailedReason`
        # @return [Fixnum]
        attr_accessor :detailed_reason
      
        # Wire-format for a Status object
        # Corresponds to the JSON property `internalStatus`
        # @return [Google::Apis::ContentwarehouseV1::UtilStatusProto]
        attr_accessor :internal_status
      
        # Specifies if the current crawl state is terminal.
        # Corresponds to the JSON property `isTerminal`
        # @return [Boolean]
        attr_accessor :is_terminal
        alias_method :is_terminal?, :is_terminal
      
        # Time in seconds since epoch after which this image should be considered
        # unavailable.
        # Corresponds to the JSON property `noIndexAfterTimestamp`
        # @return [Fixnum]
        attr_accessor :no_index_after_timestamp
      
        # 
        # Corresponds to the JSON property `notCrawledReason`
        # @return [String]
        attr_accessor :not_crawled_reason
      
        # When true, it means that a non-terminal state has overwrote a terminal one.
        # Corresponds to the JSON property `overrodeTerminalState`
        # @return [Boolean]
        attr_accessor :overrode_terminal_state
        alias_method :overrode_terminal_state?, :overrode_terminal_state
      
        # The repid for the urls. This repid is the id given to the dupe cluster this
        # url belongs to.
        # Corresponds to the JSON property `repid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :repid
      
        # A comma separated list of user agents for which this image should be
        # considered roboted. All images are crawled using googlebot-images and this
        # exists here purely for informative reasons.
        # Corresponds to the JSON property `robotedAgents`
        # @return [String]
        attr_accessor :roboted_agents
      
        # The url at which we crawled this content. With us starting to use repids the
        # crawl table key no longer is suggestive of the url. In addition this is used
        # in Amarna to detect race conditions between a reference changing its crawl
        # directive and the original crawl job finishing.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Set to true if the url is taken down by clients. This indicates that this
        # crawl state is used to fast remove the crawl result of the url instead of
        # waiting for Multiverse crawl results. For more information, please refer to go/
        # amarna-url-deletion.
        # Corresponds to the JSON property `urlDeleted`
        # @return [Boolean]
        attr_accessor :url_deleted
        alias_method :url_deleted?, :url_deleted
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @detailed_reason = args[:detailed_reason] if args.key?(:detailed_reason)
          @internal_status = args[:internal_status] if args.key?(:internal_status)
          @is_terminal = args[:is_terminal] if args.key?(:is_terminal)
          @no_index_after_timestamp = args[:no_index_after_timestamp] if args.key?(:no_index_after_timestamp)
          @not_crawled_reason = args[:not_crawled_reason] if args.key?(:not_crawled_reason)
          @overrode_terminal_state = args[:overrode_terminal_state] if args.key?(:overrode_terminal_state)
          @repid = args[:repid] if args.key?(:repid)
          @roboted_agents = args[:roboted_agents] if args.key?(:roboted_agents)
          @url = args[:url] if args.key?(:url)
          @url_deleted = args[:url_deleted] if args.key?(:url_deleted)
        end
      end
      
      # For detailed info, please see go/naive-image-selection
      class ImageMustangImageLinkSelectionInfo
        include Google::Apis::Core::Hashable
      
        # score calculated in image selection phase, higher imagelink_selection_score
        # more relevant the link is related to the web page
        # Corresponds to the JSON property `webRelevanceScore`
        # @return [Float]
        attr_accessor :web_relevance_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @web_relevance_score = args[:web_relevance_score] if args.key?(:web_relevance_score)
        end
      end
      
      # A proto buffer to organize shopping offer info from Inventory & Policy Service.
      class ImageMustangShoppingOffer
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `inferredImageTypes`
        # @return [Array<String>]
        attr_accessor :inferred_image_types
      
        # 
        # Corresponds to the JSON property `ipsOfferId`
        # @return [Fixnum]
        attr_accessor :ips_offer_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @inferred_image_types = args[:inferred_image_types] if args.key?(:inferred_image_types)
          @ips_offer_id = args[:ips_offer_id] if args.key?(:ips_offer_id)
        end
      end
      
      # 
      class ImagePerDocData
        include Google::Apis::Core::Hashable
      
        # entropy and color values for thumbnail (4 bytes consisting of R, G, B and
        # entropy values)
        # Corresponds to the JSON property `DEPRECATEDEntropyColor`
        # @return [Fixnum]
        attr_accessor :deprecated_entropy_color
      
        # about 10 bytes
        # Corresponds to the JSON property `filename`
        # @return [String]
        attr_accessor :filename
      
        # image_perdoc.h
        # Corresponds to the JSON property `flags`
        # @return [Fixnum]
        attr_accessor :flags
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_entropy_color = args[:deprecated_entropy_color] if args.key?(:deprecated_entropy_color)
          @filename = args[:filename] if args.key?(:filename)
          @flags = args[:flags] if args.key?(:flags)
          @height = args[:height] if args.key?(:height)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Used to store debug information of the overall classifier.
      class ImagePornDebugInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `info`
        # @return [String]
        attr_accessor :info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @info = args[:info] if args.key?(:info)
        end
      end
      
      # A single region within an image. NEXT_ID: 11
      class ImageRegionsImageRegion
        include Google::Apis::Core::Hashable
      
        # Bounding box coordinates are relative to the width and height of the image.
        # For example, if image is 100x200 and NormalizedBoundingBox is , the bounding
        # box coordinates will be (10, 40) to (50, 180). Note parts of the bounding box
        # may fall outside the image.
        # Corresponds to the JSON property `boundingBox`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionGroundtruthdbNormalizedBoundingBox]
        attr_accessor :bounding_box
      
        # The confidence score associated with the bounding box.
        # Corresponds to the JSON property `boundingBoxScore`
        # @return [Float]
        attr_accessor :bounding_box_score
      
        # A unique identifier for the region within the image. The id is unique only
        # among other regions in the image.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # Set true if the region represents a product, i.e., if any of its labels are on
        # a product labels whitelist. See ImageRegionsConfig for details on the product
        # whitelist.
        # Corresponds to the JSON property `isProduct`
        # @return [Boolean]
        attr_accessor :is_product
        alias_method :is_product?, :is_product
      
        # The score for this region based on how visually similar its neighbors are.
        # Corresponds to the JSON property `knnScore`
        # @return [Float]
        attr_accessor :knn_score
      
        # LabelGroup is a set of labels produced by a single model, or by multiple
        # models that share the same versioning. It can be used to store results from
        # ICA, box classifier, visible labels, noun+attribute, and so on.
        # Corresponds to the JSON property `labelGroup`
        # @return [Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingLabelGroup]
        attr_accessor :label_group
      
        # The version string of the labels with which the region was processed.
        # Corresponds to the JSON property `labelVersion`
        # @return [String]
        attr_accessor :label_version
      
        # A single label with score and meta data.
        # Corresponds to the JSON property `primaryLabel`
        # @return [Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingLabel]
        attr_accessor :primary_label
      
        # 
        # Corresponds to the JSON property `renderType`
        # @return [String]
        attr_accessor :render_type
      
        # Image feature embedding proto. It supports various embedding formats: raw
        # bytes, floating point values, and tokens.
        # Corresponds to the JSON property `starburstV4`
        # @return [Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingFeature]
        attr_accessor :starburst_v4
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
          @bounding_box_score = args[:bounding_box_score] if args.key?(:bounding_box_score)
          @id = args[:id] if args.key?(:id)
          @is_product = args[:is_product] if args.key?(:is_product)
          @knn_score = args[:knn_score] if args.key?(:knn_score)
          @label_group = args[:label_group] if args.key?(:label_group)
          @label_version = args[:label_version] if args.key?(:label_version)
          @primary_label = args[:primary_label] if args.key?(:primary_label)
          @render_type = args[:render_type] if args.key?(:render_type)
          @starburst_v4 = args[:starburst_v4] if args.key?(:starburst_v4)
        end
      end
      
      # An image with regions within it. NEXT_ID: 11
      class ImageRegionsImageRegions
        include Google::Apis::Core::Hashable
      
        # The final_porn_score for the image.
        # Corresponds to the JSON property `finalPornScore`
        # @return [Float]
        attr_accessor :final_porn_score
      
        # The final_violence_score for the image.
        # Corresponds to the JSON property `finalViolenceScore`
        # @return [Float]
        attr_accessor :final_violence_score
      
        # The subset of FlowProto that we want to go into production AND be stored in
        # ContentSignals.
        # Corresponds to the JSON property `flowOutput`
        # @return [Google::Apis::ContentwarehouseV1::ImageContentFlowProtoProd]
        attr_accessor :flow_output
      
        # True if the image has a 300k thumb.
        # Corresponds to the JSON property `has300kThumb`
        # @return [Boolean]
        attr_accessor :has300k_thumb
        alias_method :has300k_thumb?, :has300k_thumb
      
        # True if the image has navboost.
        # Corresponds to the JSON property `hasNavboost`
        # @return [Boolean]
        attr_accessor :has_navboost
        alias_method :has_navboost?, :has_navboost
      
        # True if the image is iu-inappropriate.
        # Corresponds to the JSON property `isIuInappropriate`
        # @return [Boolean]
        attr_accessor :is_iu_inappropriate
        alias_method :is_iu_inappropriate?, :is_iu_inappropriate
      
        # The pedo_score of the image.
        # Corresponds to the JSON property `pedoScore`
        # @return [Float]
        attr_accessor :pedo_score
      
        # The restricts that are computed before building a Mustang index.
        # Corresponds to the JSON property `precomputedRestricts`
        # @return [Google::Apis::ContentwarehouseV1::PrecomputedRestricts]
        attr_accessor :precomputed_restricts
      
        # The racy_score of the image.
        # Corresponds to the JSON property `racyScore`
        # @return [Float]
        attr_accessor :racy_score
      
        # The list of regions.
        # Corresponds to the JSON property `region`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRegionsImageRegion>]
        attr_accessor :region
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @final_porn_score = args[:final_porn_score] if args.key?(:final_porn_score)
          @final_violence_score = args[:final_violence_score] if args.key?(:final_violence_score)
          @flow_output = args[:flow_output] if args.key?(:flow_output)
          @has300k_thumb = args[:has300k_thumb] if args.key?(:has300k_thumb)
          @has_navboost = args[:has_navboost] if args.key?(:has_navboost)
          @is_iu_inappropriate = args[:is_iu_inappropriate] if args.key?(:is_iu_inappropriate)
          @pedo_score = args[:pedo_score] if args.key?(:pedo_score)
          @precomputed_restricts = args[:precomputed_restricts] if args.key?(:precomputed_restricts)
          @racy_score = args[:racy_score] if args.key?(:racy_score)
          @region = args[:region] if args.key?(:region)
        end
      end
      
      # Next Tag: 7
      class ImageRepositoryAmarnaCloudSpeechSignals
        include Google::Apis::Core::Hashable
      
        # The language id input for creating this ASR without regional info. Same format
        # as in go/ytlangid. This field is populated in Kronos Amarna Cloud Speech
        # operator and passed to Amarna, but it is cleared before stored in Amarna's
        # metadata table.
        # Corresponds to the JSON property `langWithoutLocale`
        # @return [String]
        attr_accessor :lang_without_locale
      
        # Identifying which ASR models are used for the result
        # Corresponds to the JSON property `modelIdentifier`
        # @return [String]
        attr_accessor :model_identifier
      
        # Raw results from Cloud Speech API
        # Corresponds to the JSON property `results`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositorySpeechRecognitionResult>]
        attr_accessor :results
      
        # Available tags: 14+
        # Corresponds to the JSON property `transcriptAsr`
        # @return [Google::Apis::ContentwarehouseV1::PseudoVideoData]
        attr_accessor :transcript_asr
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lang_without_locale = args[:lang_without_locale] if args.key?(:lang_without_locale)
          @model_identifier = args[:model_identifier] if args.key?(:model_identifier)
          @results = args[:results] if args.key?(:results)
          @transcript_asr = args[:transcript_asr] if args.key?(:transcript_asr)
        end
      end
      
      # 
      class ImageRepositoryAmarnaSignalsBlob
        include Google::Apis::Core::Hashable
      
        # This represents a sequence (ordered) of FeatureSetData elements.
        # Corresponds to the JSON property `frameFeatures`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureSetDataSequence]
        attr_accessor :frame_features
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_features = args[:frame_features] if args.key?(:frame_features)
        end
      end
      
      # 
      class ImageRepositoryAmarnaSignalsBlobInfo
        include Google::Apis::Core::Hashable
      
        # Blob id for AmarnaSignalsBlob (see `Blob proto` section of go/revisit-frame-
        # level-signals-amarna).
        # Corresponds to the JSON property `signalsBlobId`
        # @return [String]
        attr_accessor :signals_blob_id
      
        # Additional timestamp field for when the blob is written/updated, serving as
        # the dirty field to help checksum-based update push (see `Dirty field` section
        # in go/revisit-frame-level-signals-amarna).
        # Corresponds to the JSON property `signalsBlobUpdateTimestamp`
        # @return [String]
        attr_accessor :signals_blob_update_timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @signals_blob_id = args[:signals_blob_id] if args.key?(:signals_blob_id)
          @signals_blob_update_timestamp = args[:signals_blob_update_timestamp] if args.key?(:signals_blob_update_timestamp)
        end
      end
      
      # This message stores the status and reason why Amarna was unable to provide
      # perdoc information for an image.
      class ImageRepositoryAmarnaStatus
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `reason`
        # @return [String]
        attr_accessor :reason
      
        # 
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reason = args[:reason] if args.key?(:reason)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Additional animated image data stored in perdoc (ImageData); will only be
      # stored for animated images.
      class ImageRepositoryAnimatedImagePerdocData
        include Google::Apis::Core::Hashable
      
        # Don't change the field names. The names are used as sparse feature labels in
        # client projects.
        # Corresponds to the JSON property `aggregatedPornScores`
        # @return [Google::Apis::ContentwarehouseV1::ImageSafesearchContentBrainPornAnnotation]
        attr_accessor :aggregated_porn_scores
      
        # Total duration of animation, in ms.
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_porn_scores = args[:aggregated_porn_scores] if args.key?(:aggregated_porn_scores)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
        end
      end
      
      # The metadata returned with each transcode. Next available field: 9
      class ImageRepositoryApiItagSpecificMetadata
        include Google::Apis::Core::Hashable
      
        # Timestamp (measured in seconds since epoch) after which Amarna will delete the
        # serving transcode.
        # Corresponds to the JSON property `expirationTimestampSec`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp_sec
      
        # The Venom Genus that this transcode was produced for.
        # Corresponds to the JSON property `genus`
        # @return [String]
        attr_accessor :genus
      
        # Indicates the state in Venom for this transcode type.
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # transcode type which are available for the video.
        # Corresponds to the JSON property `transcodeItag`
        # @return [Fixnum]
        attr_accessor :transcode_itag
      
        # A VideoId is the unique identifier of a video. Privacy: VideoIds are visible
        # in logs, notifications, etc and must not contain PII.
        # Corresponds to the JSON property `videoId`
        # @return [Google::Apis::ContentwarehouseV1::VideoAssetsVenomVideoId]
        attr_accessor :video_id
      
        # XtagList -- a collection of Xtag instances with unique names. This would be
        # associated with one specific piece of content.
        # Corresponds to the JSON property `xtagsList`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryApiXtagList]
        attr_accessor :xtags_list
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiration_timestamp_sec = args[:expiration_timestamp_sec] if args.key?(:expiration_timestamp_sec)
          @genus = args[:genus] if args.key?(:genus)
          @state = args[:state] if args.key?(:state)
          @transcode_itag = args[:transcode_itag] if args.key?(:transcode_itag)
          @video_id = args[:video_id] if args.key?(:video_id)
          @xtags_list = args[:xtags_list] if args.key?(:xtags_list)
        end
      end
      
      # 
      class ImageRepositoryApiXtag
        include Google::Apis::Core::Hashable
      
        # Names are all stored case-sensitive, and no case-folding is done for
        # comparisons.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The value associated with this Xtag. Values are all stored case-sensitive, and
        # no case-folding is done for comparisons.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # XtagList -- a collection of Xtag instances with unique names. This would be
      # associated with one specific piece of content.
      class ImageRepositoryApiXtagList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `xtags`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryApiXtag>]
        attr_accessor :xtags
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @xtags = args[:xtags] if args.key?(:xtags)
        end
      end
      
      # Next Tag: 48
      class ImageRepositoryContentBasedVideoMetadata
        include Google::Apis::Core::Hashable
      
        # A hash of the video bytes used as a key to Amarna's video_metadata table.
        # Corresponds to the JSON property `amarnaDocid`
        # @return [String]
        attr_accessor :amarna_docid
      
        # Timestamp of the last successful Ares classification request.
        # Corresponds to the JSON property `aresClassificationRequestTimestamp`
        # @return [String]
        attr_accessor :ares_classification_request_timestamp
      
        # Both audio- and audio-video-files are treated as videos during indexing (
        # whether they share a container format, like .mp4, or not, like .mp3). This
        # bool indicates that there's no video track, just an audio track.
        # Corresponds to the JSON property `audioOnly`
        # @return [Boolean]
        attr_accessor :audio_only
        alias_method :audio_only?, :audio_only
      
        # Next Tag: 7
        # Corresponds to the JSON property `cloudSpeechSignals`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryAmarnaCloudSpeechSignals]
        attr_accessor :cloud_speech_signals
      
        # Video Understanding Golden features. (go/amarna-video-signals#golden-signals)
        # Note: Golden6 features (names matching "video_*") are DEPRECATED. Please
        # migrate to Golden7 ("VideoFeatures.*"). For more context, see go/golden7/
        # migrating-from-golden6 and go/amarna-golden-feature-tracker.
        # Corresponds to the JSON property `featureSetData`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureSetData]
        attr_accessor :feature_set_data
      
        # Golden7 video-level people features. (go/ypf-video-features)
        # Corresponds to the JSON property `golden7SoapboxSummary`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureSetData]
        attr_accessor :golden7_soapbox_summary
      
        # This message is used to store information about Inline Playback in the
        # VideoWebAttachment portion of the websearch index. LINT.IfChange
        # Corresponds to the JSON property `inlinePlayback`
        # @return [Google::Apis::ContentwarehouseV1::VideoCrawlVideoInlinePlaybackMetadata]
        attr_accessor :inline_playback
      
        # 
        # Corresponds to the JSON property `languageIdentification`
        # @return [Google::Apis::ContentwarehouseV1::VideoTimedtextS4AliResults]
        attr_accessor :language_identification
      
        # Legos results
        # Corresponds to the JSON property `legosAnnotationData`
        # @return [Google::Apis::ContentwarehouseV1::VideoLegosLegosAnnotationsSets]
        attr_accessor :legos_annotation_data
      
        # This proto stores perdocs extracted from video frames.
        # Corresponds to the JSON property `lmsPreviewFramePerdocs`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryFramePerdocs]
        attr_accessor :lms_preview_frame_perdocs
      
        # Measurement of loudness. Next tag = 3
        # Corresponds to the JSON property `loudnessData`
        # @return [Google::Apis::ContentwarehouseV1::VideoStorageLoudnessData]
        attr_accessor :loudness_data
      
        # Feel free to ignore this lint warning if only the trivia (e.g., comments) is
        # is changed. LINT.IfChange
        # Corresponds to the JSON property `mediaInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoMediaInfo]
        attr_accessor :media_info
      
        # This defines the per-doc data which is extracted from thumbnails and
        # propagated over to indexing. It contains all information that can be used for
        # restricts. Next tag id: 127
        # Corresponds to the JSON property `representativeFrameData`
        # @return [Google::Apis::ContentwarehouseV1::ImageData]
        attr_accessor :representative_frame_data
      
        # Next Tag: 9
        # Corresponds to the JSON property `s3LanguageIdentification`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryS3LangIdSignals]
        attr_accessor :s3_language_identification
      
        # SafeSearch video content classification scores are computed based on go/
        # golden7 video features. To access these scores see the library at: google3/
        # quality/safesearch/video/api/video_score_info.h
        # Corresponds to the JSON property `safesearchVideoContentSignals`
        # @return [Google::Apis::ContentwarehouseV1::SafesearchVideoContentSignals]
        attr_accessor :safesearch_video_content_signals
      
        # 64 bit docid used for retrieving video previews.
        # Corresponds to the JSON property `searchDocid`
        # @return [Fixnum]
        attr_accessor :search_docid
      
        # Amarna signals blob that contains large-size signals like VCA frame-level
        # signals.
        # Corresponds to the JSON property `signalsBlob`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryAmarnaSignalsBlob]
        attr_accessor :signals_blob
      
        # Information for the amarna signals blob.
        # Corresponds to the JSON property `signalsBlobInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryAmarnaSignalsBlobInfo]
        attr_accessor :signals_blob_info
      
        # The information about spoken content that's based on purely the media resource
        # contents (and not the embedding page or context, etc).
        # Corresponds to the JSON property `speechProperties`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSpeechSpeechPropertiesProto]
        attr_accessor :speech_properties
      
        # LINT.IfChange Score calculated from a thumbnail. NextID: 15
        # Corresponds to the JSON property `thumbnailQualityScore`
        # @return [Google::Apis::ContentwarehouseV1::VideoThumbnailsThumbnailScore]
        attr_accessor :thumbnail_quality_score
      
        # 
        # Corresponds to the JSON property `thumbnailerData`
        # @return [Google::Apis::ContentwarehouseV1::VideoPipelineViperThumbnailerColumnData]
        attr_accessor :thumbnailer_data
      
        # Metadata about each transcode requested.
        # Corresponds to the JSON property `transcodeMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryApiItagSpecificMetadata>]
        attr_accessor :transcode_metadata
      
        # Available tags: 14+
        # Corresponds to the JSON property `transcriptAsr`
        # @return [Google::Apis::ContentwarehouseV1::PseudoVideoData]
        attr_accessor :transcript_asr
      
        # Describes our knowledge about whether a stored file is truncated with respect
        # to its original file online.
        # Corresponds to the JSON property `truncationInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryFileTruncationInfo]
        attr_accessor :truncation_info
      
        # To indicate whether the image is to be deleted from the repository due to
        # legal reasons.
        # Corresponds to the JSON property `unwantedContent`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryUnwantedContent]
        attr_accessor :unwanted_content
      
        # The video id in the venom pipeline for STAMP purposes. DEPRECATED: Use
        # transcode_metadata or venom_processing_info instead, which includes the ID and
        # contains information for all clients.
        # Corresponds to the JSON property `venomId`
        # @return [String]
        attr_accessor :venom_id
      
        # Information about the video's status in Venom, including IDs and processing
        # times.
        # Corresponds to the JSON property `venomProcessingInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryVenomProcessingInfo]
        attr_accessor :venom_processing_info
      
        # One video can have multiple types of text anchors. For example, https://www.
        # youtube.com/watch?v=Rtk0I5PVOIc has both list anchors and OCR anchors.
        # Corresponds to the JSON property `videoAnchorSet`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorSets]
        attr_accessor :video_anchor_set
      
        # Set from the video header if truncated, or is the verified length if
        # completely crawled.
        # Corresponds to the JSON property `videoDurationSec`
        # @return [Float]
        attr_accessor :video_duration_sec
      
        # The video porn confidence score extracted from Whisper featureSet: "
        # video_labels:whisper_v3", with CR2 label: "/cr2/1".
        # Corresponds to the JSON property `videoPornScore`
        # @return [Float]
        attr_accessor :video_porn_score
      
        # The video porn confidence score extracted from WhisperV4 featureSet: "
        # VideoFeatures.whisper_v4_labels", with CR2 label: "/tns/porn".
        # Corresponds to the JSON property `videoPornScoreV4`
        # @return [Float]
        attr_accessor :video_porn_score_v4
      
        # video_preview_bytes is only exported as virtual dataset by IE
        # VideoUnderstanding and should not be persisted. It will be used by downstream
        # IE functions to push for serving.
        # Corresponds to the JSON property `videoPreviewBytes`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryVideoPreviewsVideoPreview>]
        attr_accessor :video_preview_bytes
      
        # video_previews contain the preview metadata but no bytes. It exits for IE and
        # non-IE cases.
        # Corresponds to the JSON property `videoPreviews`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageBaseVideoPreviewMetadata>]
        attr_accessor :video_previews
      
        # Deprecated, please use media_info.
        # Corresponds to the JSON property `videoStreamInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoPipelineViperVsiColumnData]
        attr_accessor :video_stream_info
      
        # VideoTranscriptAnnotations holds sentence segmented text and timing
        # information to be used for VideoAnswers (go/video-answers). Note that only
        # punctuated_transcript, timing_info, and lang field are filled, and other
        # fields will be filled in the later stage.
        # Corresponds to the JSON property `videoTranscriptAnnotations`
        # @return [Google::Apis::ContentwarehouseV1::QualityWebanswersVideoTranscriptAnnotations]
        attr_accessor :video_transcript_annotations
      
        # Next available tag: 13
        # Corresponds to the JSON property `youtubeProcessingFilter`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryYoutubeProcessingFilter]
        attr_accessor :youtube_processing_filter
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amarna_docid = args[:amarna_docid] if args.key?(:amarna_docid)
          @ares_classification_request_timestamp = args[:ares_classification_request_timestamp] if args.key?(:ares_classification_request_timestamp)
          @audio_only = args[:audio_only] if args.key?(:audio_only)
          @cloud_speech_signals = args[:cloud_speech_signals] if args.key?(:cloud_speech_signals)
          @feature_set_data = args[:feature_set_data] if args.key?(:feature_set_data)
          @golden7_soapbox_summary = args[:golden7_soapbox_summary] if args.key?(:golden7_soapbox_summary)
          @inline_playback = args[:inline_playback] if args.key?(:inline_playback)
          @language_identification = args[:language_identification] if args.key?(:language_identification)
          @legos_annotation_data = args[:legos_annotation_data] if args.key?(:legos_annotation_data)
          @lms_preview_frame_perdocs = args[:lms_preview_frame_perdocs] if args.key?(:lms_preview_frame_perdocs)
          @loudness_data = args[:loudness_data] if args.key?(:loudness_data)
          @media_info = args[:media_info] if args.key?(:media_info)
          @representative_frame_data = args[:representative_frame_data] if args.key?(:representative_frame_data)
          @s3_language_identification = args[:s3_language_identification] if args.key?(:s3_language_identification)
          @safesearch_video_content_signals = args[:safesearch_video_content_signals] if args.key?(:safesearch_video_content_signals)
          @search_docid = args[:search_docid] if args.key?(:search_docid)
          @signals_blob = args[:signals_blob] if args.key?(:signals_blob)
          @signals_blob_info = args[:signals_blob_info] if args.key?(:signals_blob_info)
          @speech_properties = args[:speech_properties] if args.key?(:speech_properties)
          @thumbnail_quality_score = args[:thumbnail_quality_score] if args.key?(:thumbnail_quality_score)
          @thumbnailer_data = args[:thumbnailer_data] if args.key?(:thumbnailer_data)
          @transcode_metadata = args[:transcode_metadata] if args.key?(:transcode_metadata)
          @transcript_asr = args[:transcript_asr] if args.key?(:transcript_asr)
          @truncation_info = args[:truncation_info] if args.key?(:truncation_info)
          @unwanted_content = args[:unwanted_content] if args.key?(:unwanted_content)
          @venom_id = args[:venom_id] if args.key?(:venom_id)
          @venom_processing_info = args[:venom_processing_info] if args.key?(:venom_processing_info)
          @video_anchor_set = args[:video_anchor_set] if args.key?(:video_anchor_set)
          @video_duration_sec = args[:video_duration_sec] if args.key?(:video_duration_sec)
          @video_porn_score = args[:video_porn_score] if args.key?(:video_porn_score)
          @video_porn_score_v4 = args[:video_porn_score_v4] if args.key?(:video_porn_score_v4)
          @video_preview_bytes = args[:video_preview_bytes] if args.key?(:video_preview_bytes)
          @video_previews = args[:video_previews] if args.key?(:video_previews)
          @video_stream_info = args[:video_stream_info] if args.key?(:video_stream_info)
          @video_transcript_annotations = args[:video_transcript_annotations] if args.key?(:video_transcript_annotations)
          @youtube_processing_filter = args[:youtube_processing_filter] if args.key?(:youtube_processing_filter)
        end
      end
      
      # Fields for crawl-status-related debugging information.
      class ImageRepositoryCrawlStatusInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `code`
        # @return [String]
        attr_accessor :code
      
        # 
        # Corresponds to the JSON property `notCrawledReason`
        # @return [String]
        attr_accessor :not_crawled_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @not_crawled_reason = args[:not_crawled_reason] if args.key?(:not_crawled_reason)
        end
      end
      
      # Describes our knowledge about whether a stored file is truncated with respect
      # to its original file online.
      class ImageRepositoryFileTruncationInfo
        include Google::Apis::Core::Hashable
      
        # A lower bound on the original file's size.
        # Corresponds to the JSON property `originalFileSizeLowerBoundBytes`
        # @return [Fixnum]
        attr_accessor :original_file_size_lower_bound_bytes
      
        # Indicates whether the stored file is equal to the original file (COMPLETE), is
        # only a prefix (TRUNCATED), or that we don't know (UNKNOWN, the default).
        # Corresponds to the JSON property `truncationState`
        # @return [String]
        attr_accessor :truncation_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @original_file_size_lower_bound_bytes = args[:original_file_size_lower_bound_bytes] if args.key?(:original_file_size_lower_bound_bytes)
          @truncation_state = args[:truncation_state] if args.key?(:truncation_state)
        end
      end
      
      # Identifier for frames associated with a video.
      class ImageRepositoryFrameIdentifier
        include Google::Apis::Core::Hashable
      
        # This variant defines the frame to be the first frame of the video's generated
        # preview.
        # Corresponds to the JSON property `previewFrameZeroVariant`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryFrameIdentifierPreviewFrameZeroVariant]
        attr_accessor :preview_frame_zero_variant
      
        # This variant defines the frame to be a thumbnail of the video.
        # Corresponds to the JSON property `thumbnailVariant`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryFrameIdentifierThumbnailVariant]
        attr_accessor :thumbnail_variant
      
        # Offset of the frame from the beginning of the video (in milliseconds).
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @preview_frame_zero_variant = args[:preview_frame_zero_variant] if args.key?(:preview_frame_zero_variant)
          @thumbnail_variant = args[:thumbnail_variant] if args.key?(:thumbnail_variant)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
        end
      end
      
      # This variant defines the frame to be the first frame of the video's generated
      # preview.
      class ImageRepositoryFrameIdentifierPreviewFrameZeroVariant
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `previewLength`
        # @return [String]
        attr_accessor :preview_length
      
        # XtagList -- a collection of Xtag instances with unique names. This would be
        # associated with one specific piece of content.
        # Corresponds to the JSON property `xtagList`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryApiXtagList]
        attr_accessor :xtag_list
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @preview_length = args[:preview_length] if args.key?(:preview_length)
          @xtag_list = args[:xtag_list] if args.key?(:xtag_list)
        end
      end
      
      # This variant defines the frame to be a thumbnail of the video.
      class ImageRepositoryFrameIdentifierThumbnailVariant
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Only one of timestamp_msec or frame_identifier should be set. timestamp_msec
      # is the old identifier for frames, and is still used on thumbnail frames.
      # frame_identifier should be used on other kinds of frames (e.g. preview frame
      # zero).
      class ImageRepositoryFramePerdoc
        include Google::Apis::Core::Hashable
      
        # Identifier for frames associated with a video.
        # Corresponds to the JSON property `frameIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryFrameIdentifier]
        attr_accessor :frame_identifier
      
        # This defines the per-doc data which is extracted from thumbnails and
        # propagated over to indexing. It contains all information that can be used for
        # restricts. Next tag id: 127
        # Corresponds to the JSON property `perdoc`
        # @return [Google::Apis::ContentwarehouseV1::ImageData]
        attr_accessor :perdoc
      
        # Timestamp (in msec) of the frame from the original video DEPRECATED: Use the
        # timestamp_ms field in frame_identifier instead.
        # Corresponds to the JSON property `timestampMsec`
        # @return [Fixnum]
        attr_accessor :timestamp_msec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_identifier = args[:frame_identifier] if args.key?(:frame_identifier)
          @perdoc = args[:perdoc] if args.key?(:perdoc)
          @timestamp_msec = args[:timestamp_msec] if args.key?(:timestamp_msec)
        end
      end
      
      # This proto stores perdocs extracted from video frames.
      class ImageRepositoryFramePerdocs
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `framePerdoc`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryFramePerdoc>]
        attr_accessor :frame_perdoc
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_perdoc = args[:frame_perdoc] if args.key?(:frame_perdoc)
        end
      end
      
      # 
      class ImageRepositoryNimaOutput
        include Google::Apis::Core::Hashable
      
        # NIMA score.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Next Tag: 9
      class ImageRepositoryS3LangIdSignals
        include Google::Apis::Core::Hashable
      
        # Whether this audio chunk has speech or not.
        # Corresponds to the JSON property `containsSpeech`
        # @return [Boolean]
        attr_accessor :contains_speech
        alias_method :contains_speech?, :contains_speech
      
        # 
        # Corresponds to the JSON property `endSec`
        # @return [Fixnum]
        attr_accessor :end_sec
      
        # Response proto for the LangId service running on a Greco server in prod. Next
        # Tag: 6
        # Corresponds to the JSON property `langidResult`
        # @return [Google::Apis::ContentwarehouseV1::SpeechS3LanguageIdentificationResult]
        attr_accessor :langid_result
      
        # Converted version of the langid_result field, so that we have the YT
        # compatible version of the langID result.
        # Corresponds to the JSON property `languageIdentification`
        # @return [Google::Apis::ContentwarehouseV1::VideoTimedtextS4AliResults]
        attr_accessor :language_identification
      
        # The version of the model used for S3 LangID service.
        # Corresponds to the JSON property `modelVersion`
        # @return [String]
        attr_accessor :model_version
      
        # 
        # Corresponds to the JSON property `speechFrameCount`
        # @return [Fixnum]
        attr_accessor :speech_frame_count
      
        # The audio chunk which corresponds to this langID result expressed as a
        # start_sec and end_sec.
        # Corresponds to the JSON property `startSec`
        # @return [Fixnum]
        attr_accessor :start_sec
      
        # Count the number of total frames in the audio chunk as well as the number of
        # speech frames.
        # Corresponds to the JSON property `totalFrameCount`
        # @return [Fixnum]
        attr_accessor :total_frame_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contains_speech = args[:contains_speech] if args.key?(:contains_speech)
          @end_sec = args[:end_sec] if args.key?(:end_sec)
          @langid_result = args[:langid_result] if args.key?(:langid_result)
          @language_identification = args[:language_identification] if args.key?(:language_identification)
          @model_version = args[:model_version] if args.key?(:model_version)
          @speech_frame_count = args[:speech_frame_count] if args.key?(:speech_frame_count)
          @start_sec = args[:start_sec] if args.key?(:start_sec)
          @total_frame_count = args[:total_frame_count] if args.key?(:total_frame_count)
        end
      end
      
      # A message containing embedding information and localization scores using the
      # VSS product recognition module.
      class ImageRepositoryShoppingProductInformation
        include Google::Apis::Core::Hashable
      
        # Information about versioned product sets found. There will be at most two
        # versions present. The results from the current version of the models used in
        # VSS and the results from the previous version of the models used. Note that
        # not all products may have two version since the model might detect the product
        # in one version and not the other.
        # Corresponds to the JSON property `productSets`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformationVersionedProductInformationSet>]
        attr_accessor :product_sets
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @product_sets = args[:product_sets] if args.key?(:product_sets)
        end
      end
      
      # Contains the coordinates of the normalized bounding box.
      class ImageRepositoryShoppingProductInformationBoundingBox
        include Google::Apis::Core::Hashable
      
        # The vertical height of the bounding box (ymax - ymin + 1), normalized by image
        # height with range [0,1].
        # Corresponds to the JSON property `h`
        # @return [Float]
        attr_accessor :h
      
        # The horizontal width of the bound box (xmax - xmin + 1), normalized by image
        # width with range [0,1].
        # Corresponds to the JSON property `w`
        # @return [Float]
        attr_accessor :w
      
        # The x coordinate (xmin), normalized by image width with range [0,1).
        # Corresponds to the JSON property `x`
        # @return [Float]
        attr_accessor :x
      
        # The y coordinate (ymin), normalized by image height with range [0,1).
        # Corresponds to the JSON property `y`
        # @return [Float]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @h = args[:h] if args.key?(:h)
          @w = args[:w] if args.key?(:w)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # The recognized entity.
      class ImageRepositoryShoppingProductInformationEntity
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The normalized recognition score between 0 and 1.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Information about a single product. For ProductNet models, each product has
      # one label with a detection score. The label is mapped to one or multiple
      # category ids. For PRIMI generic feature models, each product can have multiple
      # entities, and each entity has a score. The category_id and detection_score
      # fields are not populated for PRIMI generic feature models.
      class ImageRepositoryShoppingProductInformationProductInformation
        include Google::Apis::Core::Hashable
      
        # The possible Merlot ids for the item. There may be more than one if the
        # product detector result corresponds to a collection of merlot ids, which can't
        # be easily grouped up to a common ancestor, for which the detector would still
        # make sense for all the children. E.g. a detected "chair" can be either an
        # indoor chair or an outdoor one, however in Merlot the common ancestor of the
        # two is furniture.
        # Corresponds to the JSON property `categoryId`
        # @return [Array<Fixnum>]
        attr_accessor :category_id
      
        # The k-d tree clusters for retrieval. Will be deprecated, use the token_groups
        # instead. To add tokens/cluster_ids from new tokenization model in the future,
        # add it to the token_groups.
        # Corresponds to the JSON property `clusterIds`
        # @return [Array<Fixnum>]
        attr_accessor :cluster_ids
      
        # The localization detection score.
        # Corresponds to the JSON property `detectionScore`
        # @return [Float]
        attr_accessor :detection_score
      
        # The serialized embedding values.
        # Corresponds to the JSON property `embedding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :embedding
      
        # The recognized entities and scores.
        # Corresponds to the JSON property `entities`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformationEntity>]
        attr_accessor :entities
      
        # Feature type (different detectors and embedders) requested.
        # Corresponds to the JSON property `featureType`
        # @return [String]
        attr_accessor :feature_type
      
        # Contains the coordinates of the normalized bounding box.
        # Corresponds to the JSON property `productLocation`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformationBoundingBox]
        attr_accessor :product_location
      
        # 
        # Corresponds to the JSON property `tokenGroups`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformationProductInformationTokenGroup>]
        attr_accessor :token_groups
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_id = args[:category_id] if args.key?(:category_id)
          @cluster_ids = args[:cluster_ids] if args.key?(:cluster_ids)
          @detection_score = args[:detection_score] if args.key?(:detection_score)
          @embedding = args[:embedding] if args.key?(:embedding)
          @entities = args[:entities] if args.key?(:entities)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @product_location = args[:product_location] if args.key?(:product_location)
          @token_groups = args[:token_groups] if args.key?(:token_groups)
        end
      end
      
      # The tokens for retrieval.
      class ImageRepositoryShoppingProductInformationProductInformationTokenGroup
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `model`
        # @return [String]
        attr_accessor :model
      
        # 
        # Corresponds to the JSON property `tokens`
        # @return [Array<Fixnum>]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @model = args[:model] if args.key?(:model)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # Store ProductInformation for a given version of the models used in VSS.
      class ImageRepositoryShoppingProductInformationVersionedProductInformationSet
        include Google::Apis::Core::Hashable
      
        # The type of the model.
        # Corresponds to the JSON property `modelType`
        # @return [String]
        attr_accessor :model_type
      
        # List of ProductInformation for this version.
        # Corresponds to the JSON property `products`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryShoppingProductInformationProductInformation>]
        attr_accessor :products
      
        # The version of the models used in VSS. Newer version will have a higher
        # version number.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @model_type = args[:model_type] if args.key?(:model_type)
          @products = args[:products] if args.key?(:products)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Alternative hypotheses (a.k.a. n-best list).
      class ImageRepositorySpeechRecognitionAlternative
        include Google::Apis::Core::Hashable
      
        # The confidence estimate between 0.0 and 1.0. A higher number indicates an
        # estimated greater likelihood that the recognized words are correct. This field
        # is set only for the top alternative of a non-streaming result or, of a
        # streaming result where `is_final=true`. This field is not guaranteed to be
        # accurate and users should not rely on it to be always provided. The default of
        # 0.0 is a sentinel value indicating `confidence` was not set.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Transcript text representing the words that the user spoke.
        # Corresponds to the JSON property `transcript`
        # @return [String]
        attr_accessor :transcript
      
        # A list of word-specific information for each recognized word. Note: When `
        # enable_speaker_diarization` is true, you will see all the words from the
        # beginning of the audio.
        # Corresponds to the JSON property `words`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryWordInfo>]
        attr_accessor :words
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @transcript = args[:transcript] if args.key?(:transcript)
          @words = args[:words] if args.key?(:words)
        end
      end
      
      # A speech recognition result corresponding to a portion of the audio. This
      # field is copied from cloud/speech/v1p1beta1/cloud_speech.proto. Amarna needs
      # to have a standalone version as v1p1beta1/cloud_speech.proto is in the for of
      # versioned proto and it breaks other prod code depending on Amarna's video
      # schema.
      class ImageRepositorySpeechRecognitionResult
        include Google::Apis::Core::Hashable
      
        # May contain one or more recognition hypotheses (up to the maximum specified in
        # `max_alternatives`). These alternatives are ordered in terms of accuracy, with
        # the top (first) alternative being the most probable, as ranked by the
        # recognizer.
        # Corresponds to the JSON property `alternatives`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositorySpeechRecognitionAlternative>]
        attr_accessor :alternatives
      
        # For multi-channel audio, this is the channel number corresponding to the
        # recognized result for the audio from that channel. For audio_channel_count = N,
        # its output values can range from '1' to 'N'.
        # Corresponds to the JSON property `channelTag`
        # @return [Fixnum]
        attr_accessor :channel_tag
      
        # The [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag of the
        # language in this result. This language code was detected to have the most
        # likelihood of being spoken in the audio.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # Time offset of the end of this result relative to the beginning of the audio.
        # This field is internal-only and is used to order results based on their
        # timestamps.
        # Corresponds to the JSON property `resultEndTime`
        # @return [String]
        attr_accessor :result_end_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternatives = args[:alternatives] if args.key?(:alternatives)
          @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
          @language_code = args[:language_code] if args.key?(:language_code)
          @result_end_time = args[:result_end_time] if args.key?(:result_end_time)
        end
      end
      
      # To indicate whether the image is to be deleted from the repository due to
      # legal reasons.
      class ImageRepositoryUnwantedContent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `deletionReason`
        # @return [String]
        attr_accessor :deletion_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deletion_reason = args[:deletion_reason] if args.key?(:deletion_reason)
        end
      end
      
      # 
      class ImageRepositoryVenomProcessingInfo
        include Google::Apis::Core::Hashable
      
        # Contains one status for each Genus that this video belongs to in Venom. For
        # example, a video that is both 1) Found on the web, and 2) Opted-in by an
        # Interest Feed partner would have two entries, one for GENUS_CRAWL and one for
        # GENUS_VIDEO_INTEREST_FEED
        # Corresponds to the JSON property `venomStatus`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryVenomStatus>]
        attr_accessor :venom_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @venom_status = args[:venom_status] if args.key?(:venom_status)
        end
      end
      
      # 
      class ImageRepositoryVenomStatus
        include Google::Apis::Core::Hashable
      
        # Valid fields in ACL are "mdb/groupname", or "user/username", e.g., "mdb/
        # youtube-prod", or "user/alice".
        # Corresponds to the JSON property `acl`
        # @return [Google::Apis::ContentwarehouseV1::VideoAssetsVenomAcl]
        attr_accessor :acl
      
        # 
        # Corresponds to the JSON property `deletionTimestampUsec`
        # @return [Fixnum]
        attr_accessor :deletion_timestamp_usec
      
        # The Genus (Venom's client ID) that this media belongs to.
        # Corresponds to the JSON property `genus`
        # @return [String]
        attr_accessor :genus
      
        # Time that VideoNotification result was received from Venom.
        # Corresponds to the JSON property `insertionResponseTimestampUsec`
        # @return [Fixnum]
        attr_accessor :insertion_response_timestamp_usec
      
        # 
        # Corresponds to the JSON property `insertionTimestampUsec`
        # @return [Fixnum]
        attr_accessor :insertion_timestamp_usec
      
        # Record the attempts num of previous insertion. It's only updated when either
        # the insertion succeeds or fails with reason INSERTION_ATTEMPTS_EXCEEDED, but
        # it's always set so that we can easily construct venom_id with this attempts
        # num for future insertions.
        # Corresponds to the JSON property `lastInsertionAttemptsNum`
        # @return [Fixnum]
        attr_accessor :last_insertion_attempts_num
      
        # 
        # Corresponds to the JSON property `reason`
        # @return [String]
        attr_accessor :reason
      
        # The Settings that were used to customize the Venom request for this media.
        # Corresponds to the JSON property `settings`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoAssetsVenomSettings>]
        attr_accessor :settings
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # As video mutations are reconciled by Venom, we can tell if the ingredient did
        # or did not reach certain objectives. When processing has completed, all
        # objectives will have a corresponding transition. All transitions are reset for
        # every mutation, but will take into account assets outside of that mutation.
        # For example, if Asset X fails, and was part of "OBJECTIVE_PRIMARY_ASSETS_DONE",
        # a rerun of Asset Y is destined to result in OUTCOME_FAILED, regardless of the
        # fate of Asset Y. Some phenonema have effects on most or all Objectives. For
        # example, a bad input file will result on OUTCOME_INFEASIBLE across the board (
        # eventually, for now it's just GO_LIVE and DO_ALL, work in progress), and a
        # failure to produce Format 18 will cause OUTCOME_FAILED across most Objectives.
        # Corresponds to the JSON property `transition`
        # @return [Google::Apis::ContentwarehouseV1::VideoAssetsVenomTransition]
        attr_accessor :transition
      
        # A VideoId is the unique identifier of a video. Privacy: VideoIds are visible
        # in logs, notifications, etc and must not contain PII.
        # Corresponds to the JSON property `venomId`
        # @return [Google::Apis::ContentwarehouseV1::VideoAssetsVenomVideoId]
        attr_accessor :venom_id
      
        # The generation number returned by Venom.
        # Corresponds to the JSON property `venomMutationGeneration`
        # @return [Fixnum]
        attr_accessor :venom_mutation_generation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acl = args[:acl] if args.key?(:acl)
          @deletion_timestamp_usec = args[:deletion_timestamp_usec] if args.key?(:deletion_timestamp_usec)
          @genus = args[:genus] if args.key?(:genus)
          @insertion_response_timestamp_usec = args[:insertion_response_timestamp_usec] if args.key?(:insertion_response_timestamp_usec)
          @insertion_timestamp_usec = args[:insertion_timestamp_usec] if args.key?(:insertion_timestamp_usec)
          @last_insertion_attempts_num = args[:last_insertion_attempts_num] if args.key?(:last_insertion_attempts_num)
          @reason = args[:reason] if args.key?(:reason)
          @settings = args[:settings] if args.key?(:settings)
          @state = args[:state] if args.key?(:state)
          @transition = args[:transition] if args.key?(:transition)
          @venom_id = args[:venom_id] if args.key?(:venom_id)
          @venom_mutation_generation = args[:venom_mutation_generation] if args.key?(:venom_mutation_generation)
        end
      end
      
      # 
      class ImageRepositoryVideoIndexingInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `notIndexedVideoLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageRepositoryVideoLinkIndexingInfo>]
        attr_accessor :not_indexed_video_link
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @not_indexed_video_link = args[:not_indexed_video_link] if args.key?(:not_indexed_video_link)
        end
      end
      
      # 
      class ImageRepositoryVideoLinkIndexingInfo
        include Google::Apis::Core::Hashable
      
        # Fields for crawl-status-related debugging information.
        # Corresponds to the JSON property `crawlStatusInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryCrawlStatusInfo]
        attr_accessor :crawl_status_info
      
        # The video URL.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crawl_status_info = args[:crawl_status_info] if args.key?(:crawl_status_info)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class ImageRepositoryVideoPreviewsDebuggingInfo
        include Google::Apis::Core::Hashable
      
        # Last Amarna processing timestamp.
        # Corresponds to the JSON property `lastAmarnaProcessingTime`
        # @return [String]
        attr_accessor :last_amarna_processing_time
      
        # The underlying processing engine, like 'viper' or 'kronos'.
        # Corresponds to the JSON property `processingEngine`
        # @return [String]
        attr_accessor :processing_engine
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_amarna_processing_time = args[:last_amarna_processing_time] if args.key?(:last_amarna_processing_time)
          @processing_engine = args[:processing_engine] if args.key?(:processing_engine)
        end
      end
      
      # 
      class ImageRepositoryVideoPreviewsVideoPreview
        include Google::Apis::Core::Hashable
      
        # The actual video preview bytes generated for the video.
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # Used for debugging only.
        # Corresponds to the JSON property `debuggingInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryVideoPreviewsDebuggingInfo]
        attr_accessor :debugging_info
      
        # This message is used internally in Amarna and is also used to store
        # information in the VideoWebAttachment portion of the websearch index. Only the
        # following fields will be used in the index: VideoPreviewType type int32 width
        # int32 height byte byte_size If more fields are added, please update this list.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::ImageBaseVideoPreviewMetadata]
        attr_accessor :metadata
      
        # Video level container for thumbnail with its attributes, e.g., timestamp, id,
        # quality scores, annotations, or features.
        # Corresponds to the JSON property `previewFrameZero`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiVesperVideoThumbnail]
        attr_accessor :preview_frame_zero
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @debugging_info = args[:debugging_info] if args.key?(:debugging_info)
          @metadata = args[:metadata] if args.key?(:metadata)
          @preview_frame_zero = args[:preview_frame_zero] if args.key?(:preview_frame_zero)
        end
      end
      
      # 
      class ImageRepositoryVideoProperties
        include Google::Apis::Core::Hashable
      
        # Both audio- and audio-video-files are treated as videos during indexing (
        # whether they share a container format, like .mp4, or not, like .mp3). This
        # bool indicates that there's no video track, just an audio track.
        # Corresponds to the JSON property `audioOnly`
        # @return [Boolean]
        attr_accessor :audio_only
        alias_method :audio_only?, :audio_only
      
        # Next Tag: 48
        # Corresponds to the JSON property `contentBasedMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryContentBasedVideoMetadata]
        attr_accessor :content_based_metadata
      
        # The raw crawl state.
        # Corresponds to the JSON property `crawlState`
        # @return [Google::Apis::ContentwarehouseV1::ImageMoosedogCrawlState]
        attr_accessor :crawl_state
      
        # Timestamp of the first time that the video was successfully crawled.
        # Corresponds to the JSON property `firstCrawlTimestampSec`
        # @return [Fixnum]
        attr_accessor :first_crawl_timestamp_sec
      
        # Timestamp when this video's videoProperties is populated for the first time,
        # measured in seconds since epoch.
        # Corresponds to the JSON property `firstProcessingTimestampSec`
        # @return [Fixnum]
        attr_accessor :first_processing_timestamp_sec
      
        # This message is used to store information about Inline Playback in the
        # VideoWebAttachment portion of the websearch index. LINT.IfChange
        # Corresponds to the JSON property `inlinePlayback`
        # @return [Google::Apis::ContentwarehouseV1::VideoCrawlVideoInlinePlaybackMetadata]
        attr_accessor :inline_playback
      
        # Timestamp when this video's last crawling is requested, measured in seconds
        # since epoch.
        # Corresponds to the JSON property `lastCrawlRequestTimestampSec`
        # @return [Fixnum]
        attr_accessor :last_crawl_request_timestamp_sec
      
        # Last timestamp when this video's videoProperties is populated, measured in
        # seconds since epoch.
        # Corresponds to the JSON property `lastProcessingTimestampSec`
        # @return [Fixnum]
        attr_accessor :last_processing_timestamp_sec
      
        # This is the video url taken from the key of the Amarna references table row
        # corresponding to this message.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_only = args[:audio_only] if args.key?(:audio_only)
          @content_based_metadata = args[:content_based_metadata] if args.key?(:content_based_metadata)
          @crawl_state = args[:crawl_state] if args.key?(:crawl_state)
          @first_crawl_timestamp_sec = args[:first_crawl_timestamp_sec] if args.key?(:first_crawl_timestamp_sec)
          @first_processing_timestamp_sec = args[:first_processing_timestamp_sec] if args.key?(:first_processing_timestamp_sec)
          @inline_playback = args[:inline_playback] if args.key?(:inline_playback)
          @last_crawl_request_timestamp_sec = args[:last_crawl_request_timestamp_sec] if args.key?(:last_crawl_request_timestamp_sec)
          @last_processing_timestamp_sec = args[:last_processing_timestamp_sec] if args.key?(:last_processing_timestamp_sec)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Word-specific information for recognized words.
      class ImageRepositoryWordInfo
        include Google::Apis::Core::Hashable
      
        # The confidence estimate between 0.0 and 1.0. A higher number indicates an
        # estimated greater likelihood that the recognized words are correct. This field
        # is set only for the top alternative of a non-streaming result or, of a
        # streaming result where `is_final=true`. This field is not guaranteed to be
        # accurate and users should not rely on it to be always provided. The default of
        # 0.0 is a sentinel value indicating `confidence` was not set.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Time offset relative to the beginning of the audio, and corresponding to the
        # end of the spoken word. This field is only set if `enable_word_time_offsets=
        # true` and only in the top hypothesis. This is an experimental feature and the
        # accuracy of the time offset can vary.
        # Corresponds to the JSON property `endTime`
        # @return [String]
        attr_accessor :end_time
      
        # A distinct integer value is assigned for every speaker within the audio. This
        # field specifies which one of those speakers was detected to have spoken this
        # word. Value ranges from '1' to diarization_speaker_count. speaker_tag is set
        # if enable_speaker_diarization = 'true' and only in the top alternative.
        # Corresponds to the JSON property `speakerTag`
        # @return [Fixnum]
        attr_accessor :speaker_tag
      
        # Time offset relative to the beginning of the audio, and corresponding to the
        # start of the spoken word. This field is only set if `enable_word_time_offsets=
        # true` and only in the top hypothesis. This is an experimental feature and the
        # accuracy of the time offset can vary.
        # Corresponds to the JSON property `startTime`
        # @return [String]
        attr_accessor :start_time
      
        # The word corresponding to this set of information.
        # Corresponds to the JSON property `word`
        # @return [String]
        attr_accessor :word
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @end_time = args[:end_time] if args.key?(:end_time)
          @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag)
          @start_time = args[:start_time] if args.key?(:start_time)
          @word = args[:word] if args.key?(:word)
        end
      end
      
      # Next available tag: 13
      class ImageRepositoryYoutubeProcessingFilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `previewsFilteredReason`
        # @return [Array<String>]
        attr_accessor :previews_filtered_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @previews_filtered_reason = args[:previews_filtered_reason] if args.key?(:previews_filtered_reason)
        end
      end
      
      # Don't change the field names. The names are used as sparse feature labels in
      # client projects.
      class ImageSafesearchContentBrainPornAnnotation
        include Google::Apis::Core::Hashable
      
        # The probability that the youngest person in the image is a child.
        # Corresponds to the JSON property `childScore`
        # @return [Float]
        attr_accessor :child_score
      
        # This score correlates with potential child abuse. Google confidential!
        # Corresponds to the JSON property `csaiScore`
        # @return [Float]
        attr_accessor :csai_score
      
        # This field contains the probability that an image is inappropriate for Images
        # Universal, according to this policy: go/iupolicy.
        # Corresponds to the JSON property `iuInappropriateScore`
        # @return [Float]
        attr_accessor :iu_inappropriate_score
      
        # 
        # Corresponds to the JSON property `medicalScore`
        # @return [Float]
        attr_accessor :medical_score
      
        # 
        # Corresponds to the JSON property `pedoScore`
        # @return [Float]
        attr_accessor :pedo_score
      
        # 
        # Corresponds to the JSON property `pornScore`
        # @return [Float]
        attr_accessor :porn_score
      
        # This score is related to an image being sexually suggestive.
        # Corresponds to the JSON property `racyScore`
        # @return [Float]
        attr_accessor :racy_score
      
        # 
        # Corresponds to the JSON property `spoofScore`
        # @return [Float]
        attr_accessor :spoof_score
      
        # This field is an experimental one with a quite vague meaning. Please contact
        # safesearch@ before any meaningful use of it. There is no guarantee it will
        # preserve its behavior in the future.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        # 
        # Corresponds to the JSON property `violenceScore`
        # @return [Float]
        attr_accessor :violence_score
      
        # Deprecated, use porn_score instead. The most recent model version does not
        # produce this anymore.
        # Corresponds to the JSON property `ytPornScore`
        # @return [Float]
        attr_accessor :yt_porn_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child_score = args[:child_score] if args.key?(:child_score)
          @csai_score = args[:csai_score] if args.key?(:csai_score)
          @iu_inappropriate_score = args[:iu_inappropriate_score] if args.key?(:iu_inappropriate_score)
          @medical_score = args[:medical_score] if args.key?(:medical_score)
          @pedo_score = args[:pedo_score] if args.key?(:pedo_score)
          @porn_score = args[:porn_score] if args.key?(:porn_score)
          @racy_score = args[:racy_score] if args.key?(:racy_score)
          @spoof_score = args[:spoof_score] if args.key?(:spoof_score)
          @version = args[:version] if args.key?(:version)
          @violence_score = args[:violence_score] if args.key?(:violence_score)
          @yt_porn_score = args[:yt_porn_score] if args.key?(:yt_porn_score)
        end
      end
      
      # 
      class ImageSafesearchContentOcrAnnotation
        include Google::Apis::Core::Hashable
      
        # The score produced by Aksara geometry and spoof score. Describes the '
        # visibility' or 'importance' of the text on the image [0, 1]
        # Corresponds to the JSON property `ocrProminenceScore`
        # @return [Float]
        attr_accessor :ocr_prominence_score
      
        # The score produced by the sensitive_seti model.
        # Corresponds to the JSON property `offensiveScore`
        # @return [Float]
        attr_accessor :offensive_score
      
        # Image OCR racyness/pornyness, computed by porn query classifier.
        # Corresponds to the JSON property `pornScore`
        # @return [Float]
        attr_accessor :porn_score
      
        # Same as offensive_score, but weighted by prominence.
        # Corresponds to the JSON property `prominentOffensiveScore`
        # @return [Float]
        attr_accessor :prominent_offensive_score
      
        # Same as vulgar_score, but weighted by prominence.
        # Corresponds to the JSON property `prominentVulgarScore`
        # @return [Float]
        attr_accessor :prominent_vulgar_score
      
        # The score produced by offensive salient terms model.
        # Corresponds to the JSON property `qbstOffensiveScore`
        # @return [Float]
        attr_accessor :qbst_offensive_score
      
        # Presence of i18n-recognized vulgar term in the OCR.
        # Corresponds to the JSON property `vulgarI18nBit`
        # @return [Boolean]
        attr_accessor :vulgar_i18n_bit
        alias_method :vulgar_i18n_bit?, :vulgar_i18n_bit
      
        # Image OCR vulgarity, computed by vulgar query classifier.
        # Corresponds to the JSON property `vulgarScore`
        # @return [Float]
        attr_accessor :vulgar_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ocr_prominence_score = args[:ocr_prominence_score] if args.key?(:ocr_prominence_score)
          @offensive_score = args[:offensive_score] if args.key?(:offensive_score)
          @porn_score = args[:porn_score] if args.key?(:porn_score)
          @prominent_offensive_score = args[:prominent_offensive_score] if args.key?(:prominent_offensive_score)
          @prominent_vulgar_score = args[:prominent_vulgar_score] if args.key?(:prominent_vulgar_score)
          @qbst_offensive_score = args[:qbst_offensive_score] if args.key?(:qbst_offensive_score)
          @vulgar_i18n_bit = args[:vulgar_i18n_bit] if args.key?(:vulgar_i18n_bit)
          @vulgar_score = args[:vulgar_score] if args.key?(:vulgar_score)
        end
      end
      
      # 
      class ImageSafesearchContentOffensiveSymbolDetection
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matches`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageSafesearchContentOffensiveSymbolMatch>]
        attr_accessor :matches
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matches = args[:matches] if args.key?(:matches)
        end
      end
      
      # Each entry corresponds to an image containing an offensive symbol.
      class ImageSafesearchContentOffensiveSymbolMatch
        include Google::Apis::Core::Hashable
      
        # Confidence score of the match. The higher, the more likely to match the symbol.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class ImageSearchImageIndexingInfo
        include Google::Apis::Core::Hashable
      
        # Image Selection Info
        # Corresponds to the JSON property `imageLinkSelectionInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageSearchImageSelectionInfo>]
        attr_accessor :image_link_selection_info
      
        # URLs and Amarna status of images on the page for which image data is not yet
        # available and weren't selected for indexing in image search. Used by consumers
        # of docjoins that need a complete view of image urls on the page (i.e. Digdug).
        # Corresponds to the JSON property `rejectedNotIndexedImageLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageSearchUnindexedImageLink>]
        attr_accessor :rejected_not_indexed_image_link
      
        # URLs and Amarna status of images on the page for which image data is not yet
        # available and were otherwise selected for indexing in image search. Used by
        # consumers of docjoins that need a complete view of selected image urls on the
        # page (i.e. Hearse, the index selection testbed).
        # Corresponds to the JSON property `selectedNotIndexedImageLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageSearchUnindexedImageLink>]
        attr_accessor :selected_not_indexed_image_link
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_link_selection_info = args[:image_link_selection_info] if args.key?(:image_link_selection_info)
          @rejected_not_indexed_image_link = args[:rejected_not_indexed_image_link] if args.key?(:rejected_not_indexed_image_link)
          @selected_not_indexed_image_link = args[:selected_not_indexed_image_link] if args.key?(:selected_not_indexed_image_link)
        end
      end
      
      # The image license info for licensable images(go/Licensable-Images-PRD) This
      # proto in design doc: go/licensable-images-edd
      class ImageSearchImageLicenseInfo
        include Google::Apis::Core::Hashable
      
        # Records web page url about how to use the licensed image.
        # Corresponds to the JSON property `acquireLicensePage`
        # @return [String]
        attr_accessor :acquire_license_page
      
        # Provides copyright info.
        # Corresponds to the JSON property `copyrightNotice`
        # @return [String]
        attr_accessor :copyright_notice
      
        # Source type for copyright_notice field.
        # Corresponds to the JSON property `copyrightNoticeSourceType`
        # @return [String]
        attr_accessor :copyright_notice_source_type
      
        # creator, authors.
        # Corresponds to the JSON property `creator`
        # @return [Array<String>]
        attr_accessor :creator
      
        # Source type for creator field.
        # Corresponds to the JSON property `creatorSourceType`
        # @return [String]
        attr_accessor :creator_source_type
      
        # Text for crediting persons or organizations.
        # Corresponds to the JSON property `creditText`
        # @return [String]
        attr_accessor :credit_text
      
        # Source type for credit_text field.
        # Corresponds to the JSON property `creditTextSourceType`
        # @return [String]
        attr_accessor :credit_text_source_type
      
        # Whether this license url is in retired license list, which is from: https://
        # creativecommons.org/retiredlicenses/
        # Corresponds to the JSON property `isRetiredCcUrl`
        # @return [Boolean]
        attr_accessor :is_retired_cc_url
        alias_method :is_retired_cc_url?, :is_retired_cc_url
      
        # 
        # Corresponds to the JSON property `licenseType`
        # @return [String]
        attr_accessor :license_type
      
        # Records license URL.
        # Corresponds to the JSON property `licenseUrl`
        # @return [String]
        attr_accessor :license_url
      
        # A bitwise-OR of SafeSearch filtering flags. If present, the flags will be a
        # bitwise-AND between this value and all the classifier_porn::query::Vertical
        # enums. If the value is -1, it indicates there is some error with SafeSearch
        # classifier. The default value 0 means no filtering flags are set.
        # Corresponds to the JSON property `safesearchFlags`
        # @return [Fixnum]
        attr_accessor :safesearch_flags
      
        # 
        # Corresponds to the JSON property `sourceType`
        # @return [String]
        attr_accessor :source_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @acquire_license_page = args[:acquire_license_page] if args.key?(:acquire_license_page)
          @copyright_notice = args[:copyright_notice] if args.key?(:copyright_notice)
          @copyright_notice_source_type = args[:copyright_notice_source_type] if args.key?(:copyright_notice_source_type)
          @creator = args[:creator] if args.key?(:creator)
          @creator_source_type = args[:creator_source_type] if args.key?(:creator_source_type)
          @credit_text = args[:credit_text] if args.key?(:credit_text)
          @credit_text_source_type = args[:credit_text_source_type] if args.key?(:credit_text_source_type)
          @is_retired_cc_url = args[:is_retired_cc_url] if args.key?(:is_retired_cc_url)
          @license_type = args[:license_type] if args.key?(:license_type)
          @license_url = args[:license_url] if args.key?(:license_url)
          @safesearch_flags = args[:safesearch_flags] if args.key?(:safesearch_flags)
          @source_type = args[:source_type] if args.key?(:source_type)
        end
      end
      
      # 
      class ImageSearchImageSelectionInfo
        include Google::Apis::Core::Hashable
      
        # For detailed info, please see go/naive-image-selection
        # Corresponds to the JSON property `imageLinkSelectionInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageMustangImageLinkSelectionInfo]
        attr_accessor :image_link_selection_info
      
        # The image URL.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_link_selection_info = args[:image_link_selection_info] if args.key?(:image_link_selection_info)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class ImageSearchUnindexedImageLink
        include Google::Apis::Core::Hashable
      
        # This message stores the status and reason why Amarna was unable to provide
        # perdoc information for an image.
        # Corresponds to the JSON property `amarnaStatus`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryAmarnaStatus]
        attr_accessor :amarna_status
      
        # Fields for crawl-status-related debugging information.
        # Corresponds to the JSON property `crawlStatusInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageRepositoryCrawlStatusInfo]
        attr_accessor :crawl_status_info
      
        # The image URL.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amarna_status = args[:amarna_status] if args.key?(:amarna_status)
          @crawl_status_info = args[:crawl_status_info] if args.key?(:crawl_status_info)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Annotation packs various recognition, detection, embedding, and parsing
      # results. One Annotation per bounding box detection.
      class ImageUnderstandingIndexingAnnotation
        include Google::Apis::Core::Hashable
      
        # Multiple feature embeddings for this bounding box.
        # Corresponds to the JSON property `feature`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingFeature>]
        attr_accessor :feature
      
        # Multiple label annotations for this bounding box.
        # Corresponds to the JSON property `labelGroup`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingLabelGroup>]
        attr_accessor :label_group
      
        # Image region produced by a detector.
        # Corresponds to the JSON property `roi`
        # @return [Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingImageRegion]
        attr_accessor :roi
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature = args[:feature] if args.key?(:feature)
          @label_group = args[:label_group] if args.key?(:label_group)
          @roi = args[:roi] if args.key?(:roi)
        end
      end
      
      # 
      class ImageUnderstandingIndexingAnnotationGroup
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotation`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingAnnotation>]
        attr_accessor :annotation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation = args[:annotation] if args.key?(:annotation)
        end
      end
      
      # Image feature embedding proto. It supports various embedding formats: raw
      # bytes, floating point values, and tokens.
      class ImageUnderstandingIndexingFeature
        include Google::Apis::Core::Hashable
      
        # Multiple fields can be set. For example for Starburst V3, they can be used to
        # store compressed byte, raw float feature, and tokens, respectively.
        # Corresponds to the JSON property `bytesValue`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :bytes_value
      
        # 
        # Corresponds to the JSON property `floatValue`
        # @return [Array<Float>]
        attr_accessor :float_value
      
        # ImageTemplate contains local and/or global features generated from one image.
        # User-defined members can be set to any value within the constraints outlined
        # below. Algorithms usually pass these through without evaluation, unless
        # documented otherwise. Next id: 29
        # Corresponds to the JSON property `imageTemplate`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecImageTemplate]
        attr_accessor :image_template
      
        # 
        # Corresponds to the JSON property `int32Value`
        # @return [Array<Fixnum>]
        attr_accessor :int32_value
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes_value = args[:bytes_value] if args.key?(:bytes_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @image_template = args[:image_template] if args.key?(:image_template)
          @int32_value = args[:int32_value] if args.key?(:int32_value)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Image region produced by a detector.
      class ImageUnderstandingIndexingImageRegion
        include Google::Apis::Core::Hashable
      
        # Bounding box coordinates are relative to the width and height of the image.
        # For example, if image is 100x200 and NormalizedBoundingBox is , the bounding
        # box coordinates will be (10, 40) to (50, 180). Note parts of the bounding box
        # may fall outside the image.
        # Corresponds to the JSON property `box`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionGroundtruthdbNormalizedBoundingBox]
        attr_accessor :box
      
        # Box confidence score. This is used to store the confidence of the box proposal,
        # not the score associated with any specific labels. The box proposal
        # confidence score is a float number per region between [0, 1] indicating how
        # likely a box contains an "object".
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box = args[:box] if args.key?(:box)
          @score = args[:score] if args.key?(:score)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # A single label with score and meta data.
      class ImageUnderstandingIndexingLabel
        include Google::Apis::Core::Hashable
      
        # Human readable text.
        # Corresponds to the JSON property `canonicalText`
        # @return [String]
        attr_accessor :canonical_text
      
        # KG entity id.
        # Corresponds to the JSON property `entityId`
        # @return [String]
        attr_accessor :entity_id
      
        # Meta data for topicality, visible labels, attribute, etc.
        # Corresponds to the JSON property `metaData`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingMetaData>]
        attr_accessor :meta_data
      
        # Confidence score.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_text = args[:canonical_text] if args.key?(:canonical_text)
          @entity_id = args[:entity_id] if args.key?(:entity_id)
          @meta_data = args[:meta_data] if args.key?(:meta_data)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # LabelGroup is a set of labels produced by a single model, or by multiple
      # models that share the same versioning. It can be used to store results from
      # ICA, box classifier, visible labels, noun+attribute, and so on.
      class ImageUnderstandingIndexingLabelGroup
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `label`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageUnderstandingIndexingLabel>]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Meta data useful to annotation Label and Feature with extra information.
      class ImageUnderstandingIndexingMetaData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @float_value = args[:float_value] if args.key?(:float_value)
          @name = args[:name] if args.key?(:name)
          @string_value = args[:string_value] if args.key?(:string_value)
        end
      end
      
      # This protobuffer stores bad SSL certificate information for a canonical URL,
      # and meant to be included in DocJoins and push to serving time.
      class IndexingBadSslCertificate
        include Google::Apis::Core::Hashable
      
        # This protobuf specifies the results of https certificate validation, typically
        # used for the BadSSLCertificate field in FetchReplyData. -----------------------
        # --- Next Tag: 13 -------------------------------
        # Corresponds to the JSON property `badSslCertificate`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerSslCertificateInfo]
        attr_accessor :bad_ssl_certificate
      
        # The URL where the bad SSL certificate really comes from. Present iff it is
        # different from the source URL, i.e. a redirect target of the source URL).
        # Corresponds to the JSON property `urlWithBadSslCertificate`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :url_with_bad_ssl_certificate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bad_ssl_certificate = args[:bad_ssl_certificate] if args.key?(:bad_ssl_certificate)
          @url_with_bad_ssl_certificate = args[:url_with_bad_ssl_certificate] if args.key?(:url_with_bad_ssl_certificate)
        end
      end
      
      # 
      class IndexingConverterLocalizedAlternateName
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotationSource`
        # @return [String]
        attr_accessor :annotation_source
      
        # Device match info calculated only by URL pattern.
        # Corresponds to the JSON property `deviceMatchInfo`
        # @return [String]
        attr_accessor :device_match_info
      
        # Fp96 of webmirror ECN as of the last time the canonical was processed.
        # Corresponds to the JSON property `ecnFp`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ecn_fp
      
        # Populated if annotation_source is SITEMAP.
        # Corresponds to the JSON property `feedUrl`
        # @return [String]
        attr_accessor :feed_url
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Parsed language and region code from language field.
        # Corresponds to the JSON property `parsedLanguage`
        # @return [String]
        attr_accessor :parsed_language
      
        # 
        # Corresponds to the JSON property `parsedRegion`
        # @return [Fixnum]
        attr_accessor :parsed_region
      
        # 
        # Corresponds to the JSON property `url`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :url
      
        # see webutil/urlencoding
        # Corresponds to the JSON property `urlEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @device_match_info = args[:device_match_info] if args.key?(:device_match_info)
          @ecn_fp = args[:ecn_fp] if args.key?(:ecn_fp)
          @feed_url = args[:feed_url] if args.key?(:feed_url)
          @language = args[:language] if args.key?(:language)
          @parsed_language = args[:parsed_language] if args.key?(:parsed_language)
          @parsed_region = args[:parsed_region] if args.key?(:parsed_region)
          @url = args[:url] if args.key?(:url)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
        end
      end
      
      # The proto to be stored in raw_redirect_info column of document table.
      class IndexingConverterRawRedirectInfo
        include Google::Apis::Core::Hashable
      
        # Final redirect target found from rendering. It is the same as the last element
        # of raw_redirect_chain_from_rendering. It is used as an input source for the
        # indexable fragment detection pipeline and also downstream phases.
        # Corresponds to the JSON property `rawFinalTargetFromRendering`
        # @return [String]
        attr_accessor :raw_final_target_from_rendering
      
        # This is with-fragment version of redirect_with_contents. This field is
        # populated only if there was a fragment. This field is used by indexing::mobile:
        # :GetRedirectTarget() defined in indexing/mobile/internal/smartphone-util.cc,
        # which extracts the redirect target for smartphone optimized pages. The
        # extracted target in turn is served in search results for smartphone users. We
        # need with-fragment version because with-fragment url can return different
        # content than fragment-stripped url. For example, http://www.example.com/m#
        # article=11 and http://www.example.com/m can return different content. These
        # cases are most typical for Ajaxy sites. This fragment does not have to be
        # indexable.
        # Corresponds to the JSON property `rawFinalTargetFromTrawler`
        # @return [String]
        attr_accessor :raw_final_target_from_trawler
      
        # Redirect_chain is present for redirects, and absent for the final target. It
        # contains the chain from the current hop's target to the final target.
        # Corresponds to the JSON property `rawRedirectChainFromRendering`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRedirectChain]
        attr_accessor :raw_redirect_chain_from_rendering
      
        # This is used to describe how many redirect hops from Webkit were kept in the
        # raw_redirect_chain_from_rendering. If it is -1, it means it kept all the hops
        # from Webkit in redirect chain.
        # Corresponds to the JSON property `renderingRedirectLimit`
        # @return [Fixnum]
        attr_accessor :rendering_redirect_limit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_final_target_from_rendering = args[:raw_final_target_from_rendering] if args.key?(:raw_final_target_from_rendering)
          @raw_final_target_from_trawler = args[:raw_final_target_from_trawler] if args.key?(:raw_final_target_from_trawler)
          @raw_redirect_chain_from_rendering = args[:raw_redirect_chain_from_rendering] if args.key?(:raw_redirect_chain_from_rendering)
          @rendering_redirect_limit = args[:rendering_redirect_limit] if args.key?(:rendering_redirect_limit)
        end
      end
      
      # Redirect_chain is present for redirects, and absent for the final target. It
      # contains the chain from the current hop's target to the final target.
      class IndexingConverterRedirectChain
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hop`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingConverterRedirectChainHop>]
        attr_accessor :hop
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hop = args[:hop] if args.key?(:hop)
        end
      end
      
      # NOLINT
      class IndexingConverterRedirectChainHop
        include Google::Apis::Core::Hashable
      
        # If we detect any server or content based redirect, we will store the
        # characteristics in this message.
        # Corresponds to the JSON property `params`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRedirectParams]
        attr_accessor :params
      
        # Redirect target with fragment. This field is populated only if there was a
        # fragment.
        # Corresponds to the JSON property `rawTarget`
        # @return [String]
        attr_accessor :raw_target
      
        # Redirect target URL and params of the current hop in the redirect chain.
        # Corresponds to the JSON property `target`
        # @return [String]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @params = args[:params] if args.key?(:params)
          @raw_target = args[:raw_target] if args.key?(:raw_target)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # If we detect any server or content based redirect, we will store the
      # characteristics in this message.
      class IndexingConverterRedirectParams
        include Google::Apis::Core::Hashable
      
        # The time difference between page loading and redirect occurrence. When missing,
        # it means the redirect happens immediately (i.e. delay = 0). In seconds.
        # Corresponds to the JSON property `delay`
        # @return [Fixnum]
        attr_accessor :delay
      
        # Populated for SINGLE_FRAME and SINGLE_IFRAME redirects only and indicates that
        # the target url requested not to be framed, by virtue of using the "X-Frame-
        # Options" HTTP header.
        # Corresponds to the JSON property `frameTargetDeniesFraming`
        # @return [Boolean]
        attr_accessor :frame_target_denies_framing
        alias_method :frame_target_denies_framing?, :frame_target_denies_framing
      
        # Indicates corresponding redirect is a download. This field is only set when
        # rendering redirect chain is used. This field represents the value of
        # corresponding "RedirectEvent.target_content_downloaded" field.
        # Corresponds to the JSON property `isDownload`
        # @return [Boolean]
        attr_accessor :is_download
        alias_method :is_download?, :is_download
      
        # Indicates corresponding redirect is from rendering if set to true.
        # Corresponds to the JSON property `isRenderingRedirect`
        # @return [Boolean]
        attr_accessor :is_rendering_redirect
        alias_method :is_rendering_redirect?, :is_rendering_redirect
      
        # If set, it means that the redirect of type META was detected by Trawler (as
        # opposed to the content processor.) Only makes sense when type is META.
        # Corresponds to the JSON property `metaRedirectFromTrawler`
        # @return [Boolean]
        attr_accessor :meta_redirect_from_trawler
        alias_method :meta_redirect_from_trawler?, :meta_redirect_from_trawler
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @delay = args[:delay] if args.key?(:delay)
          @frame_target_denies_framing = args[:frame_target_denies_framing] if args.key?(:frame_target_denies_framing)
          @is_download = args[:is_download] if args.key?(:is_download)
          @is_rendering_redirect = args[:is_rendering_redirect] if args.key?(:is_rendering_redirect)
          @meta_redirect_from_trawler = args[:meta_redirect_from_trawler] if args.key?(:meta_redirect_from_trawler)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Contains information about 3 versions of the content of a document: 1.
      # Original: the crawled content (possibly patched in ConversionFilters). 2.
      # Processed: the final version of the content indexed in Web search. 3.
      # Intermediate (no longer generated): intermediate version between the original
      # and the processed content. All 3 versions of the content consist of HTTP
      # headers (in unknown encoding) concatenated with the document body (in
      # interchange valid UTF-8 encoding).
      class IndexingConverterRichContentData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `range`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingConverterRichContentDataRange>]
        attr_accessor :range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @range = args[:range] if args.key?(:range)
        end
      end
      
      # Stores an ordered list of ranges of content from the original, processed, and
      # intermediate content, such that: 1. The original content can be reconstructed
      # from the ranges of type ORIGINAL_AND_PROCESSED, ORIGINAL_ONLY, and
      # ORIGINAL_AND_INTERMEDIATE. 2. The processed content can be reconstructed from
      # the ranges of type ORIGINAL_AND_PROCESSED and PROCESSED_ONLY. 3. The
      # intermediate content (if present) can be reconstructed from the ranges of type
      # ORIGINAL_AND_INTERMEDIATE and INTERMEDIATE_ONLY.
      class IndexingConverterRichContentDataRange
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `rangeType`
        # @return [String]
        attr_accessor :range_type
      
        # Range size when uncompressed, in bytes.
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        # The source of this range of content. Present iff 'type' is PROCESSED_ONLY or
        # INTERMEDIATE_ONLY. Note: 'source_type' is not present for
        # ORIGINAL_AND_PROCESSED, ORIGINAL_ONLY, and ORIGINAL_AND_INTERMEDIATE because
        # for those range types the source of their content is the original crawled
        # content.
        # Corresponds to the JSON property `sourceType`
        # @return [String]
        attr_accessor :source_type
      
        # The source URL of this range of content. Present iff 'source_type' is present
        # and 'source_type' is FRAME or FLASH or IFRAME.
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # The content of the range, compressed with 'text_compression_method'. Present
        # iff 'type' is ORIGINAL_ONLY or ORIGINAL_AND_INTERMEDIATE or INTERMEDIATE_ONLY.
        # Useful to reconstruct the original content or the intermediate content. Note: '
        # text' is not present for ORIGINAL_AND_PROCESSED and PROCESSED_ONLY because the
        # processed content is already stored separately (in the contents column, and in
        # CompositeDoc.doc.Content.Representation).
        # Corresponds to the JSON property `text`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :text
      
        # Method used to compress the 'text' field. May be present only when the 'text'
        # is present.
        # Corresponds to the JSON property `textCompressionMethod`
        # @return [String]
        attr_accessor :text_compression_method
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @range_type = args[:range_type] if args.key?(:range_type)
          @size = args[:size] if args.key?(:size)
          @source_type = args[:source_type] if args.key?(:source_type)
          @source_url = args[:source_url] if args.key?(:source_url)
          @text = args[:text] if args.key?(:text)
          @text_compression_method = args[:text_compression_method] if args.key?(:text_compression_method)
        end
      end
      
      # Robots Info encapsulates all robots.txt or related information that we know
      # about the Document collected from multiple sources such as HTTP headers, meta
      # robots tags etc.
      class IndexingConverterRobotsInfo
        include Google::Apis::Core::Hashable
      
        # time in unix time format after which this content should not be shown in the
        # results. This in inferred from the X-Robots-Tag HTTP header with
        # unavailable_after: Do not use this field directly. There is a column called
        # content_expiration in Alexandria that includes this and other signals.
        # Corresponds to the JSON property `contentExpiry`
        # @return [Fixnum]
        attr_accessor :content_expiry
      
        # 
        # Corresponds to the JSON property `convertToRobotedReason`
        # @return [String]
        attr_accessor :convert_to_roboted_reason
      
        # 
        # Corresponds to the JSON property `disallowedReason`
        # @return [Fixnum]
        attr_accessor :disallowed_reason
      
        # IMPORTANT: if you add a new field here, update the MergeRobotsInfo() function
        # to merge the new field.
        # Corresponds to the JSON property `indexifembeddedReason`
        # @return [Fixnum]
        attr_accessor :indexifembedded_reason
      
        # Max image preview restriction applied to this data. A value of
        # THUMBNAIL_UNSPECIFIED can be treated as though there is no restriction.
        # Corresponds to the JSON property `maxImagePreview`
        # @return [String]
        attr_accessor :max_image_preview
      
        # Max snippet preview restriction applied to this data. If this field is zero,
        # it indicates that no snippet data can be displayed, therefore this field
        # should be checked using has_max_snippet_length to determine if it was set.
        # Corresponds to the JSON property `maxSnippetLength`
        # @return [Fixnum]
        attr_accessor :max_snippet_length
      
        # 
        # Corresponds to the JSON property `noarchiveReason`
        # @return [Fixnum]
        attr_accessor :noarchive_reason
      
        # 
        # Corresponds to the JSON property `nofollowReason`
        # @return [Fixnum]
        attr_accessor :nofollow_reason
      
        # 
        # Corresponds to the JSON property `noimageframeoverlayReason`
        # @return [Fixnum]
        attr_accessor :noimageframeoverlay_reason
      
        # 
        # Corresponds to the JSON property `noimageindexReason`
        # @return [Fixnum]
        attr_accessor :noimageindex_reason
      
        # Bit map of RobotedReasons values. When set to a non-zero value, the document
        # should not be indexed or archived etc. based on the name of the tag.
        # Corresponds to the JSON property `noindexReason`
        # @return [Fixnum]
        attr_accessor :noindex_reason
      
        # 
        # Corresponds to the JSON property `nopreviewReason`
        # @return [Fixnum]
        attr_accessor :nopreview_reason
      
        # 
        # Corresponds to the JSON property `nosnippetReason`
        # @return [Fixnum]
        attr_accessor :nosnippet_reason
      
        # 
        # Corresponds to the JSON property `notranslateReason`
        # @return [Fixnum]
        attr_accessor :notranslate_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_expiry = args[:content_expiry] if args.key?(:content_expiry)
          @convert_to_roboted_reason = args[:convert_to_roboted_reason] if args.key?(:convert_to_roboted_reason)
          @disallowed_reason = args[:disallowed_reason] if args.key?(:disallowed_reason)
          @indexifembedded_reason = args[:indexifembedded_reason] if args.key?(:indexifembedded_reason)
          @max_image_preview = args[:max_image_preview] if args.key?(:max_image_preview)
          @max_snippet_length = args[:max_snippet_length] if args.key?(:max_snippet_length)
          @noarchive_reason = args[:noarchive_reason] if args.key?(:noarchive_reason)
          @nofollow_reason = args[:nofollow_reason] if args.key?(:nofollow_reason)
          @noimageframeoverlay_reason = args[:noimageframeoverlay_reason] if args.key?(:noimageframeoverlay_reason)
          @noimageindex_reason = args[:noimageindex_reason] if args.key?(:noimageindex_reason)
          @noindex_reason = args[:noindex_reason] if args.key?(:noindex_reason)
          @nopreview_reason = args[:nopreview_reason] if args.key?(:nopreview_reason)
          @nosnippet_reason = args[:nosnippet_reason] if args.key?(:nosnippet_reason)
          @notranslate_reason = args[:notranslate_reason] if args.key?(:notranslate_reason)
        end
      end
      
      # Used for storing fingerprints, along with meta-data that expresses how the
      # fingerprint was computed. The metadata can be anything that fits in an uint64.
      class IndexingConverterShingleFingerprint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [Fixnum]
        attr_accessor :metadata
      
        # Repeated to allow for fingerprints larger than 64-bits.
        # Corresponds to the JSON property `value`
        # @return [Array<Fixnum>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class IndexingCrawlerIdServingDocumentIdentifier
        include Google::Apis::Core::Hashable
      
        # Only for double indexing experiments. This field is set for duplicated
        # documents so that docjoin users will not see duplicated docs.
        # Corresponds to the JSON property `doubleIndexingExperimentId`
        # @return [String]
        attr_accessor :double_indexing_experiment_id
      
        # Only for Experimental clusters, not relevant for production serving data:
        # Index-Dups can run experiments in Quality Clusters where different versions of
        # the same document (e.g. with different signals) are serving in parallel. They
        # are uniquely identified by the dup-experiment-IDs. This is for experimental
        # clusters only. In prod-versions the member will not be set.
        # Corresponds to the JSON property `dupExperimentId`
        # @return [String]
        attr_accessor :dup_experiment_id
      
        # The primary identifier of a production document is the document key, which is
        # the same as the row-key in Alexandria, and represents a URL and its crawling
        # context. The document key is the unique identifier for each document, but
        # multiple document keys can cover the same URL (e.g. crawled with different
        # device types). In your production code, please always assume that the document
        # key is the only way to uniquely identify a document. Link for more background
        # information: http://go/url The document key is populated for all docs in
        # indexing since 2014-03. ## Recommended way of reading: const string& doc_key =
        # cdoc.doc().id().key(); ## CHECK(!doc_key.empty()); Note: For older DocJoins (e.
        # g. historical DocJoins), the field is not populated. In those scenarios it is
        # recommended to use the function 'GetDocumentKeyFromCompositeDoc' in '//
        # indexing/crawler_id/utils/compositedoc/compositedoc_util.h' instead.
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @double_indexing_experiment_id = args[:double_indexing_experiment_id] if args.key?(:double_indexing_experiment_id)
          @dup_experiment_id = args[:dup_experiment_id] if args.key?(:dup_experiment_id)
          @key = args[:key] if args.key?(:key)
        end
      end
      
      # Following signals identify spike of spammy anchor phrases. Anchors created
      # during the spike are tagged with LINK_SPAM_PHRASE_SPIKE.
      class IndexingDocjoinerAnchorPhraseSpamInfo
        include Google::Apis::Core::Hashable
      
        # How many spam phrases found in the anchors among unique domains.
        # Corresponds to the JSON property `phraseAnchorSpamCount`
        # @return [Float]
        attr_accessor :phrase_anchor_spam_count
      
        # Over how many days 80% of these phrases were discovered.
        # Corresponds to the JSON property `phraseAnchorSpamDays`
        # @return [Float]
        attr_accessor :phrase_anchor_spam_days
      
        # Total number of demoted anchors.
        # Corresponds to the JSON property `phraseAnchorSpamDemoted`
        # @return [Fixnum]
        attr_accessor :phrase_anchor_spam_demoted
      
        # Time when anchor spam spike ended with padding.
        # Corresponds to the JSON property `phraseAnchorSpamEnd`
        # @return [Fixnum]
        attr_accessor :phrase_anchor_spam_end
      
        # Spam phrases fraction of all anchors of the document.
        # Corresponds to the JSON property `phraseAnchorSpamFraq`
        # @return [Float]
        attr_accessor :phrase_anchor_spam_fraq
      
        # Combined penalty for anchor demotion.
        # Corresponds to the JSON property `phraseAnchorSpamPenalty`
        # @return [Float]
        attr_accessor :phrase_anchor_spam_penalty
      
        # Total number of observed anchors.
        # Corresponds to the JSON property `phraseAnchorSpamProcessed`
        # @return [Fixnum]
        attr_accessor :phrase_anchor_spam_processed
      
        # Average daily rate of spam anchor discovery.
        # Corresponds to the JSON property `phraseAnchorSpamRate`
        # @return [Float]
        attr_accessor :phrase_anchor_spam_rate
      
        # Time when anchor spam spike started with padding.
        # Corresponds to the JSON property `phraseAnchorSpamStart`
        # @return [Fixnum]
        attr_accessor :phrase_anchor_spam_start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @phrase_anchor_spam_count = args[:phrase_anchor_spam_count] if args.key?(:phrase_anchor_spam_count)
          @phrase_anchor_spam_days = args[:phrase_anchor_spam_days] if args.key?(:phrase_anchor_spam_days)
          @phrase_anchor_spam_demoted = args[:phrase_anchor_spam_demoted] if args.key?(:phrase_anchor_spam_demoted)
          @phrase_anchor_spam_end = args[:phrase_anchor_spam_end] if args.key?(:phrase_anchor_spam_end)
          @phrase_anchor_spam_fraq = args[:phrase_anchor_spam_fraq] if args.key?(:phrase_anchor_spam_fraq)
          @phrase_anchor_spam_penalty = args[:phrase_anchor_spam_penalty] if args.key?(:phrase_anchor_spam_penalty)
          @phrase_anchor_spam_processed = args[:phrase_anchor_spam_processed] if args.key?(:phrase_anchor_spam_processed)
          @phrase_anchor_spam_rate = args[:phrase_anchor_spam_rate] if args.key?(:phrase_anchor_spam_rate)
          @phrase_anchor_spam_start = args[:phrase_anchor_spam_start] if args.key?(:phrase_anchor_spam_start)
        end
      end
      
      # Following structure summarizes output of AnchorSpamPenalizer. Spammy anchors
      # are tagged with LINK_SPAM_PHRASE_PENALIZER and demoted to SPAM locality in
      # anchor-localizer.cc
      class IndexingDocjoinerAnchorSpamInfo
        include Google::Apis::Core::Hashable
      
        # End date of the last anchor of the document.
        # Corresponds to the JSON property `anchorEnd`
        # @return [Fixnum]
        attr_accessor :anchor_end
      
        # Ratio of spam demoted period to all anchor period.
        # Corresponds to the JSON property `anchorFraq`
        # @return [Float]
        attr_accessor :anchor_fraq
      
        # Start date of the first anchor of the document.
        # Corresponds to the JSON property `anchorStart`
        # @return [Fixnum]
        attr_accessor :anchor_start
      
        # Following field record details of anchor demotion in action. How many anchors
        # were demoted.
        # Corresponds to the JSON property `demoted`
        # @return [Fixnum]
        attr_accessor :demoted
      
        # Demoted all anchors in the period or only anchors classified as spam.
        # Corresponds to the JSON property `demotedAll`
        # @return [Boolean]
        attr_accessor :demoted_all
        alias_method :demoted_all?, :demoted_all
      
        # End date of the demotion period.
        # Corresponds to the JSON property `demotedEnd`
        # @return [Fixnum]
        attr_accessor :demoted_end
      
        # Start date of the demotion period.
        # Corresponds to the JSON property `demotedStart`
        # @return [Fixnum]
        attr_accessor :demoted_start
      
        # Following fields record signals used in anchor spam classification. How many
        # spam phrases found in the anchors among unique domains.
        # Corresponds to the JSON property `phraseCount`
        # @return [Float]
        attr_accessor :phrase_count
      
        # Over how many days 80% of these phrases were discovered.
        # Corresponds to the JSON property `phraseDays`
        # @return [Float]
        attr_accessor :phrase_days
      
        # Spam phrases fraction of all anchors of the document.
        # Corresponds to the JSON property `phraseFraq`
        # @return [Float]
        attr_accessor :phrase_fraq
      
        # Average daily rate of spam anchor discovery.
        # Corresponds to the JSON property `phraseRate`
        # @return [Float]
        attr_accessor :phrase_rate
      
        # Total number of processed anchors.
        # Corresponds to the JSON property `processed`
        # @return [Fixnum]
        attr_accessor :processed
      
        # True if anchors were sampled during observation phrase.
        # Corresponds to the JSON property `sampled`
        # @return [Boolean]
        attr_accessor :sampled
        alias_method :sampled?, :sampled
      
        # Detailed information about trusted sources and match computation. Populated
        # only when --anchorspam_penalizer_debug=true.
        # Corresponds to the JSON property `sources`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorTrustedInfo>]
        attr_accessor :sources
      
        # Additional debug information about computation of spam probability.
        # Corresponds to the JSON property `spamDebugInfo`
        # @return [String]
        attr_accessor :spam_debug_info
      
        # Combined penalty for anchor demotion.
        # Corresponds to the JSON property `spamPenalty`
        # @return [Float]
        attr_accessor :spam_penalty
      
        # Predicted probability of spam.
        # Corresponds to the JSON property `spamProbability`
        # @return [Float]
        attr_accessor :spam_probability
      
        # Number of trusted anchors used in computation of spam probability.
        # Corresponds to the JSON property `trustedDemoted`
        # @return [Fixnum]
        attr_accessor :trusted_demoted
      
        # Examples of trusted sources.
        # Corresponds to the JSON property `trustedExamples`
        # @return [String]
        attr_accessor :trusted_examples
      
        # Number of trusted anchors with anchor text matching spam terms.
        # Corresponds to the JSON property `trustedMatching`
        # @return [Fixnum]
        attr_accessor :trusted_matching
      
        # Following fields record details about trusted anchors True if is this URL is
        # on trusted source.
        # Corresponds to the JSON property `trustedTarget`
        # @return [Boolean]
        attr_accessor :trusted_target
        alias_method :trusted_target?, :trusted_target
      
        # Total number of trusted sources for this URL.
        # Corresponds to the JSON property `trustedTotal`
        # @return [Fixnum]
        attr_accessor :trusted_total
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_end = args[:anchor_end] if args.key?(:anchor_end)
          @anchor_fraq = args[:anchor_fraq] if args.key?(:anchor_fraq)
          @anchor_start = args[:anchor_start] if args.key?(:anchor_start)
          @demoted = args[:demoted] if args.key?(:demoted)
          @demoted_all = args[:demoted_all] if args.key?(:demoted_all)
          @demoted_end = args[:demoted_end] if args.key?(:demoted_end)
          @demoted_start = args[:demoted_start] if args.key?(:demoted_start)
          @phrase_count = args[:phrase_count] if args.key?(:phrase_count)
          @phrase_days = args[:phrase_days] if args.key?(:phrase_days)
          @phrase_fraq = args[:phrase_fraq] if args.key?(:phrase_fraq)
          @phrase_rate = args[:phrase_rate] if args.key?(:phrase_rate)
          @processed = args[:processed] if args.key?(:processed)
          @sampled = args[:sampled] if args.key?(:sampled)
          @sources = args[:sources] if args.key?(:sources)
          @spam_debug_info = args[:spam_debug_info] if args.key?(:spam_debug_info)
          @spam_penalty = args[:spam_penalty] if args.key?(:spam_penalty)
          @spam_probability = args[:spam_probability] if args.key?(:spam_probability)
          @trusted_demoted = args[:trusted_demoted] if args.key?(:trusted_demoted)
          @trusted_examples = args[:trusted_examples] if args.key?(:trusted_examples)
          @trusted_matching = args[:trusted_matching] if args.key?(:trusted_matching)
          @trusted_target = args[:trusted_target] if args.key?(:trusted_target)
          @trusted_total = args[:trusted_total] if args.key?(:trusted_total)
        end
      end
      
      # Statistics of the anchors in a docjoin. Next available tag ID: 63.
      class IndexingDocjoinerAnchorStatistics
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchorCount`
        # @return [Fixnum]
        attr_accessor :anchor_count
      
        # The number of unique anchor phrases. Capped by the constant
        # kMaxAnchorPhraseCountInStats (=5000) defined in indexing/docjoiner/anchors/
        # anchor-manager.cc.
        # Corresponds to the JSON property `anchorPhraseCount`
        # @return [Fixnum]
        attr_accessor :anchor_phrase_count
      
        # Following structure summarizes output of AnchorSpamPenalizer. Spammy anchors
        # are tagged with LINK_SPAM_PHRASE_PENALIZER and demoted to SPAM locality in
        # anchor-localizer.cc
        # Corresponds to the JSON property `anchorSpamInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorSpamInfo]
        attr_accessor :anchor_spam_info
      
        # The number of anchors for which some ImprovAnchors phrases have been removed
        # due to duplication within source org.
        # Corresponds to the JSON property `anchorsWithDedupedImprovanchors`
        # @return [Fixnum]
        attr_accessor :anchors_with_deduped_improvanchors
      
        # Whether this doc is penalized by BadBackLinks, in which case we should not use
        # improvanchor score in mustang ascorer.
        # Corresponds to the JSON property `badbacklinksPenalized`
        # @return [Boolean]
        attr_accessor :badbacklinks_penalized
        alias_method :badbacklinks_penalized?, :badbacklinks_penalized
      
        # 
        # Corresponds to the JSON property `baseAnchorCount`
        # @return [Fixnum]
        attr_accessor :base_anchor_count
      
        # 
        # Corresponds to the JSON property `baseOffdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :base_offdomain_anchor_count
      
        # 
        # Corresponds to the JSON property `droppedHomepageAnchorCount`
        # @return [Fixnum]
        attr_accessor :dropped_homepage_anchor_count
      
        # 
        # Corresponds to the JSON property `droppedLocalAnchorCount`
        # @return [Fixnum]
        attr_accessor :dropped_local_anchor_count
      
        # 
        # Corresponds to the JSON property `droppedNonLocalAnchorCount`
        # @return [Fixnum]
        attr_accessor :dropped_non_local_anchor_count
      
        # Sum of anchors_dropped in the repeated group RedundantAnchorInfo, but can go
        # higher if the latter reaches the cap of kMaxRecordsToKeep. (indexing/docjoiner/
        # anchors/anchor-loader.cc), currently 10,000
        # Corresponds to the JSON property `droppedRedundantAnchorCount`
        # @return [Fixnum]
        attr_accessor :dropped_redundant_anchor_count
      
        # 
        # Corresponds to the JSON property `fakeAnchorCount`
        # @return [Fixnum]
        attr_accessor :fake_anchor_count
      
        # 
        # Corresponds to the JSON property `forwardedAnchorCount`
        # @return [Fixnum]
        attr_accessor :forwarded_anchor_count
      
        # 
        # Corresponds to the JSON property `forwardedOffdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :forwarded_offdomain_anchor_count
      
        # Metric of number of changed global anchors computed as, size(union(previous,
        # new) - intersection(previous, new)).
        # Corresponds to the JSON property `globalAnchorDelta`
        # @return [Fixnum]
        attr_accessor :global_anchor_delta
      
        # 
        # Corresponds to the JSON property `linkBeforeSitechangeTaggedAnchors`
        # @return [Fixnum]
        attr_accessor :link_before_sitechange_tagged_anchors
      
        # 
        # Corresponds to the JSON property `localAnchorCount`
        # @return [Fixnum]
        attr_accessor :local_anchor_count
      
        # 
        # Corresponds to the JSON property `lowCorpusAnchorCount`
        # @return [Fixnum]
        attr_accessor :low_corpus_anchor_count
      
        # 
        # Corresponds to the JSON property `lowCorpusOffdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :low_corpus_offdomain_anchor_count
      
        # 
        # Corresponds to the JSON property `mediumCorpusAnchorCount`
        # @return [Fixnum]
        attr_accessor :medium_corpus_anchor_count
      
        # 
        # Corresponds to the JSON property `mediumCorpusOffdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :medium_corpus_offdomain_anchor_count
      
        # Minimum local outdegree of all anchor sources that are domain home pages as
        # well as on the same domain as the current target URL.
        # Corresponds to the JSON property `minDomainHomePageLocalOutdegree`
        # @return [Fixnum]
        attr_accessor :min_domain_home_page_local_outdegree
      
        # Minimum local outdegree of all anchor sources that are host home pages as well
        # as on the same host as the current target URL.
        # Corresponds to the JSON property `minHostHomePageLocalOutdegree`
        # @return [Fixnum]
        attr_accessor :min_host_home_page_local_outdegree
      
        # 
        # Corresponds to the JSON property `nonLocalAnchorCount`
        # @return [Fixnum]
        attr_accessor :non_local_anchor_count
      
        # 
        # Corresponds to the JSON property `offdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :offdomain_anchor_count
      
        # 
        # Corresponds to the JSON property `ondomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :ondomain_anchor_count
      
        # 
        # Corresponds to the JSON property `onsiteAnchorCount`
        # @return [Fixnum]
        attr_accessor :onsite_anchor_count
      
        # Set in SignalPenalizer::FillInAnchorStatistics.
        # Corresponds to the JSON property `pageFromExpiredTaggedAnchors`
        # @return [Fixnum]
        attr_accessor :page_from_expired_tagged_anchors
      
        # 
        # Corresponds to the JSON property `pageMismatchTaggedAnchors`
        # @return [Fixnum]
        attr_accessor :page_mismatch_tagged_anchors
      
        # Doc is protected by goodness of early anchors.
        # Corresponds to the JSON property `penguinEarlyAnchorProtected`
        # @return [Boolean]
        attr_accessor :penguin_early_anchor_protected
        alias_method :penguin_early_anchor_protected?, :penguin_early_anchor_protected
      
        # BEGIN: Penguin related fields. Timestamp when penguin scores were last updated.
        # Measured in days since Jan. 1st 1995.
        # Corresponds to the JSON property `penguinLastUpdate`
        # @return [Fixnum]
        attr_accessor :penguin_last_update
      
        # Page-level penguin penalty (0 = good, 1 = bad).
        # Corresponds to the JSON property `penguinPenalty`
        # @return [Float]
        attr_accessor :penguin_penalty
      
        # Doc not scored because it has too many anchor sources. END: Penguin related
        # fields.
        # Corresponds to the JSON property `penguinTooManySources`
        # @return [Boolean]
        attr_accessor :penguin_too_many_sources
        alias_method :penguin_too_many_sources?, :penguin_too_many_sources
      
        # 
        # Corresponds to the JSON property `perdupstats`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorStatisticsPerDupStats>]
        attr_accessor :perdupstats
      
        # Following signals identify spike of spammy anchor phrases. Anchors created
        # during the spike are tagged with LINK_SPAM_PHRASE_SPIKE.
        # Corresponds to the JSON property `phraseAnchorSpamInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorPhraseSpamInfo]
        attr_accessor :phrase_anchor_spam_info
      
        # Total anchor dropped due to exceed per domain phrase cap. Equals to sum of
        # anchors_dropped in the repeated group RedundantAnchorInfoForPhraseCap, but can
        # go higher if the latter reaches the cap of kMaxDomainsToKeepForPhraseCap (
        # indexing/docjoiner/anchors/anchor-loader.h), currently 1000.
        # Corresponds to the JSON property `redundantAnchorForPhraseCapCount`
        # @return [Fixnum]
        attr_accessor :redundant_anchor_for_phrase_cap_count
      
        # 
        # Corresponds to the JSON property `redundantanchorinfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorStatisticsRedundantAnchorInfo>]
        attr_accessor :redundantanchorinfo
      
        # 
        # Corresponds to the JSON property `redundantanchorinfoforphrasecap`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDocjoinerAnchorStatisticsRedundantAnchorInfoForPhraseCap>]
        attr_accessor :redundantanchorinfoforphrasecap
      
        # The total number of anchors being scanned from storage.
        # Corresponds to the JSON property `scannedAnchorCount`
        # @return [Fixnum]
        attr_accessor :scanned_anchor_count
      
        # A count of the number of times anchor accumulation has been skipped for this
        # document. Note: Only used when canonical.
        # Corresponds to the JSON property `skippedAccumulate`
        # @return [Fixnum]
        attr_accessor :skipped_accumulate
      
        # Reason to skip accumulate, when skipped, or Reason for reprocessing when not
        # skipped.
        # Corresponds to the JSON property `skippedOrReusedReason`
        # @return [String]
        attr_accessor :skipped_or_reused_reason
      
        # The log base 10 odds that this set of anchors exhibits spammy behavior.
        # Computed in the AnchorLocalizer.
        # Corresponds to the JSON property `spamLog10Odds`
        # @return [Float]
        attr_accessor :spam_log10_odds
      
        # Walltime of when anchors were accumulated last.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # 
        # Corresponds to the JSON property `topPrOffdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :top_pr_offdomain_anchor_count
      
        # 
        # Corresponds to the JSON property `topPrOndomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :top_pr_ondomain_anchor_count
      
        # According to anchor quality bucket, anchor with pagrank > 51000 is the best
        # anchor. anchors with pagerank < 47000 are all same.
        # Corresponds to the JSON property `topPrOnsiteAnchorCount`
        # @return [Fixnum]
        attr_accessor :top_pr_onsite_anchor_count
      
        # The following should be equal to the size of the following repeated group,
        # except that it can go higher than 10,000.
        # Corresponds to the JSON property `totalDomainPhrasePairsAboveLimit`
        # @return [Fixnum]
        attr_accessor :total_domain_phrase_pairs_above_limit
      
        # Number of domain/phrase pairs in total -- i.e. how many anchors we would have
        # if the domain/phrase cutoff was set to 1 instead of 200. This is "approx" for
        # large anchor clusters because there can be double counting when the LRU cache
        # forgets about rare domain/phrase pairs.
        # Corresponds to the JSON property `totalDomainPhrasePairsSeenApprox`
        # @return [Fixnum]
        attr_accessor :total_domain_phrase_pairs_seen_approx
      
        # Number of domains above per domain phrase cap. We see too many phrases in the
        # domains.
        # Corresponds to the JSON property `totalDomainsAbovePhraseCap`
        # @return [Fixnum]
        attr_accessor :total_domains_above_phrase_cap
      
        # Number of domains seen in total.
        # Corresponds to the JSON property `totalDomainsSeen`
        # @return [Fixnum]
        attr_accessor :total_domains_seen
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_count = args[:anchor_count] if args.key?(:anchor_count)
          @anchor_phrase_count = args[:anchor_phrase_count] if args.key?(:anchor_phrase_count)
          @anchor_spam_info = args[:anchor_spam_info] if args.key?(:anchor_spam_info)
          @anchors_with_deduped_improvanchors = args[:anchors_with_deduped_improvanchors] if args.key?(:anchors_with_deduped_improvanchors)
          @badbacklinks_penalized = args[:badbacklinks_penalized] if args.key?(:badbacklinks_penalized)
          @base_anchor_count = args[:base_anchor_count] if args.key?(:base_anchor_count)
          @base_offdomain_anchor_count = args[:base_offdomain_anchor_count] if args.key?(:base_offdomain_anchor_count)
          @dropped_homepage_anchor_count = args[:dropped_homepage_anchor_count] if args.key?(:dropped_homepage_anchor_count)
          @dropped_local_anchor_count = args[:dropped_local_anchor_count] if args.key?(:dropped_local_anchor_count)
          @dropped_non_local_anchor_count = args[:dropped_non_local_anchor_count] if args.key?(:dropped_non_local_anchor_count)
          @dropped_redundant_anchor_count = args[:dropped_redundant_anchor_count] if args.key?(:dropped_redundant_anchor_count)
          @fake_anchor_count = args[:fake_anchor_count] if args.key?(:fake_anchor_count)
          @forwarded_anchor_count = args[:forwarded_anchor_count] if args.key?(:forwarded_anchor_count)
          @forwarded_offdomain_anchor_count = args[:forwarded_offdomain_anchor_count] if args.key?(:forwarded_offdomain_anchor_count)
          @global_anchor_delta = args[:global_anchor_delta] if args.key?(:global_anchor_delta)
          @link_before_sitechange_tagged_anchors = args[:link_before_sitechange_tagged_anchors] if args.key?(:link_before_sitechange_tagged_anchors)
          @local_anchor_count = args[:local_anchor_count] if args.key?(:local_anchor_count)
          @low_corpus_anchor_count = args[:low_corpus_anchor_count] if args.key?(:low_corpus_anchor_count)
          @low_corpus_offdomain_anchor_count = args[:low_corpus_offdomain_anchor_count] if args.key?(:low_corpus_offdomain_anchor_count)
          @medium_corpus_anchor_count = args[:medium_corpus_anchor_count] if args.key?(:medium_corpus_anchor_count)
          @medium_corpus_offdomain_anchor_count = args[:medium_corpus_offdomain_anchor_count] if args.key?(:medium_corpus_offdomain_anchor_count)
          @min_domain_home_page_local_outdegree = args[:min_domain_home_page_local_outdegree] if args.key?(:min_domain_home_page_local_outdegree)
          @min_host_home_page_local_outdegree = args[:min_host_home_page_local_outdegree] if args.key?(:min_host_home_page_local_outdegree)
          @non_local_anchor_count = args[:non_local_anchor_count] if args.key?(:non_local_anchor_count)
          @offdomain_anchor_count = args[:offdomain_anchor_count] if args.key?(:offdomain_anchor_count)
          @ondomain_anchor_count = args[:ondomain_anchor_count] if args.key?(:ondomain_anchor_count)
          @onsite_anchor_count = args[:onsite_anchor_count] if args.key?(:onsite_anchor_count)
          @page_from_expired_tagged_anchors = args[:page_from_expired_tagged_anchors] if args.key?(:page_from_expired_tagged_anchors)
          @page_mismatch_tagged_anchors = args[:page_mismatch_tagged_anchors] if args.key?(:page_mismatch_tagged_anchors)
          @penguin_early_anchor_protected = args[:penguin_early_anchor_protected] if args.key?(:penguin_early_anchor_protected)
          @penguin_last_update = args[:penguin_last_update] if args.key?(:penguin_last_update)
          @penguin_penalty = args[:penguin_penalty] if args.key?(:penguin_penalty)
          @penguin_too_many_sources = args[:penguin_too_many_sources] if args.key?(:penguin_too_many_sources)
          @perdupstats = args[:perdupstats] if args.key?(:perdupstats)
          @phrase_anchor_spam_info = args[:phrase_anchor_spam_info] if args.key?(:phrase_anchor_spam_info)
          @redundant_anchor_for_phrase_cap_count = args[:redundant_anchor_for_phrase_cap_count] if args.key?(:redundant_anchor_for_phrase_cap_count)
          @redundantanchorinfo = args[:redundantanchorinfo] if args.key?(:redundantanchorinfo)
          @redundantanchorinfoforphrasecap = args[:redundantanchorinfoforphrasecap] if args.key?(:redundantanchorinfoforphrasecap)
          @scanned_anchor_count = args[:scanned_anchor_count] if args.key?(:scanned_anchor_count)
          @skipped_accumulate = args[:skipped_accumulate] if args.key?(:skipped_accumulate)
          @skipped_or_reused_reason = args[:skipped_or_reused_reason] if args.key?(:skipped_or_reused_reason)
          @spam_log10_odds = args[:spam_log10_odds] if args.key?(:spam_log10_odds)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @top_pr_offdomain_anchor_count = args[:top_pr_offdomain_anchor_count] if args.key?(:top_pr_offdomain_anchor_count)
          @top_pr_ondomain_anchor_count = args[:top_pr_ondomain_anchor_count] if args.key?(:top_pr_ondomain_anchor_count)
          @top_pr_onsite_anchor_count = args[:top_pr_onsite_anchor_count] if args.key?(:top_pr_onsite_anchor_count)
          @total_domain_phrase_pairs_above_limit = args[:total_domain_phrase_pairs_above_limit] if args.key?(:total_domain_phrase_pairs_above_limit)
          @total_domain_phrase_pairs_seen_approx = args[:total_domain_phrase_pairs_seen_approx] if args.key?(:total_domain_phrase_pairs_seen_approx)
          @total_domains_above_phrase_cap = args[:total_domains_above_phrase_cap] if args.key?(:total_domains_above_phrase_cap)
          @total_domains_seen = args[:total_domains_seen] if args.key?(:total_domains_seen)
        end
      end
      
      # ------------------------------------------------------------------------- The
      # total number of anchors collected per dupforwarding (including the canonical
      # itself). Includes additional data about redundant and offdomain counts and the
      # last timestamp it was collected from.
      class IndexingDocjoinerAnchorStatisticsPerDupStats
        include Google::Apis::Core::Hashable
      
        # Count of anchors kept from forwarding.
        # Corresponds to the JSON property `anchorCount`
        # @return [Fixnum]
        attr_accessor :anchor_count
      
        # This is EcnCollectType in anchor-ecn-matcher.h for the latest ECN of this dup:
        # - kCollectNormal = 0, // Normal collection. - kCollectUnforwarded = 1, //
        # Forwarding leader docid match only. - kCollectWhitelisted = 2, // Collected
        # anchors matching whitelist. - kCollectNone = 4 // Skipped ECN anchor cluster.
        # Corresponds to the JSON property `collectType`
        # @return [Fixnum]
        attr_accessor :collect_type
      
        # If missing, the same as the canonical.
        # Corresponds to the JSON property `dupUrl`
        # @return [String]
        attr_accessor :dup_url
      
        # Count of offdomain anchors.
        # Corresponds to the JSON property `offdomainAnchorCount`
        # @return [Fixnum]
        attr_accessor :offdomain_anchor_count
      
        # Count of redundant anchors.
        # Corresponds to the JSON property `redundantAnchorCount`
        # @return [Fixnum]
        attr_accessor :redundant_anchor_count
      
        # The number of anchors being scanned from storage per dupforwarding.
        # Corresponds to the JSON property `scannedAnchorCount`
        # @return [Fixnum]
        attr_accessor :scanned_anchor_count
      
        # Walltime when this was scanned last.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_count = args[:anchor_count] if args.key?(:anchor_count)
          @collect_type = args[:collect_type] if args.key?(:collect_type)
          @dup_url = args[:dup_url] if args.key?(:dup_url)
          @offdomain_anchor_count = args[:offdomain_anchor_count] if args.key?(:offdomain_anchor_count)
          @redundant_anchor_count = args[:redundant_anchor_count] if args.key?(:redundant_anchor_count)
          @scanned_anchor_count = args[:scanned_anchor_count] if args.key?(:scanned_anchor_count)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # ------------------------------------------------------------------------- The
      # total number of redundant anchors dropped per (domain, text). If we receive a
      # large number of anchors from a particular domain, then we'll throw out all but
      # 200 of them from that domain. The data is sorted by the (domain, text) pairs.
      # This is capped at 10,000 entries (if less, it will have the same number of
      # elements as the above_limit count).
      class IndexingDocjoinerAnchorStatisticsRedundantAnchorInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchorsDropped`
        # @return [Fixnum]
        attr_accessor :anchors_dropped
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchors_dropped = args[:anchors_dropped] if args.key?(:anchors_dropped)
          @domain = args[:domain] if args.key?(:domain)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # 
      class IndexingDocjoinerAnchorStatisticsRedundantAnchorInfoForPhraseCap
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchorsDropped`
        # @return [Fixnum]
        attr_accessor :anchors_dropped
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchors_dropped = args[:anchors_dropped] if args.key?(:anchors_dropped)
          @domain = args[:domain] if args.key?(:domain)
        end
      end
      
      # This message summarized anchors of one trusted site.
      class IndexingDocjoinerAnchorTrustedInfo
        include Google::Apis::Core::Hashable
      
        # Difference in KL-divergence from spam and non-spam anchors. Value >0 indicate
        # that anchor text from this trusted source is similar to anchors classified as
        # spam which means that spammy anchors are legitimate.
        # Corresponds to the JSON property `matchedScore`
        # @return [Float]
        attr_accessor :matched_score
      
        # Detailed debug information about computation of trusted anchors match.
        # Populated only when --anchorspam_penalizer_debug=true
        # Corresponds to the JSON property `matchedScoreInfo`
        # @return [Array<String>]
        attr_accessor :matched_score_info
      
        # Count of anchors classified as spam using anchor text.
        # Corresponds to the JSON property `phrasesScore`
        # @return [Float]
        attr_accessor :phrases_score
      
        # Site name from anchor.source().site().
        # Corresponds to the JSON property `site`
        # @return [String]
        attr_accessor :site
      
        # Tokenized text of all anchors from the site.
        # Corresponds to the JSON property `text`
        # @return [Array<String>]
        attr_accessor :text
      
        # Fraction of pages with newsy anchors on the site, >0 for trusted sites.
        # Corresponds to the JSON property `trustedScore`
        # @return [Float]
        attr_accessor :trusted_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matched_score = args[:matched_score] if args.key?(:matched_score)
          @matched_score_info = args[:matched_score_info] if args.key?(:matched_score_info)
          @phrases_score = args[:phrases_score] if args.key?(:phrases_score)
          @site = args[:site] if args.key?(:site)
          @text = args[:text] if args.key?(:text)
          @trusted_score = args[:trusted_score] if args.key?(:trusted_score)
        end
      end
      
      # Holds extra info except annotations and raw cdoc for buildint the final cdoc.
      class IndexingDocjoinerCDocBuildInfo
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `extraMessage`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :extra_message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra_message = args[:extra_message] if args.key?(:extra_message)
        end
      end
      
      # DataVersion tracks the version of data in CompositeDoc. The notion of "data"
      # here is loose and people can define the name of their own. For example, a
      # signal generated by Index Signals or an annotation generated by Goldmine (and
      # other components) can all be considered as data here. Each field in this proto
      # represents the human readable version string and the timestamp of one
      # particular data. We choose to explicitly list out all of the data here for
      # better understanding about which data are tracked. NOTE that
      # human_readable_version is not intended for comparison, use timestamp_micros.
      # In addition, we have an annotation about the field paths of each data. With
      # proto reflection (using google3/net/proto2/util/public/field_path.h),
      # downstream systems can take advantage of this annotation to automatically
      # handle newly introduced data without modifying their code. Please also see the
      # comment of FieldProjector above. There are also some fields in DataInfo that
      # annotate who generates the data, the Index Signals or Goldmine annotator name.
      class IndexingDocjoinerDataVersion
        include Google::Apis::Core::Hashable
      
        # LINT.ThenChange(//depot/google3/indexing/ames/spanner/schema/websearch_main.
        # sdl)
        # Corresponds to the JSON property `acceleratedShoppingSignal`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :accelerated_shopping_signal
      
        # 
        # Corresponds to the JSON property `localyp`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :localyp
      
        # 
        # Corresponds to the JSON property `localypVersion`
        # @return [String]
        attr_accessor :localyp_version
      
        # 
        # Corresponds to the JSON property `modernFormatContent`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :modern_format_content
      
        # 
        # Corresponds to the JSON property `modernFormatContentVersion`
        # @return [String]
        attr_accessor :modern_format_content_version
      
        # LINT.IfChange
        # Corresponds to the JSON property `navboost`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :navboost
      
        # DEPRECATED
        # Corresponds to the JSON property `navboostVersion`
        # @return [String]
        attr_accessor :navboost_version
      
        # 
        # Corresponds to the JSON property `rankembed`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :rankembed
      
        # 
        # Corresponds to the JSON property `universalFacts`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :universal_facts
      
        # 
        # Corresponds to the JSON property `videoScoringSignal`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :video_scoring_signal
      
        # 
        # Corresponds to the JSON property `videoScoringSignalVersion`
        # @return [String]
        attr_accessor :video_scoring_signal_version
      
        # 
        # Corresponds to the JSON property `volt`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerDataVersionVersionInfo]
        attr_accessor :volt
      
        # 
        # Corresponds to the JSON property `voltVersion`
        # @return [String]
        attr_accessor :volt_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @accelerated_shopping_signal = args[:accelerated_shopping_signal] if args.key?(:accelerated_shopping_signal)
          @localyp = args[:localyp] if args.key?(:localyp)
          @localyp_version = args[:localyp_version] if args.key?(:localyp_version)
          @modern_format_content = args[:modern_format_content] if args.key?(:modern_format_content)
          @modern_format_content_version = args[:modern_format_content_version] if args.key?(:modern_format_content_version)
          @navboost = args[:navboost] if args.key?(:navboost)
          @navboost_version = args[:navboost_version] if args.key?(:navboost_version)
          @rankembed = args[:rankembed] if args.key?(:rankembed)
          @universal_facts = args[:universal_facts] if args.key?(:universal_facts)
          @video_scoring_signal = args[:video_scoring_signal] if args.key?(:video_scoring_signal)
          @video_scoring_signal_version = args[:video_scoring_signal_version] if args.key?(:video_scoring_signal_version)
          @volt = args[:volt] if args.key?(:volt)
          @volt_version = args[:volt_version] if args.key?(:volt_version)
        end
      end
      
      # 
      class IndexingDocjoinerDataVersionVersionInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `humanReadableVersion`
        # @return [String]
        attr_accessor :human_readable_version
      
        # 
        # Corresponds to the JSON property `timestampMicros`
        # @return [Fixnum]
        attr_accessor :timestamp_micros
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @human_readable_version = args[:human_readable_version] if args.key?(:human_readable_version)
          @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros)
        end
      end
      
      # The serving cluster id metadata. Why we cluster the documents. The default
      # value is UNKNOWN. Serving-Side Clustering is used for pages which represent
      # the same content but are not identical (e.g. translated pages, or paginated
      # content). Those documents are not dup-clustered in Alexandria so that all
      # documents (and their tokens) are available to search queries. However, those
      # documents are assigned the same Serving-Time-Cluster-ID (on the same
      # reasontype), which during serving guarantees that only one of them is shown to
      # the user.
      class IndexingDocjoinerServingTimeClusterId
        include Google::Apis::Core::Hashable
      
        # The unique id to distinguish members in cluster. It could be generated in
        # different ways according to reason, e.g. LINK_REL_NEXT_PREVIOUS: it is the
        # fingerprint of the URL of index 0; PAGE_PARAMETER_INFO: it is the fingerprint
        # of pagination pattern (pagination_pattern_fp field in PageParamInfo message).
        # Corresponds to the JSON property `clusterId`
        # @return [Fixnum]
        attr_accessor :cluster_id
      
        # The member index of this document in cluster. Starts from "0". Note that
        # indices of pages in a cluster may not be consistent with each other, because
        # we may update them at different points in time. Currently only used for
        # debugging.
        # Corresponds to the JSON property `indexForDebugging`
        # @return [Fixnum]
        attr_accessor :index_for_debugging
      
        # The reason why this document is clustered into this cluster.
        # Corresponds to the JSON property `reason`
        # @return [String]
        attr_accessor :reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @index_for_debugging = args[:index_for_debugging] if args.key?(:index_for_debugging)
          @reason = args[:reason] if args.key?(:reason)
        end
      end
      
      # This message contains a set of cluster ids used to de-dup at serving time. A
      # document could be clustered into different clusters according to different
      # properties.
      class IndexingDocjoinerServingTimeClusterIds
        include Google::Apis::Core::Hashable
      
        # The exact cluster metadata for each individual cluster if any.
        # Corresponds to the JSON property `clusterId`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDocjoinerServingTimeClusterId>]
        attr_accessor :cluster_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
        end
      end
      
      # 
      class IndexingDupsComputedLocalizedAlternateNamesLocaleEntry
        include Google::Apis::Core::Hashable
      
        # Cluster-ID of that locale entry. Not Populated if the message is part of a
        # Cluster-Proto (e.g. when loaded as a signal). The data is being populated when
        # the proto is used outside of the cluster context. For instance, when being
        # used as a dups-computed-localized-alternate-name.
        # Corresponds to the JSON property `clusterId`
        # @return [Fixnum]
        attr_accessor :cluster_id
      
        # Device match info calculated only by URL pattern.
        # Corresponds to the JSON property `deviceMatchInfo`
        # @return [String]
        attr_accessor :device_match_info
      
        # Language/Region code. E.g. "en-US" or "de". Allowed values are language-region
        # codes based on the W3C recommendation http://www.w3.org/TR/html401/struct/
        # dirlang.html#langcodes
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # The alternate url representing the content for a specific language and region (
        # or language only).
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # see webutil/urlencoding
        # Corresponds to the JSON property `urlEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        # The region code that was extracted from the URL, either by the TLD or via a
        # pattern (like 'en-ca' as a path element).. Always filled in if known, unlike
        # the sometimes left out region part of the language field. Unknown Region Code
        # Corresponds to the JSON property `urlRegionCode`
        # @return [Fixnum]
        attr_accessor :url_region_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @device_match_info = args[:device_match_info] if args.key?(:device_match_info)
          @language = args[:language] if args.key?(:language)
          @url = args[:url] if args.key?(:url)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
          @url_region_code = args[:url_region_code] if args.key?(:url_region_code)
        end
      end
      
      # 
      class IndexingDupsLocalizedLocalizedCluster
        include Google::Apis::Core::Hashable
      
        # Defined as a source-blocker, a result which can be a boost target but should
        # itself not be boosted (e.g. roboted documents). For more details on source and
        # target blocking, please read through the code for quality/twiddler/impls/
        # PROTECTED/local_result_twiddler_v2.cc
        # Corresponds to the JSON property `boostSourceBlocker`
        # @return [Boolean]
        attr_accessor :boost_source_blocker
        alias_method :boost_source_blocker?, :boost_source_blocker
      
        # 
        # Corresponds to the JSON property `cluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterCluster>]
        attr_accessor :cluster
      
        # ClusterInfo no longer being populated (they are the 'old' version of storing
        # meta-information only available in old not-reprocessed documents, all
        # documents processed since July 2014 use the 'TargetLinkSet' instead.
        # Corresponds to the JSON property `deprecatedHreflangInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfo]
        attr_accessor :deprecated_hreflang_info
      
        # ClusterInfo no longer being populated (they are the 'old' version of storing
        # meta-information only available in old not-reprocessed documents, all
        # documents processed since July 2014 use the 'TargetLinkSet' instead.
        # Corresponds to the JSON property `deprecatedOutlinksInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfo]
        attr_accessor :deprecated_outlinks_info
      
        # The language of this document (as detected by on-page language detection, not
        # influenced by external anchor signals or other indirect conclusions).
        # Corresponds to the JSON property `documentLanguage`
        # @return [String]
        attr_accessor :document_language
      
        # 
        # Corresponds to the JSON property `hreflangTargetLink`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkSets]
        attr_accessor :hreflang_target_link
      
        # 
        # Corresponds to the JSON property `inbodyTargetLink`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkSets]
        attr_accessor :inbody_target_link
      
        # 
        # Corresponds to the JSON property `outlinksTargetLink`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkSets]
        attr_accessor :outlinks_target_link
      
        # The list of Sitedup rule IDs for this specific URL. The value is only
        # populated if the URL has at least one localized cluster fulfilling the
        # following conditions: - spans more than one host - does not have filtering
        # enabled due to other input (e.g. due to being a hreflang cluster).
        # Corresponds to the JSON property `sitedupRuleId`
        # @return [Array<Fixnum>]
        attr_accessor :sitedup_rule_id
      
        # A warning indicator that a problem has occurred, e.g. cross-domain links being
        # filtered early. The warning is just presented for debugging purposes.
        # Corresponds to the JSON property `warningMessage`
        # @return [Array<String>]
        attr_accessor :warning_message
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boost_source_blocker = args[:boost_source_blocker] if args.key?(:boost_source_blocker)
          @cluster = args[:cluster] if args.key?(:cluster)
          @deprecated_hreflang_info = args[:deprecated_hreflang_info] if args.key?(:deprecated_hreflang_info)
          @deprecated_outlinks_info = args[:deprecated_outlinks_info] if args.key?(:deprecated_outlinks_info)
          @document_language = args[:document_language] if args.key?(:document_language)
          @hreflang_target_link = args[:hreflang_target_link] if args.key?(:hreflang_target_link)
          @inbody_target_link = args[:inbody_target_link] if args.key?(:inbody_target_link)
          @outlinks_target_link = args[:outlinks_target_link] if args.key?(:outlinks_target_link)
          @sitedup_rule_id = args[:sitedup_rule_id] if args.key?(:sitedup_rule_id)
          @warning_message = args[:warning_message] if args.key?(:warning_message)
        end
      end
      
      # 
      class IndexingDupsLocalizedLocalizedClusterCluster
        include Google::Apis::Core::Hashable
      
        # The cluster id, a unique int64 id for the cluster.
        # Corresponds to the JSON property `clusterId`
        # @return [Fixnum]
        attr_accessor :cluster_id
      
        # 
        # Corresponds to the JSON property `clusterType`
        # @return [String]
        attr_accessor :cluster_type
      
        # Debug Info being attached to each cluster, to understand how it was created.
        # That info is stored in Alexandria, but not available during serving.
        # Corresponds to the JSON property `deprecatedDebugInfo`
        # @return [Array<String>]
        attr_accessor :deprecated_debug_info
      
        # Indicates that filtering can be applied on the category (if many results of
        # one cluster show up on the SERP, only one should be kept).
        # Corresponds to the JSON property `filteringEnabled`
        # @return [Boolean]
        attr_accessor :filtering_enabled
        alias_method :filtering_enabled?, :filtering_enabled
      
        # The language as represented by the URL, e.g. 'use this document on the cluster
        # for German queries'.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Same as language, except for the country. This is the Stable Region Code. This
        # value may be UNKNOWN even though the URL region code is known, namely when the
        # known region code was the main region for the language and for that language
        # no other region is specified (e.g. de-DE being the only german variation).
        # Unknown Region Code
        # Corresponds to the JSON property `regionCode`
        # @return [Fixnum]
        attr_accessor :region_code
      
        # Similar to region_code, but always has the value filled in if known. Unknown
        # Region Code
        # Corresponds to the JSON property `urlRegionCode`
        # @return [Fixnum]
        attr_accessor :url_region_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_type = args[:cluster_type] if args.key?(:cluster_type)
          @deprecated_debug_info = args[:deprecated_debug_info] if args.key?(:deprecated_debug_info)
          @filtering_enabled = args[:filtering_enabled] if args.key?(:filtering_enabled)
          @language = args[:language] if args.key?(:language)
          @region_code = args[:region_code] if args.key?(:region_code)
          @url_region_code = args[:url_region_code] if args.key?(:url_region_code)
        end
      end
      
      # ClusterInfo no longer being populated (they are the 'old' version of storing
      # meta-information only available in old not-reprocessed documents, all
      # documents processed since July 2014 use the 'TargetLinkSet' instead.
      class IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfo
        include Google::Apis::Core::Hashable
      
        # A fingerprint of all outlink-URLs of this document that have been used as
        # algorithmic input.
        # Corresponds to the JSON property `fpOutlinks`
        # @return [Fixnum]
        attr_accessor :fp_outlinks
      
        # The last time the set of outgoing links of this document was modified. This is
        # the input for our calculation.
        # Corresponds to the JSON property `lastModifiedInputTimestampMs`
        # @return [Fixnum]
        attr_accessor :last_modified_input_timestamp_ms
      
        # The last time the cross-validation of the links was done. Between that last
        # timestamp and now, only cached results have been used.
        # Corresponds to the JSON property `lastProcessedOutputTimestampMs`
        # @return [Fixnum]
        attr_accessor :last_processed_output_timestamp_ms
      
        # All verified members of the cluster (including recursive inclusions).
        # Corresponds to the JSON property `linkMember`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfoLinkMember>]
        attr_accessor :link_member
      
        # 
        # Corresponds to the JSON property `unvalidatedOutlink`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfoLinkData>]
        attr_accessor :unvalidated_outlink
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fp_outlinks = args[:fp_outlinks] if args.key?(:fp_outlinks)
          @last_modified_input_timestamp_ms = args[:last_modified_input_timestamp_ms] if args.key?(:last_modified_input_timestamp_ms)
          @last_processed_output_timestamp_ms = args[:last_processed_output_timestamp_ms] if args.key?(:last_processed_output_timestamp_ms)
          @link_member = args[:link_member] if args.key?(:link_member)
          @unvalidated_outlink = args[:unvalidated_outlink] if args.key?(:unvalidated_outlink)
        end
      end
      
      # 
      class IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfoLinkData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotationSource`
        # @return [String]
        attr_accessor :annotation_source
      
        # If set, represents the crawl timestamp. If not set, there is no known crawl
        # timestamp for that url.
        # Corresponds to the JSON property `crawlTimestamp`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @crawl_timestamp = args[:crawl_timestamp] if args.key?(:crawl_timestamp)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class IndexingDupsLocalizedLocalizedClusterLinkBasedClusterInfoLinkMember
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotationSource`
        # @return [String]
        attr_accessor :annotation_source
      
        # 
        # Corresponds to the JSON property `languageCode`
        # @return [Array<String>]
        attr_accessor :language_code
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @language_code = args[:language_code] if args.key?(:language_code)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Message containing information about the localized URL linked to from this
      # document in a localized-variation-context.
      class IndexingDupsLocalizedLocalizedClusterTargetLink
        include Google::Apis::Core::Hashable
      
        # Basic information about the link target, i.e. the URL or the language code it'
        # s believed to represent.
        # Corresponds to the JSON property `linkData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkLink]
        attr_accessor :link_data
      
        # Information derived from alexandria when processing the cross-link validation (
        # e.g. when this was done the last time, or when we started to see the outlink
        # for the first time).
        # Corresponds to the JSON property `metaData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkMetadata]
        attr_accessor :meta_data
      
        # Information about the URLs being validated.
        # Corresponds to the JSON property `targetDocData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkTargetDocData]
        attr_accessor :target_doc_data
      
        # 
        # Corresponds to the JSON property `validationStatus`
        # @return [String]
        attr_accessor :validation_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @link_data = args[:link_data] if args.key?(:link_data)
          @meta_data = args[:meta_data] if args.key?(:meta_data)
          @target_doc_data = args[:target_doc_data] if args.key?(:target_doc_data)
          @validation_status = args[:validation_status] if args.key?(:validation_status)
        end
      end
      
      # Basic information about the link target, i.e. the URL or the language code it'
      # s believed to represent.
      class IndexingDupsLocalizedLocalizedClusterTargetLinkLink
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotationSourceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkLinkAnnotationSourceInfo>]
        attr_accessor :annotation_source_info
      
        # For a link A->B where B is represented by this proto, cross_domain := Host(A) !
        # = Host(B).
        # Corresponds to the JSON property `crossDomain`
        # @return [Boolean]
        attr_accessor :cross_domain
        alias_method :cross_domain?, :cross_domain
      
        # The URL the information in TargetLink refers to.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_source_info = args[:annotation_source_info] if args.key?(:annotation_source_info)
          @cross_domain = args[:cross_domain] if args.key?(:cross_domain)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Message describing where was the link discovered and with what language
      # annotation.
      class IndexingDupsLocalizedLocalizedClusterTargetLinkLinkAnnotationSourceInfo
        include Google::Apis::Core::Hashable
      
        # Optional field for storing the anchor text the language code was extracted
        # from. Applies to outlinks only.
        # Corresponds to the JSON property `anchorText`
        # @return [String]
        attr_accessor :anchor_text
      
        # Information about where the language code was extracted from.
        # Corresponds to the JSON property `annotationSource`
        # @return [String]
        attr_accessor :annotation_source
      
        # Language code extracted from the URL (hreflang or outlink). One URL can
        # represent multiple language codes, like e.g. de-at and de-ch
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # Optional field that stores the feed URL where a Sitemap annotation was
        # discovered. Only populated if annotation_source is SITEMAP.
        # Corresponds to the JSON property `sourceFeedUrl`
        # @return [String]
        attr_accessor :source_feed_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_text = args[:anchor_text] if args.key?(:anchor_text)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @language_code = args[:language_code] if args.key?(:language_code)
          @source_feed_url = args[:source_feed_url] if args.key?(:source_feed_url)
        end
      end
      
      # Information derived from alexandria when processing the cross-link validation (
      # e.g. when this was done the last time, or when we started to see the outlink
      # for the first time).
      class IndexingDupsLocalizedLocalizedClusterTargetLinkMetadata
        include Google::Apis::Core::Hashable
      
        # When was the first time a link seen. Defaults to last crawled timestamp.
        # Corresponds to the JSON property `firstSeenMs`
        # @return [Fixnum]
        attr_accessor :first_seen_ms
      
        # When was the last time a link validated. Validation is the process of (re)
        # reading the relevant information for a linked document from its respective row
        # in the document table. Data needed for understanding the correctness of the
        # cluster is copied over to have it available locally.
        # Corresponds to the JSON property `lastVerifiedMs`
        # @return [Fixnum]
        attr_accessor :last_verified_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @first_seen_ms = args[:first_seen_ms] if args.key?(:first_seen_ms)
          @last_verified_ms = args[:last_verified_ms] if args.key?(:last_verified_ms)
        end
      end
      
      # 
      class IndexingDupsLocalizedLocalizedClusterTargetLinkSets
        include Google::Apis::Core::Hashable
      
        # Direct links are the simplest scenarios where A simply links to B.
        # Corresponds to the JSON property `directTargetLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLink>]
        attr_accessor :direct_target_link
      
        # Repeated field for URLs that are not directly linking to the document
        # TargetLink refers to. We can encounter the following scenario: A -> Links to B
        # -> links to C (i.e. without (A) linking to (C)). In the context of B,
        # indirect_inclusion would include the link to 'C' but not the link back to 'A'.
        # Corresponds to the JSON property `indirectTargetLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLink>]
        attr_accessor :indirect_target_link
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @direct_target_link = args[:direct_target_link] if args.key?(:direct_target_link)
          @indirect_target_link = args[:indirect_target_link] if args.key?(:indirect_target_link)
        end
      end
      
      # Information about the URLs being validated.
      class IndexingDupsLocalizedLocalizedClusterTargetLinkTargetDocData
        include Google::Apis::Core::Hashable
      
        # The detected on-page content language of the document.
        # Corresponds to the JSON property `contentLanguage`
        # @return [String]
        attr_accessor :content_language
      
        # 
        # Corresponds to the JSON property `crawlStatus`
        # @return [String]
        attr_accessor :crawl_status
      
        # The timestamp of the last crawl attempt from crawl_timestamp column.
        # Corresponds to the JSON property `crawlTimestampSeconds`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp_seconds
      
        # Whether the URL being validated is canonical at the time of processing.
        # Corresponds to the JSON property `isCanonical`
        # @return [Boolean]
        attr_accessor :is_canonical
        alias_method :is_canonical?, :is_canonical
      
        # Repeated field for data about the outgoing hreflang links that appear in the
        # document that the currently processed URL refers to.
        # Corresponds to the JSON property `outgoingLinkData`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedClusterTargetLinkLink>]
        attr_accessor :outgoing_link_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_language = args[:content_language] if args.key?(:content_language)
          @crawl_status = args[:crawl_status] if args.key?(:crawl_status)
          @crawl_timestamp_seconds = args[:crawl_timestamp_seconds] if args.key?(:crawl_timestamp_seconds)
          @is_canonical = args[:is_canonical] if args.key?(:is_canonical)
          @outgoing_link_data = args[:outgoing_link_data] if args.key?(:outgoing_link_data)
        end
      end
      
      # This protobuf is used (1) To pass data between EmbeddedExporter and the
      # publisher, and (2) As a member of CompositeDoc, to stick embedded content
      # output into the docjoins. Next tag available: 21
      class IndexingEmbeddedContentEmbeddedContentInfo
        include Google::Apis::Core::Hashable
      
        # The document's DOM and render tree produced by WebKit as a side effect of
        # rendering the page. It might be compressed or not. Thus, use indexing::
        # embedded_content::UncompressWebkitDocument to decode it.
        # Corresponds to the JSON property `compressedDocumentTrees`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :compressed_document_trees
      
        # The converted contents, as produced by the same DocumentUpdater transaction
        # that generated the render tree. Useful whenever one of our users wants to
        # experiment with deriving an annotation from the render tree.
        # Corresponds to the JSON property `convertedContents`
        # @return [String]
        attr_accessor :converted_contents
      
        # Information about all external resources needed to render this page, a.k.a.
        # embedded links. This includes .css files, images embedded in a page, external
        # javascripts, iframes etc.
        # Corresponds to the JSON property `embeddedLinksInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentEmbeddedLinksInfo]
        attr_accessor :embedded_links_info
      
        # See go/wrs-render-quality for how to evaluate the results. Next id: 24
        # Corresponds to the JSON property `headlessResponse`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderResponse]
        attr_accessor :headless_response
      
        # Indicate if the snapshot is generated from alternate snapshot. If true, the
        # snapshot will be exported even if the snapshot quality score is low.
        # Corresponds to the JSON property `isAlternateSnapshot`
        # @return [Boolean]
        attr_accessor :is_alternate_snapshot
        alias_method :is_alternate_snapshot?, :is_alternate_snapshot
      
        # The original encoding of the content crawled from trawler. It's the value of
        # enum i18n::encodings::encoding. We put a int32 here instead of encoding proto
        # to maintain the compatibility of "py_api_version = 1"
        # Corresponds to the JSON property `originalEncoding`
        # @return [Fixnum]
        attr_accessor :original_encoding
      
        # The proto to be stored in raw_redirect_info column of document table.
        # Corresponds to the JSON property `rawRedirectInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRawRedirectInfo]
        attr_accessor :raw_redirect_info
      
        # Information about all external resources used to render this page, a.k.a.
        # embedded links. This includes .css files, images embedded in a page, external
        # javascripts, iframes etc.
        # Corresponds to the JSON property `referencedResource`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoReferencedResource>]
        attr_accessor :referenced_resource
      
        # Only exist in dry run mode.
        # Corresponds to the JSON property `renderedSnapshot`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoImage]
        attr_accessor :rendered_snapshot
      
        # Snapshot image of a rendered html document (possibly encoded as png, jpeg, or
        # webp).
        # Corresponds to the JSON property `renderedSnapshotImage`
        # @return [String]
        attr_accessor :rendered_snapshot_image
      
        # A collection of values which are needed by the users of the Kodachrome
        # bigtable.
        # Corresponds to the JSON property `renderedSnapshotMetadata`
        # @return [Google::Apis::ContentwarehouseV1::SnapshotSnapshotMetadata]
        attr_accessor :rendered_snapshot_metadata
      
        # The quality of the image, 0.0 is the worst, 1.0 is the best. If all
        # dependencies are successfully crawled, the quality should be 1.0. If one or
        # more of the dependencies are unknown, the quality will be lower.
        # Corresponds to the JSON property `renderedSnapshotQualityScore`
        # @return [Float]
        attr_accessor :rendered_snapshot_quality_score
      
        # Small values from rendering output. It's stored as a column in alexandria
        # document table. Next tag available: 30
        # Corresponds to the JSON property `renderingOutputMetadata`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentRenderingOutputMetadata]
        attr_accessor :rendering_output_metadata
      
        # Contains information about 3 versions of the content of a document: 1.
        # Original: the crawled content (possibly patched in ConversionFilters). 2.
        # Processed: the final version of the content indexed in Web search. 3.
        # Intermediate (no longer generated): intermediate version between the original
        # and the processed content. All 3 versions of the content consist of HTTP
        # headers (in unknown encoding) concatenated with the document body (in
        # interchange valid UTF-8 encoding).
        # Corresponds to the JSON property `richcontentData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRichContentData]
        attr_accessor :richcontent_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compressed_document_trees = args[:compressed_document_trees] if args.key?(:compressed_document_trees)
          @converted_contents = args[:converted_contents] if args.key?(:converted_contents)
          @embedded_links_info = args[:embedded_links_info] if args.key?(:embedded_links_info)
          @headless_response = args[:headless_response] if args.key?(:headless_response)
          @is_alternate_snapshot = args[:is_alternate_snapshot] if args.key?(:is_alternate_snapshot)
          @original_encoding = args[:original_encoding] if args.key?(:original_encoding)
          @raw_redirect_info = args[:raw_redirect_info] if args.key?(:raw_redirect_info)
          @referenced_resource = args[:referenced_resource] if args.key?(:referenced_resource)
          @rendered_snapshot = args[:rendered_snapshot] if args.key?(:rendered_snapshot)
          @rendered_snapshot_image = args[:rendered_snapshot_image] if args.key?(:rendered_snapshot_image)
          @rendered_snapshot_metadata = args[:rendered_snapshot_metadata] if args.key?(:rendered_snapshot_metadata)
          @rendered_snapshot_quality_score = args[:rendered_snapshot_quality_score] if args.key?(:rendered_snapshot_quality_score)
          @rendering_output_metadata = args[:rendering_output_metadata] if args.key?(:rendering_output_metadata)
          @richcontent_data = args[:richcontent_data] if args.key?(:richcontent_data)
        end
      end
      
      # 
      class IndexingEmbeddedContentEmbeddedLinksInfo
        include Google::Apis::Core::Hashable
      
        # This field is optional only because we're adding it late and want to support
        # records written before that. For newly produced records, this field should
        # always be set.
        # Corresponds to the JSON property `embedderInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentEmbedderInfo]
        attr_accessor :embedder_info
      
        # 
        # Corresponds to the JSON property `link`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentLinkInfo>]
        attr_accessor :link
      
        # Page download size information.
        # Corresponds to the JSON property `pageSizeInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentPageSizeInfo]
        attr_accessor :page_size_info
      
        # This field is the sum of http_response_length for the embedder and all
        # embedded resources. This is expected to be set only in the docjoins, not in
        # the pinax tables or the exported bigtable.
        # Corresponds to the JSON property `sumHttpResponseLength`
        # @return [Fixnum]
        attr_accessor :sum_http_response_length
      
        # 
        # Corresponds to the JSON property `uncrawledLinkUrl`
        # @return [Array<String>]
        attr_accessor :uncrawled_link_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @embedder_info = args[:embedder_info] if args.key?(:embedder_info)
          @link = args[:link] if args.key?(:link)
          @page_size_info = args[:page_size_info] if args.key?(:page_size_info)
          @sum_http_response_length = args[:sum_http_response_length] if args.key?(:sum_http_response_length)
          @uncrawled_link_url = args[:uncrawled_link_url] if args.key?(:uncrawled_link_url)
        end
      end
      
      # 
      class IndexingEmbeddedContentEmbedderInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `importanceAsEmbedder`
        # @return [Fixnum]
        attr_accessor :importance_as_embedder
      
        # Information about one embedded link. Next tag: 18
        # Corresponds to the JSON property `linkInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentLinkInfo]
        attr_accessor :link_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @importance_as_embedder = args[:importance_as_embedder] if args.key?(:importance_as_embedder)
          @link_info = args[:link_info] if args.key?(:link_info)
        end
      end
      
      # Log how many urls finally goes to trawler on a host in rendering.
      class IndexingEmbeddedContentFetchHostCount
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `counter`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentFetchHostCountCounter>]
        attr_accessor :counter
      
        # 
        # Corresponds to the JSON property `host`
        # @return [String]
        attr_accessor :host
      
        # 
        # Corresponds to the JSON property `num`
        # @return [Fixnum]
        attr_accessor :num
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @counter = args[:counter] if args.key?(:counter)
          @host = args[:host] if args.key?(:host)
          @num = args[:num] if args.key?(:num)
        end
      end
      
      # 
      class IndexingEmbeddedContentFetchHostCountCounter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `num`
        # @return [Fixnum]
        attr_accessor :num
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @num = args[:num] if args.key?(:num)
        end
      end
      
      # Capsulate all metadata annotated from fetch server. This message will
      # typically go through: - EmbeddedContentFetcher, or - EmbeddedLinkGetter->
      # DenormalizedContent -> ContentStore. And finally deposit in
      # referenced_resources and link_info.
      class IndexingEmbeddedContentFetchUrlResponseMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `adsResourceType`
        # @return [String]
        attr_accessor :ads_resource_type
      
        # The field always exists, and has four options: UNKNOWN, CONTENT, ROBOTED and
        # ERROR, which are defined in indexing.converter.CrawlStatus.
        # Corresponds to the JSON property `crawlStatus`
        # @return [Fixnum]
        attr_accessor :crawl_status
      
        # 
        # Corresponds to the JSON property `criticalResourceType`
        # @return [String]
        attr_accessor :critical_resource_type
      
        # True if the response is fetched with SMARTPHONE user agent.
        # Corresponds to the JSON property `fetchWithSmartphoneUa`
        # @return [Boolean]
        attr_accessor :fetch_with_smartphone_ua
        alias_method :fetch_with_smartphone_ua?, :fetch_with_smartphone_ua
      
        # 
        # Corresponds to the JSON property `isAdsResource`
        # @return [Boolean]
        attr_accessor :is_ads_resource
        alias_method :is_ads_resource?, :is_ads_resource
      
        # 
        # Corresponds to the JSON property `isCriticalResource`
        # @return [Boolean]
        attr_accessor :is_critical_resource
        alias_method :is_critical_resource?, :is_critical_resource
      
        # 
        # Corresponds to the JSON property `isTrivialResource`
        # @return [Boolean]
        attr_accessor :is_trivial_resource
        alias_method :is_trivial_resource?, :is_trivial_resource
      
        # Number of trawler fetches while fetching this URL. In most cases, this number
        # will be 0 or 1.
        # Corresponds to the JSON property `numTrawlerFetches`
        # @return [Fixnum]
        attr_accessor :num_trawler_fetches
      
        # Used for logging purposes only here.
        # Corresponds to the JSON property `rewriteMethod`
        # @return [String]
        attr_accessor :rewrite_method
      
        # Robots Info encapsulates all robots.txt or related information that we know
        # about the Document collected from multiple sources such as HTTP headers, meta
        # robots tags etc.
        # Corresponds to the JSON property `robotsInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingConverterRobotsInfo]
        attr_accessor :robots_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ads_resource_type = args[:ads_resource_type] if args.key?(:ads_resource_type)
          @crawl_status = args[:crawl_status] if args.key?(:crawl_status)
          @critical_resource_type = args[:critical_resource_type] if args.key?(:critical_resource_type)
          @fetch_with_smartphone_ua = args[:fetch_with_smartphone_ua] if args.key?(:fetch_with_smartphone_ua)
          @is_ads_resource = args[:is_ads_resource] if args.key?(:is_ads_resource)
          @is_critical_resource = args[:is_critical_resource] if args.key?(:is_critical_resource)
          @is_trivial_resource = args[:is_trivial_resource] if args.key?(:is_trivial_resource)
          @num_trawler_fetches = args[:num_trawler_fetches] if args.key?(:num_trawler_fetches)
          @rewrite_method = args[:rewrite_method] if args.key?(:rewrite_method)
          @robots_info = args[:robots_info] if args.key?(:robots_info)
        end
      end
      
      # Information about one embedded link. Next tag: 18
      class IndexingEmbeddedContentLinkInfo
        include Google::Apis::Core::Hashable
      
        # Size of the HTTP body (payload of the HTTP response, excluding headers), pre-
        # decompression. Equal to the value of the Content-Length header if any. NOTE:
        # if this proto is converted to from ReferencedResource, we have to use the size
        # of the full HTTP response (i.e. http_response_length) as an approximation, as
        # we could not get the size of HTTP headers.
        # Corresponds to the JSON property `contentLength`
        # @return [Fixnum]
        attr_accessor :content_length
      
        # 
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # Time spent downloading this resource, in milliseconds. Not a timestamp!
        # Corresponds to the JSON property `crawlDuration`
        # @return [Fixnum]
        attr_accessor :crawl_duration
      
        # Enum values for crawl_status are defined in indexing/converter/proto/converter.
        # proto
        # Corresponds to the JSON property `crawlStatus`
        # @return [Fixnum]
        attr_accessor :crawl_status
      
        # 
        # Corresponds to the JSON property `crawlTimestamp`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp
      
        # 
        # Corresponds to the JSON property `deprecatedRedirect`
        # @return [Array<String>]
        attr_accessor :deprecated_redirect
      
        # Where this resource comes from.
        # Corresponds to the JSON property `fetchSourceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::WirelessTranscoderFetchFetchSourceInfo>]
        attr_accessor :fetch_source_info
      
        # Fetch status from trawler.
        # Corresponds to the JSON property `fetchStatus`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchStatus]
        attr_accessor :fetch_status
      
        # Capsulate all metadata annotated from fetch server. This message will
        # typically go through: - EmbeddedContentFetcher, or - EmbeddedLinkGetter->
        # DenormalizedContent -> ContentStore. And finally deposit in
        # referenced_resources and link_info.
        # Corresponds to the JSON property `fetchUrlResponseMetadata`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentFetchUrlResponseMetadata]
        attr_accessor :fetch_url_response_metadata
      
        # Fetcher -> FetchClient FetchReplyData is the metadata for a reply from a
        # FetchRequest. For metadata + document body, FetchReply is further below. NOTE:
        # FetchReplyData (and FetchReply) is the output interface from Multiverse. Teams
        # outside Multiverse/Trawler should not create fake FetchReplies. Trawler: When
        # adding new fields here, it is recommended that at least the following be
        # rebuilt and pushed: - cron_fetcher_index mapreduces: so that UrlReplyIndex,
        # etc. retain the new fields - tlookup, tlookup_server: want to be able to
        # return the new fields - logviewer, fetchutil: annoying to get back 'tag88:' in
        # results -------------------------- Next Tag: 124 -----------------------
        # Corresponds to the JSON property `frd`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyData]
        attr_accessor :frd
      
        # Size of the full HTTP response (headers and body pre-decompression).
        # Semantically equal to content_length plus size of the HTTP headers.
        # Corresponds to the JSON property `httpResponseLength`
        # @return [Fixnum]
        attr_accessor :http_response_length
      
        # 
        # Corresponds to the JSON property `isCacheable`
        # @return [Boolean]
        attr_accessor :is_cacheable
        alias_method :is_cacheable?, :is_cacheable
      
        # 
        # Corresponds to the JSON property `isRobotedContentFromFastnet`
        # @return [Boolean]
        attr_accessor :is_roboted_content_from_fastnet
        alias_method :is_roboted_content_from_fastnet?, :is_roboted_content_from_fastnet
      
        # Size of the HTTP body (payload of the HTTP response, excluding headers), post-
        # decompression. Equal to content_length if the body was not compressed to begin
        # with. NOTE: if this proto is converted to from ReferencedResource, we have to
        # use the size of the full HTTP response as an approximation, as we could not
        # get the size of HTTP headers.
        # Corresponds to the JSON property `uncompressedContentLength`
        # @return [Fixnum]
        attr_accessor :uncompressed_content_length
      
        # 
        # Corresponds to the JSON property `url`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :url
      
        # WebkKitFetchMetadata holds additional webkit-specific information for a single
        # resource fetch.
        # Corresponds to the JSON property `webkitFetchMetadata`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoWebKitFetchMetadata]
        attr_accessor :webkit_fetch_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_length = args[:content_length] if args.key?(:content_length)
          @content_type = args[:content_type] if args.key?(:content_type)
          @crawl_duration = args[:crawl_duration] if args.key?(:crawl_duration)
          @crawl_status = args[:crawl_status] if args.key?(:crawl_status)
          @crawl_timestamp = args[:crawl_timestamp] if args.key?(:crawl_timestamp)
          @deprecated_redirect = args[:deprecated_redirect] if args.key?(:deprecated_redirect)
          @fetch_source_info = args[:fetch_source_info] if args.key?(:fetch_source_info)
          @fetch_status = args[:fetch_status] if args.key?(:fetch_status)
          @fetch_url_response_metadata = args[:fetch_url_response_metadata] if args.key?(:fetch_url_response_metadata)
          @frd = args[:frd] if args.key?(:frd)
          @http_response_length = args[:http_response_length] if args.key?(:http_response_length)
          @is_cacheable = args[:is_cacheable] if args.key?(:is_cacheable)
          @is_roboted_content_from_fastnet = args[:is_roboted_content_from_fastnet] if args.key?(:is_roboted_content_from_fastnet)
          @uncompressed_content_length = args[:uncompressed_content_length] if args.key?(:uncompressed_content_length)
          @url = args[:url] if args.key?(:url)
          @webkit_fetch_metadata = args[:webkit_fetch_metadata] if args.key?(:webkit_fetch_metadata)
        end
      end
      
      # For each of the output fields generated by the embedded content system, the
      # Unix timestamp of when it was most recently generated. Used for controlling
      # the frequency of generation (and thus exporting) of the fields which are
      # expensive to generate and/or the consumers of which are not able to handle the
      # high load of daily/hourly updates. If a timestamp corresponding to an output
      # field is missing, it means the last attempt to generate this field failed (
      # which could be mean that the document was not important enough for this field
      # to be generated, or that we hit a bug in WebKit). In case we choose not to
      # regenerate the field (because the latest generation timestamp is too fresh)
      # the corresponding timestamp doesn't change. Next tag available: 8
      class IndexingEmbeddedContentOutputGenerationTimestamps
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `documentData`
        # @return [Fixnum]
        attr_accessor :document_data
      
        # 
        # Corresponds to the JSON property `renderedSnapshot`
        # @return [Fixnum]
        attr_accessor :rendered_snapshot
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_data = args[:document_data] if args.key?(:document_data)
          @rendered_snapshot = args[:rendered_snapshot] if args.key?(:rendered_snapshot)
        end
      end
      
      # Page download size information.
      class IndexingEmbeddedContentPageSizeInfo
        include Google::Apis::Core::Hashable
      
        # Images are also resources. num_images <= num_resources.
        # Corresponds to the JSON property `numImages`
        # @return [Fixnum]
        attr_accessor :num_images
      
        # Number of images whose crawl status is CONTENT.
        # Corresponds to the JSON property `numImagesWithContent`
        # @return [Fixnum]
        attr_accessor :num_images_with_content
      
        # Numbers below don't include embedder.
        # Corresponds to the JSON property `numResources`
        # @return [Fixnum]
        attr_accessor :num_resources
      
        # Number of resources whose crawl status is CONTENT.
        # Corresponds to the JSON property `numResourcesWithContent`
        # @return [Fixnum]
        attr_accessor :num_resources_with_content
      
        # Sum of embedder and all referenced resources.
        # Corresponds to the JSON property `sumHttpResponseLength`
        # @return [Fixnum]
        attr_accessor :sum_http_response_length
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_images = args[:num_images] if args.key?(:num_images)
          @num_images_with_content = args[:num_images_with_content] if args.key?(:num_images_with_content)
          @num_resources = args[:num_resources] if args.key?(:num_resources)
          @num_resources_with_content = args[:num_resources_with_content] if args.key?(:num_resources_with_content)
          @sum_http_response_length = args[:sum_http_response_length] if args.key?(:sum_http_response_length)
        end
      end
      
      # Fields used to track cache use in the rendering microservice. Next tag
      # available: 6
      class IndexingEmbeddedContentRenderCacheStats
        include Google::Apis::Core::Hashable
      
        # When the rendered content would expire from the cache in microseconds.
        # Corresponds to the JSON property `cacheExpireTimestampUsec`
        # @return [Fixnum]
        attr_accessor :cache_expire_timestamp_usec
      
        # 
        # Corresponds to the JSON property `crawledSimhashDistance`
        # @return [Fixnum]
        attr_accessor :crawled_simhash_distance
      
        # The last time the document was rendered, in microseconds. Does not update in
        # case of cache use.
        # Corresponds to the JSON property `lastRenderedTimestampUsec`
        # @return [Fixnum]
        attr_accessor :last_rendered_timestamp_usec
      
        # 
        # Corresponds to the JSON property `renderCache`
        # @return [String]
        attr_accessor :render_cache
      
        # 
        # Corresponds to the JSON property `renderedSimhashDistance`
        # @return [Fixnum]
        attr_accessor :rendered_simhash_distance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cache_expire_timestamp_usec = args[:cache_expire_timestamp_usec] if args.key?(:cache_expire_timestamp_usec)
          @crawled_simhash_distance = args[:crawled_simhash_distance] if args.key?(:crawled_simhash_distance)
          @last_rendered_timestamp_usec = args[:last_rendered_timestamp_usec] if args.key?(:last_rendered_timestamp_usec)
          @render_cache = args[:render_cache] if args.key?(:render_cache)
          @rendered_simhash_distance = args[:rendered_simhash_distance] if args.key?(:rendered_simhash_distance)
        end
      end
      
      # 
      class IndexingEmbeddedContentRenderRequestConfigConfigParams
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `virtualTime`
        # @return [Float]
        attr_accessor :virtual_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @virtual_time = args[:virtual_time] if args.key?(:virtual_time)
        end
      end
      
      # Fetch stats during rendering.
      class IndexingEmbeddedContentRenderingFetchStats
        include Google::Apis::Core::Hashable
      
        # A host->count mapping to log how many embedded_links in each host finally goes
        # to trawler during rendering.
        # Corresponds to the JSON property `fetchHostCount`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentFetchHostCount>]
        attr_accessor :fetch_host_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fetch_host_count = args[:fetch_host_count] if args.key?(:fetch_host_count)
        end
      end
      
      # Small values from rendering output. It's stored as a column in alexandria
      # document table. Next tag available: 30
      class IndexingEmbeddedContentRenderingOutputMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `configParams`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentRenderRequestConfigConfigParams]
        attr_accessor :config_params
      
        # The exceptions observed during the rendering. In bit-field encoding of enum
        # values of RenderResponse.RenderingException.
        # Corresponds to the JSON property `exceptions`
        # @return [Fixnum]
        attr_accessor :exceptions
      
        # Total GCU time for rendering the document in millisecond. This data is from
        # render_stats.render_cost_mgcu in RenderResponse proto. Note that this is *
        # experimental* field. Please check with rendering-infra@ if you want to use.
        # Corresponds to the JSON property `experimentalRenderTimeMsec`
        # @return [Fixnum]
        attr_accessor :experimental_render_time_msec
      
        # For each of the output fields generated by the embedded content system, the
        # Unix timestamp of when it was most recently generated. Used for controlling
        # the frequency of generation (and thus exporting) of the fields which are
        # expensive to generate and/or the consumers of which are not able to handle the
        # high load of daily/hourly updates. If a timestamp corresponding to an output
        # field is missing, it means the last attempt to generate this field failed (
        # which could be mean that the document was not important enough for this field
        # to be generated, or that we hit a bug in WebKit). In case we choose not to
        # regenerate the field (because the latest generation timestamp is too fresh)
        # the corresponding timestamp doesn't change. Next tag available: 8
        # Corresponds to the JSON property `generationTimestamps`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentOutputGenerationTimestamps]
        attr_accessor :generation_timestamps
      
        # The importance value of the rendered document.
        # Corresponds to the JSON property `importance`
        # @return [Fixnum]
        attr_accessor :importance
      
        # The timestamp of last new content probing.
        # Corresponds to the JSON property `lastNewContentProbingTimestamp`
        # @return [Fixnum]
        attr_accessor :last_new_content_probing_timestamp
      
        # Percentage of new tokens in the rendered the document content.
        # Corresponds to the JSON property `newTokensPercentageAfterRendering`
        # @return [Float]
        attr_accessor :new_tokens_percentage_after_rendering
      
        # 
        # Corresponds to the JSON property `numNewTokensFoundInRendering`
        # @return [Fixnum]
        attr_accessor :num_new_tokens_found_in_rendering
      
        # 
        # Corresponds to the JSON property `refresh`
        # @return [Boolean]
        attr_accessor :refresh
        alias_method :refresh?, :refresh
      
        # Fields used to track cache use in the rendering microservice. Next tag
        # available: 6
        # Corresponds to the JSON property `renderCacheStats`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentRenderCacheStats]
        attr_accessor :render_cache_stats
      
        # 
        # Corresponds to the JSON property `renderEngine`
        # @return [String]
        attr_accessor :render_engine
      
        # Different types of events which happened during rendering.
        # Corresponds to the JSON property `renderEvent`
        # @return [Array<Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoRenderEvent>]
        attr_accessor :render_event
      
        # The CL from which the render engine was built.
        # Corresponds to the JSON property `renderServerCl`
        # @return [Fixnum]
        attr_accessor :render_server_cl
      
        # 
        # Corresponds to the JSON property `renderTreeQualityScore`
        # @return [Float]
        attr_accessor :render_tree_quality_score
      
        # Short signature (usually less than 1 KB) which captures a perceptual hash on
        # the rendered image. This is used to determine whether successive renderings
        # should be output. See the library in googlen/snapshot/shared/similarity.* for
        # more info about how this value is interpreted and used.
        # Corresponds to the JSON property `renderedSnapshotSignature`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :rendered_snapshot_signature
      
        # Current time in microseconds the document is going through rendering system.
        # This field is set regardless of whether the document is being rendered or if
        # we are skipping rendering by using a cache.
        # Corresponds to the JSON property `renderedTimeUsec`
        # @return [Fixnum]
        attr_accessor :rendered_time_usec
      
        # Fetch stats during rendering.
        # Corresponds to the JSON property `renderingFetchStats`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentRenderingFetchStats]
        attr_accessor :rendering_fetch_stats
      
        # Output that indicates a url should be in our corpus.
        # Corresponds to the JSON property `selectionResult`
        # @return [Google::Apis::ContentwarehouseV1::IndexingEmbeddedContentSelectionResult]
        attr_accessor :selection_result
      
        # These scores are copied from htmlrender_webkit_headless_proto.Document.
        # Corresponds to the JSON property `snapshotQualityScore`
        # @return [Float]
        attr_accessor :snapshot_quality_score
      
        # True if there were any missing resources during the rendering.
        # Corresponds to the JSON property `withMissingResources`
        # @return [Boolean]
        attr_accessor :with_missing_resources
        alias_method :with_missing_resources?, :with_missing_resources
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @config_params = args[:config_params] if args.key?(:config_params)
          @exceptions = args[:exceptions] if args.key?(:exceptions)
          @experimental_render_time_msec = args[:experimental_render_time_msec] if args.key?(:experimental_render_time_msec)
          @generation_timestamps = args[:generation_timestamps] if args.key?(:generation_timestamps)
          @importance = args[:importance] if args.key?(:importance)
          @last_new_content_probing_timestamp = args[:last_new_content_probing_timestamp] if args.key?(:last_new_content_probing_timestamp)
          @new_tokens_percentage_after_rendering = args[:new_tokens_percentage_after_rendering] if args.key?(:new_tokens_percentage_after_rendering)
          @num_new_tokens_found_in_rendering = args[:num_new_tokens_found_in_rendering] if args.key?(:num_new_tokens_found_in_rendering)
          @refresh = args[:refresh] if args.key?(:refresh)
          @render_cache_stats = args[:render_cache_stats] if args.key?(:render_cache_stats)
          @render_engine = args[:render_engine] if args.key?(:render_engine)
          @render_event = args[:render_event] if args.key?(:render_event)
          @render_server_cl = args[:render_server_cl] if args.key?(:render_server_cl)
          @render_tree_quality_score = args[:render_tree_quality_score] if args.key?(:render_tree_quality_score)
          @rendered_snapshot_signature = args[:rendered_snapshot_signature] if args.key?(:rendered_snapshot_signature)
          @rendered_time_usec = args[:rendered_time_usec] if args.key?(:rendered_time_usec)
          @rendering_fetch_stats = args[:rendering_fetch_stats] if args.key?(:rendering_fetch_stats)
          @selection_result = args[:selection_result] if args.key?(:selection_result)
          @snapshot_quality_score = args[:snapshot_quality_score] if args.key?(:snapshot_quality_score)
          @with_missing_resources = args[:with_missing_resources] if args.key?(:with_missing_resources)
        end
      end
      
      # Output that indicates a url should be in our corpus.
      class IndexingEmbeddedContentSelectionResult
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `renderEffort`
        # @return [String]
        attr_accessor :render_effort
      
        # Indicate which selector has made the decision.
        # Corresponds to the JSON property `selectorId`
        # @return [String]
        attr_accessor :selector_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @render_effort = args[:render_effort] if args.key?(:render_effort)
          @selector_id = args[:selector_id] if args.key?(:selector_id)
        end
      end
      
      # 
      class IndexingMlVerticalVerticalItem
        include Google::Apis::Core::Hashable
      
        # Unique ID.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # The description name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The corresponding Petacat ID.
        # Corresponds to the JSON property `petacatId`
        # @return [Fixnum]
        attr_accessor :petacat_id
      
        # The probability of the vertical, whose value is in [0.0, 1.0].
        # Corresponds to the JSON property `probability`
        # @return [Float]
        attr_accessor :probability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @name = args[:name] if args.key?(:name)
          @petacat_id = args[:petacat_id] if args.key?(:petacat_id)
          @probability = args[:probability] if args.key?(:probability)
        end
      end
      
      # Desktop interstitials signal. The message contains both fields for site-level
      # signal lookup in Index Signals (go/index-signals) and fields for final
      # attachment in DocJoin.
      class IndexingMobileInterstitialsProtoDesktopInterstitials
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `details`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingMobileInterstitialsProtoDesktopInterstitialsDetails>]
        attr_accessor :details
      
        # Epoch of the interstitial offline pipeline generating this signal.
        # Corresponds to the JSON property `pipelineEpoch`
        # @return [String]
        attr_accessor :pipeline_epoch
      
        # If present, pipeline_pattern identifies the cluster of URLs for which the
        # signal value was smeared.
        # Corresponds to the JSON property `pipelinePattern`
        # @return [String]
        attr_accessor :pipeline_pattern
      
        # URL tree of interstitial patterns belong to the host, to be used as site-level
        # signal in Index Signals. A pattern may contain a payload
        # InterstitialPatternPayload, which will indicate the violated interstitial
        # types of this pattern.
        # Corresponds to the JSON property `urlTree`
        # @return [Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlTree]
        attr_accessor :url_tree
      
        # Overall policy violation status. If this is true, at least one of the
        # InterstitialSignal below indicates a violation.
        # Corresponds to the JSON property `violatesDesktopInterstitialPolicy`
        # @return [Boolean]
        attr_accessor :violates_desktop_interstitial_policy
        alias_method :violates_desktop_interstitial_policy?, :violates_desktop_interstitial_policy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @details = args[:details] if args.key?(:details)
          @pipeline_epoch = args[:pipeline_epoch] if args.key?(:pipeline_epoch)
          @pipeline_pattern = args[:pipeline_pattern] if args.key?(:pipeline_pattern)
          @url_tree = args[:url_tree] if args.key?(:url_tree)
          @violates_desktop_interstitial_policy = args[:violates_desktop_interstitial_policy] if args.key?(:violates_desktop_interstitial_policy)
        end
      end
      
      # An optional message that may contain details of the signals computation.
      class IndexingMobileInterstitialsProtoDesktopInterstitialsDetails
        include Google::Apis::Core::Hashable
      
        # Basic interstitial info, shared by all layout types. This message can be used
        # to quickly iterate through detected interstitials, if layout type specific
        # details are not required. Note: this message stores info for one primary
        # interstitial as detected by a particular layout codepath. Some codepaths, e.g.
        # overlay interstitial detection, may find multiple interstitial candidates;
        # such details can be found in codepath-specific messages below.
        # Corresponds to the JSON property `basicInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingMobileInterstitialsProtoInterstitialBasicInfo]
        attr_accessor :basic_info
      
        # Indicates whether the signal value is "smeared", e.g. extrapolated from other
        # URLs.
        # Corresponds to the JSON property `isSmearedSignal`
        # @return [Boolean]
        attr_accessor :is_smeared_signal
        alias_method :is_smeared_signal?, :is_smeared_signal
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @basic_info = args[:basic_info] if args.key?(:basic_info)
          @is_smeared_signal = args[:is_smeared_signal] if args.key?(:is_smeared_signal)
        end
      end
      
      # Basic interstitial info, shared by all layout types. This message can be used
      # to quickly iterate through detected interstitials, if layout type specific
      # details are not required. Note: this message stores info for one primary
      # interstitial as detected by a particular layout codepath. Some codepaths, e.g.
      # overlay interstitial detection, may find multiple interstitial candidates;
      # such details can be found in codepath-specific messages below.
      class IndexingMobileInterstitialsProtoInterstitialBasicInfo
        include Google::Apis::Core::Hashable
      
        # A simple 2D box represented by an (x, y) coordinate, a width, and a height.
        # Coordinates are in pixels.
        # Corresponds to the JSON property `absoluteBox`
        # @return [Google::Apis::ContentwarehouseV1::HtmlrenderWebkitHeadlessProtoBox]
        attr_accessor :absolute_box
      
        # 
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # 
        # Corresponds to the JSON property `detectionMode`
        # @return [String]
        attr_accessor :detection_mode
      
        # 
        # Corresponds to the JSON property `layoutType`
        # @return [String]
        attr_accessor :layout_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @absolute_box = args[:absolute_box] if args.key?(:absolute_box)
          @content_type = args[:content_type] if args.key?(:content_type)
          @detection_mode = args[:detection_mode] if args.key?(:detection_mode)
          @layout_type = args[:layout_type] if args.key?(:layout_type)
        end
      end
      
      # Core Web Vitals (https://web.dev/vitals/) carried in VoltSignal: the field
      # data metrics extracted from UKM aggregated 75-percentile data.
      class IndexingMobileVoltCoreWebVitals
        include Google::Apis::Core::Hashable
      
        # Cumulative Layout Shift.
        # Corresponds to the JSON property `cls`
        # @return [Fixnum]
        attr_accessor :cls
      
        # First Input Delay.
        # Corresponds to the JSON property `fid`
        # @return [Fixnum]
        attr_accessor :fid
      
        # 
        # Corresponds to the JSON property `inp`
        # @return [Fixnum]
        attr_accessor :inp
      
        # Largest Contentful Paint.
        # Corresponds to the JSON property `lcp`
        # @return [Fixnum]
        attr_accessor :lcp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cls = args[:cls] if args.key?(:cls)
          @fid = args[:fid] if args.key?(:fid)
          @inp = args[:inp] if args.key?(:inp)
          @lcp = args[:lcp] if args.key?(:lcp)
        end
      end
      
      # The protocol buffer stored in the legacyperdocdata muppet attachment for VOLT (
      # go/volt). The data is used for ranking changes. Only CWV signals and secure
      # signal are stored. MobileFriendliness is stored separately in the
      # legacyperdocdata. Safe browsing and BAS/AER conditions are not used for
      # ranking.
      class IndexingMobileVoltVoltPerDocData
        include Google::Apis::Core::Hashable
      
        # Core Web Vitals (https://web.dev/vitals/) carried in VoltSignal: the field
        # data metrics extracted from UKM aggregated 75-percentile data.
        # Corresponds to the JSON property `desktopCwv`
        # @return [Google::Apis::ContentwarehouseV1::IndexingMobileVoltCoreWebVitals]
        attr_accessor :desktop_cwv
      
        # 
        # Corresponds to the JSON property `desktopDisplayUrlIsHttps`
        # @return [Boolean]
        attr_accessor :desktop_display_url_is_https
        alias_method :desktop_display_url_is_https?, :desktop_display_url_is_https
      
        # 
        # Corresponds to the JSON property `displayUrlIsHttps`
        # @return [Boolean]
        attr_accessor :display_url_is_https
        alias_method :display_url_is_https?, :display_url_is_https
      
        # Core Web Vitals (https://web.dev/vitals/) carried in VoltSignal: the field
        # data metrics extracted from UKM aggregated 75-percentile data.
        # Corresponds to the JSON property `mobileCwv`
        # @return [Google::Apis::ContentwarehouseV1::IndexingMobileVoltCoreWebVitals]
        attr_accessor :mobile_cwv
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @desktop_cwv = args[:desktop_cwv] if args.key?(:desktop_cwv)
          @desktop_display_url_is_https = args[:desktop_display_url_is_https] if args.key?(:desktop_display_url_is_https)
          @display_url_is_https = args[:display_url_is_https] if args.key?(:display_url_is_https)
          @mobile_cwv = args[:mobile_cwv] if args.key?(:mobile_cwv)
        end
      end
      
      # 
      class IndexingPrivacyAccessAccessRequirements
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `restrictionCategories`
        # @return [Array<String>]
        attr_accessor :restriction_categories
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @restriction_categories = args[:restriction_categories] if args.key?(:restriction_categories)
        end
      end
      
      # State data for AdaptiveFrequencyEstimator
      class IndexingSignalAggregatorAdaptiveIntervalData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `clicksGoodInterval`
        # @return [Float]
        attr_accessor :clicks_good_interval
      
        # 
        # Corresponds to the JSON property `clicksGoodPriorWeight`
        # @return [Float]
        attr_accessor :clicks_good_prior_weight
      
        # 
        # Corresponds to the JSON property `clicksTotalInterval`
        # @return [Float]
        attr_accessor :clicks_total_interval
      
        # 
        # Corresponds to the JSON property `clicksTotalPriorWeight`
        # @return [Float]
        attr_accessor :clicks_total_prior_weight
      
        # 
        # Corresponds to the JSON property `ctrwiInterval`
        # @return [Float]
        attr_accessor :ctrwi_interval
      
        # 
        # Corresponds to the JSON property `ctrwiPriorWeight`
        # @return [Float]
        attr_accessor :ctrwi_prior_weight
      
        # 
        # Corresponds to the JSON property `dwellsInterval`
        # @return [Float]
        attr_accessor :dwells_interval
      
        # 
        # Corresponds to the JSON property `dwellsPriorWeight`
        # @return [Float]
        attr_accessor :dwells_prior_weight
      
        # 
        # Corresponds to the JSON property `luDwellsInterval`
        # @return [Float]
        attr_accessor :lu_dwells_interval
      
        # 
        # Corresponds to the JSON property `luDwellsPriorWeight`
        # @return [Float]
        attr_accessor :lu_dwells_prior_weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @clicks_good_interval = args[:clicks_good_interval] if args.key?(:clicks_good_interval)
          @clicks_good_prior_weight = args[:clicks_good_prior_weight] if args.key?(:clicks_good_prior_weight)
          @clicks_total_interval = args[:clicks_total_interval] if args.key?(:clicks_total_interval)
          @clicks_total_prior_weight = args[:clicks_total_prior_weight] if args.key?(:clicks_total_prior_weight)
          @ctrwi_interval = args[:ctrwi_interval] if args.key?(:ctrwi_interval)
          @ctrwi_prior_weight = args[:ctrwi_prior_weight] if args.key?(:ctrwi_prior_weight)
          @dwells_interval = args[:dwells_interval] if args.key?(:dwells_interval)
          @dwells_prior_weight = args[:dwells_prior_weight] if args.key?(:dwells_prior_weight)
          @lu_dwells_interval = args[:lu_dwells_interval] if args.key?(:lu_dwells_interval)
          @lu_dwells_prior_weight = args[:lu_dwells_prior_weight] if args.key?(:lu_dwells_prior_weight)
        end
      end
      
      # Accumulated coverage data for an url using a constant half-life time. Next tag:
      # 28
      class IndexingSignalAggregatorAgeWeightedCoverageData
        include Google::Apis::Core::Hashable
      
        # Weighted averged timestamps of the decayed chances.
        # Corresponds to the JSON property `averageChanceTime`
        # @return [Float]
        attr_accessor :average_chance_time
      
        # Numbers below are all total in the decayed manner. To get rate of impression/
        # clicks, divide by chances.
        # Corresponds to the JSON property `chances`
        # @return [Float]
        attr_accessor :chances
      
        # 
        # Corresponds to the JSON property `clicksBad`
        # @return [Float]
        attr_accessor :clicks_bad
      
        # 
        # Corresponds to the JSON property `clicksGood`
        # @return [Float]
        attr_accessor :clicks_good
      
        # 
        # Corresponds to the JSON property `clicksImage`
        # @return [Float]
        attr_accessor :clicks_image
      
        # 
        # Corresponds to the JSON property `clicksTotal`
        # @return [Float]
        attr_accessor :clicks_total
      
        # 
        # Corresponds to the JSON property `clicksUnclassified`
        # @return [Float]
        attr_accessor :clicks_unclassified
      
        # Epoch seconds at which this weighted coverage data was calculated.
        # Corresponds to the JSON property `coverageTimestamp`
        # @return [Fixnum]
        attr_accessor :coverage_timestamp
      
        # 
        # Corresponds to the JSON property `ctrWeightedImpressions`
        # @return [Float]
        attr_accessor :ctr_weighted_impressions
      
        # Dwells from KnowledgePanel and WebAnswers.
        # Corresponds to the JSON property `dwells`
        # @return [Float]
        attr_accessor :dwells
      
        # Epoch seconds at which this url first gets coverage in BASE.
        # Corresponds to the JSON property `firstBaseCoverageTimestamp`
        # @return [Fixnum]
        attr_accessor :first_base_coverage_timestamp
      
        # The pagerank when the url was serving for the first time.
        # Corresponds to the JSON property `firstCoveragePagerankNs`
        # @return [Fixnum]
        attr_accessor :first_coverage_pagerank_ns
      
        # Epoch seconds at which this url first gets coverage data.
        # Corresponds to the JSON property `firstCoverageTimestamp`
        # @return [Fixnum]
        attr_accessor :first_coverage_timestamp
      
        # 
        # Corresponds to the JSON property `firstseen`
        # @return [Fixnum]
        attr_accessor :firstseen
      
        # 
        # Corresponds to the JSON property `impressions`
        # @return [Float]
        attr_accessor :impressions
      
        # State data for AdaptiveFrequencyEstimator
        # Corresponds to the JSON property `intervalData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAdaptiveIntervalData]
        attr_accessor :interval_data
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # Indicates the date when this document received the last KnowledgePanel or
        # WebAnswer dwell. Note: The date is identified in terms of number of days since
        # Epoch.
        # Corresponds to the JSON property `lastDwellDateInDays`
        # @return [Fixnum]
        attr_accessor :last_dwell_date_in_days
      
        # Indicates the date when this document received the last good click. Note: The
        # date is identified in terms of number of days since Epoch.
        # Corresponds to the JSON property `lastGoodClickDateInDays`
        # @return [Fixnum]
        attr_accessor :last_good_click_date_in_days
      
        # Indicates the date when this document received the last impression. Note: The
        # date is identified in terms of number of days since Epoch.
        # Corresponds to the JSON property `lastImpressionDateInDays`
        # @return [Fixnum]
        attr_accessor :last_impression_date_in_days
      
        # Indicates the date when this document received the last LocalUniversal dwell.
        # Note: The date is identified in terms of number of days since Epoch.
        # Corresponds to the JSON property `lastLuDwellDateInDays`
        # @return [Fixnum]
        attr_accessor :last_lu_dwell_date_in_days
      
        # Indicates the date when this document received the last pseudo-impression. I.e.
        # , when it was retrieved as a result but GWS would not show it because of the
        # document's age in the index. Note: The date is identified in terms of number
        # of days since Epoch.
        # Corresponds to the JSON property `lastPseudoImpressionsDateInDays`
        # @return [Fixnum]
        attr_accessor :last_pseudo_impressions_date_in_days
      
        # Dwells from LocalUniversal.
        # Corresponds to the JSON property `luDwells`
        # @return [Float]
        attr_accessor :lu_dwells
      
        # Repid in Alexandria pipeline.
        # Corresponds to the JSON property `repid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :repid
      
        # Total number of chances on this urls (not decayed).
        # Corresponds to the JSON property `totalChances`
        # @return [Fixnum]
        attr_accessor :total_chances
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Temporary variable, only used during mapreduce.
        # Corresponds to the JSON property `urlfp`
        # @return [Fixnum]
        attr_accessor :urlfp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_chance_time = args[:average_chance_time] if args.key?(:average_chance_time)
          @chances = args[:chances] if args.key?(:chances)
          @clicks_bad = args[:clicks_bad] if args.key?(:clicks_bad)
          @clicks_good = args[:clicks_good] if args.key?(:clicks_good)
          @clicks_image = args[:clicks_image] if args.key?(:clicks_image)
          @clicks_total = args[:clicks_total] if args.key?(:clicks_total)
          @clicks_unclassified = args[:clicks_unclassified] if args.key?(:clicks_unclassified)
          @coverage_timestamp = args[:coverage_timestamp] if args.key?(:coverage_timestamp)
          @ctr_weighted_impressions = args[:ctr_weighted_impressions] if args.key?(:ctr_weighted_impressions)
          @dwells = args[:dwells] if args.key?(:dwells)
          @first_base_coverage_timestamp = args[:first_base_coverage_timestamp] if args.key?(:first_base_coverage_timestamp)
          @first_coverage_pagerank_ns = args[:first_coverage_pagerank_ns] if args.key?(:first_coverage_pagerank_ns)
          @first_coverage_timestamp = args[:first_coverage_timestamp] if args.key?(:first_coverage_timestamp)
          @firstseen = args[:firstseen] if args.key?(:firstseen)
          @impressions = args[:impressions] if args.key?(:impressions)
          @interval_data = args[:interval_data] if args.key?(:interval_data)
          @language = args[:language] if args.key?(:language)
          @last_dwell_date_in_days = args[:last_dwell_date_in_days] if args.key?(:last_dwell_date_in_days)
          @last_good_click_date_in_days = args[:last_good_click_date_in_days] if args.key?(:last_good_click_date_in_days)
          @last_impression_date_in_days = args[:last_impression_date_in_days] if args.key?(:last_impression_date_in_days)
          @last_lu_dwell_date_in_days = args[:last_lu_dwell_date_in_days] if args.key?(:last_lu_dwell_date_in_days)
          @last_pseudo_impressions_date_in_days = args[:last_pseudo_impressions_date_in_days] if args.key?(:last_pseudo_impressions_date_in_days)
          @lu_dwells = args[:lu_dwells] if args.key?(:lu_dwells)
          @repid = args[:repid] if args.key?(:repid)
          @total_chances = args[:total_chances] if args.key?(:total_chances)
          @url = args[:url] if args.key?(:url)
          @urlfp = args[:urlfp] if args.key?(:urlfp)
        end
      end
      
      # Aggregated signal used by NumericSignalAggregator. Next field id: 25
      class IndexingSignalAggregatorAggregatedScore
        include Google::Apis::Core::Hashable
      
        # A number reflecting the deviation of Url scores.
        # Corresponds to the JSON property `deviation`
        # @return [Float]
        attr_accessor :deviation
      
        # State variables for West & Chan variance algorithm used to be stored here
        # directly. Now they are stored inside RunningMeanAndVarianceInternalState.
        # Corresponds to the JSON property `m2`
        # @return [Float]
        attr_accessor :m2
      
        # Representation of numeric signal of a url.
        # Corresponds to the JSON property `maxScoreUrl`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlScore]
        attr_accessor :max_score_url
      
        # 
        # Corresponds to the JSON property `mean`
        # @return [Float]
        attr_accessor :mean
      
        # Overall stats that are only available in final aggregation results. The
        # aggregated score.
        # Corresponds to the JSON property `meanScore`
        # @return [Float]
        attr_accessor :mean_score
      
        # Representation of numeric signal of a url.
        # Corresponds to the JSON property `minScoreUrl`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlScore]
        attr_accessor :min_score_url
      
        # 
        # Corresponds to the JSON property `numImportantUrls`
        # @return [Fixnum]
        attr_accessor :num_important_urls
      
        # Final Stats that are also available in intermediate output. Number of Urls
        # matching the class.
        # Corresponds to the JSON property `numUrlsMatched`
        # @return [Fixnum]
        attr_accessor :num_urls_matched
      
        # Not every matching url has a signal.
        # Corresponds to the JSON property `numUrlsWithSignal`
        # @return [Fixnum]
        attr_accessor :num_urls_with_signal
      
        # Experimental layer of the corresponding pattern.
        # Corresponds to the JSON property `patternLayer`
        # @return [String]
        attr_accessor :pattern_layer
      
        # Optionally populated in mediators. A list of patterns that actually
        # contributed to the final mediated signal.
        # Corresponds to the JSON property `patternsUsedInMediation`
        # @return [Array<String>]
        attr_accessor :patterns_used_in_mediation
      
        # Score percentile of matching urls. If present, it has N entries for buckets of
        # roughly equal number of urls. N is specified the aggregation. The value is the
        # min score in that bucket.
        # Corresponds to the JSON property `percentile`
        # @return [Array<Float>]
        attr_accessor :percentile
      
        # Internal state of the West & Chan running variance algorithm. Fields of this
        # proto should not be accessed directly; instead, please use
        # RunningMeanAndVarianceUtil. The fields of this message only have meaning in
        # the context of the West & Chan algorithm, which is documented (or Wikipedia-
        # linked) in the doc comments of RunningMeanAndVarianceUtil. We do however give
        # some explanation of the meanings of these fields in the context of the
        # algorithm (i.e. if you have the Wikipedia page open and are ready to do some
        # math). Also see the file doc of RunningMeanAndVarianceUtil for a specification
        # and more info about the algorithm. Notation: The data set is X = `(x_1, w_1), .
        # .., (x_n, w_n)`. It consists of n weighted data points. The ith data point has
        # value x_i and weight w_i. REQUIRES: x_i is finite for each i. w_i is finite
        # for each i. w_i >= 0 for each i.
        # Corresponds to the JSON property `runningMeanAndVarianceInternalState`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorRunningMeanAndVarianceInternalState]
        attr_accessor :running_mean_and_variance_internal_state
      
        # Random samples.
        # Corresponds to the JSON property `samples`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlScore>]
        attr_accessor :samples
      
        # for calculating percentile
        # Corresponds to the JSON property `scores`
        # @return [Array<Float>]
        attr_accessor :scores
      
        # For debugging purposes, this is an id of the signal associated with this
        # AggregatedScore. For pattern score, this may be the length of the pattern.
        # Corresponds to the JSON property `signalId`
        # @return [Fixnum]
        attr_accessor :signal_id
      
        # Representation of numeric signal of a url.
        # Corresponds to the JSON property `singleUrlScore`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlScore]
        attr_accessor :single_url_score
      
        # summation varaible used to get mean
        # Corresponds to the JSON property `totalScore`
        # @return [Float]
        attr_accessor :total_score
      
        # low-order part of total_score
        # Corresponds to the JSON property `totalScoreLow`
        # @return [Float]
        attr_accessor :total_score_low
      
        # summation variable for calculating deviation note, these are now only used for
        # legacy and debugging purposes
        # Corresponds to the JSON property `totalScoreSqr`
        # @return [Float]
        attr_accessor :total_score_sqr
      
        # low order part of total_score_sq
        # Corresponds to the JSON property `totalScoreSqrLow`
        # @return [Float]
        attr_accessor :total_score_sqr_low
      
        # for calculating weighted mean/dev
        # Corresponds to the JSON property `totalWeight`
        # @return [Float]
        attr_accessor :total_weight
      
        # low order part of total_weight
        # Corresponds to the JSON property `totalWeightLow`
        # @return [Float]
        attr_accessor :total_weight_low
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deviation = args[:deviation] if args.key?(:deviation)
          @m2 = args[:m2] if args.key?(:m2)
          @max_score_url = args[:max_score_url] if args.key?(:max_score_url)
          @mean = args[:mean] if args.key?(:mean)
          @mean_score = args[:mean_score] if args.key?(:mean_score)
          @min_score_url = args[:min_score_url] if args.key?(:min_score_url)
          @num_important_urls = args[:num_important_urls] if args.key?(:num_important_urls)
          @num_urls_matched = args[:num_urls_matched] if args.key?(:num_urls_matched)
          @num_urls_with_signal = args[:num_urls_with_signal] if args.key?(:num_urls_with_signal)
          @pattern_layer = args[:pattern_layer] if args.key?(:pattern_layer)
          @patterns_used_in_mediation = args[:patterns_used_in_mediation] if args.key?(:patterns_used_in_mediation)
          @percentile = args[:percentile] if args.key?(:percentile)
          @running_mean_and_variance_internal_state = args[:running_mean_and_variance_internal_state] if args.key?(:running_mean_and_variance_internal_state)
          @samples = args[:samples] if args.key?(:samples)
          @scores = args[:scores] if args.key?(:scores)
          @signal_id = args[:signal_id] if args.key?(:signal_id)
          @single_url_score = args[:single_url_score] if args.key?(:single_url_score)
          @total_score = args[:total_score] if args.key?(:total_score)
          @total_score_low = args[:total_score_low] if args.key?(:total_score_low)
          @total_score_sqr = args[:total_score_sqr] if args.key?(:total_score_sqr)
          @total_score_sqr_low = args[:total_score_sqr_low] if args.key?(:total_score_sqr_low)
          @total_weight = args[:total_weight] if args.key?(:total_weight)
          @total_weight_low = args[:total_weight_low] if args.key?(:total_weight_low)
        end
      end
      
      # Internal state of the West & Chan running variance algorithm. Fields of this
      # proto should not be accessed directly; instead, please use
      # RunningMeanAndVarianceUtil. The fields of this message only have meaning in
      # the context of the West & Chan algorithm, which is documented (or Wikipedia-
      # linked) in the doc comments of RunningMeanAndVarianceUtil. We do however give
      # some explanation of the meanings of these fields in the context of the
      # algorithm (i.e. if you have the Wikipedia page open and are ready to do some
      # math). Also see the file doc of RunningMeanAndVarianceUtil for a specification
      # and more info about the algorithm. Notation: The data set is X = `(x_1, w_1), .
      # .., (x_n, w_n)`. It consists of n weighted data points. The ith data point has
      # value x_i and weight w_i. REQUIRES: x_i is finite for each i. w_i is finite
      # for each i. w_i >= 0 for each i.
      class IndexingSignalAggregatorRunningMeanAndVarianceInternalState
        include Google::Apis::Core::Hashable
      
        # The variable which in the Wikipedia page is referred to as M_2: m2 = w_1 * (
        # x_1 - mean)^2 + ... + w_n * (x_n - mean)^2. The algorithm implemented in
        # RunningMeanAndVarianceUtil provides a way to update m2 in a numerically stable
        # way when the data set grows. If total_weight = 0, then m2 is meaningless, and
        # its value is unspecified, except that it must be finite and >= 0.
        # Corresponds to the JSON property `m2`
        # @return [Float]
        attr_accessor :m2
      
        # Mean of the data set, mean = (w_1 * x_1 + ... + w_n * x_n) / total_weight. The
        # algorithm implemented in RunningMeanAndVarianceUtil provides a way to update
        # this mean in a numerically stable way when the data set grows. If total_weight
        # = 0, then mean is meaningless, and its value is unspecified, except that it
        # must be finite.
        # Corresponds to the JSON property `mean`
        # @return [Float]
        attr_accessor :mean
      
        # Total weight of the data set, total_weight = w_1 + ... + w_n.
        # Corresponds to the JSON property `totalWeight`
        # @return [Float]
        attr_accessor :total_weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @m2 = args[:m2] if args.key?(:m2)
          @mean = args[:mean] if args.key?(:mean)
          @total_weight = args[:total_weight] if args.key?(:total_weight)
        end
      end
      
      # 
      class IndexingSignalAggregatorSccData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `parentPattern`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorSccSignal]
        attr_accessor :parent_pattern
      
        # The most immediate pattern data.
        # Corresponds to the JSON property `pattern`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorSccSignal]
        attr_accessor :pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @parent_pattern = args[:parent_pattern] if args.key?(:parent_pattern)
          @pattern = args[:pattern] if args.key?(:pattern)
        end
      end
      
      # 
      class IndexingSignalAggregatorSccSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `clicksBad`
        # @return [Float]
        attr_accessor :clicks_bad
      
        # 
        # Corresponds to the JSON property `clicksImage`
        # @return [Float]
        attr_accessor :clicks_image
      
        # 
        # Corresponds to the JSON property `clicksTotal`
        # @return [Float]
        attr_accessor :clicks_total
      
        # For debugging purpose only.
        # Corresponds to the JSON property `debugInfo`
        # @return [Array<String>]
        attr_accessor :debug_info
      
        # This represents the number of urls with image clicks. A url can have both
        # image and non-image clicks, in which case we set num_image_urls to be the
        # ratio of image_clicks vs total clicks. For example, if a url has 10 total
        # clicks and 7 image clicks, num_image_urls will be set to 0.7.
        # Corresponds to the JSON property `numImageUrls`
        # @return [Float]
        attr_accessor :num_image_urls
      
        # 
        # Corresponds to the JSON property `numUrls`
        # @return [Fixnum]
        attr_accessor :num_urls
      
        # For debugging purpose only.
        # Corresponds to the JSON property `pattern`
        # @return [String]
        attr_accessor :pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @clicks_bad = args[:clicks_bad] if args.key?(:clicks_bad)
          @clicks_image = args[:clicks_image] if args.key?(:clicks_image)
          @clicks_total = args[:clicks_total] if args.key?(:clicks_total)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @num_image_urls = args[:num_image_urls] if args.key?(:num_image_urls)
          @num_urls = args[:num_urls] if args.key?(:num_urls)
          @pattern = args[:pattern] if args.key?(:pattern)
        end
      end
      
      # Contains only the signals necessary to perform per-URL click prediction. Used
      # by Index Selection for scoring. NEXT ID TO USE: 7
      class IndexingSignalAggregatorUrlPatternSignals
        include Google::Apis::Core::Hashable
      
        # Accumulated coverage data for an url using a constant half-life time. Next tag:
        # 28
        # Corresponds to the JSON property `coverage`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAgeWeightedCoverageData]
        attr_accessor :coverage
      
        # Aggregated signal used by NumericSignalAggregator. Next field id: 25
        # Corresponds to the JSON property `pagerankScore`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAggregatedScore]
        attr_accessor :pagerank_score
      
        # Aggregated signal used by NumericSignalAggregator. Next field id: 25
        # Corresponds to the JSON property `patternScore`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAggregatedScore]
        attr_accessor :pattern_score
      
        # 
        # Corresponds to the JSON property `priorSignal`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorUrlPatternSignalsPriorSignal>]
        attr_accessor :prior_signal
      
        # Aggregated signal used by NumericSignalAggregator. Next field id: 25
        # Corresponds to the JSON property `regexpPatternScore`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAggregatedScore]
        attr_accessor :regexp_pattern_score
      
        # 
        # Corresponds to the JSON property `sccData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorSccData]
        attr_accessor :scc_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @coverage = args[:coverage] if args.key?(:coverage)
          @pagerank_score = args[:pagerank_score] if args.key?(:pagerank_score)
          @pattern_score = args[:pattern_score] if args.key?(:pattern_score)
          @prior_signal = args[:prior_signal] if args.key?(:prior_signal)
          @regexp_pattern_score = args[:regexp_pattern_score] if args.key?(:regexp_pattern_score)
          @scc_data = args[:scc_data] if args.key?(:scc_data)
        end
      end
      
      # This message provides a container for any signal used in scoring, and allows
      # UrlPatternSignals to extend beyond (regexp_)pattern_score and pagerank_score.
      class IndexingSignalAggregatorUrlPatternSignalsPriorSignal
        include Google::Apis::Core::Hashable
      
        # Aggregated signal used by NumericSignalAggregator. Next field id: 25
        # Corresponds to the JSON property `aggregatedScore`
        # @return [Google::Apis::ContentwarehouseV1::IndexingSignalAggregatorAggregatedScore]
        attr_accessor :aggregated_score
      
        # 
        # Corresponds to the JSON property `priorSignalId`
        # @return [String]
        attr_accessor :prior_signal_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_score = args[:aggregated_score] if args.key?(:aggregated_score)
          @prior_signal_id = args[:prior_signal_id] if args.key?(:prior_signal_id)
        end
      end
      
      # Representation of numeric signal of a url.
      class IndexingSignalAggregatorUrlScore
        include Google::Apis::Core::Hashable
      
        # The number of weekly performance records if the UrlScore is extracted from the
        # DSAC data. It should be used in case a URL is no longer served. As of 2014-10-
        # 14, this field is for the evaluation purpose only.
        # Corresponds to the JSON property `dsacNumWeeklyPerfRecords`
        # @return [Fixnum]
        attr_accessor :dsac_num_weekly_perf_records
      
        # If this field is set, it indicates the url is eligible to be aggregated to one
        # of the experimental layers.
        # Corresponds to the JSON property `eligibleExperimentalLayer`
        # @return [String]
        attr_accessor :eligible_experimental_layer
      
        # The timestamp of the first time this document is served anywhere.
        # Corresponds to the JSON property `firstServedTimestamp`
        # @return [Fixnum]
        attr_accessor :first_served_timestamp
      
        # Whether this url has important signal. Used for keeping patterns that match
        # too few URLs but some of them have good clicks.
        # Corresponds to the JSON property `isImportant`
        # @return [Boolean]
        attr_accessor :is_important
        alias_method :is_important?, :is_important
      
        # score might be missing if the url does not have signal.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # url might be missing if we can get it from sstable key.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # weight for this url.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dsac_num_weekly_perf_records = args[:dsac_num_weekly_perf_records] if args.key?(:dsac_num_weekly_perf_records)
          @eligible_experimental_layer = args[:eligible_experimental_layer] if args.key?(:eligible_experimental_layer)
          @first_served_timestamp = args[:first_served_timestamp] if args.key?(:first_served_timestamp)
          @is_important = args[:is_important] if args.key?(:is_important)
          @score = args[:score] if args.key?(:score)
          @url = args[:url] if args.key?(:url)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # The information about spoken content that's based on purely the media resource
      # contents (and not the embedding page or context, etc).
      class IndexingSpeechSpeechPropertiesProto
        include Google::Apis::Core::Hashable
      
        # Duration of audio in processed fragment (including non-speech), in seconds.
        # Corresponds to the JSON property `audioDuration`
        # @return [Fixnum]
        attr_accessor :audio_duration
      
        # If true, the media file is audio-only. If false, also has video track(s).
        # Corresponds to the JSON property `audioOnly`
        # @return [Boolean]
        attr_accessor :audio_only
        alias_method :audio_only?, :audio_only
      
        # Estimated duration of audio in the whole file (including non-speech), in
        # seconds. If this is greater than 0, then it will either be equal to
        # audio_duration (when truncated_file is false), or to the length of the content
        # (audio or video) according to the file header (when truncated_file is true).
        # Corresponds to the JSON property `estimatedAudioDuration`
        # @return [Fixnum]
        attr_accessor :estimated_audio_duration
      
        # Our confidence in the duration estimate, on a scale from 0 (not confident) to
        # 1 (very confident). An estimate should have a confidence of at least 0.5 if it
        # is to be shown to users.
        # Corresponds to the JSON property `estimatedAudioDurationConfidence`
        # @return [Float]
        attr_accessor :estimated_audio_duration_confidence
      
        # The spoken language, see i18n/identifiers/languagecode.h and go/gl2014. This
        # may or may not match the language of the written page. (Examples: "en", "sv", "
        # zh-CN").
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # Total number of recognized words in processed fragment.
        # Corresponds to the JSON property `numWords`
        # @return [Fixnum]
        attr_accessor :num_words
      
        # Measure of the estimated output accuracy from the speech recognition code,
        # from 0 to 1. Based on word-level confidence and possibly other factors.
        # Corresponds to the JSON property `recognizerAccuracy`
        # @return [Float]
        attr_accessor :recognizer_accuracy
      
        # Duration of speech in processed fragment, in seconds.
        # Corresponds to the JSON property `speechDuration`
        # @return [Fixnum]
        attr_accessor :speech_duration
      
        # If true, we may have processed a truncated file (most likely due to a size-
        # cutoff when crawling). As a result, the audio duration is a lower bound and
        # the other fields reflect only the processed prefix of the file.
        # Corresponds to the JSON property `truncatedFile`
        # @return [Boolean]
        attr_accessor :truncated_file
        alias_method :truncated_file?, :truncated_file
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_duration = args[:audio_duration] if args.key?(:audio_duration)
          @audio_only = args[:audio_only] if args.key?(:audio_only)
          @estimated_audio_duration = args[:estimated_audio_duration] if args.key?(:estimated_audio_duration)
          @estimated_audio_duration_confidence = args[:estimated_audio_duration_confidence] if args.key?(:estimated_audio_duration_confidence)
          @language_code = args[:language_code] if args.key?(:language_code)
          @num_words = args[:num_words] if args.key?(:num_words)
          @recognizer_accuracy = args[:recognizer_accuracy] if args.key?(:recognizer_accuracy)
          @speech_duration = args[:speech_duration] if args.key?(:speech_duration)
          @truncated_file = args[:truncated_file] if args.key?(:truncated_file)
        end
      end
      
      # Representing a dominating branch of the URL tree.
      class IndexingUrlPatternUrlTreeBigTreeBranch
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `features`
        # @return [Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlFeatures]
        attr_accessor :features
      
        # The fingerprint of the features string.
        # Corresponds to the JSON property `patternId`
        # @return [Fixnum]
        attr_accessor :pattern_id
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `payload`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :payload
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @features = args[:features] if args.key?(:features)
          @pattern_id = args[:pattern_id] if args.key?(:pattern_id)
          @payload = args[:payload] if args.key?(:payload)
        end
      end
      
      # 
      class IndexingUrlPatternUrlTreeUrlFeature
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fingerprint`
        # @return [Fixnum]
        attr_accessor :fingerprint
      
        # If consider position when calculating fingerprint of url feature.
        # Corresponds to the JSON property `fingerprintWithGroupInType`
        # @return [Boolean]
        attr_accessor :fingerprint_with_group_in_type
        alias_method :fingerprint_with_group_in_type?, :fingerprint_with_group_in_type
      
        # Used together w/ type field to group features, for finding features with too
        # many possible values.
        # Corresponds to the JSON property `groupInType`
        # @return [String]
        attr_accessor :group_in_type
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @fingerprint_with_group_in_type = args[:fingerprint_with_group_in_type] if args.key?(:fingerprint_with_group_in_type)
          @group_in_type = args[:group_in_type] if args.key?(:group_in_type)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class IndexingUrlPatternUrlTreeUrlFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `feature`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlFeature>]
        attr_accessor :feature
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature = args[:feature] if args.key?(:feature)
        end
      end
      
      # 
      class IndexingUrlPatternUrlTreeUrlTree
        include Google::Apis::Core::Hashable
      
        # Keeping information for dominating branches separately, to prevent docs on
        # smaller branches from being dropping during sampling.
        # Corresponds to the JSON property `bigBranch`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeBigTreeBranch>]
        attr_accessor :big_branch
      
        # 
        # Corresponds to the JSON property `debugInfo`
        # @return [Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlTreeDebugInfo]
        attr_accessor :debug_info
      
        # A UID of URL Tree. There is a hash function and a equality function for
        # UrlTreeKey in //indexing/url_pattern/url_tree/util/url-tree-key-util.h. When
        # adding or deprecating a field in this proto, please also update the hash
        # function and the equality function. LINT.IfChange
        # Corresponds to the JSON property `key`
        # @return [Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlTreeKey]
        attr_accessor :key
      
        # node(0) is root.
        # Corresponds to the JSON property `node`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlTreeNode>]
        attr_accessor :node
      
        # Used in url pattern matcher for cache invalidation.
        # Corresponds to the JSON property `retrievalTimestamp`
        # @return [Fixnum]
        attr_accessor :retrieval_timestamp
      
        # The key for this UrlTree, also will be the key in sstable. The old format is
        # site, while the new format will be UrlTreeKey. Only one field can be set in
        # the same time for site and key.
        # Corresponds to the JSON property `site`
        # @return [String]
        attr_accessor :site
      
        # The time when this UrlTree is built, encoded as seconds past the epoch (Jan 1,
        # 1970).
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `treeInfo`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :tree_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @big_branch = args[:big_branch] if args.key?(:big_branch)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @key = args[:key] if args.key?(:key)
          @node = args[:node] if args.key?(:node)
          @retrieval_timestamp = args[:retrieval_timestamp] if args.key?(:retrieval_timestamp)
          @site = args[:site] if args.key?(:site)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @tree_info = args[:tree_info] if args.key?(:tree_info)
        end
      end
      
      # 
      class IndexingUrlPatternUrlTreeUrlTreeDebugInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `innerSimilarity`
        # @return [Float]
        attr_accessor :inner_similarity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @inner_similarity = args[:inner_similarity] if args.key?(:inner_similarity)
        end
      end
      
      # A UID of URL Tree. There is a hash function and a equality function for
      # UrlTreeKey in //indexing/url_pattern/url_tree/util/url-tree-key-util.h. When
      # adding or deprecating a field in this proto, please also update the hash
      # function and the equality function. LINT.IfChange
      class IndexingUrlPatternUrlTreeUrlTreeKey
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `crawlerId`
        # @return [String]
        attr_accessor :crawler_id
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `hostname`
        # @return [String]
        attr_accessor :hostname
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crawler_id = args[:crawler_id] if args.key?(:crawler_id)
          @domain = args[:domain] if args.key?(:domain)
          @hostname = args[:hostname] if args.key?(:hostname)
        end
      end
      
      # 
      class IndexingUrlPatternUrlTreeUrlTreeNode
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `indexOfSubTreeWithSplittingFeature`
        # @return [Fixnum]
        attr_accessor :index_of_sub_tree_with_splitting_feature
      
        # 
        # Corresponds to the JSON property `indexOfSubTreeWithoutSplittingFeature`
        # @return [Fixnum]
        attr_accessor :index_of_sub_tree_without_splitting_feature
      
        # 
        # Corresponds to the JSON property `parent`
        # @return [Fixnum]
        attr_accessor :parent
      
        # The path from root to current node. This is only used for debugging.
        # Corresponds to the JSON property `pathFromRoot`
        # @return [String]
        attr_accessor :path_from_root
      
        # This is only used in leaf nodes which represents a url pattern. It is the
        # fingerprint of the splitting url features from root to the leaf.
        # Corresponds to the JSON property `patternId`
        # @return [Fixnum]
        attr_accessor :pattern_id
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `payload`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :payload
      
        # 
        # Corresponds to the JSON property `splittingFeature`
        # @return [Google::Apis::ContentwarehouseV1::IndexingUrlPatternUrlTreeUrlFeature]
        attr_accessor :splitting_feature
      
        # The information gain of content features when selecting this splitting feature
        # to split the node.
        # Corresponds to the JSON property `splittingFeatureScore`
        # @return [Float]
        attr_accessor :splitting_feature_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index_of_sub_tree_with_splitting_feature = args[:index_of_sub_tree_with_splitting_feature] if args.key?(:index_of_sub_tree_with_splitting_feature)
          @index_of_sub_tree_without_splitting_feature = args[:index_of_sub_tree_without_splitting_feature] if args.key?(:index_of_sub_tree_without_splitting_feature)
          @parent = args[:parent] if args.key?(:parent)
          @path_from_root = args[:path_from_root] if args.key?(:path_from_root)
          @pattern_id = args[:pattern_id] if args.key?(:pattern_id)
          @payload = args[:payload] if args.key?(:payload)
          @splitting_feature = args[:splitting_feature] if args.key?(:splitting_feature)
          @splitting_feature_score = args[:splitting_feature_score] if args.key?(:splitting_feature_score)
        end
      end
      
      # 
      class KaltixPerDocData
        include Google::Apis::Core::Hashable
      
        # approx. 2 bytes for top 1B
        # Corresponds to the JSON property `KaltixRank`
        # @return [Fixnum]
        attr_accessor :kaltix_rank
      
        # empty for now
        # Corresponds to the JSON property `LocalKaltixRank`
        # @return [Fixnum]
        attr_accessor :local_kaltix_rank
      
        # empty for now
        # Corresponds to the JSON property `SiteKaltixRank`
        # @return [Fixnum]
        attr_accessor :site_kaltix_rank
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @kaltix_rank = args[:kaltix_rank] if args.key?(:kaltix_rank)
          @local_kaltix_rank = args[:local_kaltix_rank] if args.key?(:local_kaltix_rank)
          @site_kaltix_rank = args[:site_kaltix_rank] if args.key?(:site_kaltix_rank)
        end
      end
      
      # Wrapper message containing list of regions and their corresponding type of
      # region signal to use in data governance.
      class KeGovernanceTypedRegions
        include Google::Apis::Core::Hashable
      
        # The particular type of region should be explicitly set to disambiguate.
        # Corresponds to the JSON property `regionType`
        # @return [String]
        attr_accessor :region_type
      
        # Values are go/iii RegionCode in capital case. It is a good practice to keep
        # elements in this list unique, although not enforced. In case of duplicated
        # entries, they'll be treated as if there were only one entry of the same value.
        # Corresponds to the JSON property `regions`
        # @return [Array<String>]
        attr_accessor :regions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @region_type = args[:region_type] if args.key?(:region_type)
          @regions = args[:regions] if args.key?(:regions)
        end
      end
      
      # Accepts any non-empty value. This is meant for special cases allowing any
      # value or any composition to be valid in a slot. If you are thinking of using
      # this, please contact mrf-team@.
      class KnowledgeAnswersAnyType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # An attribute type configures a value whose type is intended to be a attribute
      # defined in the schema.
      class KnowledgeAnswersAttributeType
        include Google::Apis::Core::Hashable
      
        # Use in parsing: the value filled with must be in the list of this. If no
        # attribute ids are specified, this value can be filled with any attribute.
        # Corresponds to the JSON property `attribute`
        # @return [Array<String>]
        attr_accessor :attribute
      
        # If exist, the attribute will be applied on the given pivot slot. This helps
        # type checking when qrewrite constructs function calls with an attribute-typed
        # slot.
        # Corresponds to the JSON property `pivotEntitySlot`
        # @return [String]
        attr_accessor :pivot_entity_slot
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute = args[:attribute] if args.key?(:attribute)
          @pivot_entity_slot = args[:pivot_entity_slot] if args.key?(:pivot_entity_slot)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A BooleanType configures a yes/no value.
      class KnowledgeAnswersBooleanType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A CollectionType configures a value whose type is intended to be a collection.
      class KnowledgeAnswersCollectionType
        include Google::Apis::Core::Hashable
      
        # The collection this value is filled with must be one of these collections (
        # denoted by a /collection/* id). If no collections are specified, this value
        # can be filled with any collection.
        # Corresponds to the JSON property `collection`
        # @return [Array<String>]
        attr_accessor :collection
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection = args[:collection] if args.key?(:collection)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A CompoundType configures a value composed of multiple answer values.
      class KnowledgeAnswersCompoundType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # 
      class KnowledgeAnswersContainerType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slotNames`
        # @return [Array<String>]
        attr_accessor :slot_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slot_names = args[:slot_names] if args.key?(:slot_names)
        end
      end
      
      # A DateType configures a value whose type is intended to be a date. LINT.
      # IfChange Next id: 16
      class KnowledgeAnswersDateType
        include Google::Apis::Core::Hashable
      
        # If true, will allow all resolutions that are ranges.
        # Corresponds to the JSON property `allowAllRangeResolutions`
        # @return [Boolean]
        attr_accessor :allow_all_range_resolutions
        alias_method :allow_all_range_resolutions?, :allow_all_range_resolutions
      
        # If true, overrides all other options in this message and allows any kind of
        # DateTime annotation.
        # Corresponds to the JSON property `allowAllResolutions`
        # @return [Boolean]
        attr_accessor :allow_all_resolutions
        alias_method :allow_all_resolutions?, :allow_all_resolutions
      
        # If true, will allow all resolutions except holidays.
        # Corresponds to the JSON property `allowAllResolutionsExceptHolidays`
        # @return [Boolean]
        attr_accessor :allow_all_resolutions_except_holidays
        alias_method :allow_all_resolutions_except_holidays?, :allow_all_resolutions_except_holidays
      
        # If true, will allow resolutions that aren't contiguous sequences of 4 digits
        # annotated as 24-hr times. These are often mis-interpreted years or postcodes.
        # Corresponds to the JSON property `allowAllResolutionsWithout4digit24hrTime`
        # @return [Boolean]
        attr_accessor :allow_all_resolutions_without4digit24hr_time
        alias_method :allow_all_resolutions_without4digit24hr_time?, :allow_all_resolutions_without4digit24hr_time
      
        # If true, will allow resolutions without an explicit hour. Symbolic ranges such
        # as [this evening] are not considered as explicit hour, but the range [1-3pm]
        # is considered as explicit.
        # Corresponds to the JSON property `allowAllResolutionsWithoutTime`
        # @return [Boolean]
        attr_accessor :allow_all_resolutions_without_time
        alias_method :allow_all_resolutions_without_time?, :allow_all_resolutions_without_time
      
        # If true, will parse a mention to DateTime of resolution day. This allows
        # parsing strings like "August 30th", "2012-12-25";
        # Corresponds to the JSON property `allowDayResolution`
        # @return [Boolean]
        attr_accessor :allow_day_resolution
        alias_method :allow_day_resolution?, :allow_day_resolution
      
        # If true, will allow day resolutions except holidays or ordinal numbers, such
        # as "today", "December 13", but "Christmas", "first" are not allowed.
        # Corresponds to the JSON property `allowDayResolutionExceptHolidaysOrOrdinal`
        # @return [Boolean]
        attr_accessor :allow_day_resolution_except_holidays_or_ordinal
        alias_method :allow_day_resolution_except_holidays_or_ordinal?, :allow_day_resolution_except_holidays_or_ordinal
      
        # If true, will allow resolutions with an explicit hour such as "8am", "5pm".
        # Corresponds to the JSON property `allowHourResolution`
        # @return [Boolean]
        attr_accessor :allow_hour_resolution
        alias_method :allow_hour_resolution?, :allow_hour_resolution
      
        # If true, will parse a mention to DateTime of resolution month. This allows
        # parsing strings like "this August", "2012-12";
        # Corresponds to the JSON property `allowMonthResolution`
        # @return [Boolean]
        attr_accessor :allow_month_resolution
        alias_method :allow_month_resolution?, :allow_month_resolution
      
        # If true, will allow "now" resolutions, but not any other time
        # Corresponds to the JSON property `allowNowResolution`
        # @return [Boolean]
        attr_accessor :allow_now_resolution
        alias_method :allow_now_resolution?, :allow_now_resolution
      
        # If true, will allow symbolic time resolutions such as "tonight".
        # Corresponds to the JSON property `allowSymbolicTime`
        # @return [Boolean]
        attr_accessor :allow_symbolic_time
        alias_method :allow_symbolic_time?, :allow_symbolic_time
      
        # If true, will allow time resolutions without an explicit timezone.
        # Corresponds to the JSON property `allowTimeResolutionsWithoutExplicitTimezone`
        # @return [Boolean]
        attr_accessor :allow_time_resolutions_without_explicit_timezone
        alias_method :allow_time_resolutions_without_explicit_timezone?, :allow_time_resolutions_without_explicit_timezone
      
        # If true, will parse a mention to DateTime of resolution year. This allows
        # parsing strings like "Next year ", "2010";
        # Corresponds to the JSON property `allowYearResolution`
        # @return [Boolean]
        attr_accessor :allow_year_resolution
        alias_method :allow_year_resolution?, :allow_year_resolution
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # 
        # Corresponds to the JSON property `subType`
        # @return [String]
        attr_accessor :sub_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_all_range_resolutions = args[:allow_all_range_resolutions] if args.key?(:allow_all_range_resolutions)
          @allow_all_resolutions = args[:allow_all_resolutions] if args.key?(:allow_all_resolutions)
          @allow_all_resolutions_except_holidays = args[:allow_all_resolutions_except_holidays] if args.key?(:allow_all_resolutions_except_holidays)
          @allow_all_resolutions_without4digit24hr_time = args[:allow_all_resolutions_without4digit24hr_time] if args.key?(:allow_all_resolutions_without4digit24hr_time)
          @allow_all_resolutions_without_time = args[:allow_all_resolutions_without_time] if args.key?(:allow_all_resolutions_without_time)
          @allow_day_resolution = args[:allow_day_resolution] if args.key?(:allow_day_resolution)
          @allow_day_resolution_except_holidays_or_ordinal = args[:allow_day_resolution_except_holidays_or_ordinal] if args.key?(:allow_day_resolution_except_holidays_or_ordinal)
          @allow_hour_resolution = args[:allow_hour_resolution] if args.key?(:allow_hour_resolution)
          @allow_month_resolution = args[:allow_month_resolution] if args.key?(:allow_month_resolution)
          @allow_now_resolution = args[:allow_now_resolution] if args.key?(:allow_now_resolution)
          @allow_symbolic_time = args[:allow_symbolic_time] if args.key?(:allow_symbolic_time)
          @allow_time_resolutions_without_explicit_timezone = args[:allow_time_resolutions_without_explicit_timezone] if args.key?(:allow_time_resolutions_without_explicit_timezone)
          @allow_year_resolution = args[:allow_year_resolution] if args.key?(:allow_year_resolution)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @sub_type = args[:sub_type] if args.key?(:sub_type)
        end
      end
      
      # 
      class KnowledgeAnswersDependencyType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `containerType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersContainerType]
        attr_accessor :container_type
      
        # 
        # Corresponds to the JSON property `intersectType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntersectType]
        attr_accessor :intersect_type
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # 
        # Corresponds to the JSON property `sameType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSameType]
        attr_accessor :same_type
      
        # 
        # Corresponds to the JSON property `unionType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersUnionType]
        attr_accessor :union_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @container_type = args[:container_type] if args.key?(:container_type)
          @intersect_type = args[:intersect_type] if args.key?(:intersect_type)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @same_type = args[:same_type] if args.key?(:same_type)
          @union_type = args[:union_type] if args.key?(:union_type)
        end
      end
      
      # How a piece of data was resolved through external data (either elsewhere in
      # the query, or from a previous query). Examples: [obama and his age] -> "his"
      # is resolved from the Obama entity obama -> "he" is resolved from the Obama
      # entity starbucks -> Q2 is resolved from the list of shops
      class KnowledgeAnswersDialogReferentialResolution
        include Google::Apis::Core::Hashable
      
        # True iff this ReferentialResolution is part of an intent and refers to the
        # full MRF subtree (rather than just the intent).
        # Corresponds to the JSON property `refersToFullMrf`
        # @return [Boolean]
        attr_accessor :refers_to_full_mrf
        alias_method :refers_to_full_mrf?, :refers_to_full_mrf
      
        # 
        # Corresponds to the JSON property `resolutionType`
        # @return [String]
        attr_accessor :resolution_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @refers_to_full_mrf = args[:refers_to_full_mrf] if args.key?(:refers_to_full_mrf)
          @resolution_type = args[:resolution_type] if args.key?(:resolution_type)
        end
      end
      
      # A DurationType configures a value whose type is a duration.
      class KnowledgeAnswersDurationType
        include Google::Apis::Core::Hashable
      
        # Range constraint limits the set of durations accepted. The values of the range
        # are in milliseconds. Currently, this constraint is only enforced in Loose
        # Parser.
        # Corresponds to the JSON property `rangeConstraint`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersRangeConstraint]
        attr_accessor :range_constraint
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @range_constraint = args[:range_constraint] if args.key?(:range_constraint)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # An EntityType configures a value whose type is intended to be an entity.
      # Entities may be specified using either the collection(s) to which they belong,
      # or explicitly via a list of KG-ids. Both collections and ids can be specified,
      # in which case the type will be the union of the id(s) and all mids within the
      # collection(s). Next available tag: 9
      class KnowledgeAnswersEntityType
        include Google::Apis::Core::Hashable
      
        # This field specifies that containing entity must be: - in *any* 'collection'
        # if 'in_all_collections' is false (default) - in *every* 'collection' if '
        # in_all_collections' is true. The collection field contains strings of the form
        # '/collection/'. If no collections are specified, this value can be filled with
        # any entity. A collection specified as an empty string has a special meaning
        # for Aqua induction, which is that the type includes all entities.
        # Corresponds to the JSON property `collection`
        # @return [Array<String>]
        attr_accessor :collection
      
        # The entity that this value is filled with must not be any of these collections
        # (denoted by a /collection/* id). This restriction does not affect parsing; it
        # is used only to filter attributes in the extraction flow.
        # Corresponds to the JSON property `excludedCollection`
        # @return [Array<String>]
        attr_accessor :excluded_collection
      
        # The entity that this value is filled with must be one of the following
        # explicitly specified KG-ids.
        # Corresponds to the JSON property `id`
        # @return [Array<String>]
        attr_accessor :id
      
        # The entity that this value is filled with must be of the explicit type and/or
        # contain the explicitly specified id. This field can not be used for kg mids,
        # which should directly use the id field above.
        # Corresponds to the JSON property `identifier`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryIdentifier>]
        attr_accessor :identifier
      
        # 
        # Corresponds to the JSON property `inAllCollections`
        # @return [Boolean]
        attr_accessor :in_all_collections
        alias_method :in_all_collections?, :in_all_collections
      
        # If this is set to true for a slot and the entity is a location, the latitude
        # and longitude will be available in variables $SlotName_Latitude and $
        # SlotName_Longitude, respectively. The latitude and longitude data comes from
        # KG.
        # Corresponds to the JSON property `includeGeolocationData`
        # @return [Boolean]
        attr_accessor :include_geolocation_data
        alias_method :include_geolocation_data?, :include_geolocation_data
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # This field is deprecated. It is not removed completely since this proto was
        # saved with this field in proto text files used by the Grammy tool.
        # Corresponds to the JSON property `stbrDomain`
        # @return [Array<String>]
        attr_accessor :stbr_domain
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection = args[:collection] if args.key?(:collection)
          @excluded_collection = args[:excluded_collection] if args.key?(:excluded_collection)
          @id = args[:id] if args.key?(:id)
          @identifier = args[:identifier] if args.key?(:identifier)
          @in_all_collections = args[:in_all_collections] if args.key?(:in_all_collections)
          @include_geolocation_data = args[:include_geolocation_data] if args.key?(:include_geolocation_data)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @stbr_domain = args[:stbr_domain] if args.key?(:stbr_domain)
        end
      end
      
      # Modifiers decorate a Meaning Expression (i.e. intent FunctionCall) with
      # signals that depend on the source language's grammar and syntax. See go/intent-
      # modifiers for details. NOTE: Modifiers don't necessarily impact go/intent-
      # resolution semantics. LINT.IfChange
      class KnowledgeAnswersIntentModifiers
        include Google::Apis::Core::Hashable
      
        # Language of all of the non-annotation tokens of the query interpretation, if
        # it is different than |language|. This can happen with English smearing, e.g. [
        # height rousseau] will trigger as "fr" when issued in fr/FR, but really the
        # language is "en". This can also happen when we have extra information about
        # the language model, e.g. language="zh", alternate_language="zh-Hant".
        # Corresponds to the JSON property `alternateLanguage`
        # @return [String]
        attr_accessor :alternate_language
      
        # 
        # Corresponds to the JSON property `definiteness`
        # @return [String]
        attr_accessor :definiteness
      
        # Language of parsed query.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Since there's only IMPERATIVE, consider using Marker.command instead.
        # Corresponds to the JSON property `mood`
        # @return [String]
        attr_accessor :mood
      
        # 
        # Corresponds to the JSON property `plurality`
        # @return [String]
        attr_accessor :plurality
      
        # Whether or not the question is a polar (yes/no) question.
        # Corresponds to the JSON property `polarQuestion`
        # @return [Boolean]
        attr_accessor :polar_question
        alias_method :polar_question?, :polar_question
      
        # This proto contains the sentiment and emotions that the user is exhibiting at
        # the time of the query. NEXT ID: 4
        # Corresponds to the JSON property `sentiment`
        # @return [Google::Apis::ContentwarehouseV1::SentimentSentiment]
        attr_accessor :sentiment
      
        # 
        # Corresponds to the JSON property `tense`
        # @return [String]
        attr_accessor :tense
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternate_language = args[:alternate_language] if args.key?(:alternate_language)
          @definiteness = args[:definiteness] if args.key?(:definiteness)
          @language = args[:language] if args.key?(:language)
          @mood = args[:mood] if args.key?(:mood)
          @plurality = args[:plurality] if args.key?(:plurality)
          @polar_question = args[:polar_question] if args.key?(:polar_question)
          @sentiment = args[:sentiment] if args.key?(:sentiment)
          @tense = args[:tense] if args.key?(:tense)
        end
      end
      
      # Signals coming from the Annotation Layer of TUIG. See more details at http://
      # go/unified-intent-generation-apis.
      class KnowledgeAnswersIntentQueryAnnotationLayerSignals
        include Google::Apis::Core::Hashable
      
        # Signals associated with CustomVehicleActionArgumentAnnotator annotations.
        # Corresponds to the JSON property `customVehicleActionArgumentAnnotatorSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryCustomVehicleActionArgumentAnnotatorSignals]
        attr_accessor :custom_vehicle_action_argument_annotator_signals
      
        # Signals associated with FreetextAnnotator annotations. Empty. The signal being
        # present is enough for the conformance checking library to be able to check.
        # Corresponds to the JSON property `freetextAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryFreetextAnnotationSignals]
        attr_accessor :freetext_annotation_signals
      
        # Signals associated with NimbleAnnotator annotations.
        # Corresponds to the JSON property `nimbleAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryNimbleAnnotationSignals]
        attr_accessor :nimble_annotation_signals
      
        # Signals associated with NTPRAnnotator annotations. Empty. The signal being
        # present is enough for the conformance checking library to be able to check.
        # Corresponds to the JSON property `ntprAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryNtprAnnotationSignals]
        attr_accessor :ntpr_annotation_signals
      
        # Signals associated with Qref annotations.
        # Corresponds to the JSON property `qrefAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryQrefAnnotationSignals]
        attr_accessor :qref_annotation_signals
      
        # Signals associated with nlp_ig::v1::SemanticAnnotator.
        # Corresponds to the JSON property `semanticAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySemanticAnnotationSignals]
        attr_accessor :semantic_annotation_signals
      
        # Signals associated with TeleportArgumentAnnotator annotations. Empty. The
        # signal being present is enough for the conformance checking library to be able
        # to check.
        # Corresponds to the JSON property `teleportArgumentAnnotatorSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryTeleportArgumentAnnotatorSignals]
        attr_accessor :teleport_argument_annotator_signals
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @custom_vehicle_action_argument_annotator_signals = args[:custom_vehicle_action_argument_annotator_signals] if args.key?(:custom_vehicle_action_argument_annotator_signals)
          @freetext_annotation_signals = args[:freetext_annotation_signals] if args.key?(:freetext_annotation_signals)
          @nimble_annotation_signals = args[:nimble_annotation_signals] if args.key?(:nimble_annotation_signals)
          @ntpr_annotation_signals = args[:ntpr_annotation_signals] if args.key?(:ntpr_annotation_signals)
          @qref_annotation_signals = args[:qref_annotation_signals] if args.key?(:qref_annotation_signals)
          @semantic_annotation_signals = args[:semantic_annotation_signals] if args.key?(:semantic_annotation_signals)
          @teleport_argument_annotator_signals = args[:teleport_argument_annotator_signals] if args.key?(:teleport_argument_annotator_signals)
        end
      end
      
      # 
      class KnowledgeAnswersIntentQueryArgPath
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `components`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgPathComponent>]
        attr_accessor :components
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @components = args[:components] if args.key?(:components)
        end
      end
      
      # LINT.IfChange(ArgPath) Given a FunctionCall and an Argument somewhere in it,
      # an ArgPath is a list of name-index pairs that uniquely determines the path
      # down to that Argument. For each pair, the |index|, starting from zero,
      # distinguishes between "sibling" (i.e. belonging to the same sub-FunctionCall)
      # Arguments with the same name. For example, given the following FunctionCall: A(
      # X=D(W=5), Z=B(Z=6), Z=C(Y=7)) The path to the Z=6 argument is ``"Z", 0`, `"Z",
      # 0`` It's the first of two Z "siblings" under A, then the only Z under B. The
      # path to the Y=7 argument is ``"Z", 1`, `"Y", 0`` It's the second of two Z "
      # siblings" under A, then the only Y under C. The path to the Z=B(...) argument
      # is ``"Z", 0`` It's the first of two Z "siblings" under A.
      class KnowledgeAnswersIntentQueryArgPathComponent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `argName`
        # @return [String]
        attr_accessor :arg_name
      
        # 
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @arg_name = args[:arg_name] if args.key?(:arg_name)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # A message representing the function argument. Next ID: 9 Important: If you add
      # new fields that do not reflect signals data, but actual semantics of the
      # FunctionCall, please also update CreateFuncallCopyWithoutSignals and
      # CreateFuncallCopyWithArgumentSignals in function_call_utils. LINT.IfChange
      class KnowledgeAnswersIntentQueryArgument
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `heuristicEvalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :heuristic_eval_data
      
        # The primary key for a MeaningSchema slot. Next ID: 3 For //depot/google3/logs/
        # proto/knowledge/interpretation/intent_query.proto in the "ThenChange", please
        # update Argument.SlotKey. LINT.IfChange
        # Corresponds to the JSON property `key`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMeaningSchemaSlotKey]
        attr_accessor :key
      
        # Modifiers decorate a Meaning Expression (i.e. intent FunctionCall) with
        # signals that depend on the source language's grammar and syntax. See go/intent-
        # modifiers for details. NOTE: Modifiers don't necessarily impact go/intent-
        # resolution semantics. LINT.IfChange
        # Corresponds to the JSON property `modifiers`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentModifiers]
        attr_accessor :modifiers
      
        # Name of this argument. If this Argument is part of a FunctionCall, it must
        # have a name or it is not well-formed. If this Argument is from an Annotator,
        # the name field should be empty.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # A message representing the signals associated with an argument. NEXT ID TO USE:
        # 57 For //depot/google3/logs/proto/knowledge/interpretation/intent_query.proto
        # in the "ThenChange", fields under Argument.signals in the serving proto are
        # stored directly under Argument on the logging side. For example, see http://
        # google3/nlp/semantic_parsing/data_management/logs/web_logs/
        # semantic_logging_converters/semantic_logging_request_argument_converter.cc?l=
        # 58&rcl=322925428. LINT.IfChange
        # Corresponds to the JSON property `signals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentSignals]
        attr_accessor :signals
      
        # A message representing the value of an argument. All types in the "value"
        # oneof should have a corresponding field in the ValueType or OpaqueType protos
        # defined in knowledge/answers/config/value.proto. This is specified by
        # annotating each ArgumentValue type with options of the form (value_type_name) =
        # A unit test ensure that this field is set and is valid for all types in
        # ArgumentValue. A small number of special cases (such as funcall and
        # simple_value) are allowed to omit the annotation. See intent_query_proto_test.
        # cc for details. Note: If you are trying to add a new OpaqueType, stop;
        # OpaqueType is deprecated, refer to go/opaque_type for details. If you think
        # this is the only way to implement your feature, attend an office hours (go/
        # meaning-help) and discuss with the MRF team. Next Id: 41
        # Corresponds to the JSON property `value`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentValue]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @heuristic_eval_data = args[:heuristic_eval_data] if args.key?(:heuristic_eval_data)
          @key = args[:key] if args.key?(:key)
          @modifiers = args[:modifiers] if args.key?(:modifiers)
          @name = args[:name] if args.key?(:name)
          @signals = args[:signals] if args.key?(:signals)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # NextId: 11
      class KnowledgeAnswersIntentQueryArgumentProvenance
        include Google::Apis::Core::Hashable
      
        # Signals about an anaphor in the query: for example an occurrence of the
        # pronoun "it".
        # Corresponds to the JSON property `anaphor`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenanceQueryAnaphor]
        attr_accessor :anaphor
      
        # The value is carried over from an attentional entity. For example, in a dialog
        # about a movie that publishes an attentional entity for /m/matrix: U: What is
        # the cast. [Cast(location=/m/matrix)] G: The cast includes Keanu Reeves and
        # others. U: Great, buy some tickets. [BuyTickets(movie=/m/matrix)] On the
        # second user query, the "movie" argument would have a provenance of
        # ATTENTIONAL_ENTITY.
        # Corresponds to the JSON property `attentionalEntity`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenanceAttentionalEntity]
        attr_accessor :attentional_entity
      
        # NOTE: These comments should stay in sync with the comments in logs/proto/
        # knowledge/interpretation/intent_query.proto LINT.IfChange The argument comes
        # from the current query. For example: U: Book a hotel in Paris. [BookHotel(
        # location=/m/paris)] The "location" argument would have a provenance of
        # CURRENT_QUERY.
        # Corresponds to the JSON property `currentQuery`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenanceCurrentQuery]
        attr_accessor :current_query
      
        # The value is carried from injected contextual schema. Such schemas can be
        # injected by go/qu-biasing-config for particular clients when their biasing
        # configs are triggered for their traffic Config: (if QRewrite source ==
        # CARS_IMMERSIVE then inject LocalCarListings and Cars) Context: (QRewrite
        # source == CARS_IMMERSIVE) U: Red [LocalCarListings(Cars() & RelatedTo(/m/red))]
        # In this case, both LocalCarListings and Cars are spanless injected contextual
        # schemas.
        # Corresponds to the JSON property `injectedContextualSchema`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenanceInjectedContextualSchema]
        attr_accessor :injected_contextual_schema
      
        # The value is carried over from either the previous winning IntentQuery or an
        # entity annotated by QRef in a previous query. For example: U: How old is Obama.
        # [Age(person=/m/obama)] G: Barack Obama is 56 years old. U: Who is his wife. [
        # Spouse(person=/m/obama)] The "person" argument would have a provenance of
        # PREVIOUS_QUERY. However, if a dialog publishes an attentional entity for "
        # Obama", the "person" argument can have a provenance of ATTENTIONAL_ENTITY
        # instead. This includes arguments with provenance that spans both the current
        # and previous query.
        # Corresponds to the JSON property `previousQuery`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousQuery]
        attr_accessor :previous_query
      
        # 
        # Corresponds to the JSON property `previousResponseMeaning`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousResponseMeaning]
        attr_accessor :previous_response_meaning
      
        # Value is derived from previous task state (go/taskstates).
        # Corresponds to the JSON property `previousTaskState`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskState]
        attr_accessor :previous_task_state
      
        # The value was carried over from a SearchAnswerValue triggered by a previous
        # query (go/search-answer-values). For example: U: Movies with Tom Cruise. [
        # Movies(actor=/m/tom_cruise)] G: Tom Cruise's movies include Top Gun, The Mummy,
        # and 52 others. U: Reviews for the second one. [Reviews(movie=/m/the_mummy)]
        # The "movie" argument in the last query would have a provenance of
        # SEARCH_ANSWER_VALUE.
        # Corresponds to the JSON property `searchAnswerValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenanceSearchAnswerValue]
        attr_accessor :search_answer_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anaphor = args[:anaphor] if args.key?(:anaphor)
          @attentional_entity = args[:attentional_entity] if args.key?(:attentional_entity)
          @current_query = args[:current_query] if args.key?(:current_query)
          @injected_contextual_schema = args[:injected_contextual_schema] if args.key?(:injected_contextual_schema)
          @previous_query = args[:previous_query] if args.key?(:previous_query)
          @previous_response_meaning = args[:previous_response_meaning] if args.key?(:previous_response_meaning)
          @previous_task_state = args[:previous_task_state] if args.key?(:previous_task_state)
          @search_answer_value = args[:search_answer_value] if args.key?(:search_answer_value)
        end
      end
      
      # The value is carried over from an attentional entity. For example, in a dialog
      # about a movie that publishes an attentional entity for /m/matrix: U: What is
      # the cast. [Cast(location=/m/matrix)] G: The cast includes Keanu Reeves and
      # others. U: Great, buy some tickets. [BuyTickets(movie=/m/matrix)] On the
      # second user query, the "movie" argument would have a provenance of
      # ATTENTIONAL_ENTITY.
      class KnowledgeAnswersIntentQueryArgumentProvenanceAttentionalEntity
        include Google::Apis::Core::Hashable
      
        # This key can be used to recover the attentional entity from the corresponding
        # attentional_entities::EntityCache.
        # Corresponds to the JSON property `attentionalEntityKey`
        # @return [Fixnum]
        attr_accessor :attentional_entity_key
      
        # Represents the properties of a mention. Next ID: 13
        # Corresponds to the JSON property `mentionProperties`
        # @return [Google::Apis::ContentwarehouseV1::AttentionalEntitiesMentionProperties]
        attr_accessor :mention_properties
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attentional_entity_key = args[:attentional_entity_key] if args.key?(:attentional_entity_key)
          @mention_properties = args[:mention_properties] if args.key?(:mention_properties)
        end
      end
      
      # NOTE: These comments should stay in sync with the comments in logs/proto/
      # knowledge/interpretation/intent_query.proto LINT.IfChange The argument comes
      # from the current query. For example: U: Book a hotel in Paris. [BookHotel(
      # location=/m/paris)] The "location" argument would have a provenance of
      # CURRENT_QUERY.
      class KnowledgeAnswersIntentQueryArgumentProvenanceCurrentQuery
        include Google::Apis::Core::Hashable
      
        # The span(s) in the query where the value comes from. Note that if the argument
        # is split across the current and previous query, this message should *NOT* be
        # populated. Please use PreviousQuery below, populating it's eval-data fields
        # accordingly.
        # Corresponds to the JSON property `evalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :eval_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
        end
      end
      
      # The value is carried from injected contextual schema. Such schemas can be
      # injected by go/qu-biasing-config for particular clients when their biasing
      # configs are triggered for their traffic Config: (if QRewrite source ==
      # CARS_IMMERSIVE then inject LocalCarListings and Cars) Context: (QRewrite
      # source == CARS_IMMERSIVE) U: Red [LocalCarListings(Cars() & RelatedTo(/m/red))]
      # In this case, both LocalCarListings and Cars are spanless injected contextual
      # schemas.
      class KnowledgeAnswersIntentQueryArgumentProvenanceInjectedContextualSchema
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The value is carried over from either the previous winning IntentQuery or an
      # entity annotated by QRef in a previous query. For example: U: How old is Obama.
      # [Age(person=/m/obama)] G: Barack Obama is 56 years old. U: Who is his wife. [
      # Spouse(person=/m/obama)] The "person" argument would have a provenance of
      # PREVIOUS_QUERY. However, if a dialog publishes an attentional entity for "
      # Obama", the "person" argument can have a provenance of ATTENTIONAL_ENTITY
      # instead. This includes arguments with provenance that spans both the current
      # and previous query.
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousQuery
        include Google::Apis::Core::Hashable
      
        # The span(s) in the current query where the value comes from. This is used when
        # the argument spans both the current and previous query. Eg jfk death -> [death,
        # when] spans both queries.
        # Corresponds to the JSON property `currentQueryEvalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :current_query_eval_data
      
        # The span(s) in the query where the value comes from.
        # Corresponds to the JSON property `evalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :eval_data
      
        # An EventId is a 128 bit identifier that uniquely identifies an event, such as
        # a query. The event time recorded to the nearest microsecond, along with
        # information about the process generating the event, ensures that all EventIds
        # are unique. Details of this EventId are described in a design document: http://
        # www/eng/designdocs/sawmill/adlogs.html
        # Corresponds to the JSON property `eventId`
        # @return [Google::Apis::ContentwarehouseV1::EventIdMessage]
        attr_accessor :event_id
      
        # The role that this data played in the previous query.
        # Corresponds to the JSON property `role`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousQueryRole]
        attr_accessor :role
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @current_query_eval_data = args[:current_query_eval_data] if args.key?(:current_query_eval_data)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @event_id = args[:event_id] if args.key?(:event_id)
          @role = args[:role] if args.key?(:role)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # The role that this data played in the previous query.
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousQueryRole
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `intentId`
        # @return [String]
        attr_accessor :intent_id
      
        # 
        # Corresponds to the JSON property `slotName`
        # @return [String]
        attr_accessor :slot_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent_id = args[:intent_id] if args.key?(:intent_id)
          @slot_name = args[:slot_name] if args.key?(:slot_name)
        end
      end
      
      # 
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousResponseMeaning
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Value is derived from previous task state (go/taskstates).
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskState
        include Google::Apis::Core::Hashable
      
        # Argument names in the DialogIntentState that the argument corresponds to. This
        # is repeated so it can handle complex argument update paths. (ordered from
        # outermost argument to innermost argument)
        # Corresponds to the JSON property `argumentName`
        # @return [Array<String>]
        attr_accessor :argument_name
      
        # The span(s) in the current query (if any) used to resolve the previous query's
        # DIS. Example: U: Barack Obama G: Do you want his age or his height? U: The
        # first one. G: Age(/m/obama) In this example, the intent is derived from the
        # previous query's DIS, but also needs to be resolved in the current query since
        # the user was presented with multiple options.
        # Corresponds to the JSON property `currentQueryEvalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :current_query_eval_data
      
        # The id of the specific DialogIntentState instance that the argument
        # corresponds to.
        # Corresponds to the JSON property `dialogIntentStateId`
        # @return [String]
        attr_accessor :dialog_intent_state_id
      
        # Intent name of the DialogIntentState that the argument corresponds to.
        # Corresponds to the JSON property `intentName`
        # @return [String]
        attr_accessor :intent_name
      
        # The value is carried over from a field_candidate in a DialogIntentState. For
        # example: U: Send a message to John. G: Which John do you want to message? U:
        # John A. [ListPresentationIntent(contact_disambiguation.person=0)] On the
        # second user query, the "contact_disambiguation.person" argument would have a
        # provenance of PREVIOUS_TASK_STATE_LIST_CANDIDATE.
        # Corresponds to the JSON property `listCandidate`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskStateListCandidate]
        attr_accessor :list_candidate
      
        # The value was carried over from the previous function call. For example: U:
        # Create an alarm titled "Wake". [CreateAlarm(title=Wake)] G: Sure, at what time?
        # U: 5 am. [CreateAlarm(title=Wake,time=5am)] On the second user query, the "
        # title" argument would have a provenance of PREVIOUS_TASK_STATE.
        # Corresponds to the JSON property `previousFunctionCall`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskStatePreviousFunctionCall]
        attr_accessor :previous_function_call
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @argument_name = args[:argument_name] if args.key?(:argument_name)
          @current_query_eval_data = args[:current_query_eval_data] if args.key?(:current_query_eval_data)
          @dialog_intent_state_id = args[:dialog_intent_state_id] if args.key?(:dialog_intent_state_id)
          @intent_name = args[:intent_name] if args.key?(:intent_name)
          @list_candidate = args[:list_candidate] if args.key?(:list_candidate)
          @previous_function_call = args[:previous_function_call] if args.key?(:previous_function_call)
        end
      end
      
      # The value is carried over from a field_candidate in a DialogIntentState. For
      # example: U: Send a message to John. G: Which John do you want to message? U:
      # John A. [ListPresentationIntent(contact_disambiguation.person=0)] On the
      # second user query, the "contact_disambiguation.person" argument would have a
      # provenance of PREVIOUS_TASK_STATE_LIST_CANDIDATE.
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskStateListCandidate
        include Google::Apis::Core::Hashable
      
        # The presented_index of the field_candidate in the DialogIntentState
        # field_signals that the argument corresponds to.
        # Corresponds to the JSON property `candidateIndex`
        # @return [Fixnum]
        attr_accessor :candidate_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @candidate_index = args[:candidate_index] if args.key?(:candidate_index)
        end
      end
      
      # The value was carried over from the previous function call. For example: U:
      # Create an alarm titled "Wake". [CreateAlarm(title=Wake)] G: Sure, at what time?
      # U: 5 am. [CreateAlarm(title=Wake,time=5am)] On the second user query, the "
      # title" argument would have a provenance of PREVIOUS_TASK_STATE.
      class KnowledgeAnswersIntentQueryArgumentProvenancePreviousTaskStatePreviousFunctionCall
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Signals about an anaphor in the query: for example an occurrence of the
      # pronoun "it".
      class KnowledgeAnswersIntentQueryArgumentProvenanceQueryAnaphor
        include Google::Apis::Core::Hashable
      
        # If populated, the spans in the current query where this value was annotated.
        # This is a repeated field because some values can be annotated from a set of
        # discontiguous spans (e.g. some intent phrases), but in most cases this field
        # will contain only one item or it will be empty (for values inferred from
        # context without the use of anaphora).
        # Corresponds to the JSON property `evalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :eval_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
        end
      end
      
      # The value was carried over from a SearchAnswerValue triggered by a previous
      # query (go/search-answer-values). For example: U: Movies with Tom Cruise. [
      # Movies(actor=/m/tom_cruise)] G: Tom Cruise's movies include Top Gun, The Mummy,
      # and 52 others. U: Reviews for the second one. [Reviews(movie=/m/the_mummy)]
      # The "movie" argument in the last query would have a provenance of
      # SEARCH_ANSWER_VALUE.
      class KnowledgeAnswersIntentQueryArgumentProvenanceSearchAnswerValue
        include Google::Apis::Core::Hashable
      
        # An EventId is a 128 bit identifier that uniquely identifies an event, such as
        # a query. The event time recorded to the nearest microsecond, along with
        # information about the process generating the event, ensures that all EventIds
        # are unique. Details of this EventId are described in a design document: http://
        # www/eng/designdocs/sawmill/adlogs.html
        # Corresponds to the JSON property `eventId`
        # @return [Google::Apis::ContentwarehouseV1::EventIdMessage]
        attr_accessor :event_id
      
        # Each SearchAnswerValue can have a primary value and a list of metadata values.
        # If this index is set, this value was pulled from the metadata value at this
        # index, otherwise it was pulled from the primary value.
        # Corresponds to the JSON property `metadataValueIndex`
        # @return [Fixnum]
        attr_accessor :metadata_value_index
      
        # The display text of this answer value. It's taken from the search answer value
        # display text if present, or the canonical name if it's an entity.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # The index of the SearchAnswerValue where this value was pulled from.
        # Corresponds to the JSON property `valueIndex`
        # @return [Fixnum]
        attr_accessor :value_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event_id = args[:event_id] if args.key?(:event_id)
          @metadata_value_index = args[:metadata_value_index] if args.key?(:metadata_value_index)
          @text = args[:text] if args.key?(:text)
          @value_index = args[:value_index] if args.key?(:value_index)
        end
      end
      
      # A message representing the signals associated with an argument. NEXT ID TO USE:
      # 57 For //depot/google3/logs/proto/knowledge/interpretation/intent_query.proto
      # in the "ThenChange", fields under Argument.signals in the serving proto are
      # stored directly under Argument on the logging side. For example, see http://
      # google3/nlp/semantic_parsing/data_management/logs/web_logs/
      # semantic_logging_converters/semantic_logging_request_argument_converter.cc?l=
      # 58&rcl=322925428. LINT.IfChange
      class KnowledgeAnswersIntentQueryArgumentSignals
        include Google::Apis::Core::Hashable
      
        # Whether this argument was added by CloseAnswers in Postref. This bit is used
        # to mark the corresponding interpretation/intent query as such by setting
        # is_close_interpretation bit.
        # Corresponds to the JSON property `addedByCloseAnswers`
        # @return [Boolean]
        attr_accessor :added_by_close_answers
        alias_method :added_by_close_answers?, :added_by_close_answers
      
        # For this argument, backend performed fuzzy match.
        # Corresponds to the JSON property `allowedFuzzyMatch`
        # @return [Boolean]
        attr_accessor :allowed_fuzzy_match
        alias_method :allowed_fuzzy_match?, :allowed_fuzzy_match
      
        # Relationships between entities
        # Corresponds to the JSON property `annotatedRelationship`
        # @return [Array<Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQueryWebrefEntityRelationship>]
        attr_accessor :annotated_relationship
      
        # Signals coming from the Annotation Layer of TUIG. See more details at http://
        # go/unified-intent-generation-apis.
        # Corresponds to the JSON property `annotationLayerSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryAnnotationLayerSignals]
        attr_accessor :annotation_layer_signals
      
        # One or more ChainIds from a ChainAnnotation whose "organization_mid" matches
        # the MID. As of 2021-01 multiple chain_ids may be specified if the organization
        # for MID controls multiple chains. See go/chains-lckp-robust-triggering for
        # motivation.
        # Corresponds to the JSON property `chainId`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalsearchChainId>]
        attr_accessor :chain_id
      
        # Stores cluster scoring information for an entity Next Id: 6
        # Corresponds to the JSON property `clusterInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityViewsExtractionClusterInfo]
        attr_accessor :cluster_info
      
        # If the literal.obj_type of the argument value is ID (Entity), this represents
        # the collection that the entity in this argument is a member of.
        # Corresponds to the JSON property `collectionMembership`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryCollectionMembership>]
        attr_accessor :collection_membership
      
        # How this argument was resolved through context from a previous query. Examples:
        # obama -> "he" is resolved from the Obama entity starbucks -> Q2 is resolved
        # from the list of shops (Attentional Entities)
        # Corresponds to the JSON property `contextResolution`
        # @return [String]
        attr_accessor :context_resolution
      
        # If the literal.obj_type of the argument value is ID (Entity), this represents
        # freebase types of the entity in this argument.
        # Corresponds to the JSON property `deprecatedFreebaseType`
        # @return [Array<String>]
        attr_accessor :deprecated_freebase_type
      
        # A list of mids that "support" this argument in voting, i.e, results that
        # support these mids will be treated as if they support the argument. This field
        # has been deprecated in favor of related_entity. b/27363861
        # Corresponds to the JSON property `deprecatedSupportingMid`
        # @return [Array<String>]
        attr_accessor :deprecated_supporting_mid
      
        # Signals about what other entities this entity implies / is implied by. This is
        # useful for grounding. Example: b/138388207: suppressing song intents if the
        # artist entity doesn't link to the song title. This value specifies the order
        # of annotations in a QRef annotation chain so they can refer to each other.
        # Corresponds to the JSON property `entityNumber`
        # @return [Fixnum]
        attr_accessor :entity_number
      
        # Signals about what other entities this entity implies / is implied by. This is
        # useful for grounding. Example: b/138388207: suppressing song intents if the
        # artist entity doesn't link to the song title.
        # Corresponds to the JSON property `entityRelationship`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotationEntityRelationship>]
        attr_accessor :entity_relationship
      
        # Status indicating whether the user has finished expressing their intended
        # semantics during a streaming interaction. Semantics are partially expressed
        # when later, unprompted user input is expected to modify the semantics. Future
        # inputs are typically additional speech or continued modification of argument
        # text in form field. These inputs can trigger modifications including adding
        # arguments, changing the intent, or modifying existing arguments. Sensing this
        # status can be done both directly and indirectly. Fluid Actions directly
        # detects this status as the user moves between, or enters and leaves, argument
        # form fields. Understanding indirectly detects this status by the pace of the
        # user's speech, the semantics of the language, and the user's intonation. See
        # go/streaming-nlu-fulfilment-protocol-v1 for details about how it is used in
        # the Streaming NLU Fulfillment protocol.
        # Corresponds to the JSON property `expressionStatus`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingExpressionStatus]
        attr_accessor :expression_status
      
        # Whether the argument entity comes from a manual graphic symbol annotation.
        # This is later used as a heuristic for poor web result quality.
        # Corresponds to the JSON property `fromManualSymbolAnnotation`
        # @return [Boolean]
        attr_accessor :from_manual_symbol_annotation
        alias_method :from_manual_symbol_annotation?, :from_manual_symbol_annotation
      
        # Whether the argument entity comes from a graphic symbol annotation. This is
        # later used as a heuristic for poor web result quality.
        # Corresponds to the JSON property `fromSymbolAnnotation`
        # @return [Boolean]
        attr_accessor :from_symbol_annotation
        alias_method :from_symbol_annotation?, :from_symbol_annotation
      
        # The gaia id for the entity (person or plus page).
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # Grounding-related signals to be propagated down stream. Next ID: 12
        # Corresponds to the JSON property `groundingSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryGroundingSignals]
        attr_accessor :grounding_signals
      
        # If the argument is entity, the ungrounded type the entity is. For example, the
        # entity argument is /m/0p83l (Jasmine), the value of this field should be "
        # Plant" if it is present.
        # Corresponds to the JSON property `isAUngroundedTypeOf`
        # @return [String]
        attr_accessor :is_a_ungrounded_type_of
      
        # If true, the value of the argument is populated with the default value
        # specified by the system if the value can't be inferred from the input query.
        # In IntentConfig case, the default value is specified by using IntentConfig.
        # slot.default_value.
        # Corresponds to the JSON property `isDefaultValue`
        # @return [Boolean]
        attr_accessor :is_default_value
        alias_method :is_default_value?, :is_default_value
      
        # Set when the argument has an enum value - a normalized_string_type from the
        # intent catalog.
        # Corresponds to the JSON property `isEnum`
        # @return [Boolean]
        attr_accessor :is_enum
        alias_method :is_enum?, :is_enum
      
        # Set when the eval_data was not derived at parsing time, but heuristically
        # determined by matching the ArgumentValue to an annotation/query fragment.
        # Corresponds to the JSON property `isEvalDataHeuristic`
        # @return [Boolean]
        attr_accessor :is_eval_data_heuristic
        alias_method :is_eval_data_heuristic?, :is_eval_data_heuristic
      
        # Whether this annotation was propagated as part of a Genie rewrite (go/genie-
        # aqua).
        # Corresponds to the JSON property `isGenieAnnotation`
        # @return [Boolean]
        attr_accessor :is_genie_annotation
        alias_method :is_genie_annotation?, :is_genie_annotation
      
        # Whether this argument was annotated by Intentgen QUIK model (go/intentgen-quik)
        # Corresponds to the JSON property `isIntentgenAnnotation`
        # @return [Boolean]
        attr_accessor :is_intentgen_annotation
        alias_method :is_intentgen_annotation?, :is_intentgen_annotation
      
        # Whether this argument was annotated by nimble (go/nimble-annotator)
        # Corresponds to the JSON property `isNimbleAnnotation`
        # @return [Boolean]
        attr_accessor :is_nimble_annotation
        alias_method :is_nimble_annotation?, :is_nimble_annotation
      
        # Entity location information (latitude/longitude) from freebase.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :location
      
        # Signals from LightweightToken. The span for an argument may have been extended
        # to include lightweight token markers such as FROM or TO. This signal provides
        # the semantics for the range extension.
        # Corresponds to the JSON property `locationMarkersSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryLocationMarkersSignals]
        attr_accessor :location_markers_signals
      
        # Signals about the media entity.
        # Corresponds to the JSON property `mediaEntitySignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryMediaEntitySignals]
        attr_accessor :media_entity_signals
      
        # List of QRef implied entities merged into this entity during parsing. Clients
        # should not rely on the order, as it is derivation-dependent.
        # Corresponds to the JSON property `mergedImpliedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryImpliedEntity>]
        attr_accessor :merged_implied_entity
      
        # For collection arguments, it is useful to save what was the original mid that
        # qref annotated. For example, if the collection is /collection/films, we'll
        # have the mid for /en/film here (/m/02vxn).
        # Corresponds to the JSON property `midEquivalentToCollection`
        # @return [String]
        attr_accessor :mid_equivalent_to_collection
      
        # Whether there were multiple equally good matches from
        # horizontal_list_selection.
        # Corresponds to the JSON property `multipleHorizontalListSelectionMatches`
        # @return [Boolean]
        attr_accessor :multiple_horizontal_list_selection_matches
        alias_method :multiple_horizontal_list_selection_matches?, :multiple_horizontal_list_selection_matches
      
        # Signals derived from Munin Function call annotations.
        # Corresponds to the JSON property `muninSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryMuninSignals]
        attr_accessor :munin_signals
      
        # Signals coming from on-device annotators.
        # Corresponds to the JSON property `onDeviceAnnotationSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryOnDeviceAnnotationSignals]
        attr_accessor :on_device_annotation_signals
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `oysterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :oyster_id
      
        # Experiment ID for experiments that were used to parse this FunctionCall. Empty
        # indicates no experiments used.
        # Corresponds to the JSON property `parsedDueToExperiment`
        # @return [Array<String>]
        attr_accessor :parsed_due_to_experiment
      
        # Personal entities are compound entities made up of entities and their
        # attributes, where the entities can be compound too. E.g., "my father's mother"
        # can have a summary node annotation of "Mother(Father(Myself))"
        # Corresponds to the JSON property `personalEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryPersonalEntity>]
        attr_accessor :personal_entity
      
        # Information about where the value of this argument came from. For example, it
        # could have been explicitly provided in the query, pulled in from the previous
        # state, or pulled from attentional entities.
        # Corresponds to the JSON property `provenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenance>]
        attr_accessor :provenance
      
        # The QRef confidence score for an entity argument.
        # Corresponds to the JSON property `qrefConfidenceScore`
        # @return [Float]
        attr_accessor :qref_confidence_score
      
        # The index of the QueryJoin interpretation from which this annotation is taken.
        # We copy over the value given by nlp.semantic_parsing.annotators.QrefAnnotator.
        # The value will be "-1" if the annotation is coming from low confidence Qref
        # annotations. NOTE - this is generated from as QRef's interetation_number.
        # Corresponds to the JSON property `qrefInterpretationIndex`
        # @return [Fixnum]
        attr_accessor :qref_interpretation_index
      
        # A copy of the span of canonical (raw) parser input text corresponding to this
        # annotation.
        # Corresponds to the JSON property `rawQueryText`
        # @return [String]
        attr_accessor :raw_query_text
      
        # List of entities that are semantically related to the argument as well as
        # details of the relationship.
        # Corresponds to the JSON property `relatedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingRelatedEntity>]
        attr_accessor :related_entity
      
        # Relatedness Matrix signals for FunctionCall Arguments.
        # Corresponds to the JSON property `relatednessSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryRelatednessSignals]
        attr_accessor :relatedness_signals
      
        # Whether this argument was resolved through context from a previous query.
        # Examples: obama -> "he" is resolved from the Obama entity starbucks -> Q2 is
        # resolved from the list of shops
        # Corresponds to the JSON property `resolvedFromContext`
        # @return [Boolean]
        attr_accessor :resolved_from_context
        alias_method :resolved_from_context?, :resolved_from_context
      
        # Whether this argument was resolved from a pronoun mention in the query. Eg: [
        # how old was obama when *he* became president]
        # Corresponds to the JSON property `resolvedFromPronoun`
        # @return [Boolean]
        attr_accessor :resolved_from_pronoun
        alias_method :resolved_from_pronoun?, :resolved_from_pronoun
      
        # The list of result supports for this Argument.
        # Corresponds to the JSON property `resultSupport`
        # @return [Array<Google::Apis::ContentwarehouseV1::UniversalsearchNewPackerKnowledgeResultSupport>]
        attr_accessor :result_support
      
        # Signals derived from overlapping saft annotations.
        # Corresponds to the JSON property `saftSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySaftSignals]
        attr_accessor :saft_signals
      
        # Additional shopping identifiers related to an entity or IQL function call.
        # This must be passed along to the shopping backend (go/o4) to aid in
        # fulfillment. Because the shopping data models do not always line up 1-1 with
        # KG entities and are not always reconciled with each other, the message may
        # contain multiple ids. Next id: 8 LINT.IfChange
        # Corresponds to the JSON property `shoppingIds`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryShoppingIds]
        attr_accessor :shopping_ids
      
        # go/stbr supportthis is an
        # Corresponds to the JSON property `supportTransferRules`
        # @return [Array<Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQuerySupportTransferRule>]
        attr_accessor :support_transfer_rules
      
        # Signals indicating whether this entity received or transferred support (and
        # from which entities).
        # Corresponds to the JSON property `supportTransferSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySupportTransferSignals]
        attr_accessor :support_transfer_signals
      
        # Specifies the allowed type(s) that a value can have, e.g. for a Slot. For
        # example, having both entity_type and string_type present in a ValueType field
        # of a Slot means that the Slot can take _either_ an an EntityType _or_
        # StringType as a value, and nothing else. It may be helpful to think of this
        # proto as being called something like AllAllowedValueTypes. Next tag id: 24
        # LINT.IfChange
        # Corresponds to the JSON property `ungroundedValueType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersValueType]
        attr_accessor :ungrounded_value_type
      
        # Webref entity index for this argument, necessary for interpreting the
        # relationship structure, and the list to index into. Specifically we need this
        # to understand qref implications since they edges are represented with entity
        # indexes.
        # Corresponds to the JSON property `webrefEntitiesIndex`
        # @return [Fixnum]
        attr_accessor :webref_entities_index
      
        # This represents which list entities index refers to.
        # Corresponds to the JSON property `webrefListSource`
        # @return [String]
        attr_accessor :webref_list_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @added_by_close_answers = args[:added_by_close_answers] if args.key?(:added_by_close_answers)
          @allowed_fuzzy_match = args[:allowed_fuzzy_match] if args.key?(:allowed_fuzzy_match)
          @annotated_relationship = args[:annotated_relationship] if args.key?(:annotated_relationship)
          @annotation_layer_signals = args[:annotation_layer_signals] if args.key?(:annotation_layer_signals)
          @chain_id = args[:chain_id] if args.key?(:chain_id)
          @cluster_info = args[:cluster_info] if args.key?(:cluster_info)
          @collection_membership = args[:collection_membership] if args.key?(:collection_membership)
          @context_resolution = args[:context_resolution] if args.key?(:context_resolution)
          @deprecated_freebase_type = args[:deprecated_freebase_type] if args.key?(:deprecated_freebase_type)
          @deprecated_supporting_mid = args[:deprecated_supporting_mid] if args.key?(:deprecated_supporting_mid)
          @entity_number = args[:entity_number] if args.key?(:entity_number)
          @entity_relationship = args[:entity_relationship] if args.key?(:entity_relationship)
          @expression_status = args[:expression_status] if args.key?(:expression_status)
          @from_manual_symbol_annotation = args[:from_manual_symbol_annotation] if args.key?(:from_manual_symbol_annotation)
          @from_symbol_annotation = args[:from_symbol_annotation] if args.key?(:from_symbol_annotation)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @grounding_signals = args[:grounding_signals] if args.key?(:grounding_signals)
          @is_a_ungrounded_type_of = args[:is_a_ungrounded_type_of] if args.key?(:is_a_ungrounded_type_of)
          @is_default_value = args[:is_default_value] if args.key?(:is_default_value)
          @is_enum = args[:is_enum] if args.key?(:is_enum)
          @is_eval_data_heuristic = args[:is_eval_data_heuristic] if args.key?(:is_eval_data_heuristic)
          @is_genie_annotation = args[:is_genie_annotation] if args.key?(:is_genie_annotation)
          @is_intentgen_annotation = args[:is_intentgen_annotation] if args.key?(:is_intentgen_annotation)
          @is_nimble_annotation = args[:is_nimble_annotation] if args.key?(:is_nimble_annotation)
          @location = args[:location] if args.key?(:location)
          @location_markers_signals = args[:location_markers_signals] if args.key?(:location_markers_signals)
          @media_entity_signals = args[:media_entity_signals] if args.key?(:media_entity_signals)
          @merged_implied_entity = args[:merged_implied_entity] if args.key?(:merged_implied_entity)
          @mid_equivalent_to_collection = args[:mid_equivalent_to_collection] if args.key?(:mid_equivalent_to_collection)
          @multiple_horizontal_list_selection_matches = args[:multiple_horizontal_list_selection_matches] if args.key?(:multiple_horizontal_list_selection_matches)
          @munin_signals = args[:munin_signals] if args.key?(:munin_signals)
          @on_device_annotation_signals = args[:on_device_annotation_signals] if args.key?(:on_device_annotation_signals)
          @oyster_id = args[:oyster_id] if args.key?(:oyster_id)
          @parsed_due_to_experiment = args[:parsed_due_to_experiment] if args.key?(:parsed_due_to_experiment)
          @personal_entity = args[:personal_entity] if args.key?(:personal_entity)
          @provenance = args[:provenance] if args.key?(:provenance)
          @qref_confidence_score = args[:qref_confidence_score] if args.key?(:qref_confidence_score)
          @qref_interpretation_index = args[:qref_interpretation_index] if args.key?(:qref_interpretation_index)
          @raw_query_text = args[:raw_query_text] if args.key?(:raw_query_text)
          @related_entity = args[:related_entity] if args.key?(:related_entity)
          @relatedness_signals = args[:relatedness_signals] if args.key?(:relatedness_signals)
          @resolved_from_context = args[:resolved_from_context] if args.key?(:resolved_from_context)
          @resolved_from_pronoun = args[:resolved_from_pronoun] if args.key?(:resolved_from_pronoun)
          @result_support = args[:result_support] if args.key?(:result_support)
          @saft_signals = args[:saft_signals] if args.key?(:saft_signals)
          @shopping_ids = args[:shopping_ids] if args.key?(:shopping_ids)
          @support_transfer_rules = args[:support_transfer_rules] if args.key?(:support_transfer_rules)
          @support_transfer_signals = args[:support_transfer_signals] if args.key?(:support_transfer_signals)
          @ungrounded_value_type = args[:ungrounded_value_type] if args.key?(:ungrounded_value_type)
          @webref_entities_index = args[:webref_entities_index] if args.key?(:webref_entities_index)
          @webref_list_source = args[:webref_list_source] if args.key?(:webref_list_source)
        end
      end
      
      # A message representing the value of an argument. All types in the "value"
      # oneof should have a corresponding field in the ValueType or OpaqueType protos
      # defined in knowledge/answers/config/value.proto. This is specified by
      # annotating each ArgumentValue type with options of the form (value_type_name) =
      # A unit test ensure that this field is set and is valid for all types in
      # ArgumentValue. A small number of special cases (such as funcall and
      # simple_value) are allowed to omit the annotation. See intent_query_proto_test.
      # cc for details. Note: If you are trying to add a new OpaqueType, stop;
      # OpaqueType is deprecated, refer to go/opaque_type for details. If you think
      # this is the only way to implement your feature, attend an office hours (go/
      # meaning-help) and discuss with the MRF team. Next Id: 41
      class KnowledgeAnswersIntentQueryArgumentValue
        include Google::Apis::Core::Hashable
      
        # In simple cases, each NLU slot will contain one or multiple possible values.
        # But in the case of a composite entity - slots can have a complex tree
        # structure. Each slot can represent a List parameter. List parameters are only
        # allowed at the top level, i.e. lists can't ne nested in maps. Next Id: 9 LINT.
        # IfChange
        # Corresponds to the JSON property `aogSlot`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleAogSlot]
        attr_accessor :aog_slot
      
        # The App annotator annotates potential app name in the parser's input and
        # outputs the proto with the details about app(s).
        # Corresponds to the JSON property `appAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAppAnnotation]
        attr_accessor :app_annotation
      
        # Represents a music recording (usually a song). Each populated field can be
        # thought of as additional constraint about the song's identity. For instance,
        # if no fields are set, then this represents "some song." If only the
        # music_artist is set, then it represents "some song by the specified
        # music_artist." Inspired (but not strictly adhered to) http://schema.org/
        # MusicRecording Next ID: 22
        # Corresponds to the JSON property `audio`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaAudio]
        attr_accessor :audio
      
        # This proto contains the information of a calendar event, including title,
        # start time, end time, etc. IMPORTANT: The definition of CalendarEvent proto is
        # being moved to //assistant/api/core_types/governed/calendar_event_type.proto.
        # All existing references will be updated to point to the new location. If you
        # are adding a reference, use the new one instead. LINT.IfChange(CalendarEvent)
        # NEXT_ID: 26
        # Corresponds to the JSON property `calendarEvent`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEvent]
        attr_accessor :calendar_event
      
        # This empty type allows us to publish sensitive calendar events to go/
        # attentional-entities, while maintaining BUILD visibility protection for their
        # contents. The BUILD-visibility-protected extension to this message is defined
        # at http://google3/assistant/verticals/calendar/proto/
        # multi_account_calendar_event.proto IMPORTANT: The definition of
        # CalendarEventWrapper proto is being moved to //assistant/api/core_types/
        # governed/calendar_event_type.proto. All existing references will be updated to
        # point to the new location. If you are adding a reference, use the new one
        # instead.
        # Corresponds to the JSON property `calendarEventWrapper`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventWrapper]
        attr_accessor :calendar_event_wrapper
      
        # 
        # Corresponds to the JSON property `calendarReference`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteCalendarReference]
        attr_accessor :calendar_reference
      
        # Custom type used by Complex Queries. This is populated based on the output of
        # the RPC to the Complex Queries Boq node.
        # Corresponds to the JSON property `complexQueriesRewrite`
        # @return [Google::Apis::ContentwarehouseV1::QualityGenieComplexQueriesComplexQueriesOutputRewrite]
        attr_accessor :complex_queries_rewrite
      
        # The ArgumentValue reference to Mention.CompoundMention.Component. Next
        # available tag number: 4
        # Corresponds to the JSON property `componentReference`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefComponentReference]
        attr_accessor :component_reference
      
        # A message representing a coreferenced value defined elsewhere in the meaning
        # struct.
        # Corresponds to the JSON property `coreference`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryCoreference]
        attr_accessor :coreference
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `dateTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :date_time
      
        # Media device. Like, Chromecast, TV or Chirp. When emitted from the cast_device
        # domain, you should expect it to be one of 3 different forms: 1) Personal
        # Device: The annotation comes from a device we found in the user's home.
        # device_id and name should be set, cast_device_type is set if device type is
        # mentioned in query. e.g. "Dima's Pineapple Chirp" device_id: FOOBAR name: "
        # Dima's Pineapple" cast_device_type: CHIRP 2) Common Device Name: The
        # annotation comes from a model of the common names of user's device. name and
        # cast_device_type should be set but device_id will not be. cast_device_type can
        # be UNKNOWN. e.g. "John's Living Room" name: "John's Living Room"
        # cast_device_type: UNKNOWN 3) Device Type: The annotation comes from a model of
        # common cast device types. Only cast_device_type will be set. e.g. "TV" or "
        # chromecast" cast_device_type: CHROMECAST Next ID: 9
        # Corresponds to the JSON property `device`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaCastDeviceAnnotation]
        attr_accessor :device
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceId`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_id
      
        # IMPORTANT: The definition of DeviceUserIdentity is being moved to //assistant/
        # api/core_types/governed/device_user_identity.proto. All existing references
        # will be updated to point to the new location. If you are adding a reference,
        # use the new DeviceUserIdentity instead of this one. // LINT.IfChange
        # Corresponds to the JSON property `deviceUserIdentity`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceUserIdentity]
        attr_accessor :device_user_identity
      
        # To represent unanchored durations - the length of a date/time expression not
        # related to calendar in local context. E.g., "play first (DURATION: 5 minutes)
        # of Yellow Submarine", "it takes (DURATION: more than 3 days) to finish." In
        # contrast, queries like: "wake me up in 5 minutes" will be resolved to a
        # AbsoluteDateTime since the query indicates that the reference is now. A
        # duration can be turned into a range if either end is anchored.
        # Corresponds to the JSON property `duration`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDuration]
        attr_accessor :duration
      
        # A message representing the function call of an answers intent query. Next ID:
        # 19 Important: If you add new fields that do not reflect signals data, but
        # actual semantics of the FunctionCall, please also update
        # CreateFuncallCopyWithoutSignals and CreateFuncallCopyWithArgumentSignals in
        # function_call_utils. LINT.IfChange
        # Corresponds to the JSON property `funcall`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryFunctionCall]
        attr_accessor :funcall
      
        # Next ID: 9
        # Corresponds to the JSON property `homeAutomationDevice`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsHomeautomationProtoHomeAutomationDevice]
        attr_accessor :home_automation_device
      
        # There are a few types of locations: - Basic locations are sequences of
        # location elements which can be either actual locations or modifiers. E.g., "
        # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
        # location), "CA" (an actual location, and "94040" (a numeric modifier). -
        # Compound locations: these are two locations combined by a joiner. E.g., "
        # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
        # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
        # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
        # indicates an area around a certain location. The area can be defined by time
        # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
        # a few miles from here". Next ID: 14
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocation]
        attr_accessor :location
      
        # Annotation for media entities. Next ID: 17
        # Corresponds to the JSON property `media`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotation]
        attr_accessor :media
      
        # This proto captures the contents of a messaging app notification that is
        # typically part of a conversation thread. Next Id: 20
        # Corresponds to the JSON property `messageNotification`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesMessageNotification]
        attr_accessor :message_notification
      
        # Represent a money quantity
        # Corresponds to the JSON property `money`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMoneyMoney]
        attr_accessor :money
      
        # Corresponds to an entry in our hand-curated Nimble table of providers.
        # Corresponds to the JSON property `narrativeNewsProvider`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsNarrativeNewsNewsProvider]
        attr_accessor :narrative_news_provider
      
        # Next ID: 9
        # Corresponds to the JSON property `number`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberNumber]
        attr_accessor :number
      
        # OnDevice describes the device(s) to perform an action. This message type can
        # be imported in action messages as an argument.
        # Corresponds to the JSON property `onDevice`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsOnDevice]
        attr_accessor :on_device
      
        # Represents: structured person names, including common names and personal
        # contacts. Annotated by: go/person-subgrammar.
        # Corresponds to the JSON property `person`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsPersonPerson]
        attr_accessor :person
      
        # This message should be wire-equivalent to the Entity proto defined in nlp/
        # semantic_parsing/models/personal_intelligence.proto. The message is cloned
        # here to allow legacy intents to extract entities to slots; trying to add
        # Entity to knowledge_answers::intent_query::ArgumentValue creates a BUILD
        # dependency loop. For the proto used for GwsLogs, see logs/proto/knowledge/
        # interpretation/personal_intelligence.proto.
        # Corresponds to the JSON property `personalIntelligenceEntity`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingPersonalIntelligenceEntity]
        attr_accessor :personal_intelligence_entity
      
        # A message to represent an item in a list. Just a basic string for now, but
        # extensible for the future.
        # Corresponds to the JSON property `productivityListItem`
        # @return [Google::Apis::ContentwarehouseV1::AssistantProductivityListItem]
        attr_accessor :productivity_list_item
      
        # Recurrence rule for specifying date- and time-based repetition for tasks. Next
        # id: 12.
        # Corresponds to the JSON property `recurrence`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrence]
        attr_accessor :recurrence
      
        # Next id: 30
        # Corresponds to the JSON property `reminder`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminder]
        attr_accessor :reminder
      
        # Sensitive value, see go/sensitive-intents and go/a4w-multi-turn-dialog
        # Corresponds to the JSON property `sensitiveValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySensitiveArgumentValueGuard]
        attr_accessor :sensitive_value
      
        # Argument level query sensitivities. 1) Statically defined Sensitivity is
        # copied from IntentSlot at serving time so it can be propagated along with
        # FunctionCall to places where the Intent Catalog is not available. See go/
        # sensitive-intents for details. 2) For the same reason, contextual sensitivites
        # (eg., from AttentionalEntity mentions) are populated here too. See go/tagging-
        # sensitive-ae for details.
        # Corresponds to the JSON property `sensitivity`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivitySensitivity>]
        attr_accessor :sensitivity
      
        # A merchant that sells products.
        # Corresponds to the JSON property `shoppingMerchant`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantMerchant]
        attr_accessor :shopping_merchant
      
        # A product for sale from a particular merchant, possibly available at a
        # specific store.
        # Corresponds to the JSON property `shoppingOffer`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantOffer]
        attr_accessor :shopping_offer
      
        # A product that can be purchased.
        # Corresponds to the JSON property `shoppingProduct`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProduct]
        attr_accessor :shopping_product
      
        # An expression parsed from a user query that describes a product or set of
        # products.
        # Corresponds to the JSON property `shoppingProductExpression`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductExpression]
        attr_accessor :shopping_product_expression
      
        # A merchant's physical store.
        # Corresponds to the JSON property `shoppingStore`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantStore]
        attr_accessor :shopping_store
      
        # A message representing a simple literal value.
        # Corresponds to the JSON property `simpleValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySimpleValue]
        attr_accessor :simple_value
      
        # Conceptually, timers are clocks that count down from an initial duration and
        # notify when they reach 0. In practice, as a timer is running, it holds a
        # stable expiration time and computes the remaining duration using the current
        # time. When a timer is paused, it holds a stable remaining duration.
        # Corresponds to the JSON property `timer`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsTimer]
        attr_accessor :timer
      
        # Represents: timezone expressions (e.g. Eastern Daylight Time). Annotated by:
        # datetime subgrammar.
        # Corresponds to the JSON property `timezone`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeTimeZone]
        attr_accessor :timezone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aog_slot = args[:aog_slot] if args.key?(:aog_slot)
          @app_annotation = args[:app_annotation] if args.key?(:app_annotation)
          @audio = args[:audio] if args.key?(:audio)
          @calendar_event = args[:calendar_event] if args.key?(:calendar_event)
          @calendar_event_wrapper = args[:calendar_event_wrapper] if args.key?(:calendar_event_wrapper)
          @calendar_reference = args[:calendar_reference] if args.key?(:calendar_reference)
          @complex_queries_rewrite = args[:complex_queries_rewrite] if args.key?(:complex_queries_rewrite)
          @component_reference = args[:component_reference] if args.key?(:component_reference)
          @coreference = args[:coreference] if args.key?(:coreference)
          @date_time = args[:date_time] if args.key?(:date_time)
          @device = args[:device] if args.key?(:device)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_user_identity = args[:device_user_identity] if args.key?(:device_user_identity)
          @duration = args[:duration] if args.key?(:duration)
          @funcall = args[:funcall] if args.key?(:funcall)
          @home_automation_device = args[:home_automation_device] if args.key?(:home_automation_device)
          @location = args[:location] if args.key?(:location)
          @media = args[:media] if args.key?(:media)
          @message_notification = args[:message_notification] if args.key?(:message_notification)
          @money = args[:money] if args.key?(:money)
          @narrative_news_provider = args[:narrative_news_provider] if args.key?(:narrative_news_provider)
          @number = args[:number] if args.key?(:number)
          @on_device = args[:on_device] if args.key?(:on_device)
          @person = args[:person] if args.key?(:person)
          @personal_intelligence_entity = args[:personal_intelligence_entity] if args.key?(:personal_intelligence_entity)
          @productivity_list_item = args[:productivity_list_item] if args.key?(:productivity_list_item)
          @recurrence = args[:recurrence] if args.key?(:recurrence)
          @reminder = args[:reminder] if args.key?(:reminder)
          @sensitive_value = args[:sensitive_value] if args.key?(:sensitive_value)
          @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
          @shopping_merchant = args[:shopping_merchant] if args.key?(:shopping_merchant)
          @shopping_offer = args[:shopping_offer] if args.key?(:shopping_offer)
          @shopping_product = args[:shopping_product] if args.key?(:shopping_product)
          @shopping_product_expression = args[:shopping_product_expression] if args.key?(:shopping_product_expression)
          @shopping_store = args[:shopping_store] if args.key?(:shopping_store)
          @simple_value = args[:simple_value] if args.key?(:simple_value)
          @timer = args[:timer] if args.key?(:timer)
          @timezone = args[:timezone] if args.key?(:timezone)
        end
      end
      
      # Contains an attribute id and it's completion score.
      class KnowledgeAnswersIntentQueryAttributeSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # A message representing the collection membership of an entity.
      class KnowledgeAnswersIntentQueryCollectionMembership
        include Google::Apis::Core::Hashable
      
        # Human readable id of the collection.
        # Corresponds to the JSON property `collectionId`
        # @return [String]
        attr_accessor :collection_id
      
        # Identifier of the collection, usually a MID (/m/xyz or /g/zyw).
        # Corresponds to the JSON property `collectionMid`
        # @return [String]
        attr_accessor :collection_mid
      
        # The collection score for a entity.
        # Corresponds to the JSON property `collectionScore`
        # @return [Float]
        attr_accessor :collection_score
      
        # Different types of scores for the collection. Each score type has at most one
        # score.
        # Corresponds to the JSON property `score`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryCollectionScore>]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection_id = args[:collection_id] if args.key?(:collection_id)
          @collection_mid = args[:collection_mid] if args.key?(:collection_mid)
          @collection_score = args[:collection_score] if args.key?(:collection_score)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # 
      class KnowledgeAnswersIntentQueryCollectionScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `scoreType`
        # @return [String]
        attr_accessor :score_type
      
        # 
        # Corresponds to the JSON property `scoreValue`
        # @return [Float]
        attr_accessor :score_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score_type = args[:score_type] if args.key?(:score_type)
          @score_value = args[:score_value] if args.key?(:score_value)
        end
      end
      
      # A message representing a coreferenced value defined elsewhere in the meaning
      # struct.
      class KnowledgeAnswersIntentQueryCoreference
        include Google::Apis::Core::Hashable
      
        # A coreference is represented by an argument path starting from the root of the
        # whole tree to the referenced value.
        # Corresponds to the JSON property `argPath`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgPath]
        attr_accessor :arg_path
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @arg_path = args[:arg_path] if args.key?(:arg_path)
        end
      end
      
      # Signals associated with CustomVehicleActionArgumentAnnotator annotations.
      class KnowledgeAnswersIntentQueryCustomVehicleActionArgumentAnnotatorSignals
        include Google::Apis::Core::Hashable
      
        # Stores any additional data which is required only at the intent fulfilment
        # phase.
        # Corresponds to the JSON property `additionalAnnotationData`
        # @return [Hash<String,String>]
        attr_accessor :additional_annotation_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_annotation_data = args[:additional_annotation_data] if args.key?(:additional_annotation_data)
        end
      end
      
      # Signals associated with FreetextAnnotator annotations. Empty. The signal being
      # present is enough for the conformance checking library to be able to check.
      class KnowledgeAnswersIntentQueryFreetextAnnotationSignals
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # A message representing the function call of an answers intent query. Next ID:
      # 19 Important: If you add new fields that do not reflect signals data, but
      # actual semantics of the FunctionCall, please also update
      # CreateFuncallCopyWithoutSignals and CreateFuncallCopyWithArgumentSignals in
      # function_call_utils. LINT.IfChange
      class KnowledgeAnswersIntentQueryFunctionCall
        include Google::Apis::Core::Hashable
      
        # A list of arguments of this function call.
        # Corresponds to the JSON property `argument`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgument>]
        attr_accessor :argument
      
        # The corresponding meaning catalog version that was used to generate this
        # FunctionCall.
        # Corresponds to the JSON property `catalogVersion`
        # @return [Fixnum]
        attr_accessor :catalog_version
      
        # Contextual Sensitivity (go/contextual-sensitivity) metadata indicating that a
        # policy- or privacy- sensitive conversation context (previous queries,
        # rewritten user queries, and previous system responses, like attentional
        # entities) is used to generate this FunctionCall. This needs propagation (1)
        # from Interp to DialogIntentState (DIS) (see b/148479837) and (2) from QRewrite/
        # QUS down to Assistant Server's memory finalizer. One can use knowledge/answers/
        # sensitivity/sensitivity_reader.h to parse this proto. NOTE(b/149091449): This
        # is part of the migration of contextual sensitivity protos from Interp
        # sensitivity extension. (nlp::semantic_parsing::sensitivity) to this proto
        # field. See the bug to track the migration progress and for more details.
        # Corresponds to the JSON property `contextualSensitivity`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivitySensitivity>]
        attr_accessor :contextual_sensitivity
      
        # This is the FunctionCall counterpart to the "MeaningRemodelings" structure.
        # When present, it is used for typechecking the FunctionCall against the schema
        # with the remodelings enabled.
        # Corresponds to the JSON property `enabledRemodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelingControl]
        attr_accessor :enabled_remodelings
      
        # A list of token lists that were ignored during parsing because they are known
        # context phrases for this interpretation. For example, for query [tell me how
        # tall height of Obama really], assuming "tell me", "tall", "of", "really" are
        # explained and thus ignored, with corresponding prior 0.9, 0.8, 0.7, 0.6,
        # following ignored tokens will be populated: ` ignored_tokens ` token ` ngram: "
        # tell me", prior: 0.9` score: 0.9 ` ignored_tokens ` token ` ngram: "tall",
        # prior: 0.8` token ` ngram: "of", prior: 0.7` score: 0.56 // currently score =
        # prior1 * prior2 * ... * prior N ` ignored_tokens ` token ` ngram: "really",
        # prior: 0.6` score: 0.6 ` ` These tokens can serve two purpose: 1) debug info
        # to show why an interpretation is generated; 2) carry the signals for
        # downstream usage. Note: This field is under active development, and
        # significant changes could happen. Please contact porky-pig@ if you want to use
        # it.
        # Corresponds to the JSON property `ignoredTokens`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryTokens>]
        attr_accessor :ignored_tokens
      
        # The primary key for an intent. Next ID: 3
        # Corresponds to the JSON property `key`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMeaningSchemaKey]
        attr_accessor :key
      
        # A Marker specifies a Meaning Expression's (i.e. intent FunctionCall) purpose.
        # NOTE: Markers always impact go/intent-resolution semantics.
        # Corresponds to the JSON property `marker`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMarker]
        attr_accessor :marker
      
        # Modifiers decorate a Meaning Expression (i.e. intent FunctionCall) with
        # signals that depend on the source language's grammar and syntax. See go/intent-
        # modifiers for details. NOTE: Modifiers don't necessarily impact go/intent-
        # resolution semantics. LINT.IfChange
        # Corresponds to the JSON property `modifiers`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentModifiers]
        attr_accessor :modifiers
      
        # Name of this function call. The name must be present. If it is omitted, the
        # FunctionCall is not well-formed.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Canonical representation of query sensitivites. See go/sensitive-intents for
        # more details.
        # Corresponds to the JSON property `sensitivity`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivitySensitivity]
        attr_accessor :sensitivity
      
        # Next ID: 34
        # Corresponds to the JSON property `signals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryFunctionCallSignals]
        attr_accessor :signals
      
        # A list of tokens that were ignored during parsing that cannot be explained by
        # context phrases.
        # Corresponds to the JSON property `unexplainedTokens`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryTokens>]
        attr_accessor :unexplained_tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @argument = args[:argument] if args.key?(:argument)
          @catalog_version = args[:catalog_version] if args.key?(:catalog_version)
          @contextual_sensitivity = args[:contextual_sensitivity] if args.key?(:contextual_sensitivity)
          @enabled_remodelings = args[:enabled_remodelings] if args.key?(:enabled_remodelings)
          @ignored_tokens = args[:ignored_tokens] if args.key?(:ignored_tokens)
          @key = args[:key] if args.key?(:key)
          @marker = args[:marker] if args.key?(:marker)
          @modifiers = args[:modifiers] if args.key?(:modifiers)
          @name = args[:name] if args.key?(:name)
          @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
          @signals = args[:signals] if args.key?(:signals)
          @unexplained_tokens = args[:unexplained_tokens] if args.key?(:unexplained_tokens)
        end
      end
      
      # Next ID: 34
      class KnowledgeAnswersIntentQueryFunctionCallSignals
        include Google::Apis::Core::Hashable
      
        # The argument mid that was used to compose the entity for a concept
        # interpretation, along with the intent_composing_mid (one of the intent's
        # equivalent MIDs).
        # Corresponds to the JSON property `argumentComposingMid`
        # @return [String]
        attr_accessor :argument_composing_mid
      
        # The attributes from which this intent was generated during execution of
        # AttributeSignalsProvider. |attribute_signals| is only populated for single
        # entity funcalls.
        # Corresponds to the JSON property `attributeSignals`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryAttributeSignal>]
        attr_accessor :attribute_signals
      
        # An entity that represents the concept of an entity-attribute intent by being
        # composed of an intent equivalent MID and the argument MID.
        # Corresponds to the JSON property `conceptEntityMid`
        # @return [String]
        attr_accessor :concept_entity_mid
      
        # 
        # Corresponds to the JSON property `confidenceLevel`
        # @return [String]
        attr_accessor :confidence_level
      
        # FunctionCall-s that this funcall was deduped against.
        # Corresponds to the JSON property `dedupedFuncalls`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryFunctionCall>]
        attr_accessor :deduped_funcalls
      
        # Status indicating whether the user has finished expressing their intended
        # semantics during a streaming interaction. Semantics are partially expressed
        # when later, unprompted user input is expected to modify the semantics. Future
        # inputs are typically additional speech or continued modification of argument
        # text in form field. These inputs can trigger modifications including adding
        # arguments, changing the intent, or modifying existing arguments. Sensing this
        # status can be done both directly and indirectly. Fluid Actions directly
        # detects this status as the user moves between, or enters and leaves, argument
        # form fields. Understanding indirectly detects this status by the pace of the
        # user's speech, the semantics of the language, and the user's intonation. See
        # go/streaming-nlu-fulfilment-protocol-v1 for details about how it is used in
        # the Streaming NLU Fulfillment protocol.
        # Corresponds to the JSON property `expressionStatus`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingExpressionStatus]
        attr_accessor :expression_status
      
        # 
        # Corresponds to the JSON property `freefolksTrigger`
        # @return [String]
        attr_accessor :freefolks_trigger
      
        # Grounding-related signals to be propagated down stream. Next ID: 12
        # Corresponds to the JSON property `groundingSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryGroundingSignals]
        attr_accessor :grounding_signals
      
        # Used to indicate that an interpretation is high confidence and triggers
        # different voting behavior. This bit should only be set for verticals.
        # DEPRECATED. Use confidence_level instead.
        # Corresponds to the JSON property `highConfidence`
        # @return [Boolean]
        attr_accessor :high_confidence
        alias_method :high_confidence?, :high_confidence
      
        # 
        # Corresponds to the JSON property `intentAnnotationSources`
        # @return [Array<String>]
        attr_accessor :intent_annotation_sources
      
        # An intent_relevant_mid that was used to compose the entity for a concept
        # interpretation, along with argument_composing_mid (the question's argument MID)
        # .
        # Corresponds to the JSON property `intentComposingMid`
        # @return [String]
        attr_accessor :intent_composing_mid
      
        # Information about where the value of this intent came from. For example, it
        # could have been explicitly provided in the query, pulled in from the previous
        # dialog state, or pulled from previous queries.
        # Corresponds to the JSON property `intentProvenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentProvenance>]
        attr_accessor :intent_provenance
      
        # KG mids of entities that represent this intent. These entities are seen as
        # equivalent to the Intent definition, and are specified in the Intent Catalog
        # as relevant_mid.
        # Corresponds to the JSON property `intentRelevantMid`
        # @return [Array<String>]
        attr_accessor :intent_relevant_mid
      
        # Whether the interpretation was generated using similar queries in POSTREF. In
        # case POSTREF_AQUA generated the same entity-attribute interpretation, this is
        # still set to true.
        # Corresponds to the JSON property `isCloseInterpretation`
        # @return [Boolean]
        attr_accessor :is_close_interpretation
        alias_method :is_close_interpretation?, :is_close_interpretation
      
        # Denotes whether this is an intent being fulfilled from user tapping a
        # disambiguation card. More info in go/cardea-deck.
        # Corresponds to the JSON property `isDisambiguationCardIntent`
        # @return [Boolean]
        attr_accessor :is_disambiguation_card_intent
        alias_method :is_disambiguation_card_intent?, :is_disambiguation_card_intent
      
        # Denotes whether this is a sub-intent of an ambiguous SystemUncertain intent go/
        # intent-disambiguation.
        # Corresponds to the JSON property `isDisambiguationIntent`
        # @return [Boolean]
        attr_accessor :is_disambiguation_intent
        alias_method :is_disambiguation_intent?, :is_disambiguation_intent
      
        # Denotes this is a sub-intent used for composing an Assistant UI response. The
        # assistant dialog should output ui_composition_shelf in the SystemResponse if
        # it can fulfill the intent. More info in go/davinci-design and go/davinci-di-
        # fulfillment
        # Corresponds to the JSON property `isUiCompositionIntent`
        # @return [Boolean]
        attr_accessor :is_ui_composition_intent
        alias_method :is_ui_composition_intent?, :is_ui_composition_intent
      
        # A message that stores information about Local results to be used in the Packer
        # for Local Categorical derived intent deduplication and conformance.
        # Corresponds to the JSON property `localSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryLocalSignals]
        attr_accessor :local_signals
      
        # A tag to annotate user's journey (e.g., JourneyFollowCampusUpdates). This will
        # be used for Journey OSRP demo (go/josrp-sprint). !!NOTE!! This field is
        # reserved for Journey OSRP demo, and will be deprecated shortly after its
        # completion. DO NOT USE.
        # Corresponds to the JSON property `osrpJourneyTag`
        # @return [String]
        attr_accessor :osrp_journey_tag
      
        # Experiments that caused this FunctionCall to parse, without which this would
        # not have parsed.
        # Corresponds to the JSON property `parsedDueToExperiment`
        # @return [Array<String>]
        attr_accessor :parsed_due_to_experiment
      
        # Parsing-related signals. Only horizontal signals should appear directly as
        # fields on this message. Each domain should create their own extension for
        # anything that they need to propagate down stream from AQUA. Note that this
        # proto is not the same as the Superroot proto ParsingSignals (http://google3/
        # knowledge/proto/scoring-signals.proto), which is a Superroot-specific signal
        # used in Scoring. Next ID: 4
        # Corresponds to the JSON property `parsingSignals`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryParsingSignals]
        attr_accessor :parsing_signals
      
        # Identifies a score, determined before fulfillment but after grounding. Written
        # by the Prefulfillment Ranker, and used as a signal for ACE Ranking.
        # Corresponds to the JSON property `prefulfillmentRankingScore`
        # @return [Float]
        attr_accessor :prefulfillment_ranking_score
      
        # Signals to be used by the Prefulfillment Ranker. Derived from the
        # ParsingSignals and GroundingSignals carried by the FunctionCall. LINT.IfChange
        # Next ID: 25
        # Corresponds to the JSON property `prefulfillmentSignals`
        # @return [Google::Apis::ContentwarehouseV1::AssistantPrefulfillmentRankerPrefulfillmentSignals]
        attr_accessor :prefulfillment_signals
      
        # How a piece of data was resolved through external data (either elsewhere in
        # the query, or from a previous query). Examples: [obama and his age] -> "his"
        # is resolved from the Obama entity obama -> "he" is resolved from the Obama
        # entity starbucks -> Q2 is resolved from the list of shops
        # Corresponds to the JSON property `referentialResolution`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersDialogReferentialResolution]
        attr_accessor :referential_resolution
      
        # The id of the summary node if this funcall represents an mdvc interpretation
        # Corresponds to the JSON property `refxSummaryNodeId`
        # @return [String]
        attr_accessor :refx_summary_node_id
      
        # The list of result supports for this FunctionCall.
        # Corresponds to the JSON property `resultSupport`
        # @return [Array<Google::Apis::ContentwarehouseV1::UniversalsearchNewPackerKnowledgeResultSupport>]
        attr_accessor :result_support
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # Identifies whether the Prefulfillment Ranker selected this intent for emission.
        # This is needed temporarily while migrating intent emitters from ACE to QUS/
        # PFR. See go/pfr-intent-emitter for more info
        # Corresponds to the JSON property `selectedByPrefulfillmentRanking`
        # @return [Boolean]
        attr_accessor :selected_by_prefulfillment_ranking
        alias_method :selected_by_prefulfillment_ranking?, :selected_by_prefulfillment_ranking
      
        # Additional shopping identifiers related to an entity or IQL function call.
        # This must be passed along to the shopping backend (go/o4) to aid in
        # fulfillment. Because the shopping data models do not always line up 1-1 with
        # KG entities and are not always reconciled with each other, the message may
        # contain multiple ids. Next id: 8 LINT.IfChange
        # Corresponds to the JSON property `shoppingIds`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryShoppingIds]
        attr_accessor :shopping_ids
      
        # Additional intents to be used for intent scoring. This field must only be
        # populated when we cannot find a single unified intent. For example, when we
        # compute signals for a LocalEntities function call, this means we could not
        # find a unified intent to capture all the local results. In this case, we add a
        # fallback intent for each local result (e.g. GeoSchool, GeoRestaurant, and
        # GeoBank if those are the results we show).
        # Corresponds to the JSON property `signalsFallbackIntents`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySignalComputationFallbackIntent>]
        attr_accessor :signals_fallback_intents
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @argument_composing_mid = args[:argument_composing_mid] if args.key?(:argument_composing_mid)
          @attribute_signals = args[:attribute_signals] if args.key?(:attribute_signals)
          @concept_entity_mid = args[:concept_entity_mid] if args.key?(:concept_entity_mid)
          @confidence_level = args[:confidence_level] if args.key?(:confidence_level)
          @deduped_funcalls = args[:deduped_funcalls] if args.key?(:deduped_funcalls)
          @expression_status = args[:expression_status] if args.key?(:expression_status)
          @freefolks_trigger = args[:freefolks_trigger] if args.key?(:freefolks_trigger)
          @grounding_signals = args[:grounding_signals] if args.key?(:grounding_signals)
          @high_confidence = args[:high_confidence] if args.key?(:high_confidence)
          @intent_annotation_sources = args[:intent_annotation_sources] if args.key?(:intent_annotation_sources)
          @intent_composing_mid = args[:intent_composing_mid] if args.key?(:intent_composing_mid)
          @intent_provenance = args[:intent_provenance] if args.key?(:intent_provenance)
          @intent_relevant_mid = args[:intent_relevant_mid] if args.key?(:intent_relevant_mid)
          @is_close_interpretation = args[:is_close_interpretation] if args.key?(:is_close_interpretation)
          @is_disambiguation_card_intent = args[:is_disambiguation_card_intent] if args.key?(:is_disambiguation_card_intent)
          @is_disambiguation_intent = args[:is_disambiguation_intent] if args.key?(:is_disambiguation_intent)
          @is_ui_composition_intent = args[:is_ui_composition_intent] if args.key?(:is_ui_composition_intent)
          @local_signals = args[:local_signals] if args.key?(:local_signals)
          @osrp_journey_tag = args[:osrp_journey_tag] if args.key?(:osrp_journey_tag)
          @parsed_due_to_experiment = args[:parsed_due_to_experiment] if args.key?(:parsed_due_to_experiment)
          @parsing_signals = args[:parsing_signals] if args.key?(:parsing_signals)
          @prefulfillment_ranking_score = args[:prefulfillment_ranking_score] if args.key?(:prefulfillment_ranking_score)
          @prefulfillment_signals = args[:prefulfillment_signals] if args.key?(:prefulfillment_signals)
          @referential_resolution = args[:referential_resolution] if args.key?(:referential_resolution)
          @refx_summary_node_id = args[:refx_summary_node_id] if args.key?(:refx_summary_node_id)
          @result_support = args[:result_support] if args.key?(:result_support)
          @role = args[:role] if args.key?(:role)
          @selected_by_prefulfillment_ranking = args[:selected_by_prefulfillment_ranking] if args.key?(:selected_by_prefulfillment_ranking)
          @shopping_ids = args[:shopping_ids] if args.key?(:shopping_ids)
          @signals_fallback_intents = args[:signals_fallback_intents] if args.key?(:signals_fallback_intents)
        end
      end
      
      # Grounding-related signals to be propagated down stream. Next ID: 12
      class KnowledgeAnswersIntentQueryGroundingSignals
        include Google::Apis::Core::Hashable
      
        # True if the argument was added during grounding. This signal is intended to be
        # used with ArgumentSignals. Note that the added argument's value must be a
        # FunctionCall that only contains resolutions, i.e. grounding cannot add/modify/
        # delete any ungrounded values.
        # Corresponds to the JSON property `addedByGrounding`
        # @return [Boolean]
        attr_accessor :added_by_grounding
        alias_method :added_by_grounding?, :added_by_grounding
      
        # Score indicating how grounded the intent is, populated by the Grounding Box,
        # used by the pre-fulfillment ranker, see http://go/prefulfillment-ranker.
        # Corresponds to the JSON property `groundabilityScore`
        # @return [Float]
        attr_accessor :groundability_score
      
        # Sum of the number of constraints used by the Grounding Box to ground each
        # variable.
        # Corresponds to the JSON property `numConstraints`
        # @return [Float]
        attr_accessor :num_constraints
      
        # Sum of the number of constraints satisfied for each variable. Depending on the
        # match score for a constraint, this number can be fractional and is in the
        # range [0, num_constraints].
        # Corresponds to the JSON property `numConstraintsSatisfied`
        # @return [Float]
        attr_accessor :num_constraints_satisfied
      
        # Number of groundable arguments in the parsed intent.
        # Corresponds to the JSON property `numGroundableArgs`
        # @return [Float]
        attr_accessor :num_groundable_args
      
        # Number of arguments that got actually grounded.
        # Corresponds to the JSON property `numGroundedArgs`
        # @return [Float]
        attr_accessor :num_grounded_args
      
        # Number of arguments, possibly nested, that the Grounding Box tried to ground.
        # Corresponds to the JSON property `numVariables`
        # @return [Float]
        attr_accessor :num_variables
      
        # Number of arguments, possibly nested, that the Grounding Box was able to
        # ground. This includes ambiguously grounded arguments.
        # Corresponds to the JSON property `numVariablesGrounded`
        # @return [Float]
        attr_accessor :num_variables_grounded
      
        # PGRP outputs PROD_INTENT_FACTORY intent format by default. See go/intent-
        # conversion-locations-in-sage. Experimental flags can change or make PGRP
        # output additional intents formatted for PORTMON_FULFILLMENT (e.g. with RDs).
        # This is used by the PortMon/ARM dark launch (go/arm-dark-launch-infra). Longer
        # term, this will be replaced by DGS system-internal transformations (go/if-dgs).
        # Corresponds to the JSON property `pgrpOutputFormat`
        # @return [String]
        attr_accessor :pgrp_output_format
      
        # If true, then GroundingBox and PGRP are used in AnswersRewriter to process the
        # intent. Other post-processing steps, including IGDP, are adjusted accordingly.
        # Note this will be removed once GroundingBox is fully launched and all prod
        # traffic goes through it. Before that happens, each IG that needs to go through
        # GB and PGRP (post GB ranking pruning) will need to explicitly set this field
        # to true. See http://go/gb-impl and http://go/gb-post-ranker-pruner for details.
        # Corresponds to the JSON property `usesGroundingBox`
        # @return [Boolean]
        attr_accessor :uses_grounding_box
        alias_method :uses_grounding_box?, :uses_grounding_box
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @added_by_grounding = args[:added_by_grounding] if args.key?(:added_by_grounding)
          @groundability_score = args[:groundability_score] if args.key?(:groundability_score)
          @num_constraints = args[:num_constraints] if args.key?(:num_constraints)
          @num_constraints_satisfied = args[:num_constraints_satisfied] if args.key?(:num_constraints_satisfied)
          @num_groundable_args = args[:num_groundable_args] if args.key?(:num_groundable_args)
          @num_grounded_args = args[:num_grounded_args] if args.key?(:num_grounded_args)
          @num_variables = args[:num_variables] if args.key?(:num_variables)
          @num_variables_grounded = args[:num_variables_grounded] if args.key?(:num_variables_grounded)
          @pgrp_output_format = args[:pgrp_output_format] if args.key?(:pgrp_output_format)
          @uses_grounding_box = args[:uses_grounding_box] if args.key?(:uses_grounding_box)
        end
      end
      
      # Identifiers are references to a specific entity of a specified type, such as a
      # TIMER_ID XXX. For more backround and uses see go/grounding-common-ids.
      class KnowledgeAnswersIntentQueryIdentifier
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `idType`
        # @return [String]
        attr_accessor :id_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @id_type = args[:id_type] if args.key?(:id_type)
        end
      end
      
      # Signals for $QRefImpliedEntities that are merged into entity arguments during
      # parsing.
      class KnowledgeAnswersIntentQueryImpliedEntity
        include Google::Apis::Core::Hashable
      
        # A copy of the span of canonical (raw) parser input text corresponding to this
        # annotation. Copied from QRefAnnotation.annotated_span.
        # Corresponds to the JSON property `annotatedSpan`
        # @return [String]
        attr_accessor :annotated_span
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # TODO (b/143536264): Create a new ImpliedTokens message and remove this.
        # Whether the implied entity is ungrounded value, set to true when the entity
        # doesn't have a KG mid.
        # Corresponds to the JSON property `isUngroundedValue`
        # @return [Boolean]
        attr_accessor :is_ungrounded_value
        alias_method :is_ungrounded_value?, :is_ungrounded_value
      
        # The KG mid of the implied entity.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The QRef confidence (in [0, 1]) of the entity being correctly annotated.
        # Corresponds to the JSON property `qrefConfidenceScore`
        # @return [Float]
        attr_accessor :qref_confidence_score
      
        # Additional shopping identifiers related to an entity or IQL function call.
        # This must be passed along to the shopping backend (go/o4) to aid in
        # fulfillment. Because the shopping data models do not always line up 1-1 with
        # KG entities and are not always reconciled with each other, the message may
        # contain multiple ids. Next id: 8 LINT.IfChange
        # Corresponds to the JSON property `shoppingIds`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryShoppingIds]
        attr_accessor :shopping_ids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotated_span = args[:annotated_span] if args.key?(:annotated_span)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_ungrounded_value = args[:is_ungrounded_value] if args.key?(:is_ungrounded_value)
          @mid = args[:mid] if args.key?(:mid)
          @qref_confidence_score = args[:qref_confidence_score] if args.key?(:qref_confidence_score)
          @shopping_ids = args[:shopping_ids] if args.key?(:shopping_ids)
        end
      end
      
      # Mustang/Kgraph attachment to encode IQL expressions annotated by Webref,
      # Pianno, and other applications. This is currently a prototype implementation.
      # The attachment is not yet output in production. Please contact simonz@ for
      # more info. The planned use-cases include: - Pianno page-level intents (go/
      # pianno-design). - Compound entity representations (go/compounds-in-refx). See
      # go/iql-in-wma for more details about IQL attachment and its encoding design.
      # Next available tag: 5
      class KnowledgeAnswersIntentQueryIndexingIqlAttachment
        include Google::Apis::Core::Hashable
      
        # The version of encoder for the IQL FunctionCalls. We bump up the version when,
        # but not limited to, we change how an IQL is converted to a byte array, or the
        # change of byte compression algorithm.
        # Corresponds to the JSON property `iqlEncodingVersion`
        # @return [Fixnum]
        attr_accessor :iql_encoding_version
      
        # A compressed byte array that represents IQL FunctionCalls. A list of IQL
        # FunctionCalls are first encoded as a byte array. The byte array is then
        # compressed. For more details on the encoding, see go/iql-in-wma.
        # Corresponds to the JSON property `iqlFuncalls`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :iql_funcalls
      
        # The Pianno confidence scores of all intents of the IQL FunctionCalls. For
        # space reasons this is stored as a [0, 100] integer that represents the
        # confidence up to two decimal points (fixed point). Convert it to
        # confidence_score using the following formula: float pianno_confidence_score =
        # pianno_confidence_score_e2 / 100.0f It should have the same number of elements
        # as the IQL expressions after decoding. For non-Pianno top level intents, this
        # score is 0.
        # Corresponds to the JSON property `piannoConfidenceScoreE2`
        # @return [Array<Fixnum>]
        attr_accessor :pianno_confidence_score_e2
      
        # A bit map indicating if the intents in the IQL FunctionCalls are top level
        # intents for Pianno (go/pianno). This is a repeated field. In the event of more
        # than 32 intents, the first uint32/ represents the 1st to the 32nd intents, and
        # the second uint32 represents/ the 33rd to the 64th intents, and so on. Within
        # each uint32, the bits are in reversed order, i.e. the right-most bit of the
        # first uint32 indicating if the first intent in IQL expressions is a top level
        # intent for Pianno. The prevailing (unused) bits of the last uint32 are filled
        # with 0s.
        # Corresponds to the JSON property `piannoIqlBitmap`
        # @return [Array<Fixnum>]
        attr_accessor :pianno_iql_bitmap
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @iql_encoding_version = args[:iql_encoding_version] if args.key?(:iql_encoding_version)
          @iql_funcalls = args[:iql_funcalls] if args.key?(:iql_funcalls)
          @pianno_confidence_score_e2 = args[:pianno_confidence_score_e2] if args.key?(:pianno_confidence_score_e2)
          @pianno_iql_bitmap = args[:pianno_iql_bitmap] if args.key?(:pianno_iql_bitmap)
        end
      end
      
      # A message that stores signals relating to a Local result.
      class KnowledgeAnswersIntentQueryLocalResultSignals
        include Google::Apis::Core::Hashable
      
        # Geo intents corresponding to the gcids obtained from the Local result.
        # Corresponds to the JSON property `gcidIntent`
        # @return [Array<String>]
        attr_accessor :gcid_intent
      
        # SalientTermSet is a collection of terms (unigrams and bigrams) with associated
        # weights that can describe something. The "salient terms".
        # Corresponds to the JSON property `salientTermSet`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTermSet]
        attr_accessor :salient_term_set
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcid_intent = args[:gcid_intent] if args.key?(:gcid_intent)
          @salient_term_set = args[:salient_term_set] if args.key?(:salient_term_set)
        end
      end
      
      # A message that stores information about Local results to be used in the Packer
      # for Local Categorical derived intent deduplication and conformance.
      class KnowledgeAnswersIntentQueryLocalSignals
        include Google::Apis::Core::Hashable
      
        # Signals relating to each Local result.
        # Corresponds to the JSON property `localResultSignals`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryLocalResultSignals>]
        attr_accessor :local_result_signals
      
        # Minimum salient term similarity between Local results.
        # Corresponds to the JSON property `minSalientTermSimilarity`
        # @return [Float]
        attr_accessor :min_salient_term_similarity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @local_result_signals = args[:local_result_signals] if args.key?(:local_result_signals)
          @min_salient_term_similarity = args[:min_salient_term_similarity] if args.key?(:min_salient_term_similarity)
        end
      end
      
      # Signals from LightweightToken. The span for an argument may have been extended
      # to include lightweight token markers such as FROM or TO. This signal provides
      # the semantics for the range extension.
      class KnowledgeAnswersIntentQueryLocationMarkersSignals
        include Google::Apis::Core::Hashable
      
        # The type of the lightweight token match.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Signals about the media entity.
      class KnowledgeAnswersIntentQueryMediaEntitySignals
        include Google::Apis::Core::Hashable
      
        # For songs, this is the name of the primary artist, i.e. "Shallow" would "Lady
        # Gaga" set.
        # Corresponds to the JSON property `artistTitle`
        # @return [String]
        attr_accessor :artist_title
      
        # Name of the media entity, i.e. "Lady Gaga".
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @artist_title = args[:artist_title] if args.key?(:artist_title)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Signals derived from Munin Function call annotations.
      class KnowledgeAnswersIntentQueryMuninSignals
        include Google::Apis::Core::Hashable
      
        # If the modifier is only a good soft modifier by itself, then we would trigger
        # only if it's the only modifier
        # Corresponds to the JSON property `isIsolated`
        # @return [Boolean]
        attr_accessor :is_isolated
        alias_method :is_isolated?, :is_isolated
      
        # Signals for $ListQueryRuleWithSoftModifier. Collections allowed by the soft
        # modifier.
        # Corresponds to the JSON property `softModifierCollection`
        # @return [Array<String>]
        attr_accessor :soft_modifier_collection
      
        # If true, the text for this argument did not come from the query, but was
        # generated somehow else.
        # Corresponds to the JSON property `textIsGenerated`
        # @return [Boolean]
        attr_accessor :text_is_generated
        alias_method :text_is_generated?, :text_is_generated
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_isolated = args[:is_isolated] if args.key?(:is_isolated)
          @soft_modifier_collection = args[:soft_modifier_collection] if args.key?(:soft_modifier_collection)
          @text_is_generated = args[:text_is_generated] if args.key?(:text_is_generated)
        end
      end
      
      # Signals associated with NTPRAnnotator annotations. Empty. The signal being
      # present is enough for the conformance checking library to be able to check.
      class KnowledgeAnswersIntentQueryNtprAnnotationSignals
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Signals associated with NimbleAnnotator annotations.
      class KnowledgeAnswersIntentQueryNimbleAnnotationSignals
        include Google::Apis::Core::Hashable
      
        # Where the annotation has been read from.
        # Corresponds to the JSON property `annotationSource`
        # @return [String]
        attr_accessor :annotation_source
      
        # A client-controlled identifier that the client can use to distinguish between
        # different sets of annotations.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Version identifier used to isolate different clients from each other. A client
        # should intersect this list of versions with the ones the client is interested
        # in, and use the annotation if the intersection is non-empty.
        # Corresponds to the JSON property `version`
        # @return [Array<String>]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @type = args[:type] if args.key?(:type)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Signals coming from on-device annotators.
      class KnowledgeAnswersIntentQueryOnDeviceAnnotationSignals
        include Google::Apis::Core::Hashable
      
        # Provenance of the annotator. Equivalent to the `provenance` field in
        # OnDeviceParserInput::AnnotationInfo. This is used to map from AnnotationInfo
        # to nlp_sage.ScoredAnnotation, since nlp_sage.ScoredAnnotation doesn't have a
        # native `provenance` field. Note in the (very) long term, we'd like to replace
        # ScoredAnnotation with Argument altogether.
        # Corresponds to the JSON property `provenance`
        # @return [String]
        attr_accessor :provenance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provenance = args[:provenance] if args.key?(:provenance)
        end
      end
      
      # Parsing-related signals. Only horizontal signals should appear directly as
      # fields on this message. Each domain should create their own extension for
      # anything that they need to propagate down stream from AQUA. Note that this
      # proto is not the same as the Superroot proto ParsingSignals (http://google3/
      # knowledge/proto/scoring-signals.proto), which is a Superroot-specific signal
      # used in Scoring. Next ID: 4
      class KnowledgeAnswersIntentQueryParsingSignals
        include Google::Apis::Core::Hashable
      
        # A parsing score that is independently calibrated by each parser/IG, used by
        # pre-fulfillment ranker, see http://go/prefulfillment-ranker.
        # Corresponds to the JSON property `calibratedParsingScore`
        # @return [Float]
        attr_accessor :calibrated_parsing_score
      
        # The proto that holds the complete call path info of the QRewrite client (e.g.
        # the QUS's phase like "RBT","QBT"; the QUS's candidate type like "Identity";
        # and the ACE's candidate type like "FuzzyMatcher"). Next ID: 5 ACE tags
        # Corresponds to the JSON property `qrewriteCallPathInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpLoggingQRewriteClientCallPathInfo]
        attr_accessor :qrewrite_call_path_info
      
        # The parser that calibrated the parsing score below.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calibrated_parsing_score = args[:calibrated_parsing_score] if args.key?(:calibrated_parsing_score)
          @qrewrite_call_path_info = args[:qrewrite_call_path_info] if args.key?(:qrewrite_call_path_info)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # A message encapsulating all "/collection/personal_memory" annotations from
      # QRef annotator. These annotations are present in personal_summary_node_child
      # proto field of input QRefAnnotation proto. NEXT ID TO USE: 5
      class KnowledgeAnswersIntentQueryPersonalEntity
        include Google::Apis::Core::Hashable
      
        # Attribute ID of a personal_summary_node_child.
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        # 
        # Corresponds to the JSON property `entityRelationship`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryPersonalEntityEntityRelationship>]
        attr_accessor :entity_relationship
      
        # The mid of the entity in freebase associated with this span.
        # Corresponds to the JSON property `freebaseMid`
        # @return [String]
        attr_accessor :freebase_mid
      
        # Every PersonalEntity might itself rescursively contain related Personal
        # Entities, e.g. for, "my father's mother" a parent Personal Entity for 'Mother()
        # ' contains a child Personal Entity of the form 'Mother(Myself)'.
        # Corresponds to the JSON property `personalEntityChild`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryPersonalEntity>]
        attr_accessor :personal_entity_child
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
          @entity_relationship = args[:entity_relationship] if args.key?(:entity_relationship)
          @freebase_mid = args[:freebase_mid] if args.key?(:freebase_mid)
          @personal_entity_child = args[:personal_entity_child] if args.key?(:personal_entity_child)
        end
      end
      
      # The relationship information from QRef. Only included if the QRefAnnotator is
      # initialised with include_annotated_relationships.
      class KnowledgeAnswersIntentQueryPersonalEntityEntityRelationship
        include Google::Apis::Core::Hashable
      
        # The index of the other entity in the relationship.
        # Corresponds to the JSON property `entityIndex`
        # @return [Fixnum]
        attr_accessor :entity_index
      
        # Names of the relationship links.
        # Corresponds to the JSON property `linkPropertyName`
        # @return [Array<String>]
        attr_accessor :link_property_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_index = args[:entity_index] if args.key?(:entity_index)
          @link_property_name = args[:link_property_name] if args.key?(:link_property_name)
        end
      end
      
      # Signals associated with Qref annotations.
      class KnowledgeAnswersIntentQueryQrefAnnotationSignals
        include Google::Apis::Core::Hashable
      
        # Numeric value associated with each annotation within the Qref servlet output.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Trusted name confidence signal https://g3doc.corp.google.com/repository/webref/
        # preprocessing/names/tnc_classifier/README.md
        # Corresponds to the JSON property `trustedNameConfidence`
        # @return [Float]
        attr_accessor :trusted_name_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @trusted_name_confidence = args[:trusted_name_confidence] if args.key?(:trusted_name_confidence)
        end
      end
      
      # Relatedness Matrix signals for FunctionCall Arguments.
      class KnowledgeAnswersIntentQueryRelatednessSignals
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `queryPopularity`
        # @return [Float]
        attr_accessor :query_popularity
      
        # 
        # Corresponds to the JSON property `youtubeViews`
        # @return [Fixnum]
        attr_accessor :youtube_views
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @query_popularity = args[:query_popularity] if args.key?(:query_popularity)
          @youtube_views = args[:youtube_views] if args.key?(:youtube_views)
        end
      end
      
      # Signals derived from overlapping saft annotations.
      class KnowledgeAnswersIntentQuerySaftSignals
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entityType`
        # @return [String]
        attr_accessor :entity_type
      
        # 
        # Corresponds to the JSON property `isHeadOfIntent`
        # @return [Boolean]
        attr_accessor :is_head_of_intent
        alias_method :is_head_of_intent?, :is_head_of_intent
      
        # Saft often marks verbs as head of intent and we may want to ignore those.
        # Corresponds to the JSON property `isVerb`
        # @return [Boolean]
        attr_accessor :is_verb
        alias_method :is_verb?, :is_verb
      
        # 
        # Corresponds to the JSON property `number`
        # @return [String]
        attr_accessor :number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @is_head_of_intent = args[:is_head_of_intent] if args.key?(:is_head_of_intent)
          @is_verb = args[:is_verb] if args.key?(:is_verb)
          @number = args[:number] if args.key?(:number)
        end
      end
      
      # Signals associated with nlp_ig::v1::SemanticAnnotator.
      class KnowledgeAnswersIntentQuerySemanticAnnotationSignals
        include Google::Apis::Core::Hashable
      
        # Name of the subgrammar category this annotation is associated with.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # Name of the subgrammar domain.
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `features`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQuerySemanticAnnotationSignalsFeature>]
        attr_accessor :features
      
        # Numeric value associated with each subgrammar annotation. Used for in-domain
        # ranking inside the Aqua Analyzer. This field is not guaranteed to be in any
        # range. Furthermore, this field should never be compared for annotations with
        # differing 'domain' value. The field is included here for making the Aqua
        # Analyzer work with subgrammar annotations that have been generated in a
        # different Aqua Analyzer (typically by TUIG SemanticAnnotationServlet). TL;DR:
        # Consumers of this message are STRONGLY DISCOURAGED from using this field.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @domain = args[:domain] if args.key?(:domain)
          @features = args[:features] if args.key?(:features)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Aqua features exported from a subgrammar. Primarily added here for External
      # Subgrammar Annotations to work. See go/esa-exported-features for details. NOTE:
      # Feature names can change and the existence of any feature is not guaranteed.
      # Get in touch with ig-eng@ before using these features.
      class KnowledgeAnswersIntentQuerySemanticAnnotationSignalsFeature
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class KnowledgeAnswersIntentQuerySensitiveArgumentValueGuard
        include Google::Apis::Core::Hashable
      
        # A message representing the value of an argument. All types in the "value"
        # oneof should have a corresponding field in the ValueType or OpaqueType protos
        # defined in knowledge/answers/config/value.proto. This is specified by
        # annotating each ArgumentValue type with options of the form (value_type_name) =
        # A unit test ensure that this field is set and is valid for all types in
        # ArgumentValue. A small number of special cases (such as funcall and
        # simple_value) are allowed to omit the annotation. See intent_query_proto_test.
        # cc for details. Note: If you are trying to add a new OpaqueType, stop;
        # OpaqueType is deprecated, refer to go/opaque_type for details. If you think
        # this is the only way to implement your feature, attend an office hours (go/
        # meaning-help) and discuss with the MRF team. Next Id: 41
        # Corresponds to the JSON property `doNotUseDebugOnlyDecryptedValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgumentValue]
        attr_accessor :do_not_use_debug_only_decrypted_value
      
        # Encrypted protobuffer of type ArgumentValue.
        # Corresponds to the JSON property `encryptedValue`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encrypted_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @do_not_use_debug_only_decrypted_value = args[:do_not_use_debug_only_decrypted_value] if args.key?(:do_not_use_debug_only_decrypted_value)
          @encrypted_value = args[:encrypted_value] if args.key?(:encrypted_value)
        end
      end
      
      # Additional shopping identifiers related to an entity or IQL function call.
      # This must be passed along to the shopping backend (go/o4) to aid in
      # fulfillment. Because the shopping data models do not always line up 1-1 with
      # KG entities and are not always reconciled with each other, the message may
      # contain multiple ids. Next id: 8 LINT.IfChange
      class KnowledgeAnswersIntentQueryShoppingIds
        include Google::Apis::Core::Hashable
      
        # A shopping aspect cluster id. These are attributes mined from mentions in web
        # articles.
        # Corresponds to the JSON property `aspectClusterIds`
        # @return [Array<Fixnum>]
        attr_accessor :aspect_cluster_ids
      
        # Brand entity id. Brands are fully reconciled with KG entities so there should
        # never be ambiguity as to which brand applies (those would be separate MIDs).
        # Corresponds to the JSON property `brandEntityId`
        # @return [Fixnum]
        attr_accessor :brand_entity_id
      
        # A category in the shopping browseonomy, a taxonomy of product types that can
        # be found at go/bx. This field is expected to contain the deepest node in the
        # browseonomy that the intent or argument pertains to, which may be an internal
        # node. It does not contain the entire path of categories.
        # Corresponds to the JSON property `bxCategoryIds`
        # @return [Array<Fixnum>]
        attr_accessor :bx_category_ids
      
        # 
        # Corresponds to the JSON property `measures`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryShoppingIdsMeasureValue>]
        attr_accessor :measures
      
        # List of merchant customer account IDs associated with a merchant entity in KG.
        # NOTE: Soon to be deprecated, see go/merchant_mids_in_indexer design
        # Corresponds to the JSON property `merchantIds`
        # @return [Array<Fixnum>]
        attr_accessor :merchant_ids
      
        # A shopping merchant source id, i.e. the key used to identify Shopping
        # Merchants as they are imported into KG. For reference, these IDs are populated
        # in: * CommerceDB under BusinessIdentification.knowledge_graph.source_id * KG
        # using the /shopping/merchant/id predicate
        # Corresponds to the JSON property `merchantSourceIds`
        # @return [Array<Fixnum>]
        attr_accessor :merchant_source_ids
      
        # Moka attributes of a product. This includes color tags but currently not brand.
        # We allow the possibility for multiple tag ids, as multiple Moka tag ids may
        # map to the same mid, and we may not be able to find a single matching Moka tag.
        # Also, cross-category Moka colors intentionally map a single color mentioned
        # in the query to an expansion of many tags representing points in LAB color
        # space (although this representation is expected to change).
        # Corresponds to the JSON property `tagIds`
        # @return [Array<Fixnum>]
        attr_accessor :tag_ids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aspect_cluster_ids = args[:aspect_cluster_ids] if args.key?(:aspect_cluster_ids)
          @brand_entity_id = args[:brand_entity_id] if args.key?(:brand_entity_id)
          @bx_category_ids = args[:bx_category_ids] if args.key?(:bx_category_ids)
          @measures = args[:measures] if args.key?(:measures)
          @merchant_ids = args[:merchant_ids] if args.key?(:merchant_ids)
          @merchant_source_ids = args[:merchant_source_ids] if args.key?(:merchant_source_ids)
          @tag_ids = args[:tag_ids] if args.key?(:tag_ids)
        end
      end
      
      # A measured value of a product (e.g. Hard drive size = 1 TB). The value is
      # measured in the facet's base unit. This does not necessarily match the unit
      # expressed by the user in the query. The exact unit is known to the O4 server
      # and is used in fulfillment.
      class KnowledgeAnswersIntentQueryShoppingIdsMeasureValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `facetId`
        # @return [Fixnum]
        attr_accessor :facet_id
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @facet_id = args[:facet_id] if args.key?(:facet_id)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A message representing an intent to use for intent scoring if the root intent
      # is invalid.
      class KnowledgeAnswersIntentQuerySignalComputationFallbackIntent
        include Google::Apis::Core::Hashable
      
        # The intent name of the fallback intent.
        # Corresponds to the JSON property `intent`
        # @return [String]
        attr_accessor :intent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent = args[:intent] if args.key?(:intent)
        end
      end
      
      # A message representing a simple literal value.
      class KnowledgeAnswersIntentQuerySimpleValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # 
        # Corresponds to the JSON property `doubleValue`
        # @return [Float]
        attr_accessor :double_value
      
        # Identifiers are references to a specific entity of a specified type, such as a
        # TIMER_ID XXX. For more backround and uses see go/grounding-common-ids.
        # Corresponds to the JSON property `identifier`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryIdentifier]
        attr_accessor :identifier
      
        # 
        # Corresponds to the JSON property `intValue`
        # @return [Fixnum]
        attr_accessor :int_value
      
        # 
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # Ungrounded value contains the part of the query (or web snippet, etc.) that
        # was not understood. For more information on this field, see the "Ungrounded
        # value" item in the table of contents of go/iql-v1
        # Corresponds to the JSON property `ungroundedValue`
        # @return [String]
        attr_accessor :ungrounded_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @double_value = args[:double_value] if args.key?(:double_value)
          @identifier = args[:identifier] if args.key?(:identifier)
          @int_value = args[:int_value] if args.key?(:int_value)
          @string_value = args[:string_value] if args.key?(:string_value)
          @ungrounded_value = args[:ungrounded_value] if args.key?(:ungrounded_value)
        end
      end
      
      # Signals indicating whether this entity received or transferred support (and
      # from which entities).
      class KnowledgeAnswersIntentQuerySupportTransferSignals
        include Google::Apis::Core::Hashable
      
        # Entities that transferred support to this entity (mids).
        # Corresponds to the JSON property `supportTransferSource`
        # @return [Array<String>]
        attr_accessor :support_transfer_source
      
        # Entities that received support from this entity (mids).
        # Corresponds to the JSON property `supportTransferTarget`
        # @return [Array<String>]
        attr_accessor :support_transfer_target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @support_transfer_source = args[:support_transfer_source] if args.key?(:support_transfer_source)
          @support_transfer_target = args[:support_transfer_target] if args.key?(:support_transfer_target)
        end
      end
      
      # Signals associated with TeleportArgumentAnnotator annotations. Empty. The
      # signal being present is enough for the conformance checking library to be able
      # to check.
      class KnowledgeAnswersIntentQueryTeleportArgumentAnnotatorSignals
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # A token represents an ngram with relevant information about it. If the token
      # is a context phrase, it will have a prior score associated with it. The prior
      # is computed via knowledge/answers/query_generalization/ word_prior/
      # word_prior_from_examples_lib.cc, and ranges between 0 and 1. Stopwords and
      # intent tokens (primary and component) have a score of 1.0.
      class KnowledgeAnswersIntentQueryToken
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # |ngram| should be populated with a string from the raw query, not the
        # normalized tokens. E.g. The ngram in the ignored token for the Height intent
        # on the query [Height of barack obama], will be "Height". The ngram in the
        # ignored token for the Videos intent on the query [vidéos] will be "vidéos".
        # Corresponds to the JSON property `ngram`
        # @return [String]
        attr_accessor :ngram
      
        # Experiments that caused this Token to parse, without which this would not have
        # parsed.
        # Corresponds to the JSON property `parsedDueToExperiment`
        # @return [Array<String>]
        attr_accessor :parsed_due_to_experiment
      
        # 
        # Corresponds to the JSON property `prior`
        # @return [Float]
        attr_accessor :prior
      
        # 
        # Corresponds to the JSON property `provenance`
        # @return [String]
        attr_accessor :provenance
      
        # Unique identifiers for the provenance of this token, for example, NLP
        # Repository Example IDs.
        # Corresponds to the JSON property `provenanceId`
        # @return [Array<String>]
        attr_accessor :provenance_id
      
        # 
        # Corresponds to the JSON property `provenanceLanguage`
        # @return [String]
        attr_accessor :provenance_language
      
        # 
        # Corresponds to the JSON property `synonyms`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryTokenSynonym>]
        attr_accessor :synonyms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @ngram = args[:ngram] if args.key?(:ngram)
          @parsed_due_to_experiment = args[:parsed_due_to_experiment] if args.key?(:parsed_due_to_experiment)
          @prior = args[:prior] if args.key?(:prior)
          @provenance = args[:provenance] if args.key?(:provenance)
          @provenance_id = args[:provenance_id] if args.key?(:provenance_id)
          @provenance_language = args[:provenance_language] if args.key?(:provenance_language)
          @synonyms = args[:synonyms] if args.key?(:synonyms)
        end
      end
      
      # A TokenSynonym contains information about synonyms of a Token's ngram. The
      # synonyms were the ones used during parsing for token explanation in place of
      # the original ngrams. Example 1: [present population of nyc] We can generate
      # interpretation kc:/location/statistical_region:population by converting "
      # present" to its synonym "current", which is a context phrase for the intent.
      # The ngram for this token would be "present" and the string "current" would be
      # stored in synonym_ngram. Example 2: [nys important cities] We can generate
      # interpretation kc:/location/us_state:cities by converting "important" to its
      # synonym "major" or its synonym "biggest", because both "major cities" and "
      # biggest cities" are attribute phrases for the intent. In this case, the ngram
      # in this Token is "important cities", and the token_synonyms (specifically, the
      # synonym_ngram field) would store "major cities" and "biggest cities", since
      # those are the actual synonym ngrams that match the attribute phrases. For
      # context phrases, we generally should have only one matched_squery_synonyms,
      # since we try to find the best synonyms to use using the context phrase score.
      # However, for attribute phrase we don't really have enough info to determine
      # which synonym is better if they both trigger the same intent, and hence we
      # will propagate both synonyms.
      class KnowledgeAnswersIntentQueryTokenSynonym
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `synonymNgram`
        # @return [String]
        attr_accessor :synonym_ngram
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source = args[:source] if args.key?(:source)
          @synonym_ngram = args[:synonym_ngram] if args.key?(:synonym_ngram)
        end
      end
      
      # Tokens includes a list of tokens, with an aggregated score of the priors of
      # the tokens, if any.
      class KnowledgeAnswersIntentQueryTokens
        include Google::Apis::Core::Hashable
      
        # Score for this group of tokens is currently product of priors.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `token`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryToken>]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # 
      class KnowledgeAnswersIntersectType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slotNames`
        # @return [Array<String>]
        attr_accessor :slot_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slot_names = args[:slot_names] if args.key?(:slot_names)
        end
      end
      
      # A Marker specifies a Meaning Expression's (i.e. intent FunctionCall) purpose.
      # NOTE: Markers always impact go/intent-resolution semantics.
      class KnowledgeAnswersMarker
        include Google::Apis::Core::Hashable
      
        # Indicates a command, instructing someone to do something which might be
        # explicit (e.g. [call me]) or implicit (e.g. [can you call me]).
        # Corresponds to the JSON property `command`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMarkerCommand]
        attr_accessor :command
      
        # Indicates a question, requesting the value of a specified slot. Not applicable
        # if the requested slot simultaneously appears as an argument. See go/requested-
        # slots for details. Next ID: 3
        # Corresponds to the JSON property `openQuestion`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMarkerOpenQuestion]
        attr_accessor :open_question
      
        # Indicates a question, requesting the truth-value/actualness of a state of
        # affairs denoted by the expression encompassed by the FunctionCall this appears
        # on. Often this is a yes/no question, e.g. [was tom cruise in top gun] :
        # ActedIn.polar(Movie=/m/top_gun, Actor=/m/tom_cruise) Not all polar questions
        # will necessarily have a yes/no answer; the expected resolution of a polar
        # question is a StateOfAffairs. e.g. [is chocolate good for you] :
        # FoodItemAttribute.polar(/m/chocolate, /m/healthy) which may not have a simple
        # yes/no answer. See go/mrf-polar-questions for details.
        # Corresponds to the JSON property `polarQuestion`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMarkerPolarQuestion]
        attr_accessor :polar_question
      
        # Indicates a reference to a particular state of affairs denoted by the
        # expression encompassed by the FunctionCall this appears on. The state may be
        # actual e.g. [new york is a city] : IsA.state(/m/new_york, /m/city) or not e.g.
        # [1+1=3] : Addition.state(Sum=3, Addend=1, Addend=1) The state can also
        # represent an proposition of an action, e.g. [cinar gave jason a cookie] : Give.
        # state(Giver=cinar, Receiver=jason, Object=cookie) See go/mrf-polar-questions
        # for details.
        # Corresponds to the JSON property `stateOfAffairs`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMarkerStateOfAffairs]
        attr_accessor :state_of_affairs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @command = args[:command] if args.key?(:command)
          @open_question = args[:open_question] if args.key?(:open_question)
          @polar_question = args[:polar_question] if args.key?(:polar_question)
          @state_of_affairs = args[:state_of_affairs] if args.key?(:state_of_affairs)
        end
      end
      
      # Indicates a command, instructing someone to do something which might be
      # explicit (e.g. [call me]) or implicit (e.g. [can you call me]).
      class KnowledgeAnswersMarkerCommand
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Indicates a question, requesting the value of a specified slot. Not applicable
      # if the requested slot simultaneously appears as an argument. See go/requested-
      # slots for details. Next ID: 3
      class KnowledgeAnswersMarkerOpenQuestion
        include Google::Apis::Core::Hashable
      
        # The primary key for a MeaningSchema slot. Next ID: 3 For //depot/google3/logs/
        # proto/knowledge/interpretation/intent_query.proto in the "ThenChange", please
        # update Argument.SlotKey. LINT.IfChange
        # Corresponds to the JSON property `slotKey`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMeaningSchemaSlotKey]
        attr_accessor :slot_key
      
        # One or multiple slots may be requested by the marker. See go/mrf-multiple-
        # output-slots for details on requesting multiple output slots.
        # Corresponds to the JSON property `slotName`
        # @return [Array<String>]
        attr_accessor :slot_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slot_key = args[:slot_key] if args.key?(:slot_key)
          @slot_name = args[:slot_name] if args.key?(:slot_name)
        end
      end
      
      # Indicates a question, requesting the truth-value/actualness of a state of
      # affairs denoted by the expression encompassed by the FunctionCall this appears
      # on. Often this is a yes/no question, e.g. [was tom cruise in top gun] :
      # ActedIn.polar(Movie=/m/top_gun, Actor=/m/tom_cruise) Not all polar questions
      # will necessarily have a yes/no answer; the expected resolution of a polar
      # question is a StateOfAffairs. e.g. [is chocolate good for you] :
      # FoodItemAttribute.polar(/m/chocolate, /m/healthy) which may not have a simple
      # yes/no answer. See go/mrf-polar-questions for details.
      class KnowledgeAnswersMarkerPolarQuestion
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Indicates a reference to a particular state of affairs denoted by the
      # expression encompassed by the FunctionCall this appears on. The state may be
      # actual e.g. [new york is a city] : IsA.state(/m/new_york, /m/city) or not e.g.
      # [1+1=3] : Addition.state(Sum=3, Addend=1, Addend=1) The state can also
      # represent an proposition of an action, e.g. [cinar gave jason a cookie] : Give.
      # state(Giver=cinar, Receiver=jason, Object=cookie) See go/mrf-polar-questions
      # for details.
      class KnowledgeAnswersMarkerStateOfAffairs
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # The primary key for an intent. Next ID: 3
      class KnowledgeAnswersMeaningSchemaKey
        include Google::Apis::Core::Hashable
      
        # The version has been changed to be defined as a horizontal version on the
        # entire meaning catalog instead of per-schema.
        # Corresponds to the JSON property `deprecatedVersion`
        # @return [Fixnum]
        attr_accessor :deprecated_version
      
        # The minted MID for an intent.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_version = args[:deprecated_version] if args.key?(:deprecated_version)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # The primary key for a MeaningSchema slot. Next ID: 3 For //depot/google3/logs/
      # proto/knowledge/interpretation/intent_query.proto in the "ThenChange", please
      # update Argument.SlotKey. LINT.IfChange
      class KnowledgeAnswersMeaningSchemaSlotKey
        include Google::Apis::Core::Hashable
      
        # The minted MID for the slot. This ID uniquely identifies the slot globally.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # A stable unique ID for this intent minted from go/uniqueid. NOTE: This is
        # considered a private field used only for internal Intent Catalog purposes (i.e.
        # as a source ID for generating this intent's associated MID). Additionally,
        # this field is only populated on the schema. TODO (b/168907943): Move "
        # unique_id" out of MeaningSchemaSlotKey proto message. Note: Please do not use
        # this field. It is going to be moved out of this proto message.
        # Corresponds to the JSON property `uniqueId`
        # @return [Fixnum]
        attr_accessor :unique_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @unique_id = args[:unique_id] if args.key?(:unique_id)
        end
      end
      
      # A MeasurementType configures a value that consists of a measurement. The
      # expected value should have a number and a mid representing the unit. Note:
      # this is currently only used for attribute answer value types. Configuration
      # intent slot as measurement is yet to be supported (or instead we should
      # universally use SemanticType).
      class KnowledgeAnswersMeasurementType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A NormalizedStringType configures a value that is one of the listed
      # normalized_values. An arbitrary mapping from input strings to
      # normalized_values can be specified in the local intent config. Only
      # alphabetical strings can be used as normalized_values. This type should NOT be
      # used for: - Mids, ids, dates, or other structured data. Use an annotator
      # instead, and address any quality issues at the annotator level. - Simplifying
      # grammar rules. If you are not using the normalized_values in your question
      # semantics, you should remove the slot. Use additional query_examples instead.
      class KnowledgeAnswersNormalizedStringType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `normalizedValue`
        # @return [Array<String>]
        attr_accessor :normalized_value
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A NumberType configures a value whose type is intended to be numeric.
      class KnowledgeAnswersNumberType
        include Google::Apis::Core::Hashable
      
        # If true, the semantics of the NumberType argument are retained as a string,
        # rather than being converted to a float-type object. This option is
        # particularly useful in cases where leading 0s in the user input are meaningful,
        # e.g. for zip codes or sports jersey numbers. For the user- specified value "
        # 01", for instance, the PathQuery semantics will be: def $Slot "01"
        # Corresponds to the JSON property `keepAsString`
        # @return [Boolean]
        attr_accessor :keep_as_string
        alias_method :keep_as_string?, :keep_as_string
      
        # Range constraint limits the set of numbers accepted by this type. The
        # constraint applies to all subtypes. Currently, this constraint is only
        # enforced in Loose Parser.
        # Corresponds to the JSON property `rangeConstraint`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersRangeConstraint]
        attr_accessor :range_constraint
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # sub_type is a list of the NumberSubTypes which are accepted. If the list is
        # empty, that means all numeric or ordinal values are accepted. If multiple
        # values are specified, then this value accepts any of the sub_types in the list.
        # Corresponds to the JSON property `subType`
        # @return [Array<String>]
        attr_accessor :sub_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @keep_as_string = args[:keep_as_string] if args.key?(:keep_as_string)
          @range_constraint = args[:range_constraint] if args.key?(:range_constraint)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @sub_type = args[:sub_type] if args.key?(:sub_type)
        end
      end
      
      # Custom opaque type used by actions-on-google in-dialog queries. See go/3p-
      # custom-intents-wrt-meaning-catalog
      class KnowledgeAnswersOpaqueAogType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueAppAnnotationType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueAudioType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueCalendarEventType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Used for sensitive calendar events that require additional BUILD visibility
      # protection. See go/multi-account-event-representation.
      class KnowledgeAnswersOpaqueCalendarEventWrapperType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueCalendarReferenceType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueComplexQueriesRewriteType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueComponentReferenceIndexType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueDeviceIdType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueDeviceType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueDeviceUserIdentityType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueHomeAutomationDeviceType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueLocationType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueMediaType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueMessageNotificationType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueMoneyType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueNewsProviderType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueOnDeviceType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaquePersonType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Entity parsed from manual grammar interpretation in the Personal Intelligence
      # domain.
      class KnowledgeAnswersOpaquePersonalIntelligenceEntityType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueProductivityListItemType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueRecurrenceType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueReminderType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueShoppingMerchantType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueShoppingOfferType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueShoppingProductExpressionType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueShoppingProductType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueShoppingStoreType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class KnowledgeAnswersOpaqueTimerType
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Note: OpaqueType is deprecated and addition of new fields is not allowed.
      # Refer to go/opaque_type for details. If you think this is the only way to
      # implement your feature, attend an office hours (go/meaning-help) and discuss
      # with the MRF team. An OpaqueType configures a value whose type is only
      # interpretable by _specific_ clients of the intent catalog. This means
      # horizontal 'features' like pretty printing, correct logging, intent
      # blacklisting and signal aggregation will not work for opaque value types. It
      # has a field for each type in IntentQuery that is not covered by a non-opaque
      # type (specifically: protocol messages). The fields are themselves messages
      # declared in this file. The specific opaque value types must be empty messages.
      # If you find a need to add any fields to these messages, make them non-opaque
      # and implement all of the code to treat them as first class types. It is
      # allowable for a value to have more than one of the opaque types. See http://go/
      # opaque-type-for-value-type. LINT.IfChange Next Id: 31
      class KnowledgeAnswersOpaqueType
        include Google::Apis::Core::Hashable
      
        # Custom opaque type used by actions-on-google in-dialog queries. See go/3p-
        # custom-intents-wrt-meaning-catalog
        # Corresponds to the JSON property `aogType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueAogType]
        attr_accessor :aog_type
      
        # 
        # Corresponds to the JSON property `appAnnotationType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueAppAnnotationType]
        attr_accessor :app_annotation_type
      
        # 
        # Corresponds to the JSON property `audioType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueAudioType]
        attr_accessor :audio_type
      
        # 
        # Corresponds to the JSON property `calendarEventType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueCalendarEventType]
        attr_accessor :calendar_event_type
      
        # Used for sensitive calendar events that require additional BUILD visibility
        # protection. See go/multi-account-event-representation.
        # Corresponds to the JSON property `calendarEventWrapperType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueCalendarEventWrapperType]
        attr_accessor :calendar_event_wrapper_type
      
        # 
        # Corresponds to the JSON property `calendarReferenceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueCalendarReferenceType]
        attr_accessor :calendar_reference_type
      
        # 
        # Corresponds to the JSON property `complexQueriesRewriteType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueComplexQueriesRewriteType]
        attr_accessor :complex_queries_rewrite_type
      
        # 
        # Corresponds to the JSON property `componentReferenceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueComponentReferenceIndexType]
        attr_accessor :component_reference_type
      
        # 
        # Corresponds to the JSON property `deviceIdType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueDeviceIdType]
        attr_accessor :device_id_type
      
        # 
        # Corresponds to the JSON property `deviceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueDeviceType]
        attr_accessor :device_type
      
        # 
        # Corresponds to the JSON property `deviceUserIdentityType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueDeviceUserIdentityType]
        attr_accessor :device_user_identity_type
      
        # 
        # Corresponds to the JSON property `homeAutomationDeviceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueHomeAutomationDeviceType]
        attr_accessor :home_automation_device_type
      
        # 
        # Corresponds to the JSON property `locationType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueLocationType]
        attr_accessor :location_type
      
        # 
        # Corresponds to the JSON property `mediaType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueMediaType]
        attr_accessor :media_type
      
        # 
        # Corresponds to the JSON property `messageNotificationType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueMessageNotificationType]
        attr_accessor :message_notification_type
      
        # 
        # Corresponds to the JSON property `moneyType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueMoneyType]
        attr_accessor :money_type
      
        # 
        # Corresponds to the JSON property `narrativeNewsProviderType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueNewsProviderType]
        attr_accessor :narrative_news_provider_type
      
        # 
        # Corresponds to the JSON property `onDeviceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueOnDeviceType]
        attr_accessor :on_device_type
      
        # 
        # Corresponds to the JSON property `personType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaquePersonType]
        attr_accessor :person_type
      
        # Entity parsed from manual grammar interpretation in the Personal Intelligence
        # domain.
        # Corresponds to the JSON property `personalIntelligenceEntityType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaquePersonalIntelligenceEntityType]
        attr_accessor :personal_intelligence_entity_type
      
        # 
        # Corresponds to the JSON property `productivityListItemType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueProductivityListItemType]
        attr_accessor :productivity_list_item_type
      
        # 
        # Corresponds to the JSON property `recurrenceType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueRecurrenceType]
        attr_accessor :recurrence_type
      
        # 
        # Corresponds to the JSON property `reminderType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueReminderType]
        attr_accessor :reminder_type
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # 
        # Corresponds to the JSON property `shoppingMerchantType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueShoppingMerchantType]
        attr_accessor :shopping_merchant_type
      
        # 
        # Corresponds to the JSON property `shoppingOfferType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueShoppingOfferType]
        attr_accessor :shopping_offer_type
      
        # 
        # Corresponds to the JSON property `shoppingProductExpressionType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueShoppingProductExpressionType]
        attr_accessor :shopping_product_expression_type
      
        # 
        # Corresponds to the JSON property `shoppingProductType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueShoppingProductType]
        attr_accessor :shopping_product_type
      
        # 
        # Corresponds to the JSON property `shoppingStoreType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueShoppingStoreType]
        attr_accessor :shopping_store_type
      
        # 
        # Corresponds to the JSON property `timerType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueTimerType]
        attr_accessor :timer_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aog_type = args[:aog_type] if args.key?(:aog_type)
          @app_annotation_type = args[:app_annotation_type] if args.key?(:app_annotation_type)
          @audio_type = args[:audio_type] if args.key?(:audio_type)
          @calendar_event_type = args[:calendar_event_type] if args.key?(:calendar_event_type)
          @calendar_event_wrapper_type = args[:calendar_event_wrapper_type] if args.key?(:calendar_event_wrapper_type)
          @calendar_reference_type = args[:calendar_reference_type] if args.key?(:calendar_reference_type)
          @complex_queries_rewrite_type = args[:complex_queries_rewrite_type] if args.key?(:complex_queries_rewrite_type)
          @component_reference_type = args[:component_reference_type] if args.key?(:component_reference_type)
          @device_id_type = args[:device_id_type] if args.key?(:device_id_type)
          @device_type = args[:device_type] if args.key?(:device_type)
          @device_user_identity_type = args[:device_user_identity_type] if args.key?(:device_user_identity_type)
          @home_automation_device_type = args[:home_automation_device_type] if args.key?(:home_automation_device_type)
          @location_type = args[:location_type] if args.key?(:location_type)
          @media_type = args[:media_type] if args.key?(:media_type)
          @message_notification_type = args[:message_notification_type] if args.key?(:message_notification_type)
          @money_type = args[:money_type] if args.key?(:money_type)
          @narrative_news_provider_type = args[:narrative_news_provider_type] if args.key?(:narrative_news_provider_type)
          @on_device_type = args[:on_device_type] if args.key?(:on_device_type)
          @person_type = args[:person_type] if args.key?(:person_type)
          @personal_intelligence_entity_type = args[:personal_intelligence_entity_type] if args.key?(:personal_intelligence_entity_type)
          @productivity_list_item_type = args[:productivity_list_item_type] if args.key?(:productivity_list_item_type)
          @recurrence_type = args[:recurrence_type] if args.key?(:recurrence_type)
          @reminder_type = args[:reminder_type] if args.key?(:reminder_type)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @shopping_merchant_type = args[:shopping_merchant_type] if args.key?(:shopping_merchant_type)
          @shopping_offer_type = args[:shopping_offer_type] if args.key?(:shopping_offer_type)
          @shopping_product_expression_type = args[:shopping_product_expression_type] if args.key?(:shopping_product_expression_type)
          @shopping_product_type = args[:shopping_product_type] if args.key?(:shopping_product_type)
          @shopping_store_type = args[:shopping_store_type] if args.key?(:shopping_store_type)
          @timer_type = args[:timer_type] if args.key?(:timer_type)
        end
      end
      
      # Plexity is a conceptual distinction between viewing something (a slot filler,
      # for example) as a single individual, or as a complex concept consisting of
      # multiple individuals or subparts. Note that plexity is not the same as (or
      # correlated with) either grammatical number or with distributive and collective
      # interpretations of the slot. The PlexityRequirement proto and Plexity enum are
      # defined outside ValueType as we may move the plexity specification to a
      # different place in the intent protos in future.
      class KnowledgeAnswersPlexityRequirement
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # Simple plexity: the slot's filler must allow the specified plexity value, for
        # example it must contain multiple individuals if the plexity is MULTIPLEX.
        # Corresponds to the JSON property `simplePlexity`
        # @return [String]
        attr_accessor :simple_plexity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @simple_plexity = args[:simple_plexity] if args.key?(:simple_plexity)
        end
      end
      
      # A special type representing a polar question.
      class KnowledgeAnswersPolarQuestionType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # 
      class KnowledgeAnswersRangeConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `max`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersRangeConstraintRangeEndpoint]
        attr_accessor :max
      
        # 
        # Corresponds to the JSON property `min`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersRangeConstraintRangeEndpoint]
        attr_accessor :min
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max = args[:max] if args.key?(:max)
          @min = args[:min] if args.key?(:min)
        end
      end
      
      # 
      class KnowledgeAnswersRangeConstraintRangeEndpoint
        include Google::Apis::Core::Hashable
      
        # If true, then this endpoint's value is not included in the range.
        # Corresponds to the JSON property `isExclusive`
        # @return [Boolean]
        attr_accessor :is_exclusive
        alias_method :is_exclusive?, :is_exclusive
      
        # The value of this endpoint
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_exclusive = args[:is_exclusive] if args.key?(:is_exclusive)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class KnowledgeAnswersSameType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slotName`
        # @return [String]
        attr_accessor :slot_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slot_name = args[:slot_name] if args.key?(:slot_name)
        end
      end
      
      # A SemanticType configures a value determined by another source, in particular
      # another intent or a semantic frame. See go/unifying-intents and go/framery.
      class KnowledgeAnswersSemanticType
        include Google::Apis::Core::Hashable
      
        # Determines whether or not the meaning schema that contains this semantic_type
        # conforms to a function call with the name and arguments taken from the meaning
        # schema. As it refers to the "containing_intent", this field should only be set
        # in a semantic_type declared in an intent's type_members field. The behavior of
        # this field is undefined in other cases, for example, declaring the type of an
        # intent slot. On Assistant, we use meaning schemas for argument types to
        # represent both function call values as well as a reusable tool to host other
        # argument values (opaque types, normalized strings, subsets of entities) across
        # intents. Teams need this information to run conformance checks and annotate
        # new data. Example: If the intents below are in the intent catalog, then: -
        # Intent(slot="some string") is conformant, because Type has string_type`` in
        # its type_members. - Intent(slot=Type()) is not conformant, because Type has
        # set semantic_type.includes_containing_intent to false. - Intent(slot=SubType())
        # is conformant, because type_members is not inherited. ` id: "Intent" slot: `
        # name: "slot" type: ` semantic_type ` name: "Type" `` ` ` ` id: "Type"
        # type_members ` string_type`` semantic_type ` includes_containing_intent: false
        # ` ` ` ` id: "SubType" parent ` id: "Type" relationship_type: SUBTYPE ` `
        # Corresponds to the JSON property `includesContainingIntent`
        # @return [Boolean]
        attr_accessor :includes_containing_intent
        alias_method :includes_containing_intent?, :includes_containing_intent
      
        # Names of valid sources of the semantics (for example: a frame or an intent).
        # Corresponds to the JSON property `name`
        # @return [Array<String>]
        attr_accessor :name
      
        # Contains data about current schema remodelings at the SemanticType name level.
        # The "name" field contains all possible semantic type names and "
        # semantic_type_name_remodelings" acts as an overlay to determine which ones to
        # surface based on which schema remodeling IDs are requested. For more
        # information see go/meaning-remodeling-framework.
        # Corresponds to the JSON property `nameRemodelings`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpMeaningSemanticTypeNameMeaningRemodelings>]
        attr_accessor :name_remodelings
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @includes_containing_intent = args[:includes_containing_intent] if args.key?(:includes_containing_intent)
          @name = args[:name] if args.key?(:name)
          @name_remodelings = args[:name_remodelings] if args.key?(:name_remodelings)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # Policy controlling argument level eval.
      class KnowledgeAnswersSensitivityArgumentEvalPolicy
        include Google::Apis::Core::Hashable
      
        # Optional cannery policy name. If it presents then Intent Scrubber will use the
        # corresponding Cannery rule for argument scrubbing and redaction instead. It
        # should only be used for existing complex argment value types such as
        # HomeAutomationDevice.
        # Corresponds to the JSON property `policyName`
        # @return [String]
        attr_accessor :policy_name
      
        # Redact corresponding span of the string query.
        # Corresponds to the JSON property `redactQuerySpan`
        # @return [Boolean]
        attr_accessor :redact_query_span
        alias_method :redact_query_span?, :redact_query_span
      
        # Customized replacement phrase, if missing $`ArgumentName`_REDACTED is used as
        # default.
        # Corresponds to the JSON property `replacement`
        # @return [String]
        attr_accessor :replacement
      
        # Scrub argument value and signals before saving to eval storage. If not set, 1)
        # inherit the policy from the outer argument if there is one (for nested intents)
        # ; 2) finally default to type based scrubbing: see go/argument-type-scrubbing.
        # Corresponds to the JSON property `scrubArgumentValue`
        # @return [Boolean]
        attr_accessor :scrub_argument_value
        alias_method :scrub_argument_value?, :scrub_argument_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @policy_name = args[:policy_name] if args.key?(:policy_name)
          @redact_query_span = args[:redact_query_span] if args.key?(:redact_query_span)
          @replacement = args[:replacement] if args.key?(:replacement)
          @scrub_argument_value = args[:scrub_argument_value] if args.key?(:scrub_argument_value)
        end
      end
      
      # Instructions (eg., logging, disambiguation, ads serving) of handling a
      # sensitive intent and its data. LINT.IfChange NextId: 8
      class KnowledgeAnswersSensitivityInstruction
        include Google::Apis::Core::Hashable
      
        # Slot/Argument level instructions.
        # Corresponds to the JSON property `argument`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityInstructionArgument]
        attr_accessor :argument
      
        # Intent level instructions apply to the entire intent and all its argument
        # values.
        # Corresponds to the JSON property `intent`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityInstructionIntent]
        attr_accessor :intent
      
        # Encapsulates sensitivity mode, source, and other metadata, used for ranking
        # when there are multiple sensitivies set by default sources (eg, followon,
        # query understanding, attentional entity).
        # Corresponds to the JSON property `legacyAssistantSensitivity`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivity]
        attr_accessor :legacy_assistant_sensitivity
      
        # Controls whether a top-level intent is multi-account approved. NLU will do go/
        # cross-account-understanding only for intents with this bit on. Also, this bit
        # should be propagated to user turn Attentionl Entities to extend protection of
        # cross-account data to next turns. In principle fulfillment services (e.g.,
        # Monastery) should only dispatch such intents to multi-account approved
        # fulfillers (schemas), at least when the user has a linked dasher account. The
        # Assistant runtime policy engine should treat a query as dasher data if 1) this
        # bit is true in the string redaction, and 2) the user has a linked dasher
        # account, and apply a more restrictive rule for whitelisting, regardless of the
        # actual account provenance in Sensitivity. Example: [User logged in to their
        # personal gmail account.] Q1: "Schedule a meeting tiltled okr review at 3pm".
        # Assistant: "Should I scheduled it on your xyz@gmail.com account?" Q2: "No, add
        # it to my xyz@bigcorp.com account." We don't know Q1 is dasher data until Q2.
        # To prevent leaking of Q1 to non-dasher approved binaries, this bit should be
        # used as a proactive measure. It might introduce some over-triggering (e.g.,
        # user says "Yes" in Q2), but is much better than blindly treating every query
        # as dasher, not considering whether it actually triggers any multi-account
        # capable intents or not (see b/164420114 for example).
        # Corresponds to the JSON property `multiAccountAllowed`
        # @return [Boolean]
        attr_accessor :multi_account_allowed
        alias_method :multi_account_allowed?, :multi_account_allowed
      
        # Instructions for knowledge_context.PreviousQuery. See go/apps-userdata-
        # guidelines.
        # Corresponds to the JSON property `previousQuery`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityInstructionPreviousQuery]
        attr_accessor :previous_query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @argument = args[:argument] if args.key?(:argument)
          @intent = args[:intent] if args.key?(:intent)
          @legacy_assistant_sensitivity = args[:legacy_assistant_sensitivity] if args.key?(:legacy_assistant_sensitivity)
          @multi_account_allowed = args[:multi_account_allowed] if args.key?(:multi_account_allowed)
          @previous_query = args[:previous_query] if args.key?(:previous_query)
        end
      end
      
      # Slot/Argument level instructions.
      class KnowledgeAnswersSensitivityInstructionArgument
        include Google::Apis::Core::Hashable
      
        # Policy controlling argument level eval.
        # Corresponds to the JSON property `eval`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityArgumentEvalPolicy]
        attr_accessor :eval
      
        # Policies controlling the logging.
        # Corresponds to the JSON property `logging`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityLoggingPolicy]
        attr_accessor :logging
      
        # Policies controlling RPC Whitelist at serving time.
        # Corresponds to the JSON property `serving`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityServingPolicy]
        attr_accessor :serving
      
        # Policies controlling the storage.
        # Corresponds to the JSON property `storage`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityStoragePolicy]
        attr_accessor :storage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval = args[:eval] if args.key?(:eval)
          @logging = args[:logging] if args.key?(:logging)
          @serving = args[:serving] if args.key?(:serving)
          @storage = args[:storage] if args.key?(:storage)
        end
      end
      
      # Intent level instructions apply to the entire intent and all its argument
      # values.
      class KnowledgeAnswersSensitivityInstructionIntent
        include Google::Apis::Core::Hashable
      
        # Policy controlling intent level eval.
        # Corresponds to the JSON property `eval`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityIntentEvalPolicy]
        attr_accessor :eval
      
        # Policy controlling MyActivity.
        # Corresponds to the JSON property `footprints`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityMyActivityPolicy]
        attr_accessor :footprints
      
        # Policies controlling the logging.
        # Corresponds to the JSON property `logging`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityLoggingPolicy]
        attr_accessor :logging
      
        # Policies controlling RPC Whitelist at serving time.
        # Corresponds to the JSON property `serving`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityServingPolicy]
        attr_accessor :serving
      
        # Policies controlling the storage.
        # Corresponds to the JSON property `storage`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityStoragePolicy]
        attr_accessor :storage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval = args[:eval] if args.key?(:eval)
          @footprints = args[:footprints] if args.key?(:footprints)
          @logging = args[:logging] if args.key?(:logging)
          @serving = args[:serving] if args.key?(:serving)
          @storage = args[:storage] if args.key?(:storage)
        end
      end
      
      # Instructions for knowledge_context.PreviousQuery. See go/apps-userdata-
      # guidelines.
      class KnowledgeAnswersSensitivityInstructionPreviousQuery
        include Google::Apis::Core::Hashable
      
        # Policies controlling the logging.
        # Corresponds to the JSON property `logging`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityLoggingPolicy]
        attr_accessor :logging
      
        # Policies controlling RPC Whitelist at serving time.
        # Corresponds to the JSON property `serving`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityServingPolicy]
        attr_accessor :serving
      
        # Policies controlling the storage.
        # Corresponds to the JSON property `storage`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityStoragePolicy]
        attr_accessor :storage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @logging = args[:logging] if args.key?(:logging)
          @serving = args[:serving] if args.key?(:serving)
          @storage = args[:storage] if args.key?(:storage)
        end
      end
      
      # Policy controlling intent level eval.
      class KnowledgeAnswersSensitivityIntentEvalPolicy
        include Google::Apis::Core::Hashable
      
        # Policy controlling argument level eval.
        # Corresponds to the JSON property `allArguments`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityArgumentEvalPolicy]
        attr_accessor :all_arguments
      
        # Controls whether to enabled limited logging (rpc whitelisting + GWS log query
        # redaction) if the intent wins post-fulfillment ranking.
        # Corresponds to the JSON property `enabled`
        # @return [Boolean]
        attr_accessor :enabled
        alias_method :enabled?, :enabled
      
        # The eval policy won't apply if the annotated intent is a root. This check is
        # majorly to prevent calling IntentScrubber halfway from InterpretationScrubber
        # via nested intents.
        # Corresponds to the JSON property `nestedIntentOnly`
        # @return [Boolean]
        attr_accessor :nested_intent_only
        alias_method :nested_intent_only?, :nested_intent_only
      
        # Scrub entire intent before saving to eval storage, leaving only intent name
        # and sensitivity info.
        # Corresponds to the JSON property `scrubEntireIntent`
        # @return [Boolean]
        attr_accessor :scrub_entire_intent
        alias_method :scrub_entire_intent?, :scrub_entire_intent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_arguments = args[:all_arguments] if args.key?(:all_arguments)
          @enabled = args[:enabled] if args.key?(:enabled)
          @nested_intent_only = args[:nested_intent_only] if args.key?(:nested_intent_only)
          @scrub_entire_intent = args[:scrub_entire_intent] if args.key?(:scrub_entire_intent)
        end
      end
      
      # Policies controlling the logging.
      class KnowledgeAnswersSensitivityLoggingPolicy
        include Google::Apis::Core::Hashable
      
        # The contents of the argument value should be scrubbed before being written to
        # logs.
        # Corresponds to the JSON property `scrubArgumentValue`
        # @return [Boolean]
        attr_accessor :scrub_argument_value
        alias_method :scrub_argument_value?, :scrub_argument_value
      
        # If this is set to true, this Sensitivity's presence will result in QRewrite to
        # enable AS logging to scrub any discourse context.
        # Corresponds to the JSON property `scrubContext`
        # @return [Boolean]
        attr_accessor :scrub_context
        alias_method :scrub_context?, :scrub_context
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @scrub_argument_value = args[:scrub_argument_value] if args.key?(:scrub_argument_value)
          @scrub_context = args[:scrub_context] if args.key?(:scrub_context)
        end
      end
      
      # Policy controlling MyActivity.
      class KnowledgeAnswersSensitivityMyActivityPolicy
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `myActivityRedactedAction`
        # @return [String]
        attr_accessor :my_activity_redacted_action
      
        # This field will be translated by footprints and is used to describe the
        # content that was redacted that will be displayed to the user in MyActivity.
        # Corresponds to the JSON property `myActivityRedactionKey`
        # @return [String]
        attr_accessor :my_activity_redaction_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @my_activity_redacted_action = args[:my_activity_redacted_action] if args.key?(:my_activity_redacted_action)
          @my_activity_redaction_key = args[:my_activity_redaction_key] if args.key?(:my_activity_redaction_key)
        end
      end
      
      # Canonical representation of query sensitivites. See go/sensitive-intents for
      # more details.
      class KnowledgeAnswersSensitivitySensitivity
        include Google::Apis::Core::Hashable
      
        # Used to annotate the provenace of cross-account personal data. See go/cross-
        # account-understanding. Sensitivity could be annotated at query, intent, and
        # argument levels. Query and intent could have data from multiple accounts, so
        # this field is repeated. A sensitive knowledge_context.PreviousQuery might be
        # dropped to prevent leaking cross-account data via Genie rewrite. For arguments,
        # the best practice is to not blend multi-account data, and this field should
        # be treated as singular to make ownership clear. When publishing attentional
        # entities, contextual NLU might drop an argument that contains data from a
        # different account for data protection. Mixing multi-account data in one
        # argument will cause data from the primary account to be dropped altogether,
        # which is an unnecessary quality loss.
        # Corresponds to the JSON property `accountProvenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewriteAccountProvenance>]
        attr_accessor :account_provenance
      
        # Instructions (eg., logging, disambiguation, ads serving) of handling a
        # sensitive intent and its data. LINT.IfChange NextId: 8
        # Corresponds to the JSON property `instruction`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSensitivityInstruction]
        attr_accessor :instruction
      
        # This should be systematically added without requiring the feature developers
        # to add a source. This is for debug purpose as to whether the Sensitivity's
        # trace/path included any of landmark code path helpful for tracing back the
        # sensitivity sources. One should add a new source when one sees fits. It's
        # chronological order as to which source is added first. One should not manually
        # add a source. The same source can be repeated if the Sensitivity object went
        # through the same code path twice.
        # Corresponds to the JSON property `source`
        # @return [Array<String>]
        attr_accessor :source
      
        # Sensitivity type. See the enum definition below.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_provenance = args[:account_provenance] if args.key?(:account_provenance)
          @instruction = args[:instruction] if args.key?(:instruction)
          @source = args[:source] if args.key?(:source)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Policies controlling RPC Whitelist at serving time.
      class KnowledgeAnswersSensitivityServingPolicy
        include Google::Apis::Core::Hashable
      
        # If this is set to true, QRewrite will enable RPC Whitelist to be applied in
        # Assistant Server and Genie Rewriter.
        # Corresponds to the JSON property `enableRpcWhitelist`
        # @return [Boolean]
        attr_accessor :enable_rpc_whitelist
        alias_method :enable_rpc_whitelist?, :enable_rpc_whitelist
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @enable_rpc_whitelist = args[:enable_rpc_whitelist] if args.key?(:enable_rpc_whitelist)
        end
      end
      
      # Policies controlling the storage.
      class KnowledgeAnswersSensitivityStoragePolicy
        include Google::Apis::Core::Hashable
      
        # The contents of the argument value should be encrypted before being written to
        # a persistent storage (even if the storage has short time-to-live). No-op when
        # specified at intent level.
        # Corresponds to the JSON property `encryptArgumentValue`
        # @return [Boolean]
        attr_accessor :encrypt_argument_value
        alias_method :encrypt_argument_value?, :encrypt_argument_value
      
        # If this is set true, we encrypt QueryAnnotationDataProto prior to writing it
        # to Footprint ASSISTANT_EPHEMERAL corpus. This enables restricting ACL to the
        # data.
        # Corresponds to the JSON property `encryptQueryAnnotationData`
        # @return [Boolean]
        attr_accessor :encrypt_query_annotation_data
        alias_method :encrypt_query_annotation_data?, :encrypt_query_annotation_data
      
        # If this is set to true, the following fields in ConversationSnapshot are
        # scrubbed: * circulated_state.squery * spoken_query * All client_op arguments |
        # from_assistant| interactions
        # Corresponds to the JSON property `scrubAuxiliaryFieldsInConversationSnapshot`
        # @return [Boolean]
        attr_accessor :scrub_auxiliary_fields_in_conversation_snapshot
        alias_method :scrub_auxiliary_fields_in_conversation_snapshot?, :scrub_auxiliary_fields_in_conversation_snapshot
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encrypt_argument_value = args[:encrypt_argument_value] if args.key?(:encrypt_argument_value)
          @encrypt_query_annotation_data = args[:encrypt_query_annotation_data] if args.key?(:encrypt_query_annotation_data)
          @scrub_auxiliary_fields_in_conversation_snapshot = args[:scrub_auxiliary_fields_in_conversation_snapshot] if args.key?(:scrub_auxiliary_fields_in_conversation_snapshot)
        end
      end
      
      # A special type representing a StateOfAffairs. Currently (as of 2021Q2) this is
      # duplicative with semantic_type ` name: "StateOfAffairs" ` but we (mrf-team)
      # will encourage clients to migrate to this new type.
      class KnowledgeAnswersStateOfAffairsType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A StringType configures a value whose type is intended to be arbitrary text.
      class KnowledgeAnswersStringType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # If true, this value will match a single token. If false, this value will match
        # any nonzero number of tokens.
        # Corresponds to the JSON property `singleToken`
        # @return [Boolean]
        attr_accessor :single_token
        alias_method :single_token?, :single_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @single_token = args[:single_token] if args.key?(:single_token)
        end
      end
      
      # A TimeZoneType configures a value whose type is a timezone.
      class KnowledgeAnswersTimeZoneType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A TrackingNumberType configures a value whose type is a TrackingNumber.
      class KnowledgeAnswersTrackingNumberType
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # A TypeTrait configures a value that has a property with any of the given
      # trait_id. In practice this means: - any entity that has a metadata ID defined
      # in the KP type_schema, - any intent that has a slot with the given ID. When
      # comparing trait_id to metadata IDs or slot IDs, we lowercase and normalize for
      # comparison.
      class KnowledgeAnswersTypeTrait
        include Google::Apis::Core::Hashable
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        # 
        # Corresponds to the JSON property `traitId`
        # @return [Array<String>]
        attr_accessor :trait_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
          @trait_id = args[:trait_id] if args.key?(:trait_id)
        end
      end
      
      # 
      class KnowledgeAnswersUnionType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slotNames`
        # @return [Array<String>]
        attr_accessor :slot_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slot_names = args[:slot_names] if args.key?(:slot_names)
        end
      end
      
      # Specifies the allowed type(s) that a value can have, e.g. for a Slot. For
      # example, having both entity_type and string_type present in a ValueType field
      # of a Slot means that the Slot can take _either_ an an EntityType _or_
      # StringType as a value, and nothing else. It may be helpful to think of this
      # proto as being called something like AllAllowedValueTypes. Next tag id: 24
      # LINT.IfChange
      class KnowledgeAnswersValueType
        include Google::Apis::Core::Hashable
      
        # Accepts any non-empty value. This is meant for special cases allowing any
        # value or any composition to be valid in a slot. If you are thinking of using
        # this, please contact mrf-team@.
        # Corresponds to the JSON property `anyType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersAnyType]
        attr_accessor :any_type
      
        # An attribute type configures a value whose type is intended to be a attribute
        # defined in the schema.
        # Corresponds to the JSON property `attributeType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersAttributeType]
        attr_accessor :attribute_type
      
        # A BooleanType configures a yes/no value.
        # Corresponds to the JSON property `booleanType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersBooleanType]
        attr_accessor :boolean_type
      
        # A CollectionType configures a value whose type is intended to be a collection.
        # Corresponds to the JSON property `collectionType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersCollectionType]
        attr_accessor :collection_type
      
        # A CompoundType configures a value composed of multiple answer values.
        # Corresponds to the JSON property `compoundType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersCompoundType]
        attr_accessor :compound_type
      
        # A DateType configures a value whose type is intended to be a date. LINT.
        # IfChange Next id: 16
        # Corresponds to the JSON property `dateType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersDateType]
        attr_accessor :date_type
      
        # Work in progress: Used for configuring dynamic types to allow for type
        # transparency. See: go/type-dependencies
        # Corresponds to the JSON property `dependencyType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersDependencyType]
        attr_accessor :dependency_type
      
        # A DurationType configures a value whose type is a duration.
        # Corresponds to the JSON property `durationType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersDurationType]
        attr_accessor :duration_type
      
        # An EntityType configures a value whose type is intended to be an entity.
        # Entities may be specified using either the collection(s) to which they belong,
        # or explicitly via a list of KG-ids. Both collections and ids can be specified,
        # in which case the type will be the union of the id(s) and all mids within the
        # collection(s). Next available tag: 9
        # Corresponds to the JSON property `entityType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersEntityType]
        attr_accessor :entity_type
      
        # A MeasurementType configures a value that consists of a measurement. The
        # expected value should have a number and a mid representing the unit. Note:
        # this is currently only used for attribute answer value types. Configuration
        # intent slot as measurement is yet to be supported (or instead we should
        # universally use SemanticType).
        # Corresponds to the JSON property `measurementType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersMeasurementType]
        attr_accessor :measurement_type
      
        # A NormalizedStringType configures a value that is one of the listed
        # normalized_values. An arbitrary mapping from input strings to
        # normalized_values can be specified in the local intent config. Only
        # alphabetical strings can be used as normalized_values. This type should NOT be
        # used for: - Mids, ids, dates, or other structured data. Use an annotator
        # instead, and address any quality issues at the annotator level. - Simplifying
        # grammar rules. If you are not using the normalized_values in your question
        # semantics, you should remove the slot. Use additional query_examples instead.
        # Corresponds to the JSON property `normalizedStringType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersNormalizedStringType]
        attr_accessor :normalized_string_type
      
        # A NumberType configures a value whose type is intended to be numeric.
        # Corresponds to the JSON property `numberType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersNumberType]
        attr_accessor :number_type
      
        # Note: OpaqueType is deprecated and addition of new fields is not allowed.
        # Refer to go/opaque_type for details. If you think this is the only way to
        # implement your feature, attend an office hours (go/meaning-help) and discuss
        # with the MRF team. An OpaqueType configures a value whose type is only
        # interpretable by _specific_ clients of the intent catalog. This means
        # horizontal 'features' like pretty printing, correct logging, intent
        # blacklisting and signal aggregation will not work for opaque value types. It
        # has a field for each type in IntentQuery that is not covered by a non-opaque
        # type (specifically: protocol messages). The fields are themselves messages
        # declared in this file. The specific opaque value types must be empty messages.
        # If you find a need to add any fields to these messages, make them non-opaque
        # and implement all of the code to treat them as first class types. It is
        # allowable for a value to have more than one of the opaque types. See http://go/
        # opaque-type-for-value-type. LINT.IfChange Next Id: 31
        # Corresponds to the JSON property `opaqueType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersOpaqueType]
        attr_accessor :opaque_type
      
        # Plexity is a conceptual distinction between viewing something (a slot filler,
        # for example) as a single individual, or as a complex concept consisting of
        # multiple individuals or subparts. Note that plexity is not the same as (or
        # correlated with) either grammatical number or with distributive and collective
        # interpretations of the slot. The PlexityRequirement proto and Plexity enum are
        # defined outside ValueType as we may move the plexity specification to a
        # different place in the intent protos in future.
        # Corresponds to the JSON property `plexityRequirement`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersPlexityRequirement]
        attr_accessor :plexity_requirement
      
        # 
        # Corresponds to the JSON property `pluralityType`
        # @return [String]
        attr_accessor :plurality_type
      
        # A special type representing a polar question.
        # Corresponds to the JSON property `polarQuestionType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersPolarQuestionType]
        attr_accessor :polar_question_type
      
        # A SemanticType configures a value determined by another source, in particular
        # another intent or a semantic frame. See go/unifying-intents and go/framery.
        # Corresponds to the JSON property `semanticType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersSemanticType]
        attr_accessor :semantic_type
      
        # DEPRECATED: see go/type-dependencies. Please reach out to suwu@, dqwang@ if
        # usage is required.
        # Corresponds to the JSON property `slotName`
        # @return [String]
        attr_accessor :slot_name
      
        # A special type representing a StateOfAffairs. Currently (as of 2021Q2) this is
        # duplicative with semantic_type ` name: "StateOfAffairs" ` but we (mrf-team)
        # will encourage clients to migrate to this new type.
        # Corresponds to the JSON property `stateOfAffairsType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersStateOfAffairsType]
        attr_accessor :state_of_affairs_type
      
        # A StringType configures a value whose type is intended to be arbitrary text.
        # Corresponds to the JSON property `stringType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersStringType]
        attr_accessor :string_type
      
        # A TimeZoneType configures a value whose type is a timezone.
        # Corresponds to the JSON property `timezoneType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersTimeZoneType]
        attr_accessor :timezone_type
      
        # A TrackingNumberType configures a value whose type is a TrackingNumber.
        # Corresponds to the JSON property `trackingNumberType`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersTrackingNumberType]
        attr_accessor :tracking_number_type
      
        # A TypeTrait configures a value that has a property with any of the given
        # trait_id. In practice this means: - any entity that has a metadata ID defined
        # in the KP type_schema, - any intent that has a slot with the given ID. When
        # comparing trait_id to metadata IDs or slot IDs, we lowercase and normalize for
        # comparison.
        # Corresponds to the JSON property `withTrait`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersTypeTrait]
        attr_accessor :with_trait
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @any_type = args[:any_type] if args.key?(:any_type)
          @attribute_type = args[:attribute_type] if args.key?(:attribute_type)
          @boolean_type = args[:boolean_type] if args.key?(:boolean_type)
          @collection_type = args[:collection_type] if args.key?(:collection_type)
          @compound_type = args[:compound_type] if args.key?(:compound_type)
          @date_type = args[:date_type] if args.key?(:date_type)
          @dependency_type = args[:dependency_type] if args.key?(:dependency_type)
          @duration_type = args[:duration_type] if args.key?(:duration_type)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @measurement_type = args[:measurement_type] if args.key?(:measurement_type)
          @normalized_string_type = args[:normalized_string_type] if args.key?(:normalized_string_type)
          @number_type = args[:number_type] if args.key?(:number_type)
          @opaque_type = args[:opaque_type] if args.key?(:opaque_type)
          @plexity_requirement = args[:plexity_requirement] if args.key?(:plexity_requirement)
          @plurality_type = args[:plurality_type] if args.key?(:plurality_type)
          @polar_question_type = args[:polar_question_type] if args.key?(:polar_question_type)
          @semantic_type = args[:semantic_type] if args.key?(:semantic_type)
          @slot_name = args[:slot_name] if args.key?(:slot_name)
          @state_of_affairs_type = args[:state_of_affairs_type] if args.key?(:state_of_affairs_type)
          @string_type = args[:string_type] if args.key?(:string_type)
          @timezone_type = args[:timezone_type] if args.key?(:timezone_type)
          @tracking_number_type = args[:tracking_number_type] if args.key?(:tracking_number_type)
          @with_trait = args[:with_trait] if args.key?(:with_trait)
        end
      end
      
      # /////////// DATE //////////
      class KnowledgeGraphDateTimeProto
        include Google::Apis::Core::Hashable
      
        # A day of month, 1-31. If present, year and month must be present as well, and
        # must form a valid date.
        # Corresponds to the JSON property `days`
        # @return [Fixnum]
        attr_accessor :days
      
        # Hour of the day, 0-23
        # Corresponds to the JSON property `hours`
        # @return [Fixnum]
        attr_accessor :hours
      
        # Microsecond, in the interval [0, 999999]. If present, seconds have to be
        # present as well.
        # Corresponds to the JSON property `microseconds`
        # @return [Fixnum]
        attr_accessor :microseconds
      
        # Minute, 0-59. If present, hours have to be present as well.
        # Corresponds to the JSON property `minutes`
        # @return [Fixnum]
        attr_accessor :minutes
      
        # A month, 1-12. If present, year must be present as well.
        # Corresponds to the JSON property `months`
        # @return [Fixnum]
        attr_accessor :months
      
        # Second, in the interval [0, 60], where 60 is an exceptional value reserved for
        # leap seconds. If present, minutes have to be present as well.
        # Corresponds to the JSON property `seconds`
        # @return [Fixnum]
        attr_accessor :seconds
      
        # Timezone offset in seconds (can be positive/negative). If present, hours have
        # to be present as well If absent, we expect the time above to be in local time (
        # a.k.a. civil time, go/httat#civil_time).
        # Corresponds to the JSON property `tzOffset`
        # @return [Fixnum]
        attr_accessor :tz_offset
      
        # A year.
        # Corresponds to the JSON property `years`
        # @return [Fixnum]
        attr_accessor :years
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @days = args[:days] if args.key?(:days)
          @hours = args[:hours] if args.key?(:hours)
          @microseconds = args[:microseconds] if args.key?(:microseconds)
          @minutes = args[:minutes] if args.key?(:minutes)
          @months = args[:months] if args.key?(:months)
          @seconds = args[:seconds] if args.key?(:seconds)
          @tz_offset = args[:tz_offset] if args.key?(:tz_offset)
          @years = args[:years] if args.key?(:years)
        end
      end
      
      # A nested struct is a recursive tree structure for storing a set of triples.
      # more info can be found at go/nested-struct-primer
      class KnowledgeGraphNestedStruct
        include Google::Apis::Core::Hashable
      
        # predicate_objs.pred should be unique within the list.
        # Corresponds to the JSON property `predicateObjs`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeGraphNestedStructPredicateObjs>]
        attr_accessor :predicate_objs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @predicate_objs = args[:predicate_objs] if args.key?(:predicate_objs)
        end
      end
      
      # 
      class KnowledgeGraphNestedStructPredicateObjs
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `objs`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeGraphTripleObj>]
        attr_accessor :objs
      
        # 
        # Corresponds to the JSON property `pred`
        # @return [String]
        attr_accessor :pred
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @objs = args[:objs] if args.key?(:objs)
          @pred = args[:pred] if args.key?(:pred)
        end
      end
      
      # A qualifier represents an extra piece of context about an assertion/fact. See
      # go/qualifiers-in-kg for more details.
      class KnowledgeGraphQualifier
        include Google::Apis::Core::Hashable
      
        # The qualifier pred must be a qualifier property defined in KG schema as
        # applying to the predicate of the triple this qualifier is attached to.
        # Corresponds to the JSON property `pred`
        # @return [String]
        attr_accessor :pred
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphTripleObj]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pred = args[:pred] if args.key?(:pred)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A QualifierSet represents a grouping of qualifiers that together with an SPO
      # make up a logical assertion or fact. One triple can contain multiple qualifier
      # sets and thus represent several different assertions about the same SPO.
      class KnowledgeGraphQualifierSet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `qualifiers`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeGraphQualifier>]
        attr_accessor :qualifiers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @qualifiers = args[:qualifiers] if args.key?(:qualifiers)
        end
      end
      
      # A Triple is a representation of data with a Subject, a Predicate, and an
      # Object, For example: (Triple, IS-A, "data representation"). Triples are a very
      # good representation of data where the relationship between data points is
      # significant, because the Object of a Triple can be the Subject of another
      # Triple: (Triple, HAS-A, Subject) (Subject, IS-A, "Term of a proposition") The
      # ease with which Triples can represent relationships makes them an excellent
      # candidate for representing graphs. Next id: 21
      class KnowledgeGraphTriple
        include Google::Apis::Core::Hashable
      
        # If is_negation is set to true then this triple is considered a statement that
        # the fact is false. This allows for the storage of both what we know to be true
        # and what we know to be false.
        # Corresponds to the JSON property `isNegation`
        # @return [Boolean]
        attr_accessor :is_negation
        alias_method :is_negation?, :is_negation
      
        # obj is the value of a relationship.
        # Corresponds to the JSON property `obj`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphTripleObj]
        attr_accessor :obj
      
        # pred is an arbitrary node id representing the predicate (name) of a graph
        # relationship.
        # Corresponds to the JSON property `pred`
        # @return [String]
        attr_accessor :pred
      
        # 
        # Corresponds to the JSON property `provenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeGraphTripleProvenance>]
        attr_accessor :provenance
      
        # WARNING: This is currently defined for experimentation purposes only. Please
        # do not set. Data set in this field will not be published to any systems
        # downstream of Livegraph. Together with the SPO of this triple, each qualifier
        # set here represents a different logical assertion/fact.
        # Corresponds to the JSON property `qualifierSets`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeGraphQualifierSet>]
        attr_accessor :qualifier_sets
      
        # sub is an arbitrary node id representing the source entity of a graph
        # relationship.
        # Corresponds to the JSON property `sub`
        # @return [String]
        attr_accessor :sub
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_negation = args[:is_negation] if args.key?(:is_negation)
          @obj = args[:obj] if args.key?(:obj)
          @pred = args[:pred] if args.key?(:pred)
          @provenance = args[:provenance] if args.key?(:provenance)
          @qualifier_sets = args[:qualifier_sets] if args.key?(:qualifier_sets)
          @sub = args[:sub] if args.key?(:sub)
        end
      end
      
      # 
      class KnowledgeGraphTripleObj
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # /////////// DATE //////////
        # Corresponds to the JSON property `datetimeValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphDateTimeProto]
        attr_accessor :datetime_value
      
        # 
        # Corresponds to the JSON property `doubleValue`
        # @return [Float]
        attr_accessor :double_value
      
        # seconds
        # Corresponds to the JSON property `durationValue`
        # @return [Fixnum]
        attr_accessor :duration_value
      
        # An id representing an entity (mid or hrid)
        # Corresponds to the JSON property `idValue`
        # @return [String]
        attr_accessor :id_value
      
        # 
        # Corresponds to the JSON property `int64Value`
        # @return [Fixnum]
        attr_accessor :int64_value
      
        # The language code for the object value. It must be a BCP 47-compliant language
        # tag (b/10005172). See also go/kg-data-l10n.
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # A nested struct is a recursive tree structure for storing a set of triples.
        # more info can be found at go/nested-struct-primer
        # Corresponds to the JSON property `nestedStructValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphNestedStruct]
        attr_accessor :nested_struct_value
      
        # 
        # Corresponds to the JSON property `protoValue`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphTripleObjProto]
        attr_accessor :proto_value
      
        # 
        # Corresponds to the JSON property `s2cellId`
        # @return [Fixnum]
        attr_accessor :s2cell_id
      
        # A UTF-8 string value to be used for the following expected schema types: - /
        # type/rawstring - /type/text - /type/key
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # 
        # Corresponds to the JSON property `uint64Value`
        # @return [Fixnum]
        attr_accessor :uint64_value
      
        # A UTF-8 string value to be used for expected type /type/uri - b/68760994.
        # Corresponds to the JSON property `uriValue`
        # @return [String]
        attr_accessor :uri_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @datetime_value = args[:datetime_value] if args.key?(:datetime_value)
          @double_value = args[:double_value] if args.key?(:double_value)
          @duration_value = args[:duration_value] if args.key?(:duration_value)
          @id_value = args[:id_value] if args.key?(:id_value)
          @int64_value = args[:int64_value] if args.key?(:int64_value)
          @locale = args[:locale] if args.key?(:locale)
          @nested_struct_value = args[:nested_struct_value] if args.key?(:nested_struct_value)
          @proto_value = args[:proto_value] if args.key?(:proto_value)
          @s2cell_id = args[:s2cell_id] if args.key?(:s2cell_id)
          @string_value = args[:string_value] if args.key?(:string_value)
          @uint64_value = args[:uint64_value] if args.key?(:uint64_value)
          @uri_value = args[:uri_value] if args.key?(:uri_value)
        end
      end
      
      # 
      class KnowledgeGraphTripleObjProto
        include Google::Apis::Core::Hashable
      
        # The encoded proto data.
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # The full name of the proto descriptor, such as 'music.AlbumSummary'.
        # Corresponds to the JSON property `descriptorFullName`
        # @return [String]
        attr_accessor :descriptor_full_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @descriptor_full_name = args[:descriptor_full_name] if args.key?(:descriptor_full_name)
        end
      end
      
      # Message containing information about the source of this triple. See go/kg-
      # provenance for an explanation of the fields.
      class KnowledgeGraphTripleProvenance
        include Google::Apis::Core::Hashable
      
        # Specifies the contract or legal visibility required to see the Triple. See go/
        # kg-triple-level-access-controls for details and background. Note that we use
        # an int32 here so that we won't lose values when decoding on a stale binary.
        # The int32 references to the enum storage_graph_bfg.Triple.Provenance.
        # AccessRequirement.
        # Corresponds to the JSON property `accessRequired`
        # @return [Fixnum]
        attr_accessor :access_required
      
        # Historically, this field was used to encode the Freebase User ID, Google
        # username, or Google MDB group that was responsible for the pipeline that is
        # producing this data. However, there is currently no horizontal validation in
        # place, and as of Q3 2018, this field is used essentially as a free-form string
        # by multiple data providers. NOTE: Do not use this field in new pipelines
        # without first consulting with the OWNERS of this proto.
        # Corresponds to the JSON property `creator`
        # @return [String]
        attr_accessor :creator
      
        # The dataset which asserted this data. Must be a valid mid. See go/kg-
        # provenance
        # Corresponds to the JSON property `datasetMid`
        # @return [Fixnum]
        attr_accessor :dataset_mid
      
        # Indicates that the corresponding data is supporting evidence for
        # reconciliation only, and is *not* an assertion that should be visible to other
        # systems or to external users. Note that this also means that no provenances
        # indicating supporting data will be visible in the composed graph. Please see
        # go/supporting-kg-triples-design-doc for additional details and background.
        # Corresponds to the JSON property `isSupportingData`
        # @return [Boolean]
        attr_accessor :is_supporting_data
        alias_method :is_supporting_data?, :is_supporting_data
      
        # Metadata on source assertions that isn't part of the user-visible Triple
        # payload, and that doesn't really represent data provenance, but that's used to
        # affect the way Livegraph and possibly other horizontal KG infra systems *
        # process* the triple. Read: fields below really shouldn't be part of the cross-
        # system Triple proto at all. But because Triple is used both as an internal and
        # an external KG API, we at least want to "hide" those fields that ought to be
        # purely part of the internal source <-> LG contract. Next id: 5
        # Corresponds to the JSON property `lgMetadata`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgLivegraphProvenanceMetadata]
        attr_accessor :lg_metadata
      
        # Metadata about data governance policies. For more context, see go/ke-triple-dg-
        # policy-and-metadata. If any attribute is not set, then there's no specific
        # restrictions associated with the missing attribute. For example, if `
        # availability_start_timestamp` is not set, the data won't be embargoed
        # automatically; if `availability_end_timestamp` is not set, they won't expire
        # automatically. Next ID: 8 LINT.IfChange
        # Corresponds to the JSON property `policyMetadata`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgPolicyMetadata]
        attr_accessor :policy_metadata
      
        # An identifier for the process that asserted this triple.
        # Corresponds to the JSON property `process`
        # @return [String]
        attr_accessor :process
      
        # 
        # Corresponds to the JSON property `restrictions`
        # @return [Array<String>]
        attr_accessor :restrictions
      
        # Used to measure impact of 3P contributions. See go/ke-metrics.
        # Corresponds to the JSON property `sourceCategory`
        # @return [String]
        attr_accessor :source_category
      
        # The websearch doc_id of the source_url. Used in conjunction with
        # source_category for measuring 3P contributions.
        # Corresponds to the JSON property `sourceDocId`
        # @return [Fixnum]
        attr_accessor :source_doc_id
      
        # If the triple was extracted from the web, the source URL where the assertion
        # was found. Used for citation if needed (see restrictions field below).
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # A fact about potentially sensitive personal info (http://what/SPII) can be "
        # certified" iff it meets specific requirements. See go/kg-spii-certification
        # for details.
        # Corresponds to the JSON property `spiiCertification`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgSpiiCertification]
        attr_accessor :spii_certification
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_required = args[:access_required] if args.key?(:access_required)
          @creator = args[:creator] if args.key?(:creator)
          @dataset_mid = args[:dataset_mid] if args.key?(:dataset_mid)
          @is_supporting_data = args[:is_supporting_data] if args.key?(:is_supporting_data)
          @lg_metadata = args[:lg_metadata] if args.key?(:lg_metadata)
          @policy_metadata = args[:policy_metadata] if args.key?(:policy_metadata)
          @process = args[:process] if args.key?(:process)
          @restrictions = args[:restrictions] if args.key?(:restrictions)
          @source_category = args[:source_category] if args.key?(:source_category)
          @source_doc_id = args[:source_doc_id] if args.key?(:source_doc_id)
          @source_url = args[:source_url] if args.key?(:source_url)
          @spii_certification = args[:spii_certification] if args.key?(:spii_certification)
        end
      end
      
      # A user specified location to trigger weather for a specific location. Also it
      # can be generalized for other verticals.
      class KnowledgeVerticalsWeatherProtoUserSpecifiedLocation
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # An object that represents a latitude/longitude pair. This is expressed as a
        # pair of doubles to represent degrees latitude and degrees longitude. Unless
        # specified otherwise, this object must conform to the WGS84 standard. Values
        # must be within normalized ranges.
        # Corresponds to the JSON property `latLng`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeLatLng]
        attr_accessor :lat_lng
      
        # The name to display. If specified it will override the formatted address of "
        # feature_id".
        # Corresponds to the JSON property `locationName`
        # @return [String]
        attr_accessor :location_name
      
        # The timezone to display the current conditions observation time. Optional and
        # will override the timezone of "feature_id".
        # Corresponds to the JSON property `timezone`
        # @return [String]
        attr_accessor :timezone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
          @location_name = args[:location_name] if args.key?(:location_name)
          @timezone = args[:timezone] if args.key?(:timezone)
        end
      end
      
      # 
      class LegalCitation
        include Google::Apis::Core::Hashable
      
        # For Courts, the country the court is in. For Statues,? 3 leter country code
        # ISO 3166 alpha2
        # Corresponds to the JSON property `CountryCode`
        # @return [String]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `ParseType`
        # @return [Fixnum]
        attr_accessor :parse_type
      
        # State or province of the court or statue (if applicable) What standard?
        # Corresponds to the JSON property `State`
        # @return [String]
        attr_accessor :state
      
        # DocType
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        # Information about a published version of the document. Not all references/
        # documents will have this because some will be vendor and/or media neutral.
        # Corresponds to the JSON property `courtdocument`
        # @return [Google::Apis::ContentwarehouseV1::LegalCitationCourtDocument]
        attr_accessor :courtdocument
      
        # 
        # Corresponds to the JSON property `law`
        # @return [Google::Apis::ContentwarehouseV1::LegalCitationLaw]
        attr_accessor :law
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @parse_type = args[:parse_type] if args.key?(:parse_type)
          @state = args[:state] if args.key?(:state)
          @type = args[:type] if args.key?(:type)
          @courtdocument = args[:courtdocument] if args.key?(:courtdocument)
          @law = args[:law] if args.key?(:law)
        end
      end
      
      # Information about a published version of the document. Not all references/
      # documents will have this because some will be vendor and/or media neutral.
      class LegalCitationCourtDocument
        include Google::Apis::Core::Hashable
      
        # One entry per judge who listened to the case in this court
        # Corresponds to the JSON property `ArguedBefore`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalPerson>]
        attr_accessor :argued_before
      
        # 
        # Corresponds to the JSON property `ArguedDate`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :argued_date
      
        # For an appeal, the name of the lower court that sent this up Abbreviation form?
        # Verbose form?
        # Corresponds to the JSON property `CertiorariCourtName`
        # @return [String]
        attr_accessor :certiorari_court_name
      
        # 
        # Corresponds to the JSON property `CertiorariRelationship`
        # @return [Fixnum]
        attr_accessor :certiorari_relationship
      
        # Usually the name of a month. Not sure really what it means.
        # Corresponds to the JSON property `CourtTerm`
        # @return [String]
        attr_accessor :court_term
      
        # Various dates related to the generation of document most of these are opinion-
        # centric
        # Corresponds to the JSON property `DecidedDate`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :decided_date
      
        # 
        # Corresponds to the JSON property `FiledDate`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :filed_date
      
        # Not sure what this is. But I've seen it.
        # Corresponds to the JSON property `MemoID`
        # @return [String]
        attr_accessor :memo_id
      
        # 
        # Corresponds to the JSON property `ModifiedDate`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :modified_date
      
        # A summary of the document or a syllabus for this document
        # Corresponds to the JSON property `Syllabus`
        # @return [String]
        attr_accessor :syllabus
      
        # 
        # Corresponds to the JSON property `court`
        # @return [Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentCourt]
        attr_accessor :court
      
        # 
        # Corresponds to the JSON property `opinioninfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentOpinionInfo>]
        attr_accessor :opinioninfo
      
        # 
        # Corresponds to the JSON property `perdocketinfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentPerDocketInfo>]
        attr_accessor :perdocketinfo
      
        # 
        # Corresponds to the JSON property `pub`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentPub>]
        attr_accessor :pub
      
        # 
        # Corresponds to the JSON property `unknowndate`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentUnknownDate>]
        attr_accessor :unknowndate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @argued_before = args[:argued_before] if args.key?(:argued_before)
          @argued_date = args[:argued_date] if args.key?(:argued_date)
          @certiorari_court_name = args[:certiorari_court_name] if args.key?(:certiorari_court_name)
          @certiorari_relationship = args[:certiorari_relationship] if args.key?(:certiorari_relationship)
          @court_term = args[:court_term] if args.key?(:court_term)
          @decided_date = args[:decided_date] if args.key?(:decided_date)
          @filed_date = args[:filed_date] if args.key?(:filed_date)
          @memo_id = args[:memo_id] if args.key?(:memo_id)
          @modified_date = args[:modified_date] if args.key?(:modified_date)
          @syllabus = args[:syllabus] if args.key?(:syllabus)
          @court = args[:court] if args.key?(:court)
          @opinioninfo = args[:opinioninfo] if args.key?(:opinioninfo)
          @perdocketinfo = args[:perdocketinfo] if args.key?(:perdocketinfo)
          @pub = args[:pub] if args.key?(:pub)
          @unknowndate = args[:unknowndate] if args.key?(:unknowndate)
        end
      end
      
      # 
      class LegalCitationCourtDocumentCourt
        include Google::Apis::Core::Hashable
      
        # The name of the court to be displayed to users.
        # Corresponds to the JSON property `DisplayName`
        # @return [String]
        attr_accessor :display_name
      
        # Maybe be redundant with the Name. We can remove this later if we don't find it
        # useful. Court Level
        # Corresponds to the JSON property `Level`
        # @return [Fixnum]
        attr_accessor :level
      
        # Court id for matching records; "name" is a historic misnomer.
        # Corresponds to the JSON property `Name`
        # @return [String]
        attr_accessor :name
      
        # The name of the court as taken directly from the source document
        # Corresponds to the JSON property `OriginalName`
        # @return [String]
        attr_accessor :original_name
      
        # 
        # Corresponds to the JSON property `namecomponent`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationCourtDocumentCourtNameComponent>]
        attr_accessor :namecomponent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @level = args[:level] if args.key?(:level)
          @name = args[:name] if args.key?(:name)
          @original_name = args[:original_name] if args.key?(:original_name)
          @namecomponent = args[:namecomponent] if args.key?(:namecomponent)
        end
      end
      
      # The name broken down into its various components, such as core court, state,
      # and district
      class LegalCitationCourtDocumentCourtNameComponent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Text`
        # @return [String]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A variety of opinions may be published as a single document. We have one
      # OpinionInfo for each opinion About the "CONCURRING" opinion type: It means
      # that a judge "concurs" to the conclusion (judegment) of the majority of the
      # court, however, he may not agree with the argument in the primary opinion. If
      # multiple judges "concur" or "dissent" the primary opinion, then one judge
      # delivers their opinion, and other judges are said to "join" him.
      class LegalCitationCourtDocumentOpinionInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Bench`
        # @return [Fixnum]
        attr_accessor :bench
      
        # if Type == PER_CURIAM, then DeliveredBy is unnecessary since it is delivered
        # by the full court. Who delivered the opinion?
        # Corresponds to the JSON property `DeliveredBy`
        # @return [Google::Apis::ContentwarehouseV1::LegalPerson]
        attr_accessor :delivered_by
      
        # Who agrees with the opinion
        # Corresponds to the JSON property `JoinedBy`
        # @return [Google::Apis::ContentwarehouseV1::LegalPerson]
        attr_accessor :joined_by
      
        # OpinionType
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bench = args[:bench] if args.key?(:bench)
          @delivered_by = args[:delivered_by] if args.key?(:delivered_by)
          @joined_by = args[:joined_by] if args.key?(:joined_by)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Information associated with a docket. Note that multiple dockets can be
      # combined and argued as one and produce a single opinion
      class LegalCitationCourtDocumentPerDocketInfo
        include Google::Apis::Core::Hashable
      
        # An alpha-numeric (usually, mostly numeric) string used to identify the case by
        # the court
        # Corresponds to the JSON property `DocketID`
        # @return [String]
        attr_accessor :docket_id
      
        # Who is bringing the action? (X in X vs. Y)
        # Corresponds to the JSON property `Petitioner`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalPerson>]
        attr_accessor :petitioner
      
        # Who represents the petitioner?
        # Corresponds to the JSON property `PetitionerCounsel`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalPerson>]
        attr_accessor :petitioner_counsel
      
        # Who is responding to the action? (Y in X vs. Y)
        # Corresponds to the JSON property `Respondent`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalPerson>]
        attr_accessor :respondent
      
        # Who represents the respondent?
        # Corresponds to the JSON property `RespondentCounsel`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalPerson>]
        attr_accessor :respondent_counsel
      
        # The "in re" or "matter of" field.
        # Corresponds to the JSON property `Topic`
        # @return [String]
        attr_accessor :topic
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docket_id = args[:docket_id] if args.key?(:docket_id)
          @petitioner = args[:petitioner] if args.key?(:petitioner)
          @petitioner_counsel = args[:petitioner_counsel] if args.key?(:petitioner_counsel)
          @respondent = args[:respondent] if args.key?(:respondent)
          @respondent_counsel = args[:respondent_counsel] if args.key?(:respondent_counsel)
          @topic = args[:topic] if args.key?(:topic)
        end
      end
      
      # 
      class LegalCitationCourtDocumentPub
        include Google::Apis::Core::Hashable
      
        # Page number
        # Corresponds to the JSON property `Page`
        # @return [String]
        attr_accessor :page
      
        # Paragraph number
        # Corresponds to the JSON property `Paragraph`
        # @return [String]
        attr_accessor :paragraph
      
        # The publisher of the opinion. For example, 'U.S.' - United States Reports 'S.
        # Ct.' - Supreme Court Reporter 'L. Ed. 2d' - Lawyers Edition Second Series
        # Corresponds to the JSON property `Reporter`
        # @return [String]
        attr_accessor :reporter
      
        # For documents published by a court reporter. Vendor/Media neutral citations
        # will probably not have this.
        # Corresponds to the JSON property `Volume`
        # @return [Fixnum]
        attr_accessor :volume
      
        # This is the publication year. In many citations, there is one year listed and
        # it is typically the year the opinion was handed down. For example: Roe v. Wade,
        # 410 U.S. 113 (1973) Occasionally, the publication year of the reporter is
        # included. This happens typically when the law reporter volume numbers are
        # numbered within a calendar year. For example, Swiss Bank Corp. v. Air Canada, [
        # 1988] 1 F.C. 71. It some (most?) areas, publication date is denoted by []
        # while opinion date is denoted by ().
        # Corresponds to the JSON property `Year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @page = args[:page] if args.key?(:page)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @reporter = args[:reporter] if args.key?(:reporter)
          @volume = args[:volume] if args.key?(:volume)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # Dates that we didn't fully parse, so we don't know exactly what they are, but
      # we are keeping in case it's all we have.
      class LegalCitationCourtDocumentUnknownDate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Date`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :date
      
        # 
        # Corresponds to the JSON property `Description`
        # @return [String]
        attr_accessor :description
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date = args[:date] if args.key?(:date)
          @description = args[:description] if args.key?(:description)
        end
      end
      
      # 
      class LegalCitationLaw
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `RevisionDate`
        # @return [Google::Apis::ContentwarehouseV1::LegalDate]
        attr_accessor :revision_date
      
        # LawStatus
        # Corresponds to the JSON property `Status`
        # @return [Fixnum]
        attr_accessor :status
      
        # LawType
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        # this is used to store information about law collections Normalized is the
        # normalized name for the law (e.g., USC for USCA and USCS) Source is the text
        # that represents the law in the citation
        # Corresponds to the JSON property `collectionname`
        # @return [Google::Apis::ContentwarehouseV1::LegalCitationLawCollectionName]
        attr_accessor :collectionname
      
        # 
        # Corresponds to the JSON property `level`
        # @return [Array<Google::Apis::ContentwarehouseV1::LegalCitationLawLevel>]
        attr_accessor :level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @revision_date = args[:revision_date] if args.key?(:revision_date)
          @status = args[:status] if args.key?(:status)
          @type = args[:type] if args.key?(:type)
          @collectionname = args[:collectionname] if args.key?(:collectionname)
          @level = args[:level] if args.key?(:level)
        end
      end
      
      # this is used to store information about law collections Normalized is the
      # normalized name for the law (e.g., USC for USCA and USCS) Source is the text
      # that represents the law in the citation
      class LegalCitationLawCollectionName
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Normalized`
        # @return [String]
        attr_accessor :normalized
      
        # 
        # Corresponds to the JSON property `Source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized = args[:normalized] if args.key?(:normalized)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Law have tree-like sturcture (title, section, etc), but the levels and their
      # names are not fixed. e.g., we could have: US Constitution -> Article 3 ->
      # Section 4, OR, US Code -> Title 12 -> Chapter 6 -> Sub-chapter I -> Section
      # 602, OR, US Code -> Title 10 -> Sub-title A -> Part 2 -> Chapter 32 -> Section
      # 523. We use a repeated group to represent this structure. NOTE: Always insert
      # higher levels before lower levels,
      class LegalCitationLawLevel
        include Google::Apis::Core::Hashable
      
        # A counter that specifies the depth of the level in the parse
        # Corresponds to the JSON property `Depth`
        # @return [Fixnum]
        attr_accessor :depth
      
        # "SECTION, TITLE, PART, etc."
        # Corresponds to the JSON property `LevelTypeNormalized`
        # @return [String]
        attr_accessor :level_type_normalized
      
        # "Section, Sect., §, etc"
        # Corresponds to the JSON property `LevelTypeSourceText`
        # @return [String]
        attr_accessor :level_type_source_text
      
        # deprecated
        # Corresponds to the JSON property `LevelTypeString`
        # @return [String]
        attr_accessor :level_type_string
      
        # The name of the chapter/section/etc.
        # Corresponds to the JSON property `Name`
        # @return [String]
        attr_accessor :name
      
        # deprecated
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        # "3", "42(a)", etc
        # Corresponds to the JSON property `Value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @depth = args[:depth] if args.key?(:depth)
          @level_type_normalized = args[:level_type_normalized] if args.key?(:level_type_normalized)
          @level_type_source_text = args[:level_type_source_text] if args.key?(:level_type_source_text)
          @level_type_string = args[:level_type_string] if args.key?(:level_type_string)
          @name = args[:name] if args.key?(:name)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class LegalDate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Day`
        # @return [Fixnum]
        attr_accessor :day
      
        # 
        # Corresponds to the JSON property `Month`
        # @return [Fixnum]
        attr_accessor :month
      
        # 
        # Corresponds to the JSON property `Year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day = args[:day] if args.key?(:day)
          @month = args[:month] if args.key?(:month)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # 
      class LegalPerson
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `LastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `OtherNames`
        # @return [String]
        attr_accessor :other_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @last_name = args[:last_name] if args.key?(:last_name)
          @other_names = args[:other_names] if args.key?(:other_names)
        end
      end
      
      # Aesthetics score of a style image. Check http://go/styleai-indexing-g3doc#
      # aesthetic-model for more details about the Style AI Aesthetics Model.
      class LensDiscoveryStyleAestheticsScoreSignals
        include Google::Apis::Core::Hashable
      
        # Aesthetics score discretized into range [0, 100].
        # Corresponds to the JSON property `discretizedAestheticsScore`
        # @return [Fixnum]
        attr_accessor :discretized_aesthetics_score
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discretized_aesthetics_score = args[:discretized_aesthetics_score] if args.key?(:discretized_aesthetics_score)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Bounding box with absolute integer coordinates.
      class LensDiscoveryStyleBoundingBox
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `x1`
        # @return [Fixnum]
        attr_accessor :x1
      
        # 
        # Corresponds to the JSON property `x2`
        # @return [Fixnum]
        attr_accessor :x2
      
        # 
        # Corresponds to the JSON property `y1`
        # @return [Fixnum]
        attr_accessor :y1
      
        # 
        # Corresponds to the JSON property `y2`
        # @return [Fixnum]
        attr_accessor :y2
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x1 = args[:x1] if args.key?(:x1)
          @x2 = args[:x2] if args.key?(:x2)
          @y1 = args[:y1] if args.key?(:y1)
          @y2 = args[:y2] if args.key?(:y2)
        end
      end
      
      # This message holds person attributes from the LookNet-Person model (go/looknet-
      # person) and the Style AI Iconic Person Scorer (http://go/styleai-indexing-
      # g3doc#iconic-person-scorer) for the most iconic person in a style image. There
      # is an ongoing collaboration with the Human Sensing team on LookNet-Person v3 (
      # go/looknet-person-v3-collaboration) that deals with some of these signals
      # together. Hence, the combined proto definition. Discretization of float values
      # is recommended by CDS for cheaper and more efficient storage. Next ID: 11
      class LensDiscoveryStylePersonAttributes
        include Google::Apis::Core::Hashable
      
        # The visibility of the face of the most iconic person in the image discretized
        # into range [0, 100].
        # Corresponds to the JSON property `discretizedFaceVisibilityScore`
        # @return [Fixnum]
        attr_accessor :discretized_face_visibility_score
      
        # 
        # Corresponds to the JSON property `discretizedFemaleConfidence`
        # @return [Fixnum]
        attr_accessor :discretized_female_confidence
      
        # Male and female confidence scores are discretized into the [0, 100] range.
        # Corresponds to the JSON property `discretizedMaleConfidence`
        # @return [Fixnum]
        attr_accessor :discretized_male_confidence
      
        # Age prediction is rounded to the first decimal place and multiplied by 10 (e.g.
        # 12.3 -> 123). *** Not populated in Amarna for legal reasons. ***
        # Corresponds to the JSON property `discretizedPredictedAge`
        # @return [Fixnum]
        attr_accessor :discretized_predicted_age
      
        # The area ratio of the most iconic person to the whole image discretized into
        # range [0, 100].
        # Corresponds to the JSON property `discretizedVisualSaliencyScore`
        # @return [Fixnum]
        attr_accessor :discretized_visual_saliency_score
      
        # Bounding box coordinates are relative to the width and height of the image.
        # For example, if image is 100x200 and NormalizedBoundingBox is , the bounding
        # box coordinates will be (10, 40) to (50, 180). Note parts of the bounding box
        # may fall outside the image.
        # Corresponds to the JSON property `iconicPersonBoundingBox`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionGroundtruthdbNormalizedBoundingBox]
        attr_accessor :iconic_person_bounding_box
      
        # Bounding box with absolute integer coordinates.
        # Corresponds to the JSON property `personBoundingBox`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStyleBoundingBox]
        attr_accessor :person_bounding_box
      
        # 
        # Corresponds to the JSON property `personVisibilityScores`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStylePersonAttributesPersonVisibilityScores]
        attr_accessor :person_visibility_scores
      
        # Bucketed version of the predicted age.
        # Corresponds to the JSON property `predictedAgeBucket`
        # @return [String]
        attr_accessor :predicted_age_bucket
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discretized_face_visibility_score = args[:discretized_face_visibility_score] if args.key?(:discretized_face_visibility_score)
          @discretized_female_confidence = args[:discretized_female_confidence] if args.key?(:discretized_female_confidence)
          @discretized_male_confidence = args[:discretized_male_confidence] if args.key?(:discretized_male_confidence)
          @discretized_predicted_age = args[:discretized_predicted_age] if args.key?(:discretized_predicted_age)
          @discretized_visual_saliency_score = args[:discretized_visual_saliency_score] if args.key?(:discretized_visual_saliency_score)
          @iconic_person_bounding_box = args[:iconic_person_bounding_box] if args.key?(:iconic_person_bounding_box)
          @person_bounding_box = args[:person_bounding_box] if args.key?(:person_bounding_box)
          @person_visibility_scores = args[:person_visibility_scores] if args.key?(:person_visibility_scores)
          @predicted_age_bucket = args[:predicted_age_bucket] if args.key?(:predicted_age_bucket)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class LensDiscoveryStylePersonAttributesPersonVisibilityScores
        include Google::Apis::Core::Hashable
      
        # A measure of the visibility of the most iconic person between [0, 100],
        # derived by combining all label predictions by the Person Visibility model
        # according to go/person-visibility-formula. Higher values indicate greater
        # visibility while lower values indicate lesser visibility.
        # Corresponds to the JSON property `discretizedPersonVisibilityScore`
        # @return [Fixnum]
        attr_accessor :discretized_person_visibility_score
      
        # Repeated for # of PersonVisibility types.
        # Corresponds to the JSON property `personVisibilityPredictions`
        # @return [Array<Google::Apis::ContentwarehouseV1::LensDiscoveryStylePersonAttributesPersonVisibilityScoresPersonVisibilityPrediction>]
        attr_accessor :person_visibility_predictions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discretized_person_visibility_score = args[:discretized_person_visibility_score] if args.key?(:discretized_person_visibility_score)
          @person_visibility_predictions = args[:person_visibility_predictions] if args.key?(:person_visibility_predictions)
        end
      end
      
      # 
      class LensDiscoveryStylePersonAttributesPersonVisibilityScoresPersonVisibilityPrediction
        include Google::Apis::Core::Hashable
      
        # Confidence score of the visibility type prediction discretized into range [0,
        # 100].
        # Corresponds to the JSON property `discretizedIconicPersonVisibilityConfidence`
        # @return [Fixnum]
        attr_accessor :discretized_iconic_person_visibility_confidence
      
        # Classification of how much of the body of the most iconic person in the image
        # is visible.
        # Corresponds to the JSON property `iconicPersonVisibilityType`
        # @return [String]
        attr_accessor :iconic_person_visibility_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discretized_iconic_person_visibility_confidence = args[:discretized_iconic_person_visibility_confidence] if args.key?(:discretized_iconic_person_visibility_confidence)
          @iconic_person_visibility_type = args[:iconic_person_visibility_type] if args.key?(:iconic_person_visibility_type)
        end
      end
      
      # This message holds bounding boxes of detected people in the image. Next ID: 3
      class LensDiscoveryStylePersonDetectionSignals
        include Google::Apis::Core::Hashable
      
        # Information of all detected people in the image, sorted by decreasing size of
        # the bounding box. We store a maximum of 10 detected people.
        # Corresponds to the JSON property `detectedPersons`
        # @return [Array<Google::Apis::ContentwarehouseV1::LensDiscoveryStylePersonDetectionSignalsDetectedPerson>]
        attr_accessor :detected_persons
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detected_persons = args[:detected_persons] if args.key?(:detected_persons)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Holds information about a detected person in the image.
      class LensDiscoveryStylePersonDetectionSignalsDetectedPerson
        include Google::Apis::Core::Hashable
      
        # Bounding box with absolute integer coordinates.
        # Corresponds to the JSON property `boundingBox`
        # @return [Google::Apis::ContentwarehouseV1::LensDiscoveryStyleBoundingBox]
        attr_accessor :bounding_box
      
        # Bounding box coordinates are relative to the width and height of the image.
        # For example, if image is 100x200 and NormalizedBoundingBox is , the bounding
        # box coordinates will be (10, 40) to (50, 180). Note parts of the bounding box
        # may fall outside the image.
        # Corresponds to the JSON property `normalizedBoundingBox`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionGroundtruthdbNormalizedBoundingBox]
        attr_accessor :normalized_bounding_box
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
          @normalized_bounding_box = args[:normalized_bounding_box] if args.key?(:normalized_bounding_box)
        end
      end
      
      # Prediction of a style image type: Stage, Stock, Street or Outfits. Check http:/
      # /go/styleai-indexing-g3doc#style-image-type-classifier for more details about
      # the Style AI Style Image Type Classifier.
      class LensDiscoveryStyleStyleImageTypeSignals
        include Google::Apis::Core::Hashable
      
        # Repeated for # of StyleImageType types.
        # Corresponds to the JSON property `styleImageTypePredictions`
        # @return [Array<Google::Apis::ContentwarehouseV1::LensDiscoveryStyleStyleImageTypeSignalsStyleImageTypePrediction>]
        attr_accessor :style_image_type_predictions
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @style_image_type_predictions = args[:style_image_type_predictions] if args.key?(:style_image_type_predictions)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class LensDiscoveryStyleStyleImageTypeSignalsStyleImageTypePrediction
        include Google::Apis::Core::Hashable
      
        # Style image type confidence discretized into range [0, 100].
        # Corresponds to the JSON property `discretizedStyleImageTypeConfidence`
        # @return [Fixnum]
        attr_accessor :discretized_style_image_type_confidence
      
        # Predicted style image type.
        # Corresponds to the JSON property `styleImageType`
        # @return [String]
        attr_accessor :style_image_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @discretized_style_image_type_confidence = args[:discretized_style_image_type_confidence] if args.key?(:discretized_style_image_type_confidence)
          @style_image_type = args[:style_image_type] if args.key?(:style_image_type)
        end
      end
      
      # Data to generate the list snippets UI.
      class ListSnippetResponse
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `header`
        # @return [Google::Apis::ContentwarehouseV1::ListSnippetResponseRow]
        attr_accessor :header
      
        # Should list be formatted as a table?
        # Corresponds to the JSON property `isTable`
        # @return [Boolean]
        attr_accessor :is_table
        alias_method :is_table?, :is_table
      
        # 
        # Corresponds to the JSON property `row`
        # @return [Array<Google::Apis::ContentwarehouseV1::ListSnippetResponseRow>]
        attr_accessor :row
      
        # The number of rows annotated in the doc, of which 'row' is a subset.
        # Corresponds to the JSON property `totalRows`
        # @return [Fixnum]
        attr_accessor :total_rows
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @header = args[:header] if args.key?(:header)
          @is_table = args[:is_table] if args.key?(:is_table)
          @row = args[:row] if args.key?(:row)
          @total_rows = args[:total_rows] if args.key?(:total_rows)
        end
      end
      
      # 
      class ListSnippetResponseRow
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `column`
        # @return [Array<String>]
        attr_accessor :column
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @column = args[:column] if args.key?(:column)
        end
      end
      
      # Next Id: 36
      class LocalWwwInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `address`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalWwwInfoAddress>]
        attr_accessor :address
      
        # 
        # Corresponds to the JSON property `brickAndMortarStrength`
        # @return [Float]
        attr_accessor :brick_and_mortar_strength
      
        # 
        # Corresponds to the JSON property `cluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalWwwInfoCluster>]
        attr_accessor :cluster
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # Information about geo locations, rather than individual businesses.
        # Corresponds to the JSON property `geotopicality`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryAnnotationsGeoTopicality]
        attr_accessor :geotopicality
      
        # 
        # Corresponds to the JSON property `hours`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalWwwInfoOpeningHours>]
        attr_accessor :hours
      
        # Does this LocalWWWInfo represent a widely-distributed chain?
        # Corresponds to the JSON property `isLargeChain`
        # @return [Boolean]
        attr_accessor :is_large_chain
        alias_method :is_large_chain?, :is_large_chain
      
        # 
        # Corresponds to the JSON property `isLargeLocalwwwinfo`
        # @return [Boolean]
        attr_accessor :is_large_localwwwinfo
        alias_method :is_large_localwwwinfo?, :is_large_localwwwinfo
      
        # 
        # Corresponds to the JSON property `phone`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalWwwInfoPhone>]
        attr_accessor :phone
      
        # These are per-document signals independent of any particular address.
        # Corresponds to the JSON property `siteSiblings`
        # @return [Fixnum]
        attr_accessor :site_siblings
      
        # These are for convenience during intermediate data processing, and should be
        # cleared before the data gets into doc-joins.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `wrapptorItem`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalWwwInfoWrapptorItem>]
        attr_accessor :wrapptor_item
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address = args[:address] if args.key?(:address)
          @brick_and_mortar_strength = args[:brick_and_mortar_strength] if args.key?(:brick_and_mortar_strength)
          @cluster = args[:cluster] if args.key?(:cluster)
          @docid = args[:docid] if args.key?(:docid)
          @geotopicality = args[:geotopicality] if args.key?(:geotopicality)
          @hours = args[:hours] if args.key?(:hours)
          @is_large_chain = args[:is_large_chain] if args.key?(:is_large_chain)
          @is_large_localwwwinfo = args[:is_large_localwwwinfo] if args.key?(:is_large_localwwwinfo)
          @phone = args[:phone] if args.key?(:phone)
          @site_siblings = args[:site_siblings] if args.key?(:site_siblings)
          @url = args[:url] if args.key?(:url)
          @wrapptor_item = args[:wrapptor_item] if args.key?(:wrapptor_item)
        end
      end
      
      # These are the addresses, phone numbers, and opening hours related to this
      # document, or the local businesses mentioned on this document. We currently
      # populate these fields from web extractions, i.e, from the data present
      # explicitly on the document, but in future, they can also be filled with data
      # coming from the local index. We populate addresses and phone numbers only if
      # there are <= 4 addresses and phone numbers on the document, respectively. This
      # is primarily for space reasons.
      class LocalWwwInfoAddress
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `addrFprint`
        # @return [Fixnum]
        attr_accessor :addr_fprint
      
        # This class represents an address, partial address, or address range. It is
        # intended to be attached to features to identify their address(es). Some
        # important points about addresses: - The addresses in the Geo Schema do *not*
        # include a component for the name of the feature, i.e. they are not self-
        # referential. For example, the name of a feature might be "Zack's Pizza" and
        # its address would be "123 Main Street". Similarly, streets, cities, and
        # counties do not include themselves as part of their address. The address of "
        # Seattle" is "King County, Washington, USA". If want to construct an address
        # that *does* include the feature name, you can simply prepend it to the other
        # address components. - Lakes, mountains, and other natural features do not
        # normally have addresses. Countries also do not have addresses because they are
        # at the top of the political hierarchy. - Address components in the Geo Schema
        # are listed in a particular order, independent of the conventions used by the
        # country in which they occur. The basic order is "smallest to largest" starting
        # with street numbers and routes, then political features, and ending with
        # postal features. The exact rules are defined by the implementation of the
        # AddressComponentOrdering::IsLessThan() function. - Some types of address
        # components may occur more than once in an address. For example, a UK address
        # with a "dependent thoroughfare" would have two components of TYPE_ROUTE (i.e.
        # street names). These are listed in the order they are normally written.
        # Corresponds to the JSON property `address`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAddressProto]
        attr_accessor :address
      
        # 
        # Corresponds to the JSON property `latE7`
        # @return [Fixnum]
        attr_accessor :lat_e7
      
        # 
        # Corresponds to the JSON property `lngE7`
        # @return [Fixnum]
        attr_accessor :lng_e7
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @addr_fprint = args[:addr_fprint] if args.key?(:addr_fprint)
          @address = args[:address] if args.key?(:address)
          @lat_e7 = args[:lat_e7] if args.key?(:lat_e7)
          @lng_e7 = args[:lng_e7] if args.key?(:lng_e7)
        end
      end
      
      # 
      class LocalWwwInfoCluster
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `addrFprint`
        # @return [Fixnum]
        attr_accessor :addr_fprint
      
        # Confidence score for business mention annotations which is copied from
        # LocalEntityAnnotations::location_confidence.
        # Corresponds to the JSON property `annotationConfidence`
        # @return [Float]
        attr_accessor :annotation_confidence
      
        # 
        # Corresponds to the JSON property `clusterdocid`
        # @return [Fixnum]
        attr_accessor :clusterdocid
      
        # 
        # Corresponds to the JSON property `clusterid`
        # @return [String]
        attr_accessor :clusterid
      
        # Probability that this is the authority page of the business. Same as
        # LocalListing.authority_page_probability, only set for pages with
        # page_type_flags & AUTHORITY.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Feature type for this listing, from LocalListing::info::related_feature. A
        # geostore::FeatureProto::TypeCategory. Intended primarily to indicate POI-ness (
        # i.e., TYPE_ESTABLISHMENT_POI).
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # Opening hours for the business, from Local attributes and/or extracted
        # annotations.
        # Corresponds to the JSON property `hours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :hours
      
        # 
        # Corresponds to the JSON property `hoursSource`
        # @return [String]
        attr_accessor :hours_source
      
        # 
        # Corresponds to the JSON property `includeInIndex`
        # @return [Boolean]
        attr_accessor :include_in_index
        alias_method :include_in_index?, :include_in_index
      
        # TODO(local-universal) Consider deleting is_plusbox once the new scheme that
        # uses make_plusbox_visible rolled out.
        # Corresponds to the JSON property `isPlusbox`
        # @return [Boolean]
        attr_accessor :is_plusbox
        alias_method :is_plusbox?, :is_plusbox
      
        # 
        # Corresponds to the JSON property `latitudeE6`
        # @return [Fixnum]
        attr_accessor :latitude_e6
      
        # DEPRECATED / NO LONGER WRITTEN. URL path level from actual references to this
        # webpage.
        # Corresponds to the JSON property `level`
        # @return [Fixnum]
        attr_accessor :level
      
        # 
        # Corresponds to the JSON property `longitudeE6`
        # @return [Fixnum]
        attr_accessor :longitude_e6
      
        # A hint for frontend to decide whether this plusbox should be visible or not.
        # Corresponds to the JSON property `makePlusboxVisible`
        # @return [Boolean]
        attr_accessor :make_plusbox_visible
        alias_method :make_plusbox_visible?, :make_plusbox_visible
      
        # Menu link for the business. Currently only comes from Local attributes.
        # Corresponds to the JSON property `menuUrl`
        # @return [Array<String>]
        attr_accessor :menu_url
      
        # Type of the web reference.
        # Corresponds to the JSON property `pageTypeFlags`
        # @return [Fixnum]
        attr_accessor :page_type_flags
      
        # 
        # Corresponds to the JSON property `phoneFprint`
        # @return [Fixnum]
        attr_accessor :phone_fprint
      
        # 
        # Corresponds to the JSON property `phoneNumber`
        # @return [Google::Apis::ContentwarehouseV1::TelephoneNumber]
        attr_accessor :phone_number
      
        # Next free ID: 32
        # Corresponds to the JSON property `postalAddress`
        # @return [Google::Apis::ContentwarehouseV1::PostalAddress]
        attr_accessor :postal_address
      
        # DEPRECATED / NO LONGER WRITTEN. How relevant the webpage is to the business (
        # clustering distance). Same as LocalListing::Reference.relevance. Typically
        # only set for pages with (page_type_flags & WEB_EXTRACTION && !AUTHORITY).
        # Corresponds to the JSON property `relevance`
        # @return [Float]
        attr_accessor :relevance
      
        # 
        # Corresponds to the JSON property `showInSnippets`
        # @return [Boolean]
        attr_accessor :show_in_snippets
        alias_method :show_in_snippets?, :show_in_snippets
      
        # 
        # Corresponds to the JSON property `source`
        # @return [Array<String>]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @addr_fprint = args[:addr_fprint] if args.key?(:addr_fprint)
          @annotation_confidence = args[:annotation_confidence] if args.key?(:annotation_confidence)
          @clusterdocid = args[:clusterdocid] if args.key?(:clusterdocid)
          @clusterid = args[:clusterid] if args.key?(:clusterid)
          @confidence = args[:confidence] if args.key?(:confidence)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @hours = args[:hours] if args.key?(:hours)
          @hours_source = args[:hours_source] if args.key?(:hours_source)
          @include_in_index = args[:include_in_index] if args.key?(:include_in_index)
          @is_plusbox = args[:is_plusbox] if args.key?(:is_plusbox)
          @latitude_e6 = args[:latitude_e6] if args.key?(:latitude_e6)
          @level = args[:level] if args.key?(:level)
          @longitude_e6 = args[:longitude_e6] if args.key?(:longitude_e6)
          @make_plusbox_visible = args[:make_plusbox_visible] if args.key?(:make_plusbox_visible)
          @menu_url = args[:menu_url] if args.key?(:menu_url)
          @page_type_flags = args[:page_type_flags] if args.key?(:page_type_flags)
          @phone_fprint = args[:phone_fprint] if args.key?(:phone_fprint)
          @phone_number = args[:phone_number] if args.key?(:phone_number)
          @postal_address = args[:postal_address] if args.key?(:postal_address)
          @relevance = args[:relevance] if args.key?(:relevance)
          @show_in_snippets = args[:show_in_snippets] if args.key?(:show_in_snippets)
          @source = args[:source] if args.key?(:source)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Populated from StoreHoursAnnotations.
      class LocalWwwInfoOpeningHours
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hours`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreTimeScheduleProto]
        attr_accessor :hours
      
        # 
        # Corresponds to the JSON property `hoursFprint`
        # @return [Fixnum]
        attr_accessor :hours_fprint
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hours = args[:hours] if args.key?(:hours)
          @hours_fprint = args[:hours_fprint] if args.key?(:hours_fprint)
        end
      end
      
      # 
      class LocalWwwInfoPhone
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `phoneFprint`
        # @return [Fixnum]
        attr_accessor :phone_fprint
      
        # 
        # Corresponds to the JSON property `phoneNumber`
        # @return [Google::Apis::ContentwarehouseV1::TelephoneNumber]
        attr_accessor :phone_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @phone_fprint = args[:phone_fprint] if args.key?(:phone_fprint)
          @phone_number = args[:phone_number] if args.key?(:phone_number)
        end
      end
      
      # A single WrapptorItem, with a business name, an address and a phone number. We
      # keep only the fingerprints of address and phone number. The full address and
      # phone protos will be elsewhere within LocalWWWInfo.
      class LocalWwwInfoWrapptorItem
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `addrFprint`
        # @return [Fixnum]
        attr_accessor :addr_fprint
      
        # 
        # Corresponds to the JSON property `bizName`
        # @return [String]
        attr_accessor :biz_name
      
        # 
        # Corresponds to the JSON property `phoneFprint`
        # @return [Fixnum]
        attr_accessor :phone_fprint
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @addr_fprint = args[:addr_fprint] if args.key?(:addr_fprint)
          @biz_name = args[:biz_name] if args.key?(:biz_name)
          @phone_fprint = args[:phone_fprint] if args.key?(:phone_fprint)
        end
      end
      
      # An unique identification of a chain. The following are the possible chain id
      # forms: 1) prominent_entity_id only: The entity uniquely represents a chain,
      # which may have multiple sitechunks. 2) sitechunk only: The sitechunk uniquely
      # represents a chain while the chain currently does not have an entity in KG. 3)
      # prominent_entity_id + sitechunk: The chain could be represented by the entity,
      # but not merged at last, and the sitechunks represents the chain better. 4)
      # prominent_entity_id + category: There are multiple subchains for the prominent
      # entity, and category is used to differentiate subchains. NOTE: the size and
      # complexity of the ChainId proto has implications in the serving system and
      # should be thoughtfully kept under control.
      class LocalsearchChainId
        include Google::Apis::Core::Hashable
      
        # The category associated with this chain, currently only used for subchains.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The Knowledge Graph (KG) entity of the chain, found and used in chain mining.
        # Corresponds to the JSON property `prominentEntityId`
        # @return [String]
        attr_accessor :prominent_entity_id
      
        # The website sitechunk/domain that is owned by the chain.
        # Corresponds to the JSON property `sitechunk`
        # @return [String]
        attr_accessor :sitechunk
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @prominent_entity_id = args[:prominent_entity_id] if args.key?(:prominent_entity_id)
          @sitechunk = args[:sitechunk] if args.key?(:sitechunk)
        end
      end
      
      # Next tag: 23
      class LocalsearchDocInfo
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # * Proto representing the metadata associated with food ordering internal
      # action. Next ID: 13
      class LocalsearchProtoInternalFoodOrderingActionMetadata
        include Google::Apis::Core::Hashable
      
        # The action type of this action metadata.
        # Corresponds to the JSON property `actionType`
        # @return [String]
        attr_accessor :action_type
      
        # If true, it indicates that the merchant has a primarily food intent. This
        # field will only be set when enable_food_gcid_strict_check in
        # FoodOrderingRestrictionProto is true, see go/togo-unified:overlapping-for-le.
        # See go/togo-unified-gcid for how this is calculated.
        # Corresponds to the JSON property `hasPrimarilyFoodIntent`
        # @return [Boolean]
        attr_accessor :has_primarily_food_intent
        alias_method :has_primarily_food_intent?, :has_primarily_food_intent
      
        # If set, indicates that the food ordering service is out of operational hours.
        # This could only be populated if the request explicitly asks for
        # ignore_operational_hours in request (universalsearch/rpc/geo/
        # food_ordering_restriction.proto). Design doc: go/fo-persistent-v1.
        # Corresponds to the JSON property `isOutOfOperationalHours`
        # @return [Boolean]
        attr_accessor :is_out_of_operational_hours
        alias_method :is_out_of_operational_hours?, :is_out_of_operational_hours
      
        # When true, indicates that this is a whitelisted restaurant from a first party (
        # but non FO) partner, i.e. a merchant from the orderig app, who is Google owned
        # first party food ordering platform. Design doc: go/onboard-mavn-to-fo.
        # Tracking bug: b/150331855
        # Corresponds to the JSON property `isWhitelistedExternalRestaurant`
        # @return [Boolean]
        attr_accessor :is_whitelisted_external_restaurant
        alias_method :is_whitelisted_external_restaurant?, :is_whitelisted_external_restaurant
      
        # Next opening time when the food ordering service will be available. This is
        # only present if the unavailability reason is OUT_OF_OPERATIONAL_HOURS.
        # Corresponds to the JSON property `nextOpeningTime`
        # @return [String]
        attr_accessor :next_opening_time
      
        # Indicates whether only order ahead services are available. Order ahead
        # services allow only to place order for future and ASAP order can not be placed
        # via them.
        # Corresponds to the JSON property `onlyOrderAheadServicesAvailable`
        # @return [Boolean]
        attr_accessor :only_order_ahead_services_available
        alias_method :only_order_ahead_services_available?, :only_order_ahead_services_available
      
        # Aggregated service information by service type. Each service type would only
        # have one ServiceInfo. Optional.
        # Corresponds to the JSON property `serviceInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalsearchProtoInternalFoodOrderingActionMetadataServiceInfo>]
        attr_accessor :service_info
      
        # Food ordering service type.
        # Corresponds to the JSON property `supportedServiceType`
        # @return [String]
        attr_accessor :supported_service_type
      
        # Reason for unavailability of internal food ordering action. This is only
        # present when FOPA is unavailable for a particular restaurant. When this is set,
        # all other fields in this proto will not be populated. Note(fo-search): If
        # there are log only partners and this particular restaurant is only supported
        # because of log only partners, this field will not be set to
        # NOT_INTEGRATED_WITH_FOPA.
        # Corresponds to the JSON property `unavailabilityReason`
        # @return [String]
        attr_accessor :unavailability_reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_type = args[:action_type] if args.key?(:action_type)
          @has_primarily_food_intent = args[:has_primarily_food_intent] if args.key?(:has_primarily_food_intent)
          @is_out_of_operational_hours = args[:is_out_of_operational_hours] if args.key?(:is_out_of_operational_hours)
          @is_whitelisted_external_restaurant = args[:is_whitelisted_external_restaurant] if args.key?(:is_whitelisted_external_restaurant)
          @next_opening_time = args[:next_opening_time] if args.key?(:next_opening_time)
          @only_order_ahead_services_available = args[:only_order_ahead_services_available] if args.key?(:only_order_ahead_services_available)
          @service_info = args[:service_info] if args.key?(:service_info)
          @supported_service_type = args[:supported_service_type] if args.key?(:supported_service_type)
          @unavailability_reason = args[:unavailability_reason] if args.key?(:unavailability_reason)
        end
      end
      
      # Includes all partners that are either open now or supporting order ahead.
      class LocalsearchProtoInternalFoodOrderingActionMetadataAvailablePartnerInfo
        include Google::Apis::Core::Hashable
      
        # Available partner's id.
        # Corresponds to the JSON property `availablePartnerId`
        # @return [Fixnum]
        attr_accessor :available_partner_id
      
        # Indicates whether the partner is log only.
        # Corresponds to the JSON property `logOnly`
        # @return [Boolean]
        attr_accessor :log_only
        alias_method :log_only?, :log_only
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @available_partner_id = args[:available_partner_id] if args.key?(:available_partner_id)
          @log_only = args[:log_only] if args.key?(:log_only)
        end
      end
      
      # 
      class LocalsearchProtoInternalFoodOrderingActionMetadataServiceInfo
        include Google::Apis::Core::Hashable
      
        # Information about Food Ordering partner, which is used for whitelisting the
        # partner in Food Ordering entry points such as Placesheet.
        # Corresponds to the JSON property `availablePartnerInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::LocalsearchProtoInternalFoodOrderingActionMetadataAvailablePartnerInfo>]
        attr_accessor :available_partner_info
      
        # Maximum max_wait_time in second.
        # Corresponds to the JSON property `maxWaitTimeSec`
        # @return [Fixnum]
        attr_accessor :max_wait_time_sec
      
        # Represents an amount of money with its currency type.
        # Corresponds to the JSON property `minDeliveryFee`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeMoney]
        attr_accessor :min_delivery_fee
      
        # Minimum min_wait_time in second.
        # Corresponds to the JSON property `minWaitTimeSec`
        # @return [Fixnum]
        attr_accessor :min_wait_time_sec
      
        # Food ordering service type. Please note that only ServiceType.PICKUP and
        # ServiceType.DELIVERY are valid values for this field.
        # Corresponds to the JSON property `serviceType`
        # @return [String]
        attr_accessor :service_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @available_partner_info = args[:available_partner_info] if args.key?(:available_partner_info)
          @max_wait_time_sec = args[:max_wait_time_sec] if args.key?(:max_wait_time_sec)
          @min_delivery_fee = args[:min_delivery_fee] if args.key?(:min_delivery_fee)
          @min_wait_time_sec = args[:min_wait_time_sec] if args.key?(:min_wait_time_sec)
          @service_type = args[:service_type] if args.key?(:service_type)
        end
      end
      
      # Proto-representation of the Crawler-ID in Web-Search (Alexandria-Scope). The
      # string-representation (covered in //indexing/crawler_id/scope/alexandria/
      # crawler_id.h) and the proto-representation are identical in meaning. For more
      # information in regard to the crawler_id, please look at //depot/google3/
      # indexing/crawler_id Used within the following components: - WebMirror: To
      # understand the parsed crawler-ID and apply attributes within their own tables.
      # - Serving : to identify the crawler-ID within the GenericSearchResponse, which
      # implies being stored in the MDU and returned by ascorer to Superroot. -
      # QSessions: To store the crawler-ID in all logged events for analysis. The
      # default values represent the 'empty string' crawler-ID for the Alexandria-
      # scope.
      class LogsProtoIndexingCrawlerIdCrawlerIdProto
        include Google::Apis::Core::Hashable
      
        # The country to crawl the country from, defaults to the default non-specified
        # crawling node (which is interpreted by most web-servers as USA). When
        # specified, the crawling will fetch the document from a node in that country
        # instead.
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # The device type, which maps into the useragent to be set when initiating the
        # fetch-request, e.g. desktop-googlebot vs. smartphone-googlebot.
        # Corresponds to the JSON property `deviceType`
        # @return [String]
        attr_accessor :device_type
      
        # Specifies whether the document is a duplicated document from the index growth
        # experiment, detailed at go/indexsize_exp, defaults to not in any experiment.
        # Corresponds to the JSON property `indexGrowthExptType`
        # @return [String]
        attr_accessor :index_growth_expt_type
      
        # The language being set by the crawler. Defaults to UNKNOWN_LANGUAGE which
        # indicates to not apply an accept-language header on the FetchRequest. When a
        # language is specified, on crawling this language is converted into an accept-
        # language header (e.g. GERMAN -> "Accept-language: de"). Script variations, e.g.
        # ZH-HANS vs. ZH-HANT, are handled as different enum values (e.g. CHINESE vs.
        # CHINESE_T).
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Language-code used for identifying the locale of the document. 'language' and '
        # country' above are used for web-based documents, representing the detected
        # language of the document and the country it was crawled from. The language
        # code here, however, rather represents an artifical language_code applied to
        # manually translated webpages (e.g. feeds), for instance for the pidgin-usecase.
        # They are limited to the set of III-codes being supported by the client, yet
        # are beyond the enum in 'language', e.g. to support variants of English across
        # different countries.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country = args[:country] if args.key?(:country)
          @device_type = args[:device_type] if args.key?(:device_type)
          @index_growth_expt_type = args[:index_growth_expt_type] if args.key?(:index_growth_expt_type)
          @language = args[:language] if args.key?(:language)
          @language_code = args[:language_code] if args.key?(:language_code)
        end
      end
      
      # Logs version of the repository_webref.EntityLinkMetadata proto Used to
      # represent QRef implications
      class LogsSemanticInterpretationIntentQueryEntityLinkMetadata
        include Google::Apis::Core::Hashable
      
        # Logs version of the repository_webref.LinkKindFlags proto Used to represent
        # QRef implications Next available tag: 8
        # Corresponds to the JSON property `aggregateFlags`
        # @return [Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQueryLinkKindFlags]
        attr_accessor :aggregate_flags
      
        # 
        # Corresponds to the JSON property `kindInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQueryLinkKindInfo>]
        attr_accessor :kind_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregate_flags = args[:aggregate_flags] if args.key?(:aggregate_flags)
          @kind_info = args[:kind_info] if args.key?(:kind_info)
        end
      end
      
      # Logs version of the repository_webref.LinkKindFlags proto Used to represent
      # QRef implications Next available tag: 8
      class LogsSemanticInterpretationIntentQueryLinkKindFlags
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cluster`
        # @return [String]
        attr_accessor :cluster
      
        # 
        # Corresponds to the JSON property `geoContainment`
        # @return [String]
        attr_accessor :geo_containment
      
        # 
        # Corresponds to the JSON property `implication`
        # @return [String]
        attr_accessor :implication
      
        # 
        # Corresponds to the JSON property `latentEntity`
        # @return [String]
        attr_accessor :latent_entity
      
        # 
        # Corresponds to the JSON property `mdvc`
        # @return [String]
        attr_accessor :mdvc
      
        # 
        # Corresponds to the JSON property `property`
        # @return [String]
        attr_accessor :property
      
        # 
        # Corresponds to the JSON property `resolution`
        # @return [String]
        attr_accessor :resolution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster = args[:cluster] if args.key?(:cluster)
          @geo_containment = args[:geo_containment] if args.key?(:geo_containment)
          @implication = args[:implication] if args.key?(:implication)
          @latent_entity = args[:latent_entity] if args.key?(:latent_entity)
          @mdvc = args[:mdvc] if args.key?(:mdvc)
          @property = args[:property] if args.key?(:property)
          @resolution = args[:resolution] if args.key?(:resolution)
        end
      end
      
      # Logs version of the repository_webref.LinkKindInfo proto Used to represent
      # QRef implications
      class LogsSemanticInterpretationIntentQueryLinkKindInfo
        include Google::Apis::Core::Hashable
      
        # Logs version of the repository_webref.LinkKindFlags proto Used to represent
        # QRef implications Next available tag: 8
        # Corresponds to the JSON property `flags`
        # @return [Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQueryLinkKindFlags]
        attr_accessor :flags
      
        # 
        # Corresponds to the JSON property `kcLinkName`
        # @return [String]
        attr_accessor :kc_link_name
      
        # 
        # Corresponds to the JSON property `topicPropertyName`
        # @return [String]
        attr_accessor :topic_property_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flags = args[:flags] if args.key?(:flags)
          @kc_link_name = args[:kc_link_name] if args.key?(:kc_link_name)
          @topic_property_name = args[:topic_property_name] if args.key?(:topic_property_name)
        end
      end
      
      # Logs version of the repository_webref.SupportTransferRule proto Non-logs
      # version supports go/stbr
      class LogsSemanticInterpretationIntentQuerySupportTransferRule
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `allowWildcardIntents`
        # @return [Boolean]
        attr_accessor :allow_wildcard_intents
        alias_method :allow_wildcard_intents?, :allow_wildcard_intents
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # 
        # Corresponds to the JSON property `isReverseLink`
        # @return [Boolean]
        attr_accessor :is_reverse_link
        alias_method :is_reverse_link?, :is_reverse_link
      
        # 
        # Corresponds to the JSON property `mentionsOnly`
        # @return [Boolean]
        attr_accessor :mentions_only
        alias_method :mentions_only?, :mentions_only
      
        # 
        # Corresponds to the JSON property `supportShare`
        # @return [Boolean]
        attr_accessor :support_share
        alias_method :support_share?, :support_share
      
        # 
        # Corresponds to the JSON property `targetCollection`
        # @return [String]
        attr_accessor :target_collection
      
        # 
        # Corresponds to the JSON property `userCountry`
        # @return [String]
        attr_accessor :user_country
      
        # 
        # Corresponds to the JSON property `userLanguage`
        # @return [String]
        attr_accessor :user_language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_wildcard_intents = args[:allow_wildcard_intents] if args.key?(:allow_wildcard_intents)
          @domain = args[:domain] if args.key?(:domain)
          @is_reverse_link = args[:is_reverse_link] if args.key?(:is_reverse_link)
          @mentions_only = args[:mentions_only] if args.key?(:mentions_only)
          @support_share = args[:support_share] if args.key?(:support_share)
          @target_collection = args[:target_collection] if args.key?(:target_collection)
          @user_country = args[:user_country] if args.key?(:user_country)
          @user_language = args[:user_language] if args.key?(:user_language)
        end
      end
      
      # Logs version of the repository_webref.WebrefEntityRelationship proto Used to
      # represent QRef implications
      class LogsSemanticInterpretationIntentQueryWebrefEntityRelationship
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entityIndex`
        # @return [Fixnum]
        attr_accessor :entity_index
      
        # Logs version of the repository_webref.EntityLinkMetadata proto Used to
        # represent QRef implications
        # Corresponds to the JSON property `linkMetadata`
        # @return [Google::Apis::ContentwarehouseV1::LogsSemanticInterpretationIntentQueryEntityLinkMetadata]
        attr_accessor :link_metadata
      
        # 
        # Corresponds to the JSON property `linkWeight`
        # @return [Float]
        attr_accessor :link_weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_index = args[:entity_index] if args.key?(:entity_index)
          @link_metadata = args[:link_metadata] if args.key?(:link_metadata)
          @link_weight = args[:link_weight] if args.key?(:link_weight)
        end
      end
      
      # An experimental long snippet. The protocol allows any permutation of headers
      # and plain text paragraphs, but typical responses are just paragraphs or
      # alternating headers and paragraphs.
      class LongStructuredSnippet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entry`
        # @return [Array<Google::Apis::ContentwarehouseV1::LongStructuredSnippetEntry>]
        attr_accessor :entry
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entry = args[:entry] if args.key?(:entry)
        end
      end
      
      # 
      class LongStructuredSnippetEntry
        include Google::Apis::Core::Hashable
      
        # Is this a header or normal paragraph?
        # Corresponds to the JSON property `header`
        # @return [Boolean]
        attr_accessor :header
        alias_method :header?, :header
      
        # The text of the header or paragraph.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @header = args[:header] if args.key?(:header)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # The information on whether the contact is related to an app shortcut. Next ID:
      # 2
      class MajelContactInformationShortcutInformation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `shortcutContactType`
        # @return [String]
        attr_accessor :shortcut_contact_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @shortcut_contact_type = args[:shortcut_contact_type] if args.key?(:shortcut_contact_type)
        end
      end
      
      # Manybox container message
      class ManyboxData
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `components`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :components
      
        # a bit vector of the available manybox data types
        # Corresponds to the JSON property `dataSummary`
        # @return [Fixnum]
        attr_accessor :data_summary
      
        # 
        # Corresponds to the JSON property `debug`
        # @return [String]
        attr_accessor :debug
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @components = args[:components] if args.key?(:components)
          @data_summary = args[:data_summary] if args.key?(:data_summary)
          @debug = args[:debug] if args.key?(:debug)
        end
      end
      
      # Flags that describe the information about a special word. If you add another
      # flag please add it to the special words implemenation in google3/maps/quality/
      # internal/special_words.cc. -- Next available id: 20 --
      class MapsQualitySpecialWordsFlags
        include Google::Apis::Core::Hashable
      
        # Common words E.g.: center, park, etc.
        # Corresponds to the JSON property `isCommonWord`
        # @return [Boolean]
        attr_accessor :is_common_word
        alias_method :is_common_word?, :is_common_word
      
        # Whether this special word is part of a name without a separator (like e.g.
        # suffix "strasse" in Freigutstrasse).
        # Corresponds to the JSON property `isDeconstructible`
        # @return [Boolean]
        attr_accessor :is_deconstructible
        alias_method :is_deconstructible?, :is_deconstructible
      
        # Directional modifier. E.g.: north, south, etc.
        # Corresponds to the JSON property `isDirectionalModifier`
        # @return [Boolean]
        attr_accessor :is_directional_modifier
        alias_method :is_directional_modifier?, :is_directional_modifier
      
        # Whether geo paths are forbidden to contain this word.
        # Corresponds to the JSON property `isForbiddenWord`
        # @return [Boolean]
        attr_accessor :is_forbidden_word
        alias_method :is_forbidden_word?, :is_forbidden_word
      
        # A keyword for a house id.
        # Corresponds to the JSON property `isHouseIdIdentifier`
        # @return [Boolean]
        attr_accessor :is_house_id_identifier
        alias_method :is_house_id_identifier?, :is_house_id_identifier
      
        # Intersection. E.g.: and, at, corner.
        # Corresponds to the JSON property `isIntersectionConnector`
        # @return [Boolean]
        attr_accessor :is_intersection_connector
        alias_method :is_intersection_connector?, :is_intersection_connector
      
        # An affix that indicates a landmark, e.g. "opposite", "near" etc.
        # Corresponds to the JSON property `isLandmarkIdentifier`
        # @return [Boolean]
        attr_accessor :is_landmark_identifier
        alias_method :is_landmark_identifier?, :is_landmark_identifier
      
        # Language indicator. E.g.: platz in German, straat in Dutch.
        # Corresponds to the JSON property `isLanguageIndicator`
        # @return [Boolean]
        attr_accessor :is_language_indicator
        alias_method :is_language_indicator?, :is_language_indicator
      
        # Whether this is a name synonym and should be allowed to be matched on when
        # searching (that is, added to the retrieval query with the name/ prefix).
        # Corresponds to the JSON property `isNameSynonym`
        # @return [Boolean]
        attr_accessor :is_name_synonym
        alias_method :is_name_synonym?, :is_name_synonym
      
        # Terms which are not allowed to be used by the legacy street number detection.
        # Corresponds to the JSON property `isNotForLegacyStreetNumberDetection`
        # @return [Boolean]
        attr_accessor :is_not_for_legacy_street_number_detection
        alias_method :is_not_for_legacy_street_number_detection?, :is_not_for_legacy_street_number_detection
      
        # Terms which are not allowed to be treated as optional.
        # Corresponds to the JSON property `isNotOptionalizable`
        # @return [Boolean]
        attr_accessor :is_not_optionalizable
        alias_method :is_not_optionalizable?, :is_not_optionalizable
      
        # Numbers. E.g.: 1, one, 2, two.
        # Corresponds to the JSON property `isNumber`
        # @return [Boolean]
        attr_accessor :is_number
        alias_method :is_number?, :is_number
      
        # E.g. suffixes in French: bis, ter.
        # Corresponds to the JSON property `isNumberSuffix`
        # @return [Boolean]
        attr_accessor :is_number_suffix
        alias_method :is_number_suffix?, :is_number_suffix
      
        # Is this special word optional?
        # Corresponds to the JSON property `isOptional`
        # @return [Boolean]
        attr_accessor :is_optional
        alias_method :is_optional?, :is_optional
      
        # E.g.: 1st, first.
        # Corresponds to the JSON property `isOrdinalNumber`
        # @return [Boolean]
        attr_accessor :is_ordinal_number
        alias_method :is_ordinal_number?, :is_ordinal_number
      
        # Optional terms that should not geocode by themselves.
        # Corresponds to the JSON property `isPenalizedIfMissing`
        # @return [Boolean]
        attr_accessor :is_penalized_if_missing
        alias_method :is_penalized_if_missing?, :is_penalized_if_missing
      
        # Personal titles (e.g. doctor, professor, general, etc.)
        # Corresponds to the JSON property `isPersonalTitle`
        # @return [Boolean]
        attr_accessor :is_personal_title
        alias_method :is_personal_title?, :is_personal_title
      
        # E.g.: the, in, near, where.
        # Corresponds to the JSON property `isStopWord`
        # @return [Boolean]
        attr_accessor :is_stop_word
        alias_method :is_stop_word?, :is_stop_word
      
        # A keyword that denotes a street number, e.g. "number", "unit" etc.
        # Corresponds to the JSON property `isStreetNumberIdentifier`
        # @return [Boolean]
        attr_accessor :is_street_number_identifier
        alias_method :is_street_number_identifier?, :is_street_number_identifier
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_common_word = args[:is_common_word] if args.key?(:is_common_word)
          @is_deconstructible = args[:is_deconstructible] if args.key?(:is_deconstructible)
          @is_directional_modifier = args[:is_directional_modifier] if args.key?(:is_directional_modifier)
          @is_forbidden_word = args[:is_forbidden_word] if args.key?(:is_forbidden_word)
          @is_house_id_identifier = args[:is_house_id_identifier] if args.key?(:is_house_id_identifier)
          @is_intersection_connector = args[:is_intersection_connector] if args.key?(:is_intersection_connector)
          @is_landmark_identifier = args[:is_landmark_identifier] if args.key?(:is_landmark_identifier)
          @is_language_indicator = args[:is_language_indicator] if args.key?(:is_language_indicator)
          @is_name_synonym = args[:is_name_synonym] if args.key?(:is_name_synonym)
          @is_not_for_legacy_street_number_detection = args[:is_not_for_legacy_street_number_detection] if args.key?(:is_not_for_legacy_street_number_detection)
          @is_not_optionalizable = args[:is_not_optionalizable] if args.key?(:is_not_optionalizable)
          @is_number = args[:is_number] if args.key?(:is_number)
          @is_number_suffix = args[:is_number_suffix] if args.key?(:is_number_suffix)
          @is_optional = args[:is_optional] if args.key?(:is_optional)
          @is_ordinal_number = args[:is_ordinal_number] if args.key?(:is_ordinal_number)
          @is_penalized_if_missing = args[:is_penalized_if_missing] if args.key?(:is_penalized_if_missing)
          @is_personal_title = args[:is_personal_title] if args.key?(:is_personal_title)
          @is_stop_word = args[:is_stop_word] if args.key?(:is_stop_word)
          @is_street_number_identifier = args[:is_street_number_identifier] if args.key?(:is_street_number_identifier)
        end
      end
      
      # The goal of the special words are to: - Canonicalize the user query by
      # rewriting abbreviations into the canonical version that is indexed. - Figure
      # out at index time for each element which tokens are important. We use this to
      # decide if an address component is matched or not. For instance in "1600
      # Pennsylvania Ave NW" since "NW" is recognised as a directional (and "Ave" is
      # recognised as a street visible type), "Pennsylvania" becomes the name and you
      # can't match this street by just specifying "avenue" or "NW".
      class MapsQualitySpecialWordsProto
        include Google::Apis::Core::Hashable
      
        # Alternate versions of this canonical form. This is mainly abbreviations of the
        # canonical form e.g. "St", "NE", etc. This should be present as it is used in
        # the specified language with the correct capitalization, accents, etc. in UTF-8.
        # Corresponds to the JSON property `alternate`
        # @return [Array<String>]
        attr_accessor :alternate
      
        # Canonical versions: the version which is in oyster. This should be present as
        # it is used in the specified language with the correct capitalization, accents,
        # etc. in UTF-8. The canonical can be a single or a multi-token string. There
        # can be several canonicals, e.g. "center" and "centre" in English.
        # Corresponds to the JSON property `canonical`
        # @return [Array<String>]
        attr_accessor :canonical
      
        # If empty, apply this rule to any country. Otherwise, a list of ISO 3166-1
        # alpha-2 (2-letter uppercase) country codes that this description applies to.
        # Corresponds to the JSON property `country`
        # @return [Array<String>]
        attr_accessor :country
      
        # Flags that describe the information about a special word. If you add another
        # flag please add it to the special words implemenation in google3/maps/quality/
        # internal/special_words.cc. -- Next available id: 20 --
        # Corresponds to the JSON property `flags`
        # @return [Google::Apis::ContentwarehouseV1::MapsQualitySpecialWordsFlags]
        attr_accessor :flags
      
        # The III language code of the language that this description applies to. No
        # language means that this applies worldwide. This could be useful for codes
        # like country codes or airport codes or for displayed language neutral icons. A
        # special word with a language code here also applies to the regional variants
        # of that language (e.g. "en" applies to "en-GB" and "en-US" as well).
        # Corresponds to the JSON property `language`
        # @return [Array<String>]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `position`
        # @return [String]
        attr_accessor :position
      
        # visible_type_id from VisibleTypeProto for visible types converted to the
        # special words. For original special words this field is empty.
        # Corresponds to the JSON property `visibleTypeId`
        # @return [Array<String>]
        attr_accessor :visible_type_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternate = args[:alternate] if args.key?(:alternate)
          @canonical = args[:canonical] if args.key?(:canonical)
          @country = args[:country] if args.key?(:country)
          @flags = args[:flags] if args.key?(:flags)
          @language = args[:language] if args.key?(:language)
          @position = args[:position] if args.key?(:position)
          @visible_type_id = args[:visible_type_id] if args.key?(:visible_type_id)
        end
      end
      
      # Stores coordinates corresponding to the dimensions of the box surrounding the
      # region of interest. Coordinates may be normalized or absolute depending on the
      # implementation and signal corresponding to this field.
      class MediaIndexBoundingbox
        include Google::Apis::Core::Hashable
      
        # The area of the region as a fraction of the image. The value is in the range (
        # 0, 1).
        # Corresponds to the JSON property `areaFraction`
        # @return [Float]
        attr_accessor :area_fraction
      
        # 
        # Corresponds to the JSON property `xmax`
        # @return [Float]
        attr_accessor :xmax
      
        # 
        # Corresponds to the JSON property `xmin`
        # @return [Float]
        attr_accessor :xmin
      
        # 
        # Corresponds to the JSON property `ymax`
        # @return [Float]
        attr_accessor :ymax
      
        # 
        # Corresponds to the JSON property `ymin`
        # @return [Float]
        attr_accessor :ymin
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @area_fraction = args[:area_fraction] if args.key?(:area_fraction)
          @xmax = args[:xmax] if args.key?(:xmax)
          @xmin = args[:xmin] if args.key?(:xmin)
          @ymax = args[:ymax] if args.key?(:ymax)
          @ymin = args[:ymin] if args.key?(:ymin)
        end
      end
      
      # Packages entity id and score together for a given source.
      class MediaIndexEntityField
        include Google::Apis::Core::Hashable
      
        # The custom source should only be a-z[0-9] dashes, underscores, and colons.
        # Special characters should be avoided.
        # Corresponds to the JSON property `customSource`
        # @return [String]
        attr_accessor :custom_source
      
        # 
        # Corresponds to the JSON property `entityId`
        # @return [String]
        attr_accessor :entity_id
      
        # 
        # Corresponds to the JSON property `quantizedScore`
        # @return [Fixnum]
        attr_accessor :quantized_score
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @custom_source = args[:custom_source] if args.key?(:custom_source)
          @entity_id = args[:entity_id] if args.key?(:entity_id)
          @quantized_score = args[:quantized_score] if args.key?(:quantized_score)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Identifier for frames associated with a video.
      class MediaIndexFrameIdentifier
        include Google::Apis::Core::Hashable
      
        # This variant defines the frame to be the first frame of the video's generated
        # preview.
        # Corresponds to the JSON property `previewFrameZeroVariant`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexFrameIdentifierPreviewFrameZeroVariant]
        attr_accessor :preview_frame_zero_variant
      
        # Offset of the frame from the beginning of the video (in milliseconds).
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @preview_frame_zero_variant = args[:preview_frame_zero_variant] if args.key?(:preview_frame_zero_variant)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
        end
      end
      
      # This variant defines the frame to be the first frame of the video's generated
      # preview.
      class MediaIndexFrameIdentifierPreviewFrameZeroVariant
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `previewLength`
        # @return [String]
        attr_accessor :preview_length
      
        # XtagList -- a collection of Xtag instances with unique names. This would be
        # associated with one specific piece of content.
        # Corresponds to the JSON property `xtagList`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexXtagList]
        attr_accessor :xtag_list
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @preview_length = args[:preview_length] if args.key?(:preview_length)
          @xtag_list = args[:xtag_list] if args.key?(:xtag_list)
        end
      end
      
      # Metadata associated with a region in an image. NEXT_ID: 13
      class MediaIndexRegion
        include Google::Apis::Core::Hashable
      
        # Stores coordinates corresponding to the dimensions of the box surrounding the
        # region of interest. Coordinates may be normalized or absolute depending on the
        # implementation and signal corresponding to this field.
        # Corresponds to the JSON property `boundingBox`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexBoundingbox]
        attr_accessor :bounding_box
      
        # Detected Entities found within this region.
        # Corresponds to the JSON property `entityFields`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexEntityField>]
        attr_accessor :entity_fields
      
        # The labels associated with the region encoded as a SparseFloatVector to
        # facilitate dot product computation during sorting. The columns are the
        # fingerprints of the labels and the values are the corresponding confidence
        # scores. The vector is L2 normalized.
        # Corresponds to the JSON property `labels`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexSparseFloatVector]
        attr_accessor :labels
      
        # PRIMI Apparel Features v2 embedding and tokens.
        # Corresponds to the JSON property `primiApparelFeaturesV2`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :primi_apparel_features_v2
      
        # 
        # Corresponds to the JSON property `primiApparelTokensV2`
        # @return [Array<String>]
        attr_accessor :primi_apparel_tokens_v2
      
        # PRIMI Generic Features v2.5 embedding and tokens.
        # Corresponds to the JSON property `primiGenericFeaturesV25`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :primi_generic_features_v25
      
        # 
        # Corresponds to the JSON property `primiGenericTokensV25`
        # @return [Array<String>]
        attr_accessor :primi_generic_tokens_v25
      
        # Starburst v4 embedding and tokens.
        # Corresponds to the JSON property `starburstFeaturesV4`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :starburst_features_v4
      
        # Starburst v5 embedding and tokens.
        # Corresponds to the JSON property `starburstFeaturesV5`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :starburst_features_v5
      
        # 
        # Corresponds to the JSON property `starburstTokensV4`
        # @return [Array<String>]
        attr_accessor :starburst_tokens_v4
      
        # 
        # Corresponds to the JSON property `starburstTokensV5`
        # @return [Array<String>]
        attr_accessor :starburst_tokens_v5
      
        # 
        # Corresponds to the JSON property `starburstV4`
        # @return [Google::Apis::ContentwarehouseV1::ImageContentStarburstVersionGroup]
        attr_accessor :starburst_v4
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
          @entity_fields = args[:entity_fields] if args.key?(:entity_fields)
          @labels = args[:labels] if args.key?(:labels)
          @primi_apparel_features_v2 = args[:primi_apparel_features_v2] if args.key?(:primi_apparel_features_v2)
          @primi_apparel_tokens_v2 = args[:primi_apparel_tokens_v2] if args.key?(:primi_apparel_tokens_v2)
          @primi_generic_features_v25 = args[:primi_generic_features_v25] if args.key?(:primi_generic_features_v25)
          @primi_generic_tokens_v25 = args[:primi_generic_tokens_v25] if args.key?(:primi_generic_tokens_v25)
          @starburst_features_v4 = args[:starburst_features_v4] if args.key?(:starburst_features_v4)
          @starburst_features_v5 = args[:starburst_features_v5] if args.key?(:starburst_features_v5)
          @starburst_tokens_v4 = args[:starburst_tokens_v4] if args.key?(:starburst_tokens_v4)
          @starburst_tokens_v5 = args[:starburst_tokens_v5] if args.key?(:starburst_tokens_v5)
          @starburst_v4 = args[:starburst_v4] if args.key?(:starburst_v4)
        end
      end
      
      # 
      class MediaIndexSparseFloatVector
        include Google::Apis::Core::Hashable
      
        # Parallel arrays of column / value. Exactly one of those columns vector should
        # be set. Columns must be in monotonically increasing order.
        # Corresponds to the JSON property `columns`
        # @return [Array<Fixnum>]
        attr_accessor :columns
      
        # 
        # Corresponds to the JSON property `columnsInt16`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :columns_int16
      
        # 
        # Corresponds to the JSON property `columnsInt32`
        # @return [Array<Fixnum>]
        attr_accessor :columns_int32
      
        # Columns are fixed integers, used for accelerated parse.
        # Corresponds to the JSON property `columnsInt64`
        # @return [Array<Fixnum>]
        attr_accessor :columns_int64
      
        # 
        # Corresponds to the JSON property `columnsInt8`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :columns_int8
      
        # 
        # Corresponds to the JSON property `values`
        # @return [Array<Float>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @columns = args[:columns] if args.key?(:columns)
          @columns_int16 = args[:columns_int16] if args.key?(:columns_int16)
          @columns_int32 = args[:columns_int32] if args.key?(:columns_int32)
          @columns_int64 = args[:columns_int64] if args.key?(:columns_int64)
          @columns_int8 = args[:columns_int8] if args.key?(:columns_int8)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Data about the behavior of the video across the pages it is embedded in.
      class MediaIndexVideoCentroid
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `domainScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexVideoCentroidDomainScore>]
        attr_accessor :domain_scores
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain_scores = args[:domain_scores] if args.key?(:domain_scores)
        end
      end
      
      # See go/video-centroid-domain-score.
      class MediaIndexVideoCentroidDomainScore
        include Google::Apis::Core::Hashable
      
        # The domain this score was generated for.
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # Number of pages from the domain used to generate this DomainScore.
        # Corresponds to the JSON property `numDocs`
        # @return [Fixnum]
        attr_accessor :num_docs
      
        # In general, lower scores indicate the video is appearing on more diverse pages.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
          @num_docs = args[:num_docs] if args.key?(:num_docs)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Core signals for video content corpus which will be fetched for every query.
      # If a signal is required only for a subset of search queries then it should be
      # added as a separate field in the schema.
      class MediaIndexVideoCoreSignals
        include Google::Apis::Core::Hashable
      
        # Data about the behavior of the video across the pages it is embedded in.
        # Corresponds to the JSON property `centroid`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexVideoCentroid]
        attr_accessor :centroid
      
        # 
        # Corresponds to the JSON property `videoFrames`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexVideoFrame>]
        attr_accessor :video_frames
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @centroid = args[:centroid] if args.key?(:centroid)
          @video_frames = args[:video_frames] if args.key?(:video_frames)
        end
      end
      
      # Data about a frame associated with the video.
      class MediaIndexVideoFrame
        include Google::Apis::Core::Hashable
      
        # The canonical docid of the frame.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # Identifier for frames associated with a video.
        # Corresponds to the JSON property `frameIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexFrameIdentifier]
        attr_accessor :frame_identifier
      
        # Metadata associated with regions within this frame.
        # Corresponds to the JSON property `regions`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexRegion>]
        attr_accessor :regions
      
        # Starburst v4 embedding and tokens.
        # Corresponds to the JSON property `starburstFeaturesV4`
        # @return [String]
        attr_accessor :starburst_features_v4
      
        # Note: due to the migration to Golden7-source Starburst v4 embedding, no
        # starburst_tokens_v4 will be provided in video content corpus (go/video-content-
        # corpus). But this field is kept in case other purposes may still use it in the
        # proto.
        # Corresponds to the JSON property `starburstTokensV4`
        # @return [Array<String>]
        attr_accessor :starburst_tokens_v4
      
        # Set of available thumbnail types for this frame. Should be valid image_base.
        # ThumbnailType values (enumerated at http://google3/image/base/thumbnail-type.
        # proto).
        # Corresponds to the JSON property `thumbnailType`
        # @return [Array<Fixnum>]
        attr_accessor :thumbnail_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @frame_identifier = args[:frame_identifier] if args.key?(:frame_identifier)
          @regions = args[:regions] if args.key?(:regions)
          @starburst_features_v4 = args[:starburst_features_v4] if args.key?(:starburst_features_v4)
          @starburst_tokens_v4 = args[:starburst_tokens_v4] if args.key?(:starburst_tokens_v4)
          @thumbnail_type = args[:thumbnail_type] if args.key?(:thumbnail_type)
        end
      end
      
      # Data about multiple video frames associated with the video.
      class MediaIndexVideoFrames
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `videoFrames`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexVideoFrame>]
        attr_accessor :video_frames
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @video_frames = args[:video_frames] if args.key?(:video_frames)
        end
      end
      
      # 
      class MediaIndexXtag
        include Google::Apis::Core::Hashable
      
        # Names are all stored case-sensitive, and no case-folding is done for
        # comparisons.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The value associated with this Xtag. Values are all stored case-sensitive, and
        # no case-folding is done for comparisons.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # XtagList -- a collection of Xtag instances with unique names. This would be
      # associated with one specific piece of content.
      class MediaIndexXtagList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `xtags`
        # @return [Array<Google::Apis::ContentwarehouseV1::MediaIndexXtag>]
        attr_accessor :xtags
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @xtags = args[:xtags] if args.key?(:xtags)
        end
      end
      
      # Note: This message is also in the RTUpdate protocol buffer.
      class MobilePerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `flags`
        # @return [Fixnum]
        attr_accessor :flags
      
        # DEPRECATED: Url of the mobile version of the document. This is set during
        # canonicalization if we do not know that the Web url also serves the mobile
        # version.
        # Corresponds to the JSON property `mobileurl`
        # @return [String]
        attr_accessor :mobileurl
      
        # DEPRECATED: The transcoded page quality repesented in 7-bits range from 0 to
        # 127.
        # Corresponds to the JSON property `transcodedPageScore`
        # @return [Fixnum]
        attr_accessor :transcoded_page_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flags = args[:flags] if args.key?(:flags)
          @mobileurl = args[:mobileurl] if args.key?(:mobileurl)
          @transcoded_page_score = args[:transcoded_page_score] if args.key?(:transcoded_page_score)
        end
      end
      
      # Defines the presence of a field. This can help distinguish between empty vs.
      # not-present annotations.
      class MultiscaleFieldPresence
        include Google::Apis::Core::Hashable
      
        # Whether the field (data field or pointer) is defined.
        # Corresponds to the JSON property `present`
        # @return [Boolean]
        attr_accessor :present
        alias_method :present?, :present
      
        # 
        # Corresponds to the JSON property `wellDefined`
        # @return [String]
        attr_accessor :well_defined
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @present = args[:present] if args.key?(:present)
          @well_defined = args[:well_defined] if args.key?(:well_defined)
        end
      end
      
      # Defines the presence of a layer (previously called "scale").
      class MultiscaleLayerPresence
        include Google::Apis::Core::Hashable
      
        # If the layer is not materialized but things point into it, this gives the
        # effective length.
        # Corresponds to the JSON property `implicitLength`
        # @return [Fixnum]
        attr_accessor :implicit_length
      
        # Whether the layer is present.
        # Corresponds to the JSON property `present`
        # @return [Boolean]
        attr_accessor :present
        alias_method :present?, :present
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @implicit_length = args[:implicit_length] if args.key?(:implicit_length)
          @present = args[:present] if args.key?(:present)
        end
      end
      
      # Pointer to a single node in a target scale. `pointer.Index` fields should be
      # annotated with a `(pointer.to)` annotation, indicating what scale they point
      # at.
      class MultiscalePointerIndex
        include Google::Apis::Core::Hashable
      
        # The index of the node that this pointer points to.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
      # fields should be annotated with a `(pointer.to)` annotation, indicating what
      # scale they point at.
      class MultiscalePointerSpan
        include Google::Apis::Core::Hashable
      
        # The exclusive end index for the span of nodes that this pointer points to -- i.
        # e., one plus the index of the last node in the span. Must be greater than or
        # equal to `start`. If equal to `start`, then the target span is empty.
        # Corresponds to the JSON property `limit`
        # @return [Fixnum]
        attr_accessor :limit
      
        # The inclusive start index for the span of nodes that this pointer points to --
        # i.e., the index of the first node in the span.
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @limit = args[:limit] if args.key?(:limit)
          @start = args[:start] if args.key?(:start)
        end
      end
      
      # CandidateFeature contains a pair of feature name and score for a snippet
      # candidate.
      class MustangReposWwwSnippetsCandidateFeature
        include Google::Apis::Core::Hashable
      
        # Name corresponds to the names in WebChooserScorer::FeatureNames.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Data to generate the list preview for organic list snippets.
      class MustangReposWwwSnippetsOrganicListSnippetResponse
        include Google::Apis::Core::Hashable
      
        # The texts of header and listing items.
        # Corresponds to the JSON property `header`
        # @return [String]
        attr_accessor :header
      
        # The ratio of header tokens covered by title.
        # Corresponds to the JSON property `headerTitleRedundancy`
        # @return [Float]
        attr_accessor :header_title_redundancy
      
        # If the header being used in organic snippet.
        # Corresponds to the JSON property `headerUsedInSnippet`
        # @return [Boolean]
        attr_accessor :header_used_in_snippet
        alias_method :header_used_in_snippet?, :header_used_in_snippet
      
        # 
        # Corresponds to the JSON property `items`
        # @return [Array<String>]
        attr_accessor :items
      
        # The number of items in the original list.
        # Corresponds to the JSON property `originalTotalItems`
        # @return [Fixnum]
        attr_accessor :original_total_items
      
        # The score of the radish signal.
        # Corresponds to the JSON property `radishScore`
        # @return [Float]
        attr_accessor :radish_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @header = args[:header] if args.key?(:header)
          @header_title_redundancy = args[:header_title_redundancy] if args.key?(:header_title_redundancy)
          @header_used_in_snippet = args[:header_used_in_snippet] if args.key?(:header_used_in_snippet)
          @items = args[:items] if args.key?(:items)
          @original_total_items = args[:original_total_items] if args.key?(:original_total_items)
          @radish_score = args[:radish_score] if args.key?(:radish_score)
        end
      end
      
      # This message contains features for candidates at the chooser level. For each
      # snippet candidate, we also log the final score as the last candidate feature.
      class MustangReposWwwSnippetsSnippetCandidate
        include Google::Apis::Core::Hashable
      
        # data_source_type corresponds to the ChosenSnippet::SnippetType enum.
        # Corresponds to the JSON property `dataSourceType`
        # @return [Fixnum]
        attr_accessor :data_source_type
      
        # 
        # Corresponds to the JSON property `features`
        # @return [Array<Google::Apis::ContentwarehouseV1::MustangReposWwwSnippetsCandidateFeature>]
        attr_accessor :features
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
          @features = args[:features] if args.key?(:features)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # This is a protocol buffer to export into flatfiles in ranklab. All fields are
      # converted into flatfiles with some specific prefix and a field name like '
      # snippet_features_snippet_data_source_type'.
      class MustangReposWwwSnippetsSnippetsRanklabFeatures
        include Google::Apis::Core::Hashable
      
        # Browser width.
        # Corresponds to the JSON property `browserWidth`
        # @return [Fixnum]
        attr_accessor :browser_width
      
        # Features for snippets candidates, generated by both old and new scorer.
        # Currently only features for chosen candidate is generated.
        # Corresponds to the JSON property `candidates`
        # @return [Array<Google::Apis::ContentwarehouseV1::MustangReposWwwSnippetsSnippetCandidate>]
        attr_accessor :candidates
      
        # locale of the document.
        # Corresponds to the JSON property `documentLanguage`
        # @return [String]
        attr_accessor :document_language
      
        # locale of the query,
        # Corresponds to the JSON property `queryLanguage`
        # @return [String]
        attr_accessor :query_language
      
        # Snippet data source.
        # Corresponds to the JSON property `snippetDataSourceType`
        # @return [Fixnum]
        attr_accessor :snippet_data_source_type
      
        # Query term coverage in snippets.
        # Corresponds to the JSON property `snippetQueryTermCoverage`
        # @return [Float]
        attr_accessor :snippet_query_term_coverage
      
        # Snippet features for ranklab models, generated only by snippets scorer v2. In
        # production, only the data for chosen snippet will be recorded.
        # Corresponds to the JSON property `snippets`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityPreviewRanklabSnippet>]
        attr_accessor :snippets
      
        # Title data source.
        # Corresponds to the JSON property `titleDataSourceType`
        # @return [Fixnum]
        attr_accessor :title_data_source_type
      
        # Query term coverage in titles.
        # Corresponds to the JSON property `titleQueryTermCoverage`
        # @return [Float]
        attr_accessor :title_query_term_coverage
      
        # Query term coverage in titles and snippets.
        # Corresponds to the JSON property `titleSnippetQueryTermCoverage`
        # @return [Float]
        attr_accessor :title_snippet_query_term_coverage
      
        # Per-candidate title features for ranklab models, sorted from the best
        # candidate to the worst candidate (i.e., the first element is the actually
        # selected title).
        # Corresponds to the JSON property `titles`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityPreviewRanklabTitle>]
        attr_accessor :titles
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @browser_width = args[:browser_width] if args.key?(:browser_width)
          @candidates = args[:candidates] if args.key?(:candidates)
          @document_language = args[:document_language] if args.key?(:document_language)
          @query_language = args[:query_language] if args.key?(:query_language)
          @snippet_data_source_type = args[:snippet_data_source_type] if args.key?(:snippet_data_source_type)
          @snippet_query_term_coverage = args[:snippet_query_term_coverage] if args.key?(:snippet_query_term_coverage)
          @snippets = args[:snippets] if args.key?(:snippets)
          @title_data_source_type = args[:title_data_source_type] if args.key?(:title_data_source_type)
          @title_query_term_coverage = args[:title_query_term_coverage] if args.key?(:title_query_term_coverage)
          @title_snippet_query_term_coverage = args[:title_snippet_query_term_coverage] if args.key?(:title_snippet_query_term_coverage)
          @titles = args[:titles] if args.key?(:titles)
        end
      end
      
      # Tidbit token rendered in generating snippet/title.
      class MustangSnippetsRenderedToken
        include Google::Apis::Core::Hashable
      
        # Byte offset range in the rendered text that corresponds to this token. [
        # byte_offset_begin, byte_offset_end) inclusive
        # Corresponds to the JSON property `byteOffsetBegin`
        # @return [Fixnum]
        attr_accessor :byte_offset_begin
      
        # exclusive
        # Corresponds to the JSON property `byteOffsetEnd`
        # @return [Fixnum]
        attr_accessor :byte_offset_end
      
        # Section and TokenPos of the token.
        # Corresponds to the JSON property `section`
        # @return [String]
        attr_accessor :section
      
        # 
        # Corresponds to the JSON property `tokenPos`
        # @return [Fixnum]
        attr_accessor :token_pos
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte_offset_begin = args[:byte_offset_begin] if args.key?(:byte_offset_begin)
          @byte_offset_end = args[:byte_offset_end] if args.key?(:byte_offset_end)
          @section = args[:section] if args.key?(:section)
          @token_pos = args[:token_pos] if args.key?(:token_pos)
        end
      end
      
      # Message representing a versioned NSR score used for experimentation. This
      # protobuf is copied from quality_nsr::NSRVersionedItem.
      class NsrVersionedItem
        include Google::Apis::Core::Hashable
      
        # The NSR value corresponding to this version.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        # The version id.
        # Corresponds to the JSON property `versionId`
        # @return [Fixnum]
        attr_accessor :version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @value = args[:value] if args.key?(:value)
          @version_id = args[:version_id] if args.key?(:version_id)
        end
      end
      
      # Globally unique identifier for a virtual network.
      class NetFabricRpcVirtualNetworkId
        include Google::Apis::Core::Hashable
      
        # required
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # Next ID: 6
      class NewsReconServiceLrsQ2lrs2EntryPayload
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isDailyMoment`
        # @return [Boolean]
        attr_accessor :is_daily_moment
        alias_method :is_daily_moment?, :is_daily_moment
      
        # DEPRECATED as in: will be removed shortly.
        # Corresponds to the JSON property `isMomentAnyFlavor`
        # @return [Boolean]
        attr_accessor :is_moment_any_flavor
        alias_method :is_moment_any_flavor?, :is_moment_any_flavor
      
        # 
        # Corresponds to the JSON property `isPlannedMoment`
        # @return [Boolean]
        attr_accessor :is_planned_moment
        alias_method :is_planned_moment?, :is_planned_moment
      
        # 
        # Corresponds to the JSON property `momentRankingScore`
        # @return [Fixnum]
        attr_accessor :moment_ranking_score
      
        # LRS-level feature types to be sent as triples to KG. The equivalent KG
        # collection will be added to the LRS topic.
        # Corresponds to the JSON property `outKgFeatureTypes`
        # @return [Array<String>]
        attr_accessor :out_kg_feature_types
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_daily_moment = args[:is_daily_moment] if args.key?(:is_daily_moment)
          @is_moment_any_flavor = args[:is_moment_any_flavor] if args.key?(:is_moment_any_flavor)
          @is_planned_moment = args[:is_planned_moment] if args.key?(:is_planned_moment)
          @moment_ranking_score = args[:moment_ranking_score] if args.key?(:moment_ranking_score)
          @out_kg_feature_types = args[:out_kg_feature_types] if args.key?(:out_kg_feature_types)
        end
      end
      
      # 
      class NewsReconServiceLrsQ2lrs2QueryToLrsDataset
        include Google::Apis::Core::Hashable
      
        # At most one entry per (LRS, algo version) pair.
        # Corresponds to the JSON property `entries`
        # @return [Array<Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsEntry>]
        attr_accessor :entries
      
        # 
        # Corresponds to the JSON property `timeMillis`
        # @return [Fixnum]
        attr_accessor :time_millis
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entries = args[:entries] if args.key?(:entries)
          @time_millis = args[:time_millis] if args.key?(:time_millis)
        end
      end
      
      # Each entry is specific to one LRS, and contains all the information required
      # for matching a query with the LRS. For example: entries ` lrs ` mid: "/m/
      # 2024WakandaSenateElection" ` qref_entities ` mid: "/m/election" # The general
      # concept of election debug_index: 0 ` qref_entities ` mid: "/m/senate"
      # debug_index: 1 ` qref_entities ` mid: "/m/wakanda" debug_index: 2 `
      # qref_entities ` mid: "/m/WakandaSenate" debug_index: 3 ` qref_entities ` mid: "
      # /m/2024" # The year 2024 debug_index: 4 ` patterns ` pattern: "TT***" only_in `
      # regions: "WK" # BCP-47 region code for Wakanda ` ` patterns ` pattern: "TTT**"
      # ` patterns ` pattern: "T**T*" ` algo_version: 7 ` The characters in every
      # pattern string match the `qref_entities` pairwise. For example, in the pattern
      # "TT***", the first T corresponds to the entity /m/election, the second T to /m/
      # senate, the first star to /m/wakanda. A query matches a pattern if all the
      # entities marked as T (== required) are found by QRef. If QRef also finds
      # entities marked as star (== optional), those entities will be consumed in the
      # LRS interpretation and added to the `QueryToLrsInterpretation.
      # consumed_qref_mids` field. A query matches an entry if either: - QRef found
      # the LRS entity itself in the query. This is the best-case scenario, it happens
      # when the name of the event is well defined (for example "brexit") and the
      # query mentions it explicitly; - the query matches any of the patterns defined
      # in the entry. Next id: 8
      class NewsReconServiceLrsQ2lrs2QueryToLrsEntry
        include Google::Apis::Core::Hashable
      
        # The value of a `AlgoVersion.Enum` constant.
        # Corresponds to the JSON property `algoVersion`
        # @return [Fixnum]
        attr_accessor :algo_version
      
        # Index of the entry in the list of entries. This does not need to be populated
        # in the dataset which is written to disk.
        # Corresponds to the JSON property `entryIndex`
        # @return [Fixnum]
        attr_accessor :entry_index
      
        # Next ID: 6
        # Corresponds to the JSON property `internalPayload`
        # @return [Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2EntryPayload]
        attr_accessor :internal_payload
      
        # Next id: 7
        # Corresponds to the JSON property `lrs`
        # @return [Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsEntryEntity]
        attr_accessor :lrs
      
        # 
        # Corresponds to the JSON property `patterns`
        # @return [Array<Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsEntryPattern>]
        attr_accessor :patterns
      
        # 
        # Corresponds to the JSON property `qrefEntities`
        # @return [Array<Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsEntryEntity>]
        attr_accessor :qref_entities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @algo_version = args[:algo_version] if args.key?(:algo_version)
          @entry_index = args[:entry_index] if args.key?(:entry_index)
          @internal_payload = args[:internal_payload] if args.key?(:internal_payload)
          @lrs = args[:lrs] if args.key?(:lrs)
          @patterns = args[:patterns] if args.key?(:patterns)
          @qref_entities = args[:qref_entities] if args.key?(:qref_entities)
        end
      end
      
      # Next id: 7
      class NewsReconServiceLrsQ2lrs2QueryToLrsEntryEntity
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `debugIndex`
        # @return [Fixnum]
        attr_accessor :debug_index
      
        # 
        # Corresponds to the JSON property `debugName`
        # @return [String]
        attr_accessor :debug_name
      
        # This does not need to be populated in the dataset which is written to disk.
        # Corresponds to the JSON property `encodedMid`
        # @return [Fixnum]
        attr_accessor :encoded_mid
      
        # 
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_index = args[:debug_index] if args.key?(:debug_index)
          @debug_name = args[:debug_name] if args.key?(:debug_name)
          @encoded_mid = args[:encoded_mid] if args.key?(:encoded_mid)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # A locale satisfies the restrict if there is any match.
      class NewsReconServiceLrsQ2lrs2QueryToLrsEntryLocaleRestrict
        include Google::Apis::Core::Hashable
      
        # BCP-47 region codes, e.g. "US". There is a match if the user's locale `.
        # region_subtag()` is found in this set, e.g. the user's locale is "es-US".
        # Corresponds to the JSON property `regions`
        # @return [Array<String>]
        attr_accessor :regions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @regions = args[:regions] if args.key?(:regions)
        end
      end
      
      # 
      class NewsReconServiceLrsQ2lrs2QueryToLrsEntryPattern
        include Google::Apis::Core::Hashable
      
        # A locale satisfies the restrict if there is any match.
        # Corresponds to the JSON property `onlyIn`
        # @return [Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsEntryLocaleRestrict]
        attr_accessor :only_in
      
        # A string containing N characters, where each character is 'T' (required) or '*'
        # (optional), and N is the size of `qref_entities`. Characters match QRef
        # entities pairwise.
        # Corresponds to the JSON property `pattern`
        # @return [String]
        attr_accessor :pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @only_in = args[:only_in] if args.key?(:only_in)
          @pattern = args[:pattern] if args.key?(:pattern)
        end
      end
      
      # The proto that holds the complete call path info of the QRewrite client (e.g.
      # the QUS's phase like "RBT","QBT"; the QUS's candidate type like "Identity";
      # and the ACE's candidate type like "FuzzyMatcher"). Next ID: 5 ACE tags
      class NlpLoggingQRewriteClientCallPathInfo
        include Google::Apis::Core::Hashable
      
        # A complete query candidate Id includes a list of Id fields. The Id field order
        # is maintained as the order by which each field is appended to the list.
        # Corresponds to the JSON property `qrewriteCandidateId`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteCandidateId]
        attr_accessor :qrewrite_candidate_id
      
        # A complete query candidate Id includes a list of Id fields. The Id field order
        # is maintained as the order by which each field is appended to the list.
        # Corresponds to the JSON property `qusCandidateId`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteCandidateId]
        attr_accessor :qus_candidate_id
      
        # The proto that holds the complete call path info of the QUS client (e.g. the
        # candidate type like "Identity", "FuzzyMatcher"; The intent generator like "
        # QUS_IG" in ACE).
        # Corresponds to the JSON property `qusClientCallPathInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpLoggingQusClientCallPathInfo]
        attr_accessor :qus_client_call_path_info
      
        # Indicates which QUS phase sends the QRewrite request. Note if the QRewrite
        # response is reused in succeeding phases, this field should not be overridden
        # and it is always the phase that initially sends the RPC.
        # Corresponds to the JSON property `qusPhase`
        # @return [String]
        attr_accessor :qus_phase
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @qrewrite_candidate_id = args[:qrewrite_candidate_id] if args.key?(:qrewrite_candidate_id)
          @qus_candidate_id = args[:qus_candidate_id] if args.key?(:qus_candidate_id)
          @qus_client_call_path_info = args[:qus_client_call_path_info] if args.key?(:qus_client_call_path_info)
          @qus_phase = args[:qus_phase] if args.key?(:qus_phase)
        end
      end
      
      # The proto that holds the complete call path info of the QUS client (e.g. the
      # candidate type like "Identity", "FuzzyMatcher"; The intent generator like "
      # QUS_IG" in ACE).
      class NlpLoggingQusClientCallPathInfo
        include Google::Apis::Core::Hashable
      
        # rewriter_type forms part of a unique key to be used to label QUS Requests from
        # ACE. The need to distinguish between the variety of calls from AS into QUS is
        # for two reasons: (a) currently, assistant eval can do NLU Eval only on certain
        # rewrites (b) later AS Hermetic and NLU Eval can be integrated In the furure,
        # the unique key will be expanded to add intent_generator_type or something
        # similar. There are ongoing discussions to confirm these plans
        # Corresponds to the JSON property `rewriterType`
        # @return [String]
        attr_accessor :rewriter_type
      
        # The timestamp when QUS request is built in ACE. For now we don't care about
        # the actual meaning of this tag, and only want to guarantee its uniqueness per
        # QUS call.
        # Corresponds to the JSON property `temporaryAceTag`
        # @return [Fixnum]
        attr_accessor :temporary_ace_tag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @rewriter_type = args[:rewriter_type] if args.key?(:rewriter_type)
          @temporary_ace_tag = args[:temporary_ace_tag] if args.key?(:temporary_ace_tag)
        end
      end
      
      # 
      class NlpMeaningMeaningRemodeling
        include Google::Apis::Core::Hashable
      
        # This field can be set to true to indicate that the associated part of the
        # schema is being deleted as part of the remodeling.
        # Corresponds to the JSON property `deletion`
        # @return [Boolean]
        attr_accessor :deletion
        alias_method :deletion?, :deletion
      
        # The remodeling ID. Each remodeling has a unique ID that is used to associate
        # changes with that remodeling.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deletion = args[:deletion] if args.key?(:deletion)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # This is the FunctionCall counterpart to the "MeaningRemodelings" structure.
      # When present, it is used for typechecking the FunctionCall against the schema
      # with the remodelings enabled.
      class NlpMeaningMeaningRemodelingControl
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `remodelingId`
        # @return [Array<Fixnum>]
        attr_accessor :remodeling_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodeling_id = args[:remodeling_id] if args.key?(:remodeling_id)
        end
      end
      
      # This proto will be added as a field to part of a schema to indicate it is
      # being remodeled.
      class NlpMeaningMeaningRemodelings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `remodeling`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodeling>]
        attr_accessor :remodeling
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @remodeling = args[:remodeling] if args.key?(:remodeling)
        end
      end
      
      # Associates remodeling data with a semantic type name.
      class NlpMeaningSemanticTypeNameMeaningRemodelings
        include Google::Apis::Core::Hashable
      
        # Semantic type name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # This proto will be added as a field to part of a schema to indicate it is
        # being remodeled.
        # Corresponds to the JSON property `remodelings`
        # @return [Google::Apis::ContentwarehouseV1::NlpMeaningMeaningRemodelings]
        attr_accessor :remodelings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @remodelings = args[:remodelings] if args.key?(:remodelings)
        end
      end
      
      # Representation of a phrase in the document with a particular annotation.
      # Provides the ability to annotate arbitrary spans in the document. This is
      # intended for representing spans that SAFT does NOT consider to be mentions of
      # entities within a SAFT document.
      class NlpSaftAnnotatedPhrase
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @info = args[:info] if args.key?(:info)
          @phrase = args[:phrase] if args.key?(:phrase)
        end
      end
      
      # Constituency parse tree node with tokens as the leaf nodes.
      class NlpSaftConstituencyNode
        include Google::Apis::Core::Hashable
      
        # An arbitrary number of children, ordered from left to right; empty for
        # preterminals. Represented via indices into Document.constituency_node.
        # Corresponds to the JSON property `child`
        # @return [Array<Fixnum>]
        attr_accessor :child
      
        # The label of the current node.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @child = args[:child] if args.key?(:child)
          @label = args[:label] if args.key?(:label)
          @phrase = args[:phrase] if args.key?(:phrase)
        end
      end
      
      # A document contains the raw text contents of the document as well as an
      # analysis. The document can be split into tokens which can contain information
      # about POS tags and dependency relations. The document can also contain
      # entities and mentions of these entities in the document. Next available id: 36
      class NlpSaftDocument
        include Google::Apis::Core::Hashable
      
        # Annotated phrases in the document that are not semantically well-defined
        # mentions of entities.
        # Corresponds to the JSON property `annotatedPhrase`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftAnnotatedPhrase>]
        attr_accessor :annotated_phrase
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `annotations`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :annotations
      
        # Document author(s).
        # Corresponds to the JSON property `author`
        # @return [Array<String>]
        attr_accessor :author
      
        # Document's byline date, if available: this is the date that will be shown in
        # the snippets in web search results. It is stored as the number of seconds
        # since epoch. See segindexer/compositedoc.proto
        # Corresponds to the JSON property `bylineDate`
        # @return [Fixnum]
        attr_accessor :byline_date
      
        # Constituency parse tree nodes for the sentences in this document.
        # Corresponds to the JSON property `constituencyNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftConstituencyNode>]
        attr_accessor :constituency_node
      
        # The root node of the constituency tree for each sentence. If non-empty, the
        # list of roots will be aligned with the sentences in the document. Note that
        # some sentences may not have been parsed for various reasons; these sentences
        # will be annotated with placeholder "stub parses". For details, see //nlp/saft/
        # components/constituents/util/stub-parse.h.
        # Corresponds to the JSON property `constituencyRoot`
        # @return [Array<Fixnum>]
        attr_accessor :constituency_root
      
        # Stores minimum of first time google successfully crawled a document, or
        # indexed the document with contents (i.e, not roboted). It is stored as the
        # number of seconds since epoch. See quality/historical/signals/firstseen/
        # firstseen.proto
        # Corresponds to the JSON property `contentFirstseen`
        # @return [Fixnum]
        attr_accessor :content_firstseen
      
        # Optional document content_type (from webutil/http/content-type.proto). Used
        # for setting the content_type when converting the SAFT Document to a
        # CompositeDoc. Will be inferred if not given here.
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # Age of the content of the document. For details, see: quality/historical/
        # shingle/signals/contentage.proto The format has been translated to a canonical
        # timestamp (seconds since epoch).
        # Corresponds to the JSON property `contentage`
        # @return [Fixnum]
        attr_accessor :contentage
      
        # Document anchor date in YYYYMMDDhhmmss format.
        # Corresponds to the JSON property `date`
        # @return [String]
        attr_accessor :date
      
        # Identifier for document.
        # Corresponds to the JSON property `docid`
        # @return [String]
        attr_accessor :docid
      
        # Entities in the document.
        # Corresponds to the JSON property `entity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntity>]
        attr_accessor :entity
      
        # Entity labels used in this document. This field is used to define labels for
        # the Entity::entity_type_probability field, which contains corresponding
        # probabilities. WARNING: This field is deprecated. go/saft-replace-deprecated-
        # entity-type
        # Corresponds to the JSON property `entityLabel`
        # @return [Array<String>]
        attr_accessor :entity_label
      
        # Focus entity. For lexicon articles, like Wikipedia pages, a document is often
        # about a certain entity. This is the local entity id of the focus entity for
        # the document.
        # Corresponds to the JSON property `focusEntity`
        # @return [Fixnum]
        attr_accessor :focus_entity
      
        # Flag for indicating that the document is a gold-standard document. This can be
        # used for putting additional weight on human-labeled documents in contrast to
        # automatically labeled annotations.
        # Corresponds to the JSON property `golden`
        # @return [Boolean]
        attr_accessor :golden
        alias_method :golden?, :golden
      
        # HTTP header for document. If the HTTP headers field is set it should be the
        # complete header including the HTTP status line and the trailing cr/nl. HTTP
        # headers are not required to be valid UTF-8. Per the HTTP/1.1 Syntax (RFC7230)
        # standard, non-ASCII octets should be treated as opaque data.
        # Corresponds to the JSON property `httpHeaders`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :http_headers
      
        # The hyperlinks in the document. Multiple hyperlinks are sorted in left-to-
        # right order.
        # Corresponds to the JSON property `hyperlink`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftHyperlink>]
        attr_accessor :hyperlink
      
        # Generic labeled spans (produced by the span labeling framework, go/saft-span-
        # labeling). The map key identifies spans of the same type. By convention, it
        # should be of the form "team_name/span_type_name".
        # Corresponds to the JSON property `labeledSpans`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::NlpSaftLabeledSpans>]
        attr_accessor :labeled_spans
      
        # Document language (default is English). This field's value maps cleanly to the
        # i18n.languages.Language proto enum (i18n::languages::Language in C++).
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # Last significant update of the page content, in the same format as the
        # contentage field, and also derived from ContentAge.last_significant_update in
        # quality/historical/shingle/signals/contentage.proto.
        # Corresponds to the JSON property `lastSignificantUpdate`
        # @return [Fixnum]
        attr_accessor :last_significant_update
      
        # Measures in the documents. This covers both time expressions as well as
        # physical quantities.
        # Corresponds to the JSON property `measure`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftMeasure>]
        attr_accessor :measure
      
        # True if this document contains privacy sensitive data. When the document is
        # transferred in RPC calls the RPC should use SSL_PRIVACY_AND_INTEGRITY security
        # level.
        # Corresponds to the JSON property `privacySensitive`
        # @return [Boolean]
        attr_accessor :privacy_sensitive
        alias_method :privacy_sensitive?, :privacy_sensitive
      
        # Relations between entities in the document.
        # Corresponds to the JSON property `relation`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftRelation>]
        attr_accessor :relation
      
        # True if some RPC which touched this document had an error.
        # Corresponds to the JSON property `rpcError`
        # @return [Boolean]
        attr_accessor :rpc_error
        alias_method :rpc_error?, :rpc_error
      
        # The semantic nodes for the document represent arbitrary types of higher-level
        # abstractions beyond entity mention coreference and binary relations between
        # entities. These may include: n-ary relations, semantic frames or events. The
        # semantic nodes for a document are the nodes in a directed acyclic graph, with
        # an adjacency list representation.
        # Corresponds to the JSON property `semanticNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftSemanticNode>]
        attr_accessor :semantic_node
      
        # Sub-sections for document for dividing a document into volumes, parts,
        # chapters, sections, etc.
        # Corresponds to the JSON property `subsection`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftDocument>]
        attr_accessor :subsection
      
        # Document's syntactic date (e.g. date explicitly mentioned in the URL of the
        # document or in the document title). It is stored as the number of seconds
        # since epoch. See quality/timebased/syntacticdate/proto/syntactic-date.proto
        # Corresponds to the JSON property `syntacticDate`
        # @return [Fixnum]
        attr_accessor :syntactic_date
      
        # Raw text contents of document. (In docjoin attachments from the SAFT goldmine
        # annotator this field will be empty.)
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Optional document title.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Tokenization of the document.
        # Corresponds to the JSON property `token`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftToken>]
        attr_accessor :token
      
        # 
        # Corresponds to the JSON property `topic`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftDocumentTopic>]
        attr_accessor :topic
      
        # Whether to enable component tracing during analysis of this document. See http:
        # //go/saft-tracing for details.
        # Corresponds to the JSON property `trace`
        # @return [Boolean]
        attr_accessor :trace
        alias_method :trace?, :trace
      
        # Source document URL.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotated_phrase = args[:annotated_phrase] if args.key?(:annotated_phrase)
          @annotations = args[:annotations] if args.key?(:annotations)
          @author = args[:author] if args.key?(:author)
          @byline_date = args[:byline_date] if args.key?(:byline_date)
          @constituency_node = args[:constituency_node] if args.key?(:constituency_node)
          @constituency_root = args[:constituency_root] if args.key?(:constituency_root)
          @content_firstseen = args[:content_firstseen] if args.key?(:content_firstseen)
          @content_type = args[:content_type] if args.key?(:content_type)
          @contentage = args[:contentage] if args.key?(:contentage)
          @date = args[:date] if args.key?(:date)
          @docid = args[:docid] if args.key?(:docid)
          @entity = args[:entity] if args.key?(:entity)
          @entity_label = args[:entity_label] if args.key?(:entity_label)
          @focus_entity = args[:focus_entity] if args.key?(:focus_entity)
          @golden = args[:golden] if args.key?(:golden)
          @http_headers = args[:http_headers] if args.key?(:http_headers)
          @hyperlink = args[:hyperlink] if args.key?(:hyperlink)
          @labeled_spans = args[:labeled_spans] if args.key?(:labeled_spans)
          @language = args[:language] if args.key?(:language)
          @last_significant_update = args[:last_significant_update] if args.key?(:last_significant_update)
          @measure = args[:measure] if args.key?(:measure)
          @privacy_sensitive = args[:privacy_sensitive] if args.key?(:privacy_sensitive)
          @relation = args[:relation] if args.key?(:relation)
          @rpc_error = args[:rpc_error] if args.key?(:rpc_error)
          @semantic_node = args[:semantic_node] if args.key?(:semantic_node)
          @subsection = args[:subsection] if args.key?(:subsection)
          @syntactic_date = args[:syntactic_date] if args.key?(:syntactic_date)
          @text = args[:text] if args.key?(:text)
          @title = args[:title] if args.key?(:title)
          @token = args[:token] if args.key?(:token)
          @topic = args[:topic] if args.key?(:topic)
          @trace = args[:trace] if args.key?(:trace)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Document topic(s).
      class NlpSaftDocumentTopic
        include Google::Apis::Core::Hashable
      
        # Topic name or identifier.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Topic score.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Named entities in the document.
      class NlpSaftEntity
        include Google::Apis::Core::Hashable
      
        # Antecedent for entity. This is used to make coreference chains before the
        # mentions in the document are grouped by entity.
        # Corresponds to the JSON property `antecedent`
        # @return [Fixnum]
        attr_accessor :antecedent
      
        # Entity type (e.g. PER, ORG, LOC). WARNING: This field is deprecated. go/saft-
        # replace-deprecated-entity-type
        # Corresponds to the JSON property `entityType`
        # @return [String]
        attr_accessor :entity_type
      
        # Probability distribution over entity types. These values correspond to
        # Document.entity_label values: doc.entity[e].entity_type_probability[n] is the
        # probability that the correct label for doc.entity[e] is doc.entity_label[n].
        # These probabilities sum to 1.0 (with possible rounding error). WARNING: This
        # field is deprecated. go/saft-replace-deprecated-entity-type
        # Corresponds to the JSON property `entityTypeProbability`
        # @return [Array<Float>]
        attr_accessor :entity_type_probability
      
        # Gender for entity.
        # Corresponds to the JSON property `gender`
        # @return [String]
        attr_accessor :gender
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Mentions of the entity in the document.
        # Corresponds to the JSON property `mention`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftMention>]
        attr_accessor :mention
      
        # Representative entity name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # An entity profile contains a summary of the information about a single unique
        # entity. Next available index: 46.
        # Corresponds to the JSON property `profile`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftEntityProfile]
        attr_accessor :profile
      
        # A referent contains information about what a discourse context entity is
        # referring to. It acts like a canonical mention of the entity.
        # Corresponds to the JSON property `referent`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftReferent]
        attr_accessor :referent
      
        # Representative mention, as an index into mention.
        # Corresponds to the JSON property `representativeMention`
        # @return [Fixnum]
        attr_accessor :representative_mention
      
        # Score indicating the saliency (centrality) of this entity to the document.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        # Entity types of the entity. These can include SAFT types (/saft/location, /
        # saft/art, /saft/other/living_thing, etc), collections types (/collection/
        # tv_personalities, /collection/statistical_regions, etc), and more. This refers
        # to the type of the entity itself: in "She is on TV", "She" refers to a
        # specific actor, with type "/collection/tv_personalities". Cf. Mention.Type,
        # which is the type of the referring mention.
        # Corresponds to the JSON property `type`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityType>]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @antecedent = args[:antecedent] if args.key?(:antecedent)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @entity_type_probability = args[:entity_type_probability] if args.key?(:entity_type_probability)
          @gender = args[:gender] if args.key?(:gender)
          @info = args[:info] if args.key?(:info)
          @mention = args[:mention] if args.key?(:mention)
          @name = args[:name] if args.key?(:name)
          @profile = args[:profile] if args.key?(:profile)
          @referent = args[:referent] if args.key?(:referent)
          @representative_mention = args[:representative_mention] if args.key?(:representative_mention)
          @salience = args[:salience] if args.key?(:salience)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # An entity profile contains a summary of the information about a single unique
      # entity. Next available index: 46.
      class NlpSaftEntityProfile
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `alternate`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityProfileAlternate>]
        attr_accessor :alternate
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `annotations`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :annotations
      
        # List of attributes for the entity.
        # Corresponds to the JSON property `attribute`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityProfileAttribute>]
        attr_accessor :attribute
      
        # Canonical entity name.
        # Corresponds to the JSON property `canonicalName`
        # @return [String]
        attr_accessor :canonical_name
      
        # 
        # Corresponds to the JSON property `collectionScoreType`
        # @return [String]
        attr_accessor :collection_score_type
      
        # Disambiguation phrase. The combination of entity name and disambiguation
        # phrase should be unique within the corpus.
        # Corresponds to the JSON property `disambiguation`
        # @return [String]
        attr_accessor :disambiguation
      
        # Entity embeding vector, representing the entity in a dense low-dimensional
        # embedding space.
        # Corresponds to the JSON property `embedding`
        # @return [Array<Float>]
        attr_accessor :embedding
      
        # Profile frame in binary SLING encoding.
        # Corresponds to the JSON property `frame`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :frame
      
        # Gender of the entity.
        # Corresponds to the JSON property `gender`
        # @return [String]
        attr_accessor :gender
      
        # Unique global id for entity.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # External identifiers for entity.
        # Corresponds to the JSON property `identifier`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftIdentifier>]
        attr_accessor :identifier
      
        # 
        # Corresponds to the JSON property `keyword`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityProfileKeyword>]
        attr_accessor :keyword
      
        # Freebase MID for entity. This field should be the same as FREEBASE_MID
        # identifier for the entity profile.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Representative name for entity.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Language for the name and disambiguation.
        # Corresponds to the JSON property `nameLanguage`
        # @return [Fixnum]
        attr_accessor :name_language
      
        # Nature of the entity.
        # Corresponds to the JSON property `nature`
        # @return [String]
        attr_accessor :nature
      
        # 
        # Corresponds to the JSON property `reference`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityProfileReference>]
        attr_accessor :reference
      
        # 
        # Corresponds to the JSON property `related`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftEntityProfileRelated>]
        attr_accessor :related
      
        # Entity type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternate = args[:alternate] if args.key?(:alternate)
          @annotations = args[:annotations] if args.key?(:annotations)
          @attribute = args[:attribute] if args.key?(:attribute)
          @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
          @collection_score_type = args[:collection_score_type] if args.key?(:collection_score_type)
          @disambiguation = args[:disambiguation] if args.key?(:disambiguation)
          @embedding = args[:embedding] if args.key?(:embedding)
          @frame = args[:frame] if args.key?(:frame)
          @gender = args[:gender] if args.key?(:gender)
          @id = args[:id] if args.key?(:id)
          @identifier = args[:identifier] if args.key?(:identifier)
          @keyword = args[:keyword] if args.key?(:keyword)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
          @name_language = args[:name_language] if args.key?(:name_language)
          @nature = args[:nature] if args.key?(:nature)
          @reference = args[:reference] if args.key?(:reference)
          @related = args[:related] if args.key?(:related)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Alternative names for entity.
      class NlpSaftEntityProfileAlternate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # see nlp/saft/resolution/name-form.h for values
        # Corresponds to the JSON property `form`
        # @return [Fixnum]
        attr_accessor :form
      
        # frame in SLING encoding
        # Corresponds to the JSON property `frame`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :frame
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # (1 << SRC_DEFAULT)
        # Corresponds to the JSON property `sources`
        # @return [Fixnum]
        attr_accessor :sources
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @form = args[:form] if args.key?(:form)
          @frame = args[:frame] if args.key?(:frame)
          @language = args[:language] if args.key?(:language)
          @name = args[:name] if args.key?(:name)
          @sources = args[:sources] if args.key?(:sources)
        end
      end
      
      # 
      class NlpSaftEntityProfileAttribute
        include Google::Apis::Core::Hashable
      
        # Boolean attribute value, e.g. for IsDeceased.
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # Double attribute value, e.g. for height/weight.
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # Integer attribute value, e.g. IntId("April").
        # Corresponds to the JSON property `intValue`
        # @return [Fixnum]
        attr_accessor :int_value
      
        # Language, in case the attribute value is a string.
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # String name of the type of attribute, e.g. /birth/date
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Any id of the type of the attribute, e.g. IntId(/birth/date)
        # Corresponds to the JSON property `typeId`
        # @return [Fixnum]
        attr_accessor :type_id
      
        # String attribute value, e.g. "April 2010" or "3,235,121".
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        # The type of the value.
        # Corresponds to the JSON property `valueType`
        # @return [String]
        attr_accessor :value_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @int_value = args[:int_value] if args.key?(:int_value)
          @language = args[:language] if args.key?(:language)
          @type = args[:type] if args.key?(:type)
          @type_id = args[:type_id] if args.key?(:type_id)
          @value = args[:value] if args.key?(:value)
          @value_type = args[:value_type] if args.key?(:value_type)
        end
      end
      
      # Keywords and key phrases for entity.
      class NlpSaftEntityProfileKeyword
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # Score associated with the keyword. For fine-grained types this is a
        # probability.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `term`
        # @return [String]
        attr_accessor :term
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @language = args[:language] if args.key?(:language)
          @score = args[:score] if args.key?(:score)
          @term = args[:term] if args.key?(:term)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # References to entity.
      class NlpSaftEntityProfileReference
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [String]
        attr_accessor :docid
      
        # 
        # Corresponds to the JSON property `entity`
        # @return [Fixnum]
        attr_accessor :entity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @entity = args[:entity] if args.key?(:entity)
        end
      end
      
      # Related entities.
      class NlpSaftEntityProfileRelated
        include Google::Apis::Core::Hashable
      
        # Number of occurrences.
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Inverse relations can be marked in a bidirectional graph.
        # Corresponds to the JSON property `inverse`
        # @return [Boolean]
        attr_accessor :inverse
        alias_method :inverse?, :inverse
      
        # Optional integer id for the relation.
        # Corresponds to the JSON property `relationId`
        # @return [Fixnum]
        attr_accessor :relation_id
      
        # External identifier. An external identifier is a persistent identifier for an
        # object within a domain.
        # Corresponds to the JSON property `relationIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftIdentifier]
        attr_accessor :relation_identifier
      
        # Score for related entity, i.e. p(e->r | e).
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Profile id of related entity.
        # Corresponds to the JSON property `targetId`
        # @return [Fixnum]
        attr_accessor :target_id
      
        # External identifier. An external identifier is a persistent identifier for an
        # object within a domain.
        # Corresponds to the JSON property `targetIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftIdentifier]
        attr_accessor :target_identifier
      
        # Name of related entity.
        # Corresponds to the JSON property `targetName`
        # @return [String]
        attr_accessor :target_name
      
        # Type of relation.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @inverse = args[:inverse] if args.key?(:inverse)
          @relation_id = args[:relation_id] if args.key?(:relation_id)
          @relation_identifier = args[:relation_identifier] if args.key?(:relation_identifier)
          @score = args[:score] if args.key?(:score)
          @target_id = args[:target_id] if args.key?(:target_id)
          @target_identifier = args[:target_identifier] if args.key?(:target_identifier)
          @target_name = args[:target_name] if args.key?(:target_name)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A generic type description for an entity.
      class NlpSaftEntityType
        include Google::Apis::Core::Hashable
      
        # This field can be used to specify if the entity type has been annotated or
        # predicted from a specific mention of the entity. However, the entity type does
        # still apply to the entity as a whole, and not just a specific mention.
        # Corresponds to the JSON property `basedOnMention`
        # @return [Fixnum]
        attr_accessor :based_on_mention
      
        # A domain name for the set that this particular type belongs to.
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # The type name, like "/saft/person". See README.entity-types for the inventory
        # of SAFT type tags.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # A score for this type.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @based_on_mention = args[:based_on_mention] if args.key?(:based_on_mention)
          @domain = args[:domain] if args.key?(:domain)
          @info = args[:info] if args.key?(:info)
          @name = args[:name] if args.key?(:name)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # A link on an HTML page.
      class NlpSaftHyperlink
        include Google::Apis::Core::Hashable
      
        # Clean anchor text (no HTML markup).
        # Corresponds to the JSON property `anchorText`
        # @return [String]
        attr_accessor :anchor_text
      
        # note: inclusive
        # Corresponds to the JSON property `byteEnd`
        # @return [Fixnum]
        attr_accessor :byte_end
      
        # begin/end options are for goldmine AnnotationsFinder to locate the offsets of
        # saft tokens. Start is inclusive by default and end is marked. The indices of
        # the first and last byte covered by the hyperlink.
        # Corresponds to the JSON property `byteStart`
        # @return [Fixnum]
        attr_accessor :byte_start
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # (Absolute) URL that the links to.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_text = args[:anchor_text] if args.key?(:anchor_text)
          @byte_end = args[:byte_end] if args.key?(:byte_end)
          @byte_start = args[:byte_start] if args.key?(:byte_start)
          @phrase = args[:phrase] if args.key?(:phrase)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # External identifier. An external identifier is a persistent identifier for an
      # object within a domain.
      class NlpSaftIdentifier
        include Google::Apis::Core::Hashable
      
        # Domain for the identifier.
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # Identifier within domain.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A generic span, possibly with an associated label. The span may be defined by
      # either byte-level or token-level boundaries.
      class NlpSaftLabeledSpan
        include Google::Apis::Core::Hashable
      
        # note: inclusive
        # Corresponds to the JSON property `byteEnd`
        # @return [Fixnum]
        attr_accessor :byte_end
      
        # The indices of the first and last byte covered by the span.
        # Corresponds to the JSON property `byteStart`
        # @return [Fixnum]
        attr_accessor :byte_start
      
        # The label associated with the span.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # Optionally stores alternative labels with associated scores for the span.
        # Corresponds to the JSON property `labelScores`
        # @return [Hash<String,Float>]
        attr_accessor :label_scores
      
        # A score associated with the span.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # note: inclusive
        # Corresponds to the JSON property `tokenEnd`
        # @return [Fixnum]
        attr_accessor :token_end
      
        # The indices of the first and last token covered by the span.
        # Corresponds to the JSON property `tokenStart`
        # @return [Fixnum]
        attr_accessor :token_start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte_end = args[:byte_end] if args.key?(:byte_end)
          @byte_start = args[:byte_start] if args.key?(:byte_start)
          @label = args[:label] if args.key?(:label)
          @label_scores = args[:label_scores] if args.key?(:label_scores)
          @score = args[:score] if args.key?(:score)
          @token_end = args[:token_end] if args.key?(:token_end)
          @token_start = args[:token_start] if args.key?(:token_start)
        end
      end
      
      # A list of labeled spans of the same type.
      class NlpSaftLabeledSpans
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `labeledSpan`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftLabeledSpan>]
        attr_accessor :labeled_span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @labeled_span = args[:labeled_span] if args.key?(:labeled_span)
        end
      end
      
      # Measures in the documents. This covers both time expressions as well as
      # physical quantities.
      class NlpSaftMeasure
        include Google::Apis::Core::Hashable
      
        # Canonical value for measurement.
        # Corresponds to the JSON property `canonical`
        # @return [Float]
        attr_accessor :canonical
      
        # Granularity for measurement.
        # Corresponds to the JSON property `granularity`
        # @return [Float]
        attr_accessor :granularity
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # Measurement value and unit.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical = args[:canonical] if args.key?(:canonical)
          @granularity = args[:granularity] if args.key?(:granularity)
          @info = args[:info] if args.key?(:info)
          @phrase = args[:phrase] if args.key?(:phrase)
          @type = args[:type] if args.key?(:type)
          @unit = args[:unit] if args.key?(:unit)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Mentions of the entity in the document.
      class NlpSaftMention
        include Google::Apis::Core::Hashable
      
        # Estimate of the confidence that this mention is in the correct cluster. Zero
        # means this mention is probably in the wrong cluster, 1 means this mention is
        # probably in the correct cluster. See nlp/saft/components/coreference/
        # coreference-confidence.h for details about what "correct cluster" might mean.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # 
        # Corresponds to the JSON property `kind`
        # @return [String]
        attr_accessor :kind
      
        # 
        # Corresponds to the JSON property `nestingRelation`
        # @return [String]
        attr_accessor :nesting_relation
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # Mention resolution for encoding the concept id (e.g. mid) for a mention.
        # Corresponds to the JSON property `resolution`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftMentionResolution]
        attr_accessor :resolution
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @info = args[:info] if args.key?(:info)
          @kind = args[:kind] if args.key?(:kind)
          @nesting_relation = args[:nesting_relation] if args.key?(:nesting_relation)
          @phrase = args[:phrase] if args.key?(:phrase)
          @resolution = args[:resolution] if args.key?(:resolution)
          @role = args[:role] if args.key?(:role)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Mention resolution for encoding the concept id (e.g. mid) for a mention.
      class NlpSaftMentionResolution
        include Google::Apis::Core::Hashable
      
        # An entity profile contains a summary of the information about a single unique
        # entity. Next available index: 46.
        # Corresponds to the JSON property `profile`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftEntityProfile]
        attr_accessor :profile
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @profile = args[:profile] if args.key?(:profile)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Message that stores information about the morphology of a token.
      class NlpSaftMorphology
        include Google::Apis::Core::Hashable
      
        # A list of morphology attribute-value pairs.
        # Corresponds to the JSON property `attrValue`
        # @return [Array<String>]
        attr_accessor :attr_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attr_value = args[:attr_value] if args.key?(:attr_value)
        end
      end
      
      # A document phrase marks a range of tokens in a document as a phrase. The
      # indices are token positions in the document.
      class NlpSaftPhrase
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `facet`
        # @return [String]
        attr_accessor :facet
      
        # The head token in the phrase is the id of the top-most token within the phrase.
        # It either has an arc from outside the phrase going to it, or it is a root
        # token of the sentence. A value of -1 indicates that the head has not yet been
        # computed for the phrase (not the same semantics as the head of a token!). Note
        # that even when it is uniquely defined, there is no guarantee that the head is
        # set for entities and measurements within a document: you may need to
        # explicitly compute it.
        # Corresponds to the JSON property `head`
        # @return [Fixnum]
        attr_accessor :head
      
        # First and last token in the phrase. The phrase goes from start to end (
        # inclusive).
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end = args[:end] if args.key?(:end)
          @facet = args[:facet] if args.key?(:facet)
          @head = args[:head] if args.key?(:head)
          @start = args[:start] if args.key?(:start)
        end
      end
      
      # A referent contains information about what a discourse context entity is
      # referring to. It acts like a canonical mention of the entity.
      class NlpSaftReferent
        include Google::Apis::Core::Hashable
      
        # Distance of this referent from the markables in the Document. Smaller values
        # imply that the referent is more accessible to be an antecedent for a markable
        # in the Document. The expectation is that this field would increase with every
        # new Document in which this referent is not mentioned.
        # Corresponds to the JSON property `distance`
        # @return [Float]
        attr_accessor :distance
      
        # 
        # Corresponds to the JSON property `explicitness`
        # @return [String]
        attr_accessor :explicitness
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # Prominence score for referent. This is roughly equivalent to the number of
        # previous mentions of the referent.
        # Corresponds to the JSON property `prominence`
        # @return [Float]
        attr_accessor :prominence
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # Tokenized representation for the canonical name of the referent entity.
        # Corresponds to the JSON property `token`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftToken>]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @distance = args[:distance] if args.key?(:distance)
          @explicitness = args[:explicitness] if args.key?(:explicitness)
          @info = args[:info] if args.key?(:info)
          @phrase = args[:phrase] if args.key?(:phrase)
          @prominence = args[:prominence] if args.key?(:prominence)
          @role = args[:role] if args.key?(:role)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # Relations between entities in the document. A relation is between two
      # different entities in the document. A relation can have a number of mentions
      # in the document. Next available id: 11
      class NlpSaftRelation
        include Google::Apis::Core::Hashable
      
        # External identifier. An external identifier is a persistent identifier for an
        # object within a domain.
        # Corresponds to the JSON property `identifier`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftIdentifier]
        attr_accessor :identifier
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # 
        # Corresponds to the JSON property `kind`
        # @return [String]
        attr_accessor :kind
      
        # Mentions of the relation in the document.
        # Corresponds to the JSON property `mention`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftRelationMention>]
        attr_accessor :mention
      
        # Relation score.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Source and target entity indices. These are indices into the entity array in
        # the document. If this is an attribute relation the target is the index of a
        # measure in the document.
        # Corresponds to the JSON property `source`
        # @return [Fixnum]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `target`
        # @return [Fixnum]
        attr_accessor :target
      
        # Relation type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Relation type id.
        # Corresponds to the JSON property `typeId`
        # @return [Fixnum]
        attr_accessor :type_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @identifier = args[:identifier] if args.key?(:identifier)
          @info = args[:info] if args.key?(:info)
          @kind = args[:kind] if args.key?(:kind)
          @mention = args[:mention] if args.key?(:mention)
          @score = args[:score] if args.key?(:score)
          @source = args[:source] if args.key?(:source)
          @target = args[:target] if args.key?(:target)
          @type = args[:type] if args.key?(:type)
          @type_id = args[:type_id] if args.key?(:type_id)
        end
      end
      
      # Mentions of relations in the document. A relation mention is between a mention
      # of the source entity and a mention of the target entity.
      class NlpSaftRelationMention
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # Source and target mention indices. These are indices into the mention arrays
        # for their respective entities. The target is not used for attributes.
        # Corresponds to the JSON property `source`
        # @return [Fixnum]
        attr_accessor :source
      
        # The info of the source models or systems of the relation mention.
        # Corresponds to the JSON property `sourceInfo`
        # @return [Array<String>]
        attr_accessor :source_info
      
        # 
        # Corresponds to the JSON property `target`
        # @return [Fixnum]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @info = args[:info] if args.key?(:info)
          @phrase = args[:phrase] if args.key?(:phrase)
          @source = args[:source] if args.key?(:source)
          @source_info = args[:source_info] if args.key?(:source_info)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # Semantic node for annotating semantic constructions in documents. A set of
      # SemanticNode instances represents a directed acyclic graph with an adjacency
      # list representation. Each node can optionally be connected to some existing
      # type system, such as PropBank. Each node can optionally be connected to one or
      # more concrete elements in a SAFT document, specifically, an entity mention, a
      # measure and/or a token span (Phrase). Next available id: 23
      class NlpSaftSemanticNode
        include Google::Apis::Core::Hashable
      
        # The arcs from this node. For example, if this node is the root of a subgraph
        # representing a predicate-argument structure, this node will typically refer to
        # the predicate, and there will typically be one arc per argument.
        # Corresponds to the JSON property `arc`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSaftSemanticNodeArc>]
        attr_accessor :arc
      
        # Confidence score for the annotation.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Human-readable description of the information in the subgraph represented by
        # this node. This field is only meant for display purposes.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The entity and mention fields specify a unique entity mention referred to by
        # this semantic node.
        # Corresponds to the JSON property `entity`
        # @return [Fixnum]
        attr_accessor :entity
      
        # Indicates whether the semantic node is not explicit (grounded) in the text (e.
        # g. pro-drop for a text author or an implicit predicate node for interpreting a
        # compound noun), rather than any explicit phrase or text inside the document.
        # Corresponds to the JSON property `implicit`
        # @return [Boolean]
        attr_accessor :implicit
        alias_method :implicit?, :implicit
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Encodes the kind of this node and, possibly, the entire subgraph rooted at
        # this node. For example, if this node represents a predicate-argument structure
        # in PropBank, then this node's kind will be PROPBANK, its phrase field will be
        # set to correspond to the span of tokens corresponding to the predicate (such
        # as a verb) and it will have one arc per argument. If the kind is MONOTONIC
        # this node corresponds to a semantic graph node, and arcs correspond to
        # semantic graph edges outgoing from the node. If the kind field is not set,
        # then this node is not directly connected to any type system. In such a case,
        # this node may still optionally have a concrete "payload" in the form of
        # references to an entity mention, measure or span of tokens (Phrase) in a SAFT
        # document. The values or existence of the kind field need not be identical in
        # any subgraph. For example, even if this node's kind field is not set, it may
        # still be the destination node of an arc from some other node whose kind field
        # is set.
        # Corresponds to the JSON property `kind`
        # @return [String]
        attr_accessor :kind
      
        # The index of the measure referred to by this semantic node.
        # Corresponds to the JSON property `measure`
        # @return [Fixnum]
        attr_accessor :measure
      
        # 
        # Corresponds to the JSON property `mention`
        # @return [Fixnum]
        attr_accessor :mention
      
        # A document phrase marks a range of tokens in a document as a phrase. The
        # indices are token positions in the document.
        # Corresponds to the JSON property `phrase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftPhrase]
        attr_accessor :phrase
      
        # Arbitrary type string for this semantic node, or for the subgraph rooted at
        # this node. This type string might come from an external resource, type system
        # or ontology that contains a predefined set of types.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Arbitrary value string for this semantic node.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @arc = args[:arc] if args.key?(:arc)
          @confidence = args[:confidence] if args.key?(:confidence)
          @description = args[:description] if args.key?(:description)
          @entity = args[:entity] if args.key?(:entity)
          @implicit = args[:implicit] if args.key?(:implicit)
          @info = args[:info] if args.key?(:info)
          @kind = args[:kind] if args.key?(:kind)
          @measure = args[:measure] if args.key?(:measure)
          @mention = args[:mention] if args.key?(:mention)
          @phrase = args[:phrase] if args.key?(:phrase)
          @type = args[:type] if args.key?(:type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # An arc contained by a source node pointing to a destination node in a directed
      # acyclic graph.
      class NlpSaftSemanticNodeArc
        include Google::Apis::Core::Hashable
      
        # Human-readable description of this arc's type (for display purposes).
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Indicates the arc is for an implicit semantic relation between nodes, for
        # example one that does not correspond to a grammatical relation in the text.
        # Corresponds to the JSON property `implicit`
        # @return [Boolean]
        attr_accessor :implicit
        alias_method :implicit?, :implicit
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Index of the semantic node pointed to by this arc.
        # Corresponds to the JSON property `semanticNode`
        # @return [Fixnum]
        attr_accessor :semantic_node
      
        # Arc type (akin to an edge label, or semantic operator).
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @implicit = args[:implicit] if args.key?(:implicit)
          @info = args[:info] if args.key?(:info)
          @semantic_node = args[:semantic_node] if args.key?(:semantic_node)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A document token marks a span of bytes in the document text as a token or word.
      # Next available index: 16.
      class NlpSaftToken
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `breakLevel`
        # @return [String]
        attr_accessor :break_level
      
        # Whether the break skipped over non-tag text (excluding script/style).
        # Corresponds to the JSON property `breakSkippedText`
        # @return [Boolean]
        attr_accessor :break_skipped_text
        alias_method :break_skipped_text?, :break_skipped_text
      
        # Coarse-grained word category for token. See README.categories for category
        # inventory.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # Head of this token in the dependency tree: the id of the token which has an
        # arc going to this one. If it is the root token of a sentence, then it is set
        # to -1.
        # Corresponds to the JSON property `head`
        # @return [Fixnum]
        attr_accessor :head
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Label for dependency relation between this token and its head. See README.
        # labels for label inventory.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # Word lemma. This is only filled if the lemma is different from the word form.
        # Corresponds to the JSON property `lemma`
        # @return [String]
        attr_accessor :lemma
      
        # Message that stores information about the morphology of a token.
        # Corresponds to the JSON property `morph`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftMorphology]
        attr_accessor :morph
      
        # A string representation (typically four letters, sometimes longer) of the
        # token's Unicode script code, based on BCP 47/CLDR, capitalized according to
        # ISO 15924. See i18n/identifiers/scriptcode.h for details.
        # Corresponds to the JSON property `scriptCode`
        # @return [String]
        attr_accessor :script_code
      
        # [start, end] describe the inclusive byte range of the UTF-8 encoded token in
        # document.text. End gives the index of the last byte, which may be a UTF-8
        # continuation byte, and the length in bytes is end - start + 1. begin/end
        # options are for goldmine AnnotationsFinder to locate the offsets of saft
        # tokens. Start is inclusive by default and end is marked.
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        # Part-of-speech tag for token. See README.tags for tag inventory.
        # Corresponds to the JSON property `tag`
        # @return [String]
        attr_accessor :tag
      
        # Confidence score for the tag prediction -- should be interpreted as a
        # probability estimate that the tag is correct.
        # Corresponds to the JSON property `tagConfidence`
        # @return [Float]
        attr_accessor :tag_confidence
      
        # 
        # Corresponds to the JSON property `textProperties`
        # @return [Fixnum]
        attr_accessor :text_properties
      
        # Token word form. This may not be identical to the original. For example, in
        # goldmine annotation we do UTF-8 normalization and punctuation normalization.
        # The punctuation normalization includes inferring the directionality of
        # straight doublequotes -- that is, we map " to open quote (``) or close quote ('
        # '), and sometimes we get it wrong. SAFT processing in other contexts (such as
        # queries in qrewrite) involves different normalizations.
        # Corresponds to the JSON property `word`
        # @return [String]
        attr_accessor :word
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @break_level = args[:break_level] if args.key?(:break_level)
          @break_skipped_text = args[:break_skipped_text] if args.key?(:break_skipped_text)
          @category = args[:category] if args.key?(:category)
          @end = args[:end] if args.key?(:end)
          @head = args[:head] if args.key?(:head)
          @info = args[:info] if args.key?(:info)
          @label = args[:label] if args.key?(:label)
          @lemma = args[:lemma] if args.key?(:lemma)
          @morph = args[:morph] if args.key?(:morph)
          @script_code = args[:script_code] if args.key?(:script_code)
          @start = args[:start] if args.key?(:start)
          @tag = args[:tag] if args.key?(:tag)
          @tag_confidence = args[:tag_confidence] if args.key?(:tag_confidence)
          @text_properties = args[:text_properties] if args.key?(:text_properties)
          @word = args[:word] if args.key?(:word)
        end
      end
      
      # A copy of the text of an article along with references to internal figures and
      # external citations, datasets, etc. Next available ID: 19
      class NlpSciencelitArticleData
        include Google::Apis::Core::Hashable
      
        # Standard NLX data schema.
        # Corresponds to the JSON property `analyzedText`
        # @return [Google::Apis::ContentwarehouseV1::NlxDataSchemaScaleSet]
        attr_accessor :analyzed_text
      
        # 
        # Corresponds to the JSON property `articleId`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitArticleId>]
        attr_accessor :article_id
      
        # All references from this article (Bibliography).
        # Corresponds to the JSON property `citation`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitCitationData>]
        attr_accessor :citation
      
        # The result of selecting the earliest date from various metadata (PMC, PubMed
        # Metadata, scholar citations).
        # Corresponds to the JSON property `earliestPubDate`
        # @return [String]
        attr_accessor :earliest_pub_date
      
        # Next available ID: 20.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitArticleMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `nonAbstractWordCount`
        # @return [Fixnum]
        attr_accessor :non_abstract_word_count
      
        # Path of the source document from which this was parsed.
        # Corresponds to the JSON property `parsedFrom`
        # @return [String]
        attr_accessor :parsed_from
      
        # All dates from the PMC article metadata Year/Mon/Day.
        # Corresponds to the JSON property `pubDate`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitPubDate>]
        attr_accessor :pub_date
      
        # All figure captions within this article.
        # Corresponds to the JSON property `referencedBlock`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitReferencedBlock>]
        attr_accessor :referenced_block
      
        # Citation for this article.
        # Corresponds to the JSON property `scholarCitation`
        # @return [Google::Apis::ContentwarehouseV1::ScienceCitation]
        attr_accessor :scholar_citation
      
        # DocJoins with full text article.
        # Corresponds to the JSON property `scholarDocument`
        # @return [Array<Google::Apis::ContentwarehouseV1::CompositeDoc>]
        attr_accessor :scholar_document
      
        # May also add the Scholar index signal information:
        # Corresponds to the JSON property `scholarSignal`
        # @return [Google::Apis::ContentwarehouseV1::ScienceIndexSignal]
        attr_accessor :scholar_signal
      
        # Source of this article data (e.g., PubMed, scholar index, other source.).
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Number of words in the entire article and everywhere outside of abstract
        # sections.
        # Corresponds to the JSON property `wordCount`
        # @return [Fixnum]
        attr_accessor :word_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @analyzed_text = args[:analyzed_text] if args.key?(:analyzed_text)
          @article_id = args[:article_id] if args.key?(:article_id)
          @citation = args[:citation] if args.key?(:citation)
          @earliest_pub_date = args[:earliest_pub_date] if args.key?(:earliest_pub_date)
          @metadata = args[:metadata] if args.key?(:metadata)
          @non_abstract_word_count = args[:non_abstract_word_count] if args.key?(:non_abstract_word_count)
          @parsed_from = args[:parsed_from] if args.key?(:parsed_from)
          @pub_date = args[:pub_date] if args.key?(:pub_date)
          @referenced_block = args[:referenced_block] if args.key?(:referenced_block)
          @scholar_citation = args[:scholar_citation] if args.key?(:scholar_citation)
          @scholar_document = args[:scholar_document] if args.key?(:scholar_document)
          @scholar_signal = args[:scholar_signal] if args.key?(:scholar_signal)
          @source = args[:source] if args.key?(:source)
          @title = args[:title] if args.key?(:title)
          @word_count = args[:word_count] if args.key?(:word_count)
        end
      end
      
      # Article IDs associated with an article (e.g., PMID, DOI, PMC).
      class NlpSciencelitArticleId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `idType`
        # @return [String]
        attr_accessor :id_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @id_type = args[:id_type] if args.key?(:id_type)
        end
      end
      
      # Next available ID: 20.
      class NlpSciencelitArticleMetadata
        include Google::Apis::Core::Hashable
      
        # Tokenized text with optional original representation.
        # Corresponds to the JSON property `abstract`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitTokenizedText]
        attr_accessor :abstract
      
        # 
        # Corresponds to the JSON property `articleId`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitArticleId>]
        attr_accessor :article_id
      
        # Author of article.
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitAuthor>]
        attr_accessor :author
      
        # Datasets referenced from this article.
        # Corresponds to the JSON property `dataset`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitDataset>]
        attr_accessor :dataset
      
        # Most recent date YYYY-MM-DD.
        # Corresponds to the JSON property `dateStr`
        # @return [String]
        attr_accessor :date_str
      
        # Citation for flagged for deletion by source.
        # Corresponds to the JSON property `deleted`
        # @return [Boolean]
        attr_accessor :deleted
        alias_method :deleted?, :deleted
      
        # Mesh Terms.
        # Corresponds to the JSON property `heading`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitMeshHeading>]
        attr_accessor :heading
      
        # 
        # Corresponds to the JSON property `issue`
        # @return [String]
        attr_accessor :issue
      
        # Title of journal. For books: Journal = Publisher Volume = Collection
        # Corresponds to the JSON property `journal`
        # @return [String]
        attr_accessor :journal
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Last entry revision date YYYY-MM-DD.
        # Corresponds to the JSON property `lastRevisedDateStr`
        # @return [String]
        attr_accessor :last_revised_date_str
      
        # 
        # Corresponds to the JSON property `metadataSource`
        # @return [Array<String>]
        attr_accessor :metadata_source
      
        # Source Pubmed/Medline XML file.
        # Corresponds to the JSON property `parsedFrom`
        # @return [String]
        attr_accessor :parsed_from
      
        # PMID of article (for non-pubmed data, this is the docid).
        # Corresponds to the JSON property `pmid`
        # @return [String]
        attr_accessor :pmid
      
        # 
        # Corresponds to the JSON property `publicationType`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitPublicationType>]
        attr_accessor :publication_type
      
        # Optional ScaM restrict tokens to be added to all GFVs generated from this
        # article's data.
        # Corresponds to the JSON property `scamRestrictTokens`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamV3Restrict]
        attr_accessor :scam_restrict_tokens
      
        # Title of article.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # URL(s) for the document. If possible, order by decreasing desirability.
        # Corresponds to the JSON property `url`
        # @return [Array<String>]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `volume`
        # @return [String]
        attr_accessor :volume
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abstract = args[:abstract] if args.key?(:abstract)
          @article_id = args[:article_id] if args.key?(:article_id)
          @author = args[:author] if args.key?(:author)
          @dataset = args[:dataset] if args.key?(:dataset)
          @date_str = args[:date_str] if args.key?(:date_str)
          @deleted = args[:deleted] if args.key?(:deleted)
          @heading = args[:heading] if args.key?(:heading)
          @issue = args[:issue] if args.key?(:issue)
          @journal = args[:journal] if args.key?(:journal)
          @language = args[:language] if args.key?(:language)
          @last_revised_date_str = args[:last_revised_date_str] if args.key?(:last_revised_date_str)
          @metadata_source = args[:metadata_source] if args.key?(:metadata_source)
          @parsed_from = args[:parsed_from] if args.key?(:parsed_from)
          @pmid = args[:pmid] if args.key?(:pmid)
          @publication_type = args[:publication_type] if args.key?(:publication_type)
          @scam_restrict_tokens = args[:scam_restrict_tokens] if args.key?(:scam_restrict_tokens)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
          @volume = args[:volume] if args.key?(:volume)
        end
      end
      
      # 
      class NlpSciencelitAuthor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `firstName`
        # @return [String]
        attr_accessor :first_name
      
        # 
        # Corresponds to the JSON property `lastName`
        # @return [String]
        attr_accessor :last_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @first_name = args[:first_name] if args.key?(:first_name)
          @last_name = args[:last_name] if args.key?(:last_name)
        end
      end
      
      # Next available ID: 8
      class NlpSciencelitCitationData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `articleId`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitArticleId>]
        attr_accessor :article_id
      
        # 
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitAuthor>]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `externalLink`
        # @return [String]
        attr_accessor :external_link
      
        # 
        # Corresponds to the JSON property `fullText`
        # @return [String]
        attr_accessor :full_text
      
        # Reference used in text (e.g., PMC rid).
        # Corresponds to the JSON property `reference`
        # @return [String]
        attr_accessor :reference
      
        # Scholar citation information from scholar index.
        # Corresponds to the JSON property `scholarCitation`
        # @return [Google::Apis::ContentwarehouseV1::ScienceCitation]
        attr_accessor :scholar_citation
      
        # Optional information about the publication.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @article_id = args[:article_id] if args.key?(:article_id)
          @author = args[:author] if args.key?(:author)
          @external_link = args[:external_link] if args.key?(:external_link)
          @full_text = args[:full_text] if args.key?(:full_text)
          @reference = args[:reference] if args.key?(:reference)
          @scholar_citation = args[:scholar_citation] if args.key?(:scholar_citation)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class NlpSciencelitDataset
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `association`
        # @return [String]
        attr_accessor :association
      
        # A proto for storing inferred and reconciled metadata for Science Search. Next
        # available tag: 69
        # Corresponds to the JSON property `datasetMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchReconciledMetadata]
        attr_accessor :dataset_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @association = args[:association] if args.key?(:association)
          @dataset_metadata = args[:dataset_metadata] if args.key?(:dataset_metadata)
        end
      end
      
      # A full Mesh Heading containing a descriptor and optionally multiple qualifiers.
      # https://www.nlm.nih.gov/bsd/licensee/elements_descriptions.html#
      # meshheadinglist
      class NlpSciencelitMeshHeading
        include Google::Apis::Core::Hashable
      
        # A subject heading from Mesh
        # Corresponds to the JSON property `meshDescriptor`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitSubjectHeading]
        attr_accessor :mesh_descriptor
      
        # 
        # Corresponds to the JSON property `meshQualifier`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSciencelitSubjectHeading>]
        attr_accessor :mesh_qualifier
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mesh_descriptor = args[:mesh_descriptor] if args.key?(:mesh_descriptor)
          @mesh_qualifier = args[:mesh_qualifier] if args.key?(:mesh_qualifier)
        end
      end
      
      # Pubdate extracted from PMC article metadata.
      class NlpSciencelitPubDate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dateStr`
        # @return [String]
        attr_accessor :date_str
      
        # "ppub" for a print ISSN and "epub" for an electronic ISSN.
        # Corresponds to the JSON property `pubType`
        # @return [String]
        attr_accessor :pub_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_str = args[:date_str] if args.key?(:date_str)
          @pub_type = args[:pub_type] if args.key?(:pub_type)
        end
      end
      
      # 
      class NlpSciencelitPublicationType
        include Google::Apis::Core::Hashable
      
        # Display name for the publication type, e.g. "Journal Article"
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # MeSH unique identifiers for publication types, e.g. "D016428"
        # Corresponds to the JSON property `ui`
        # @return [String]
        attr_accessor :ui
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @ui = args[:ui] if args.key?(:ui)
        end
      end
      
      # Data associate with the ReferencesBlock. Next available ID: 5
      class NlpSciencelitReferencedBlock
        include Google::Apis::Core::Hashable
      
        # Tokenized text with optional original representation.
        # Corresponds to the JSON property `caption`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitTokenizedText]
        attr_accessor :caption
      
        # Reference used from the text to point to this figure.
        # Corresponds to the JSON property `reference`
        # @return [String]
        attr_accessor :reference
      
        # Tokenized text with optional original representation.
        # Corresponds to the JSON property `title`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitTokenizedText]
        attr_accessor :title
      
        # Type of figure (table, figure, etc.).
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @caption = args[:caption] if args.key?(:caption)
          @reference = args[:reference] if args.key?(:reference)
          @title = args[:title] if args.key?(:title)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class NlpSciencelitRetrievalQueryEncodingDebugInfo
        include Google::Apis::Core::Hashable
      
        # ===================================================================== #
        # GenericFeatureVector Last tag used: 23
        # Corresponds to the JSON property `scamQueryEncoding`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamGenericFeatureVector]
        attr_accessor :scam_query_encoding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @scam_query_encoding = args[:scam_query_encoding] if args.key?(:scam_query_encoding)
        end
      end
      
      # Returned by Delver API in SearchResult.debug_info.
      class NlpSciencelitRetrievalSearchResultDebugInfo
        include Google::Apis::Core::Hashable
      
        # A copy of the text of an article along with references to internal figures and
        # external citations, datasets, etc. Next available ID: 19
        # Corresponds to the JSON property `articleData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitArticleData]
        attr_accessor :article_data
      
        # 
        # Corresponds to the JSON property `goldDocid`
        # @return [Array<String>]
        attr_accessor :gold_docid
      
        # 
        # Corresponds to the JSON property `goldSnippets`
        # @return [Array<String>]
        attr_accessor :gold_snippets
      
        # Not set by server; only used by evals.
        # Corresponds to the JSON property `isGold`
        # @return [Boolean]
        attr_accessor :is_gold
        alias_method :is_gold?, :is_gold
      
        # See SearchResultInternal.reranking_score.
        # Corresponds to the JSON property `rerankingScore`
        # @return [Float]
        attr_accessor :reranking_score
      
        # See SearchResultInternal.reverse_reranking_order.
        # Corresponds to the JSON property `reverseRerankingOrder`
        # @return [Fixnum]
        attr_accessor :reverse_reranking_order
      
        # See SearchResultInternal.section_ir_score.
        # Corresponds to the JSON property `sectionIrScore`
        # @return [Hash<String,Float>]
        attr_accessor :section_ir_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @article_data = args[:article_data] if args.key?(:article_data)
          @gold_docid = args[:gold_docid] if args.key?(:gold_docid)
          @gold_snippets = args[:gold_snippets] if args.key?(:gold_snippets)
          @is_gold = args[:is_gold] if args.key?(:is_gold)
          @reranking_score = args[:reranking_score] if args.key?(:reranking_score)
          @reverse_reranking_order = args[:reverse_reranking_order] if args.key?(:reverse_reranking_order)
          @section_ir_score = args[:section_ir_score] if args.key?(:section_ir_score)
        end
      end
      
      # Optionally returned by Delver API in the response's debug_info field.
      class NlpSciencelitRetrievalSearchResultSetDebugInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `queryEncoding`
        # @return [Google::Apis::ContentwarehouseV1::NlpSciencelitRetrievalQueryEncodingDebugInfo]
        attr_accessor :query_encoding
      
        # Response to a query. The main result is the nearest neighbor list, but we also
        # optionally include debugging information if the appropriate field is set in
        # the request. Last used: 8
        # Corresponds to the JSON property `scamResponse`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamQueryResponse]
        attr_accessor :scam_response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @query_encoding = args[:query_encoding] if args.key?(:query_encoding)
          @scam_response = args[:scam_response] if args.key?(:scam_response)
        end
      end
      
      # Returned by Delver API in Snippet.debug_info.
      class NlpSciencelitRetrievalSnippetDebugInfo
        include Google::Apis::Core::Hashable
      
        # Which highlights have sentence overlap with gold snippets. Not ordered. Might
        # only be set for the first gold highlight.
        # Corresponds to the JSON property `goldHighlightSentenceIndices`
        # @return [Array<Fixnum>]
        attr_accessor :gold_highlight_sentence_indices
      
        # Map of highlight index to best overlap with any gold snippet [0,1].
        # Corresponds to the JSON property `highlightIdxToOverlap`
        # @return [Hash<String,Float>]
        attr_accessor :highlight_idx_to_overlap
      
        # Map of highlight index to best overlap with any gold sentence [0,1].
        # Corresponds to the JSON property `highlightIdxToSentenceOverlap`
        # @return [Hash<String,Float>]
        attr_accessor :highlight_idx_to_sentence_overlap
      
        # Not set by server; only used by certain evals. Might only be set for the first
        # gold snippet.
        # Corresponds to the JSON property `isGold`
        # @return [Boolean]
        attr_accessor :is_gold
        alias_method :is_gold?, :is_gold
      
        # Byte index of text within the full section text (or within title).
        # Corresponds to the JSON property `offsetWithinSection`
        # @return [Fixnum]
        attr_accessor :offset_within_section
      
        # Section within the document. -1 if title.
        # Corresponds to the JSON property `sectionIndex`
        # @return [Fixnum]
        attr_accessor :section_index
      
        # IR score of the section the snippet is coming from.
        # Corresponds to the JSON property `sectionIrScore`
        # @return [Float]
        attr_accessor :section_ir_score
      
        # BLEU score for the entire snippet.
        # Corresponds to the JSON property `snippetBleuScore`
        # @return [Float]
        attr_accessor :snippet_bleu_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gold_highlight_sentence_indices = args[:gold_highlight_sentence_indices] if args.key?(:gold_highlight_sentence_indices)
          @highlight_idx_to_overlap = args[:highlight_idx_to_overlap] if args.key?(:highlight_idx_to_overlap)
          @highlight_idx_to_sentence_overlap = args[:highlight_idx_to_sentence_overlap] if args.key?(:highlight_idx_to_sentence_overlap)
          @is_gold = args[:is_gold] if args.key?(:is_gold)
          @offset_within_section = args[:offset_within_section] if args.key?(:offset_within_section)
          @section_index = args[:section_index] if args.key?(:section_index)
          @section_ir_score = args[:section_ir_score] if args.key?(:section_ir_score)
          @snippet_bleu_score = args[:snippet_bleu_score] if args.key?(:snippet_bleu_score)
        end
      end
      
      # A subject heading from Mesh
      class NlpSciencelitSubjectHeading
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `majorTopic`
        # @return [Boolean]
        attr_accessor :major_topic
        alias_method :major_topic?, :major_topic
      
        # 
        # Corresponds to the JSON property `term`
        # @return [String]
        attr_accessor :term
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @major_topic = args[:major_topic] if args.key?(:major_topic)
          @term = args[:term] if args.key?(:term)
        end
      end
      
      # Tokenized text with optional original representation.
      class NlpSciencelitTokenizedText
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `token`
        # @return [Array<String>]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text = args[:text] if args.key?(:text)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # Annotators whose semantics are represented via a protocol message should add
      # to that message a field or extension of this type and set it using Annotator::
      # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
      # Evaluation is done based on token spans. The byte span aligns with the token
      # span and is used when saving examples. Background: In some settings, the
      # examples used to induce/train a grammar do not specify complete semantics of
      # an annotation. For example, some examples that come from Ewok specify only the
      # span associated with each annotation. This message allows evaluation metrics
      # to test the span by embedding it in the semantics. LINT.IfChange
      class NlpSemanticParsingAnnotationEvalData
        include Google::Apis::Core::Hashable
      
        # Additional spans after the first. Empty in all additional_spans.
        # Corresponds to the JSON property `additionalSpans`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData>]
        attr_accessor :additional_spans
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # 
        # Corresponds to the JSON property `numTokens`
        # @return [Fixnum]
        attr_accessor :num_tokens
      
        # Byte position within the utterance. Safe to use across different components of
        # the NLU stack as long as said components have access to the same query.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # Token position. This is cleared when normalizing examples for storage because
        # tokenization changes over time. DO NOT use these two fields across components
        # that use different tokenizations.
        # Corresponds to the JSON property `startToken`
        # @return [Fixnum]
        attr_accessor :start_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_spans = args[:additional_spans] if args.key?(:additional_spans)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @num_tokens = args[:num_tokens] if args.key?(:num_tokens)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @start_token = args[:start_token] if args.key?(:start_token)
        end
      end
      
      # The App annotator annotates potential app name in the parser's input and
      # outputs the proto with the details about app(s).
      class NlpSemanticParsingAppAnnotation
        include Google::Apis::Core::Hashable
      
        # The app_info is to store specific information about installed/uninstalled apps
        # annotated by app annotator servlet. It contains app name, package name,
        # confidence, and source.
        # Corresponds to the JSON property `appInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityActionsAppInfo>]
        attr_accessor :app_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app_info = args[:app_info] if args.key?(:app_info)
        end
      end
      
      # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
      # overlapping and unrelated annotations. One would have a start_date = Friday
      # and the other would have start_time = 9am. It's possible for Friday to be one
      # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
      class NlpSemanticParsingDateTimeAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dateType`
        # @return [String]
        attr_accessor :date_type
      
        # 
        # Corresponds to the JSON property `endDate`
        # @return [Array<String>]
        attr_accessor :end_date
      
        # 
        # Corresponds to the JSON property `endTime`
        # @return [Array<String>]
        attr_accessor :end_time
      
        # 
        # Corresponds to the JSON property `endWeekday`
        # @return [String]
        attr_accessor :end_weekday
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # NOTE: None of these are co-indexed. If the query is 'morning', there could be
        # multiple start_time's, start_date's, end_date's, and end_time's, and they do
        # not correspond to one another in any structured way.
        # Corresponds to the JSON property `startDate`
        # @return [Array<String>]
        attr_accessor :start_date
      
        # 
        # Corresponds to the JSON property `startTime`
        # @return [Array<String>]
        attr_accessor :start_time
      
        # 
        # Corresponds to the JSON property `startWeekday`
        # @return [String]
        attr_accessor :start_weekday
      
        # 
        # Corresponds to the JSON property `timeType`
        # @return [String]
        attr_accessor :time_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_type = args[:date_type] if args.key?(:date_type)
          @end_date = args[:end_date] if args.key?(:end_date)
          @end_time = args[:end_time] if args.key?(:end_time)
          @end_weekday = args[:end_weekday] if args.key?(:end_weekday)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @start_date = args[:start_date] if args.key?(:start_date)
          @start_time = args[:start_time] if args.key?(:start_time)
          @start_weekday = args[:start_weekday] if args.key?(:start_weekday)
          @time_type = args[:time_type] if args.key?(:time_type)
        end
      end
      
      # AbsoluteDateTime represents the resolved date/time expressions that need no
      # further calculation. It has a section for date and a section for time. The
      # date section will always be filled; if the time section is filled, hour is
      # always filled; for (minute, second, partial_second), they are optional with a
      # zero default value. But if partial_second is filled, (minute, second) must be
      # filled, even they are 0s; if second is filled, minute must be filled. Next
      # field#: 21.
      class NlpSemanticParsingDatetimeAbsoluteDateTime
        include Google::Apis::Core::Hashable
      
        # allow_personal determines if personal datetimes are allowed to be used in the
        # resolution of the personal datetime. If allow_personal is false and a personal
        # date exists, the entire parse will be thrown out.
        # Corresponds to the JSON property `allowPersonal`
        # @return [Boolean]
        attr_accessor :allow_personal
        alias_method :allow_personal?, :allow_personal
      
        # 
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # Deprecated fields. Do NOT use.
        # Corresponds to the JSON property `deleted11`
        # @return [String]
        attr_accessor :deleted11
      
        # List of holidays that are not fixed absolute or relative dates on the
        # Gregorian calendar.
        # Corresponds to the JSON property `holiday`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeHoliday]
        attr_accessor :holiday
      
        # Time is 24-hour military time.
        # Corresponds to the JSON property `hour`
        # @return [Fixnum]
        attr_accessor :hour
      
        # 
        # Corresponds to the JSON property `hourState`
        # @return [String]
        attr_accessor :hour_state
      
        # |is_bc| is true if and only the date is Before Christ/Common Era. If |is_bc|
        # is true, only year is meaningful in this proto, as Gregorian calendar is only
        # meaningful for A.D. date/times.
        # Corresponds to the JSON property `isBc`
        # @return [Boolean]
        attr_accessor :is_bc
        alias_method :is_bc?, :is_bc
      
        # 
        # Corresponds to the JSON property `minute`
        # @return [Fixnum]
        attr_accessor :minute
      
        # For expressions such as "around 2 pm".
        # Corresponds to the JSON property `modifier`
        # @return [String]
        attr_accessor :modifier
      
        # 
        # Corresponds to the JSON property `month`
        # @return [String]
        attr_accessor :month
      
        # Non-Gregorian dates are similar to AbsoluteDateTime, but use non-Gregorian
        # calendars.
        # Corresponds to the JSON property `nonGregorianDate`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeNonGregorianDate]
        attr_accessor :non_gregorian_date
      
        # 
        # Corresponds to the JSON property `partialSecond`
        # @return [Float]
        attr_accessor :partial_second
      
        # DateTimeProperty contains various metadata about the DateTime interpretation.
        # Next field: 13
        # Corresponds to the JSON property `properties`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTimeProperty]
        attr_accessor :properties
      
        # 
        # Corresponds to the JSON property `quarter`
        # @return [String]
        attr_accessor :quarter
      
        # Modifier that return the appropriate subrange. For more information, see the
        # description of RangeOfDateTimeModifier. Example: * *early* 2020 * *early* on
        # March 20th When a point have a range_modifier field, the resolution library
        # will expand the point into the widest range in contains. For example, in the
        # case of a single date point like "April 22nd, 2022", the point will be
        # transformed into a range with: - "begin: April 22nd 2022 00:00:00h" - "end:
        # April 22nd 2022 23:59:59h" The modifier will then be applied over that range.
        # Corresponds to the JSON property `rangeModifier`
        # @return [String]
        attr_accessor :range_modifier
      
        # 
        # Corresponds to the JSON property `season`
        # @return [String]
        attr_accessor :season
      
        # 
        # Corresponds to the JSON property `second`
        # @return [Fixnum]
        attr_accessor :second
      
        # A string representation of the timezone information, see i18n/identifiers/
        # timezones.`h,cc`.
        # Corresponds to the JSON property `timezone`
        # @return [String]
        attr_accessor :timezone
      
        # The |weekday| field is populated to indicate that a day-of-the-week is
        # explicitly mentioned in an absolute date utterance, such as [Tuesday, July 6th,
        # 2021]. Note that when a day-of-the-week is included in other, non-absolute-
        # date expressions, such as [on Tuesday], then this this field is not populated (
        # and in fact an AbsoluteDateTime is not used at all.) Note: This field is
        # populated only when the original expression contains a day-of-the-week. It is
        # not populated by the grounding library to indicate that the date happens to be
        # a Tuesday. Examples: * "Tuesday, July 6th 2021" --> the day of the week is
        # part of an absolute date expression, so this field is populated: point ` year:
        # 2021 month: JULY day: 6 weekday: TUESDAY ` * "on Tuesday" --> the day of the
        # week is not part of an absolute date expression, so it is interpreted as a
        # relative datetime: relative ` fetched ` target ` weekday: TUESDAY ` ` `
        # Corresponds to the JSON property `weekday`
        # @return [String]
        attr_accessor :weekday
      
        # Date.
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_personal = args[:allow_personal] if args.key?(:allow_personal)
          @day = args[:day] if args.key?(:day)
          @deleted11 = args[:deleted11] if args.key?(:deleted11)
          @holiday = args[:holiday] if args.key?(:holiday)
          @hour = args[:hour] if args.key?(:hour)
          @hour_state = args[:hour_state] if args.key?(:hour_state)
          @is_bc = args[:is_bc] if args.key?(:is_bc)
          @minute = args[:minute] if args.key?(:minute)
          @modifier = args[:modifier] if args.key?(:modifier)
          @month = args[:month] if args.key?(:month)
          @non_gregorian_date = args[:non_gregorian_date] if args.key?(:non_gregorian_date)
          @partial_second = args[:partial_second] if args.key?(:partial_second)
          @properties = args[:properties] if args.key?(:properties)
          @quarter = args[:quarter] if args.key?(:quarter)
          @range_modifier = args[:range_modifier] if args.key?(:range_modifier)
          @season = args[:season] if args.key?(:season)
          @second = args[:second] if args.key?(:second)
          @timezone = args[:timezone] if args.key?(:timezone)
          @weekday = args[:weekday] if args.key?(:weekday)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # The top-level DATE/TIME representation. It can represent either (1) one or
      # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
      # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
      # point| and |recurrent| will be set: |range| contains a list of resolved Date/
      # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
      # contains the representation for periodical dates/times. |range| and |point|
      # are repeated to accommodate the need when the date/time expression under one
      # non-terminal is resolved to a list of correct values. For example, "Mondays in
      # April, 2014" may have 4 correct dates.
      class NlpSemanticParsingDatetimeDateTime
        include Google::Apis::Core::Hashable
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `compositionElement`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :composition_element
      
        # Deprecated fields. Do NOT use.
        # Corresponds to the JSON property `deleted7`
        # @return [Boolean]
        attr_accessor :deleted7
        alias_method :deleted7?, :deleted7
      
        # 
        # Corresponds to the JSON property `deleted8`
        # @return [Boolean]
        attr_accessor :deleted8
        alias_method :deleted8?, :deleted8
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `groundingStage`
        # @return [String]
        attr_accessor :grounding_stage
      
        # 
        # Corresponds to the JSON property `point`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeAbsoluteDateTime>]
        attr_accessor :point
      
        # Encapsulates metadata about the query span resolved here.
        # Corresponds to the JSON property `properties`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeResolutionProperties]
        attr_accessor :properties
      
        # Note that there is a difference between this scenario and an ambiguous date/
        # time expression. The latter is resolved to multiple proto messages, not
        # multiple values within one proto message. To be concrete, consider "Monday" in
        # "Monday football". It is ambiguous and can be reasonably resolved to "Monday
        # last week," "Monday this week" and "Monday next week." The 3 values are
        # represented as 3 separate DateTime messages, not 3 values within one DateTime
        # message.
        # Corresponds to the JSON property `range`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRange>]
        attr_accessor :range
      
        # expressions: "every Monday after December 1" "every morning starting from this
        # Friday". Note: if a recurrent DATE/TIME expression is bounded (limited by a
        # finite interval or a finite count), e.g., "every monday in the next 3 months",
        # "... at 11:00am every Monday for 4 times" the grammar will resolve it to a
        # finite number of |range|s. Next available ID: 17.
        # Corresponds to the JSON property `recurrent`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRecurrent]
        attr_accessor :recurrent
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `relative`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :relative
      
        # The byte offset and text of a span.
        # Corresponds to the JSON property `span`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeSpan]
        attr_accessor :span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @composition_element = args[:composition_element] if args.key?(:composition_element)
          @deleted7 = args[:deleted7] if args.key?(:deleted7)
          @deleted8 = args[:deleted8] if args.key?(:deleted8)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @grounding_stage = args[:grounding_stage] if args.key?(:grounding_stage)
          @point = args[:point] if args.key?(:point)
          @properties = args[:properties] if args.key?(:properties)
          @range = args[:range] if args.key?(:range)
          @recurrent = args[:recurrent] if args.key?(:recurrent)
          @relative = args[:relative] if args.key?(:relative)
          @span = args[:span] if args.key?(:span)
        end
      end
      
      # DateTimeProperty contains various metadata about the DateTime interpretation.
      # Next field: 13
      class NlpSemanticParsingDatetimeDateTimeProperty
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dateFormat`
        # @return [String]
        attr_accessor :date_format
      
        # 
        # Corresponds to the JSON property `expandYearToCurrent`
        # @return [Boolean]
        attr_accessor :expand_year_to_current
        alias_method :expand_year_to_current?, :expand_year_to_current
      
        # 
        # Corresponds to the JSON property `hourStatus`
        # @return [String]
        attr_accessor :hour_status
      
        # 
        # Corresponds to the JSON property `inferredDateValue`
        # @return [String]
        attr_accessor :inferred_date_value
      
        # Note: this may be changed to a repeated field in the future.
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # General message used to store metadata about references to personal entities,
        # even if those entities cannot be resolved.
        # Corresponds to the JSON property `personalReferenceMetadata`
        # @return [Google::Apis::ContentwarehouseV1::CopleyPersonalReferenceMetadata]
        attr_accessor :personal_reference_metadata
      
        # 
        # Corresponds to the JSON property `relationToReference`
        # @return [String]
        attr_accessor :relation_to_reference
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `relative`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :relative
      
        # 
        # Corresponds to the JSON property `sourceCalendar`
        # @return [String]
        attr_accessor :source_calendar
      
        # If the annotation was created by using personal data, we record the provenance
        # for that data here.
        # Corresponds to the JSON property `sourceTypeList`
        # @return [Google::Apis::ContentwarehouseV1::CopleySourceTypeList]
        attr_accessor :source_type_list
      
        # 
        # Corresponds to the JSON property `timeFormat`
        # @return [Array<String>]
        attr_accessor :time_format
      
        # True iff the timezone value in AbsoluteDateTime is explicit in the annotated
        # text or not. In the following examples the timezone is explicit: Query
        # Timezone -------------------------- -------- 10pst Pacific Standard Time 10
        # utc UTC 10 sydney time Australia Eastern Time
        # Corresponds to the JSON property `timezoneIsExplicit`
        # @return [Boolean]
        attr_accessor :timezone_is_explicit
        alias_method :timezone_is_explicit?, :timezone_is_explicit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_format = args[:date_format] if args.key?(:date_format)
          @expand_year_to_current = args[:expand_year_to_current] if args.key?(:expand_year_to_current)
          @hour_status = args[:hour_status] if args.key?(:hour_status)
          @inferred_date_value = args[:inferred_date_value] if args.key?(:inferred_date_value)
          @metadata = args[:metadata] if args.key?(:metadata)
          @personal_reference_metadata = args[:personal_reference_metadata] if args.key?(:personal_reference_metadata)
          @relation_to_reference = args[:relation_to_reference] if args.key?(:relation_to_reference)
          @relative = args[:relative] if args.key?(:relative)
          @source_calendar = args[:source_calendar] if args.key?(:source_calendar)
          @source_type_list = args[:source_type_list] if args.key?(:source_type_list)
          @time_format = args[:time_format] if args.key?(:time_format)
          @timezone_is_explicit = args[:timezone_is_explicit] if args.key?(:timezone_is_explicit)
        end
      end
      
      # To represent unanchored durations - the length of a date/time expression not
      # related to calendar in local context. E.g., "play first (DURATION: 5 minutes)
      # of Yellow Submarine", "it takes (DURATION: more than 3 days) to finish." In
      # contrast, queries like: "wake me up in 5 minutes" will be resolved to a
      # AbsoluteDateTime since the query indicates that the reference is now. A
      # duration can be turned into a range if either end is anchored.
      class NlpSemanticParsingDatetimeDuration
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # For expressions such as "about 2 hrs".
        # Corresponds to the JSON property `modifier`
        # @return [String]
        attr_accessor :modifier
      
        # 
        # Corresponds to the JSON property `quantity`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeQuantity]
        attr_accessor :quantity
      
        # The byte offset and text of a span.
        # Corresponds to the JSON property `span`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeSpan]
        attr_accessor :span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @modifier = args[:modifier] if args.key?(:modifier)
          @quantity = args[:quantity] if args.key?(:quantity)
          @span = args[:span] if args.key?(:span)
        end
      end
      
      # This message is defined to be a representation of events that could interact
      # with datetimes expressions through composition by shifting or fetching. For "
      # native" datetime events like sunset, sunrise, etc the type is enough, but this
      # should be extended as needed to represent richer event information.
      class NlpSemanticParsingDatetimeEvent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `moonEvent`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeMoonEventInfo]
        attr_accessor :moon_event
      
        # 
        # Corresponds to the JSON property `sunEvent`
        # @return [String]
        attr_accessor :sun_event
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @moon_event = args[:moon_event] if args.key?(:moon_event)
          @sun_event = args[:sun_event] if args.key?(:sun_event)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # For a more detailed presentation on what's a fetching operation, see go/
      # datetime-meaning-schemas. Examples to illustrate how the proto is used: I.
      # Fetching day-of-weeks: a) query: "1st 2 Mondays of April" proto: ordinal: 1
      # target `weekday: MONDAY` count: 2 range: `begin `year: RESOLVED_YEAR month:
      # APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day: 30` b) query: "1st
      # and last Monday of April" proto: ordinal: 1 ordinal: -1 target `weekday:
      # MONDAY` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `year:
      # RESOLVED_YEAR month: APRIL day: 30` c) query: "next Monday" proto: ordinal: 1
      # target `weekday: MONDAY` d) query: "last 2 Mondays" proto: ordinal: -1 count:
      # 2 target `weekday: MONDAY` e) query: "this Monday" proto: ordinal: 0 target `
      # weekday: MONDAY` f) query: "the monday after next" proto: ordinal: 2 target `
      # weekday: MONDAY` g) query: "third Monday in April" proto: ordinal: 3 target `
      # weekday: MONDAY` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `
      # year: RESOLVED_YEAR month: APRIL day: 30` h) query: "the monday before last"
      # proto: ordinal: -2 target `weekday: MONDAY` i) query: "the second to the last
      # monday in April" proto: ordinal: -2 target `weekday: MONDAY` range: `begin `
      # year: RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month:
      # APRIL day: 30` II. Fetching date/time unit: a) query: "1st 2 weeks of April"
      # proto: ordinal: 1 target `unit: WEEK` count: 2 range: `begin `year:
      # RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day:
      # 30` b) query: "1st and last week of April" proto: ordinal: 1 ordinal: -1
      # target `unit: WEEK` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `
      # end `year: RESOLVED_YEAR month: APRIL day: 30` c) query: "next year" proto:
      # ordinal: 1 target `unit: YEAR` d) query: "last 2 weeks" proto: ordinal: -1
      # count: 2 target `unit: WEEK` e) query: "this month" proto: ordinal: 0 target `
      # unit: MONTH` f) query: "the week after next" proto: ordinal: 2 target `unit:
      # WEEK` g) query: "third week in April" proto: ordinal: 3 target `unit: WEEK`
      # range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `year:
      # RESOLVED_YEAR month: APRIL day: 30` h) query: "the week before last" proto:
      # ordinal: -2 target `unit: WEEK` i) query: "the second to the last week in
      # April" proto: ordinal: -2 target `unit: WEEK` range: `begin `year:
      # RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day:
      # 30` Next field: 9
      class NlpSemanticParsingDatetimeFetchedRelativeDateTime
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `baseType`
        # @return [String]
        attr_accessor :base_type
      
        # How many to fetch (e.g. [next weekend] vs. [next two weeks])
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Can be used to tag relative datetime expressions with metadata information in
        # the grammar.
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # Encodes expressions like next (+1), last (-1), after next (+2), this (0).
        # Corresponds to the JSON property `ordinal`
        # @return [Array<Fixnum>]
        attr_accessor :ordinal
      
        # Range has 4 use cases: 1. with an explicit begin and an explicit end, e.g. "
        # from Monday to Wednesday." Both |begin| and |end| are filled in this case. 2.
        # a point date/time expression is used as a range at a finer granularity. E.g.,
        # in "first Monday of this month", "this month" is used as a range. In this case,
        # only |begin| will be filled and the |end| will be filled during the grounding
        # process. 3. a fuzzy date/time range such as "morning" or "evening." 4. with a
        # relative begin and a relative end, e.g. "from yesterday to next Monday." Note:
        # this may be used in a mixture of exact/relative begin and end. Next available
        # ID: 14.
        # Corresponds to the JSON property `range`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRange]
        attr_accessor :range
      
        # Modifier that return the appropriate subrange. For more information, see the
        # description of RangeOfDateTimeModifier. Example: * *early* next week * *late*
        # next Monday
        # Corresponds to the JSON property `rangeModifier`
        # @return [String]
        attr_accessor :range_modifier
      
        # Encapsulates metadata about the query span resolved here.
        # Corresponds to the JSON property `relativeRange`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeResolutionProperties]
        attr_accessor :relative_range
      
        # Next field: 9
        # Corresponds to the JSON property `target`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeTargetToFetch]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_type = args[:base_type] if args.key?(:base_type)
          @count = args[:count] if args.key?(:count)
          @metadata = args[:metadata] if args.key?(:metadata)
          @ordinal = args[:ordinal] if args.key?(:ordinal)
          @range = args[:range] if args.key?(:range)
          @range_modifier = args[:range_modifier] if args.key?(:range_modifier)
          @relative_range = args[:relative_range] if args.key?(:relative_range)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # List of holidays that are not fixed absolute or relative dates on the
      # Gregorian calendar.
      class NlpSemanticParsingDatetimeHoliday
        include Google::Apis::Core::Hashable
      
        # There are 3 types of holidays supported by the datetime subgrammar: 1)
        # NonFixedHolidayEnum: e.g., "easter", "chinese new year". 2)
        # FetchedRelativeDateTime: e.g., "Thanksgiving" => [4th Thursday of November] 3)
        # HolidayByMonthDay: e.g., "xmas" => [December 25] Each holiday of the first
        # type is resolved by a C++ function; the 2nd and 3rd type of holidays are
        # mapped to AbsoluteDateTime and FetchedRelativeDateTime, respectively, in
        # grammar and are not needed to be represented in proto.
        # Corresponds to the JSON property `nonFixed`
        # @return [String]
        attr_accessor :non_fixed
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @non_fixed = args[:non_fixed] if args.key?(:non_fixed)
        end
      end
      
      # 
      class NlpSemanticParsingDatetimeMoonEventInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `phase`
        # @return [String]
        attr_accessor :phase
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @phase = args[:phase] if args.key?(:phase)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Non-Gregorian dates are similar to AbsoluteDateTime, but use non-Gregorian
      # calendars.
      class NlpSemanticParsingDatetimeNonGregorianDate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `chineseMonth`
        # @return [String]
        attr_accessor :chinese_month
      
        # The day is the offset within the month, same as in Gregorian calendars.
        # Corresponds to the JSON property `day`
        # @return [Fixnum]
        attr_accessor :day
      
        # 
        # Corresponds to the JSON property `hebrewMonth`
        # @return [String]
        attr_accessor :hebrew_month
      
        # 
        # Corresponds to the JSON property `islamicMonth`
        # @return [String]
        attr_accessor :islamic_month
      
        # The year is relative to the calendar (e.g. 5777 for Hebrew calendar).
        # Corresponds to the JSON property `year`
        # @return [Fixnum]
        attr_accessor :year
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chinese_month = args[:chinese_month] if args.key?(:chinese_month)
          @day = args[:day] if args.key?(:day)
          @hebrew_month = args[:hebrew_month] if args.key?(:hebrew_month)
          @islamic_month = args[:islamic_month] if args.key?(:islamic_month)
          @year = args[:year] if args.key?(:year)
        end
      end
      
      # 
      class NlpSemanticParsingDatetimeQuantity
        include Google::Apis::Core::Hashable
      
        # For internal use - DateTime subgrammar users should look at Duration.modifier.
        # = MORE in [3 more days].
        # Corresponds to the JSON property `modifier`
        # @return [String]
        attr_accessor :modifier
      
        # = 3 in "3 milliseconds".
        # Corresponds to the JSON property `number`
        # @return [Float]
        attr_accessor :number
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `numberSpan`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :number_span
      
        # Quantities are typically converted into milliseconds, regardless of the units
        # the user used. Sometimes this loses crucial information, e.g., "5 days" vs "5
        # nights". When quantities are converted to milliseconds, 'symbolic_quantity'
        # will contain the sequence of units that the user actually supplied. This can
        # be more than one element in cases like "one minute and 30 seconds". In cases
        # where 'symbolic_quantity' has more than one element, THERE IS NO GUARANTEED
        # ORDER between elements.
        # Corresponds to the JSON property `symbolicQuantity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeQuantity>]
        attr_accessor :symbolic_quantity
      
        # = MILLISECOND in "3 milliseconds".
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @modifier = args[:modifier] if args.key?(:modifier)
          @number = args[:number] if args.key?(:number)
          @number_span = args[:number_span] if args.key?(:number_span)
          @symbolic_quantity = args[:symbolic_quantity] if args.key?(:symbolic_quantity)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # Range has 4 use cases: 1. with an explicit begin and an explicit end, e.g. "
      # from Monday to Wednesday." Both |begin| and |end| are filled in this case. 2.
      # a point date/time expression is used as a range at a finer granularity. E.g.,
      # in "first Monday of this month", "this month" is used as a range. In this case,
      # only |begin| will be filled and the |end| will be filled during the grounding
      # process. 3. a fuzzy date/time range such as "morning" or "evening." 4. with a
      # relative begin and a relative end, e.g. "from yesterday to next Monday." Note:
      # this may be used in a mixture of exact/relative begin and end. Next available
      # ID: 14.
      class NlpSemanticParsingDatetimeRange
        include Google::Apis::Core::Hashable
      
        # AbsoluteDateTime represents the resolved date/time expressions that need no
        # further calculation. It has a section for date and a section for time. The
        # date section will always be filled; if the time section is filled, hour is
        # always filled; for (minute, second, partial_second), they are optional with a
        # zero default value. But if partial_second is filled, (minute, second) must be
        # filled, even they are 0s; if second is filled, minute must be filled. Next
        # field#: 21.
        # Corresponds to the JSON property `begin`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeAbsoluteDateTime]
        attr_accessor :begin
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `beginRelative`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :begin_relative
      
        # if |duration| is set, one field from start or finish must be populated, but
        # not both. |exclusive| value is still relevant to decide if the endpoints of
        # the range are included in the range (value defined in the start/finish fields
        # as well as the datetime value resulting of offseting the duration over the
        # given range endpoint).
        # Corresponds to the JSON property `duration`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeQuantity]
        attr_accessor :duration
      
        # AbsoluteDateTime represents the resolved date/time expressions that need no
        # further calculation. It has a section for date and a section for time. The
        # date section will always be filled; if the time section is filled, hour is
        # always filled; for (minute, second, partial_second), they are optional with a
        # zero default value. But if partial_second is filled, (minute, second) must be
        # filled, even they are 0s; if second is filled, minute must be filled. Next
        # field#: 21.
        # Corresponds to the JSON property `end`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeAbsoluteDateTime]
        attr_accessor :end
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `endRelative`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :end_relative
      
        # 
        # Corresponds to the JSON property `exclusive`
        # @return [Boolean]
        attr_accessor :exclusive
        alias_method :exclusive?, :exclusive
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `finish`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :finish
      
        # 
        # Corresponds to the JSON property `fuzzyRange`
        # @return [String]
        attr_accessor :fuzzy_range
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # Encapsulates metadata about the query span resolved here.
        # Corresponds to the JSON property `properties`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeResolutionProperties]
        attr_accessor :properties
      
        # Modifier that return the appropriate subrange. For more information, see the
        # description of RangeOfDateTimeModifier. Example: * *late* morning
        # Corresponds to the JSON property `rangeModifier`
        # @return [String]
        attr_accessor :range_modifier
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `start`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :start
      
        # The field is set if the range is the result of resolving/grounding a relative
        # datetime expression referring to a part of the day. E.g. "morning", "afternoon"
        # , "evening", "night", "tonight", etc.
        # Corresponds to the JSON property `symbolicValue`
        # @return [String]
        attr_accessor :symbolic_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @begin_relative = args[:begin_relative] if args.key?(:begin_relative)
          @duration = args[:duration] if args.key?(:duration)
          @end = args[:end] if args.key?(:end)
          @end_relative = args[:end_relative] if args.key?(:end_relative)
          @exclusive = args[:exclusive] if args.key?(:exclusive)
          @finish = args[:finish] if args.key?(:finish)
          @fuzzy_range = args[:fuzzy_range] if args.key?(:fuzzy_range)
          @metadata = args[:metadata] if args.key?(:metadata)
          @properties = args[:properties] if args.key?(:properties)
          @range_modifier = args[:range_modifier] if args.key?(:range_modifier)
          @start = args[:start] if args.key?(:start)
          @symbolic_value = args[:symbolic_value] if args.key?(:symbolic_value)
        end
      end
      
      # expressions: "every Monday after December 1" "every morning starting from this
      # Friday". Note: if a recurrent DATE/TIME expression is bounded (limited by a
      # finite interval or a finite count), e.g., "every monday in the next 3 months",
      # "... at 11:00am every Monday for 4 times" the grammar will resolve it to a
      # finite number of |range|s. Next available ID: 17.
      class NlpSemanticParsingDatetimeRecurrent
        include Google::Apis::Core::Hashable
      
        # How many times it repeats.
        # Corresponds to the JSON property `countRestriction`
        # @return [Fixnum]
        attr_accessor :count_restriction
      
        # An arbitrary exception to the recurrence. This can be an absolute point, a
        # relative, a range or a recurrent expression. Examples: * "every Tuesday except
        # for July 13th 2021" * "every Tuesday except for July 13th and November 2nd" * "
        # every second Monday except during the summer" * "everyday except Thursdays" * "
        # every Friday, except from October 1st to October 22nd"
        # Corresponds to the JSON property `exception`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime>]
        attr_accessor :exception
      
        # |frequency| is used to represent the frequency of the recurrence over a given
        # recurrent period. E.g. "twice a week", "once a month". An unknown frequency is
        # represented with 0, as in just "repeating".
        # Corresponds to the JSON property `frequency`
        # @return [Fixnum]
        attr_accessor :frequency
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # |period| and |unit| specify how often |start_point| or |start_range| repeats. |
        # period| should not be 0.
        # Corresponds to the JSON property `period`
        # @return [Fixnum]
        attr_accessor :period
      
        # Range has 4 use cases: 1. with an explicit begin and an explicit end, e.g. "
        # from Monday to Wednesday." Both |begin| and |end| are filled in this case. 2.
        # a point date/time expression is used as a range at a finer granularity. E.g.,
        # in "first Monday of this month", "this month" is used as a range. In this case,
        # only |begin| will be filled and the |end| will be filled during the grounding
        # process. 3. a fuzzy date/time range such as "morning" or "evening." 4. with a
        # relative begin and a relative end, e.g. "from yesterday to next Monday." Note:
        # this may be used in a mixture of exact/relative begin and end. Next available
        # ID: 14.
        # Corresponds to the JSON property `rangeRestriction`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRange]
        attr_accessor :range_restriction
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `relativeRangeRestriction`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :relative_range_restriction
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `restriction`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :restriction
      
        # |start| is used to represent the starting points, ranges or relative datetims
        # in a recurrent expression, for example: "every morning", (range) "everyday at
        # 5 pm", (point) "every second monday" (relative) |start| should never contain a
        # recurrent element.
        # Corresponds to the JSON property `start`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime>]
        attr_accessor :start
      
        # DO NOT USE: deprecated fields soon to be removed.
        # Corresponds to the JSON property `startPoint`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeAbsoluteDateTime>]
        attr_accessor :start_point
      
        # 
        # Corresponds to the JSON property `startRange`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRange>]
        attr_accessor :start_range
      
        # 
        # Corresponds to the JSON property `startRelative`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime>]
        attr_accessor :start_relative
      
        # Next field: 9
        # Corresponds to the JSON property `target`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeTargetToFetch]
        attr_accessor :target
      
        # |time_interval| is a time amount or duration, used to described the time
        # interval between the instances of the recurrence. (e.g. "every 3 hours", "
        # every 35 minutes", "every 2 months and 15 days", etc)
        # Corresponds to the JSON property `timeInterval`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeQuantity]
        attr_accessor :time_interval
      
        # 
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count_restriction = args[:count_restriction] if args.key?(:count_restriction)
          @exception = args[:exception] if args.key?(:exception)
          @frequency = args[:frequency] if args.key?(:frequency)
          @metadata = args[:metadata] if args.key?(:metadata)
          @period = args[:period] if args.key?(:period)
          @range_restriction = args[:range_restriction] if args.key?(:range_restriction)
          @relative_range_restriction = args[:relative_range_restriction] if args.key?(:relative_range_restriction)
          @restriction = args[:restriction] if args.key?(:restriction)
          @start = args[:start] if args.key?(:start)
          @start_point = args[:start_point] if args.key?(:start_point)
          @start_range = args[:start_range] if args.key?(:start_range)
          @start_relative = args[:start_relative] if args.key?(:start_relative)
          @target = args[:target] if args.key?(:target)
          @time_interval = args[:time_interval] if args.key?(:time_interval)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # This provides a semi-abstract description for relative datetime expressions. -
      # ShiftedRelativeDateTime encodes datetimes that arise from before/after
      # expressions (e.g. [three days ago], [2 days after March 1st]). -
      # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
      # (e.g. [next weekend], [the last two Mondays]). Next field: 5
      class NlpSemanticParsingDatetimeRelativeDateTime
        include Google::Apis::Core::Hashable
      
        # For a more detailed presentation on what's a fetching operation, see go/
        # datetime-meaning-schemas. Examples to illustrate how the proto is used: I.
        # Fetching day-of-weeks: a) query: "1st 2 Mondays of April" proto: ordinal: 1
        # target `weekday: MONDAY` count: 2 range: `begin `year: RESOLVED_YEAR month:
        # APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day: 30` b) query: "1st
        # and last Monday of April" proto: ordinal: 1 ordinal: -1 target `weekday:
        # MONDAY` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `year:
        # RESOLVED_YEAR month: APRIL day: 30` c) query: "next Monday" proto: ordinal: 1
        # target `weekday: MONDAY` d) query: "last 2 Mondays" proto: ordinal: -1 count:
        # 2 target `weekday: MONDAY` e) query: "this Monday" proto: ordinal: 0 target `
        # weekday: MONDAY` f) query: "the monday after next" proto: ordinal: 2 target `
        # weekday: MONDAY` g) query: "third Monday in April" proto: ordinal: 3 target `
        # weekday: MONDAY` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `
        # year: RESOLVED_YEAR month: APRIL day: 30` h) query: "the monday before last"
        # proto: ordinal: -2 target `weekday: MONDAY` i) query: "the second to the last
        # monday in April" proto: ordinal: -2 target `weekday: MONDAY` range: `begin `
        # year: RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month:
        # APRIL day: 30` II. Fetching date/time unit: a) query: "1st 2 weeks of April"
        # proto: ordinal: 1 target `unit: WEEK` count: 2 range: `begin `year:
        # RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day:
        # 30` b) query: "1st and last week of April" proto: ordinal: 1 ordinal: -1
        # target `unit: WEEK` range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `
        # end `year: RESOLVED_YEAR month: APRIL day: 30` c) query: "next year" proto:
        # ordinal: 1 target `unit: YEAR` d) query: "last 2 weeks" proto: ordinal: -1
        # count: 2 target `unit: WEEK` e) query: "this month" proto: ordinal: 0 target `
        # unit: MONTH` f) query: "the week after next" proto: ordinal: 2 target `unit:
        # WEEK` g) query: "third week in April" proto: ordinal: 3 target `unit: WEEK`
        # range: `begin `year: RESOLVED_YEAR month: APRIL day: 1` `end `year:
        # RESOLVED_YEAR month: APRIL day: 30` h) query: "the week before last" proto:
        # ordinal: -2 target `unit: WEEK` i) query: "the second to the last week in
        # April" proto: ordinal: -2 target `unit: WEEK` range: `begin `year:
        # RESOLVED_YEAR month: APRIL day: 1` `end `year: RESOLVED_YEAR month: APRIL day:
        # 30` Next field: 9
        # Corresponds to the JSON property `fetched`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeFetchedRelativeDateTime]
        attr_accessor :fetched
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # When a relative datetime which resolves into a range is being used as the
        # endpoint of a range (begin_relative/end_relative), its begin/end will be taken
        # accordingly unless this modifier indicates the opposite: begin_relative with
        # relative range and modifier == AFTER means that its end will be taken as the
        # beginning of the resulting range. Similarly, end_relative with a relative
        # range and modifier == BEFORE means that its begin will be taken as the end of
        # the resulting range. E.g. "after next month" will be a range with a
        # begin_relative that will take the end of "next month" as its starting point (
        # exclusive). values other than AFTER and BEFORE in the specific conditions
        # explained here will be ignored and have no effect in the resolution of
        # RelativeDateTimes.
        # Corresponds to the JSON property `modifier`
        # @return [String]
        attr_accessor :modifier
      
        # 
        # Corresponds to the JSON property `shifted`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeShiftedRelativeDateTime]
        attr_accessor :shifted
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fetched = args[:fetched] if args.key?(:fetched)
          @metadata = args[:metadata] if args.key?(:metadata)
          @modifier = args[:modifier] if args.key?(:modifier)
          @shifted = args[:shifted] if args.key?(:shifted)
        end
      end
      
      # Encapsulates metadata about the query span resolved here.
      class NlpSemanticParsingDatetimeResolutionProperties
        include Google::Apis::Core::Hashable
      
        # Simple enum container for exporting meridiem mentions.
        # Corresponds to the JSON property `meridiem`
        # @return [String]
        attr_accessor :meridiem
      
        # Encodes whether the datetime was phrased in a specific way, see enum above.
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # This provides a semi-abstract description for relative datetime expressions. -
        # ShiftedRelativeDateTime encodes datetimes that arise from before/after
        # expressions (e.g. [three days ago], [2 days after March 1st]). -
        # FetchedRelativeDateTime encodes expressions that are retrieval-type statements
        # (e.g. [next weekend], [the last two Mondays]). Next field: 5
        # Corresponds to the JSON property `relative`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeRelativeDateTime]
        attr_accessor :relative
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @meridiem = args[:meridiem] if args.key?(:meridiem)
          @metadata = args[:metadata] if args.key?(:metadata)
          @relative = args[:relative] if args.key?(:relative)
        end
      end
      
      # 
      class NlpSemanticParsingDatetimeShiftedRelativeDateTime
        include Google::Apis::Core::Hashable
      
        # AbsoluteDateTime represents the resolved date/time expressions that need no
        # further calculation. It has a section for date and a section for time. The
        # date section will always be filled; if the time section is filled, hour is
        # always filled; for (minute, second, partial_second), they are optional with a
        # zero default value. But if partial_second is filled, (minute, second) must be
        # filled, even they are 0s; if second is filled, minute must be filled. Next
        # field#: 21.
        # Corresponds to the JSON property `base`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeAbsoluteDateTime]
        attr_accessor :base
      
        # 
        # Corresponds to the JSON property `baseType`
        # @return [String]
        attr_accessor :base_type
      
        # Can be used to tag relative datetime expressions with metadata information in
        # the grammar.
        # Corresponds to the JSON property `metadata`
        # @return [String]
        attr_accessor :metadata
      
        # Encapsulates metadata about the query span resolved here.
        # Corresponds to the JSON property `relativeBase`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeResolutionProperties]
        attr_accessor :relative_base
      
        # 
        # Corresponds to the JSON property `shiftAmount`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeQuantity]
        attr_accessor :shift_amount
      
        # If true, shifting to the past; if false, shifting to the future.
        # Corresponds to the JSON property `shiftPast`
        # @return [Boolean]
        attr_accessor :shift_past
        alias_method :shift_past?, :shift_past
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base = args[:base] if args.key?(:base)
          @base_type = args[:base_type] if args.key?(:base_type)
          @metadata = args[:metadata] if args.key?(:metadata)
          @relative_base = args[:relative_base] if args.key?(:relative_base)
          @shift_amount = args[:shift_amount] if args.key?(:shift_amount)
          @shift_past = args[:shift_past] if args.key?(:shift_past)
        end
      end
      
      # The byte offset and text of a span.
      class NlpSemanticParsingDatetimeSpan
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # 0-based start byte offset of the span.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # The text of the span: a substring of ParserInput's canonical_input.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Next field: 9
      class NlpSemanticParsingDatetimeTargetToFetch
        include Google::Apis::Core::Hashable
      
        # This message is defined to be a representation of events that could interact
        # with datetimes expressions through composition by shifting or fetching. For "
        # native" datetime events like sunset, sunrise, etc the type is enough, but this
        # should be extended as needed to represent richer event information.
        # Corresponds to the JSON property `event`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeEvent]
        attr_accessor :event
      
        # 
        # Corresponds to the JSON property `fuzzyRange`
        # @return [String]
        attr_accessor :fuzzy_range
      
        # 
        # Corresponds to the JSON property `month`
        # @return [String]
        attr_accessor :month
      
        # 
        # Corresponds to the JSON property `quarter`
        # @return [String]
        attr_accessor :quarter
      
        # 
        # Corresponds to the JSON property `reference`
        # @return [String]
        attr_accessor :reference
      
        # 
        # Corresponds to the JSON property `season`
        # @return [String]
        attr_accessor :season
      
        # Unnamed target: "week", "month" etc. E.g., "1st week of April".
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        # Named target: only one of the following is expected.
        # Corresponds to the JSON property `weekday`
        # @return [Array<String>]
        attr_accessor :weekday
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event = args[:event] if args.key?(:event)
          @fuzzy_range = args[:fuzzy_range] if args.key?(:fuzzy_range)
          @month = args[:month] if args.key?(:month)
          @quarter = args[:quarter] if args.key?(:quarter)
          @reference = args[:reference] if args.key?(:reference)
          @season = args[:season] if args.key?(:season)
          @unit = args[:unit] if args.key?(:unit)
          @weekday = args[:weekday] if args.key?(:weekday)
        end
      end
      
      # 
      class NlpSemanticParsingDatetimeTimeZone
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `timezone`
        # @return [String]
        attr_accessor :timezone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @timezone = args[:timezone] if args.key?(:timezone)
        end
      end
      
      # 
      class NlpSemanticParsingEntitySourceData
        include Google::Apis::Core::Hashable
      
        # Indicates backends from which parts of an entity were retrieved.
        # Corresponds to the JSON property `entitySources`
        # @return [Array<String>]
        attr_accessor :entity_sources
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_sources = args[:entity_sources] if args.key?(:entity_sources)
        end
      end
      
      # Status indicating whether the user has finished expressing their intended
      # semantics during a streaming interaction. Semantics are partially expressed
      # when later, unprompted user input is expected to modify the semantics. Future
      # inputs are typically additional speech or continued modification of argument
      # text in form field. These inputs can trigger modifications including adding
      # arguments, changing the intent, or modifying existing arguments. Sensing this
      # status can be done both directly and indirectly. Fluid Actions directly
      # detects this status as the user moves between, or enters and leaves, argument
      # form fields. Understanding indirectly detects this status by the pace of the
      # user's speech, the semantics of the language, and the user's intonation. See
      # go/streaming-nlu-fulfilment-protocol-v1 for details about how it is used in
      # the Streaming NLU Fulfillment protocol.
      class NlpSemanticParsingExpressionStatus
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # A list of amenity constraints. There is an implicit AND relationship between
      # the different constraints.
      class NlpSemanticParsingLocalAmenities
        include Google::Apis::Core::Hashable
      
        # Applied amenity constraints. Nothing should be inferred about the ordering of
        # the values in this field.
        # Corresponds to the JSON property `type`
        # @return [Array<String>]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Conceptually this describes one location. Technically, this is a sequence of
      # location elements with the intention that at least one element in the sequence
      # is an actual location (rather than a modifier).
      class NlpSemanticParsingLocalBasicLocation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `element`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocationElement>]
        attr_accessor :element
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @element = args[:element] if args.key?(:element)
        end
      end
      
      # A high-level categorization of business types. Used for location elements that
      # are either BUSINESS_NAME or BUSINESS_CATEGORY. The business types roughly
      # correspond to QRef collections and should be interpreted broadly. E.g., hotel
      # also include motels, youth hostels, and guest houses; restaurants includes
      # bars and cafes, etc. Business types can be populated by QRef collections;
      # other population is done by grammar categories from local_categories.grammar.
      # It is expected that some business organizations will match more than one
      # business type. E.g., Safeway is both a grocery store and a pharmacy. Next ID:
      # 43 NOTE(oksana): LocalCategoryReliable grammar over-rides a few business type
      # queries to include hyper_reliable location element. If you change this, please
      # make sure that LocalCategoryReliable grammar reflects this too. LINT.IfChange
      class NlpSemanticParsingLocalBusinessType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `airline`
        # @return [Boolean]
        attr_accessor :airline
        alias_method :airline?, :airline
      
        # 
        # Corresponds to the JSON property `airport`
        # @return [Boolean]
        attr_accessor :airport
        alias_method :airport?, :airport
      
        # 
        # Corresponds to the JSON property `bank`
        # @return [Boolean]
        attr_accessor :bank
        alias_method :bank?, :bank
      
        # 
        # Corresponds to the JSON property `bikeSharingStation`
        # @return [Boolean]
        attr_accessor :bike_sharing_station
        alias_method :bike_sharing_station?, :bike_sharing_station
      
        # 
        # Corresponds to the JSON property `busStop`
        # @return [Boolean]
        attr_accessor :bus_stop
        alias_method :bus_stop?, :bus_stop
      
        # 
        # Corresponds to the JSON property `clothingStore`
        # @return [Boolean]
        attr_accessor :clothing_store
        alias_method :clothing_store?, :clothing_store
      
        # If the element implies a cuisine type then we include the gcid string when
        # available. Currently this happens for BUSINESS_CATEGORY type. The field is
        # repeated to model categories like "mandarin buffet restaurant" with multiple
        # cuisine gcid's: mandarin_restaurant and buffet_restaurant.
        # Corresponds to the JSON property `cuisineGcid`
        # @return [Array<String>]
        attr_accessor :cuisine_gcid
      
        # 
        # Corresponds to the JSON property `departmentStore`
        # @return [Boolean]
        attr_accessor :department_store
        alias_method :department_store?, :department_store
      
        # 
        # Corresponds to the JSON property `drugDropOff`
        # @return [Boolean]
        attr_accessor :drug_drop_off
        alias_method :drug_drop_off?, :drug_drop_off
      
        # 
        # Corresponds to the JSON property `electricVehicleChargingStation`
        # @return [Boolean]
        attr_accessor :electric_vehicle_charging_station
        alias_method :electric_vehicle_charging_station?, :electric_vehicle_charging_station
      
        # 
        # Corresponds to the JSON property `electronicStore`
        # @return [Boolean]
        attr_accessor :electronic_store
        alias_method :electronic_store?, :electronic_store
      
        # This field is used to determine the emergency type of the element, which is
        # specified by the grammar parse in (http://cs/file:googledata/localsearch/
        # quality/grammar/local_patterns.asciipb). e.g. "coronavirus_treatment_locations"
        # TODO(b/151330576) Deprecate the emergency field and replace with normal
        # triggering.
        # Corresponds to the JSON property `emergency`
        # @return [String]
        attr_accessor :emergency
      
        # 
        # Corresponds to the JSON property `foodPantry`
        # @return [Boolean]
        attr_accessor :food_pantry
        alias_method :food_pantry?, :food_pantry
      
        # 
        # Corresponds to the JSON property `gasStation`
        # @return [Boolean]
        attr_accessor :gas_station
        alias_method :gas_station?, :gas_station
      
        # 
        # Corresponds to the JSON property `groceryStore`
        # @return [Boolean]
        attr_accessor :grocery_store
        alias_method :grocery_store?, :grocery_store
      
        # 
        # Corresponds to the JSON property `hairdresser`
        # @return [Boolean]
        attr_accessor :hairdresser
        alias_method :hairdresser?, :hairdresser
      
        # 
        # Corresponds to the JSON property `hardwareStore`
        # @return [Boolean]
        attr_accessor :hardware_store
        alias_method :hardware_store?, :hardware_store
      
        # 
        # Corresponds to the JSON property `hospital`
        # @return [Boolean]
        attr_accessor :hospital
        alias_method :hospital?, :hospital
      
        # Also youth hostels, guest houses, etc.
        # Corresponds to the JSON property `hotel`
        # @return [Boolean]
        attr_accessor :hotel
        alias_method :hotel?, :hotel
      
        # 
        # Corresponds to the JSON property `parking`
        # @return [Boolean]
        attr_accessor :parking
        alias_method :parking?, :parking
      
        # 
        # Corresponds to the JSON property `petStore`
        # @return [Boolean]
        attr_accessor :pet_store
        alias_method :pet_store?, :pet_store
      
        # 
        # Corresponds to the JSON property `pharmacy`
        # @return [Boolean]
        attr_accessor :pharmacy
        alias_method :pharmacy?, :pharmacy
      
        # This is used for transit stations annotated by QRef. The transit_station
        # business_type above is only used for business categories, and therefore is
        # used downstream to find nearby stations rather than a particular station, and
        # so cannot be present in a Location that is a specific station from QRef. For
        # these cases, this business_type is used instead. e.g. "grand central" "
        # millbrae station" "union station" will have business_type qref_transit_station
        # Corresponds to the JSON property `qrefTransitStation`
        # @return [Boolean]
        attr_accessor :qref_transit_station
        alias_method :qref_transit_station?, :qref_transit_station
      
        # Also bars and cafes
        # Corresponds to the JSON property `restaurant`
        # @return [Boolean]
        attr_accessor :restaurant
        alias_method :restaurant?, :restaurant
      
        # 
        # Corresponds to the JSON property `retail`
        # @return [Boolean]
        attr_accessor :retail
        alias_method :retail?, :retail
      
        # Pre-k to high school
        # Corresponds to the JSON property `school`
        # @return [Boolean]
        attr_accessor :school
        alias_method :school?, :school
      
        # 
        # Corresponds to the JSON property `shoppingCenter`
        # @return [Boolean]
        attr_accessor :shopping_center
        alias_method :shopping_center?, :shopping_center
      
        # 
        # Corresponds to the JSON property `soupKitchen`
        # @return [Boolean]
        attr_accessor :soup_kitchen
        alias_method :soup_kitchen?, :soup_kitchen
      
        # 
        # Corresponds to the JSON property `sportStore`
        # @return [Boolean]
        attr_accessor :sport_store
        alias_method :sport_store?, :sport_store
      
        # 
        # Corresponds to the JSON property `subwayStation`
        # @return [Boolean]
        attr_accessor :subway_station
        alias_method :subway_station?, :subway_station
      
        # 
        # Corresponds to the JSON property `telecom`
        # @return [Boolean]
        attr_accessor :telecom
        alias_method :telecom?, :telecom
      
        # 
        # Corresponds to the JSON property `toyStore`
        # @return [Boolean]
        attr_accessor :toy_store
        alias_method :toy_store?, :toy_store
      
        # 
        # Corresponds to the JSON property `trainStation`
        # @return [Boolean]
        attr_accessor :train_station
        alias_method :train_station?, :train_station
      
        # A particular line in a transit system, e.g., "3 train", "Red Line", "Cirle
        # Line", etc.
        # Corresponds to the JSON property `transitLine`
        # @return [Boolean]
        attr_accessor :transit_line
        alias_method :transit_line?, :transit_line
      
        # Operator of a transit line, e.g., "MTA", "BART", "CTA", etc.
        # Corresponds to the JSON property `transitOperator`
        # @return [Boolean]
        attr_accessor :transit_operator
        alias_method :transit_operator?, :transit_operator
      
        # The different types of transit station business types will be used to figure
        # out which vehicle types to use when querying Tripfinder's SearchStations
        # service. The stations in that backend seem to be divided into HEAVY_RAIL,
        # SUBWAY, and TRAM. There isn't a very reliable division between intercity rail
        # and commuter rail -- Amtrak, LIRR, PATH, and NJ Transit are all classified as
        # HEAVY_RAIL. That's why in these types we make a distinction between train and
        # subway, and not train and muni_rail, (unlike TransitMode in the TravelAction
        # proto).
        # Corresponds to the JSON property `transitStation`
        # @return [Boolean]
        attr_accessor :transit_station
        alias_method :transit_station?, :transit_station
      
        # Also colleges
        # Corresponds to the JSON property `university`
        # @return [Boolean]
        attr_accessor :university
        alias_method :university?, :university
      
        # All of the vehicle types serviced by this business or business category. e.g.
        # VEHICLE_TYPE_RAIL and VEHICLE_TYPE__BUS for "transit stop". This allows
        # downstream to serve different result types for transit station categories in
        # different languages. e.g. In en-US "train station" seeks both railway station
        # and subway station results. But the equivalent word in French/Italian/German
        # seeks only railway stations.
        # Corresponds to the JSON property `vehicleType`
        # @return [Array<String>]
        attr_accessor :vehicle_type
      
        # Stadiums, theaters, cinemas, etc.
        # Corresponds to the JSON property `venue`
        # @return [Boolean]
        attr_accessor :venue
        alias_method :venue?, :venue
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @airline = args[:airline] if args.key?(:airline)
          @airport = args[:airport] if args.key?(:airport)
          @bank = args[:bank] if args.key?(:bank)
          @bike_sharing_station = args[:bike_sharing_station] if args.key?(:bike_sharing_station)
          @bus_stop = args[:bus_stop] if args.key?(:bus_stop)
          @clothing_store = args[:clothing_store] if args.key?(:clothing_store)
          @cuisine_gcid = args[:cuisine_gcid] if args.key?(:cuisine_gcid)
          @department_store = args[:department_store] if args.key?(:department_store)
          @drug_drop_off = args[:drug_drop_off] if args.key?(:drug_drop_off)
          @electric_vehicle_charging_station = args[:electric_vehicle_charging_station] if args.key?(:electric_vehicle_charging_station)
          @electronic_store = args[:electronic_store] if args.key?(:electronic_store)
          @emergency = args[:emergency] if args.key?(:emergency)
          @food_pantry = args[:food_pantry] if args.key?(:food_pantry)
          @gas_station = args[:gas_station] if args.key?(:gas_station)
          @grocery_store = args[:grocery_store] if args.key?(:grocery_store)
          @hairdresser = args[:hairdresser] if args.key?(:hairdresser)
          @hardware_store = args[:hardware_store] if args.key?(:hardware_store)
          @hospital = args[:hospital] if args.key?(:hospital)
          @hotel = args[:hotel] if args.key?(:hotel)
          @parking = args[:parking] if args.key?(:parking)
          @pet_store = args[:pet_store] if args.key?(:pet_store)
          @pharmacy = args[:pharmacy] if args.key?(:pharmacy)
          @qref_transit_station = args[:qref_transit_station] if args.key?(:qref_transit_station)
          @restaurant = args[:restaurant] if args.key?(:restaurant)
          @retail = args[:retail] if args.key?(:retail)
          @school = args[:school] if args.key?(:school)
          @shopping_center = args[:shopping_center] if args.key?(:shopping_center)
          @soup_kitchen = args[:soup_kitchen] if args.key?(:soup_kitchen)
          @sport_store = args[:sport_store] if args.key?(:sport_store)
          @subway_station = args[:subway_station] if args.key?(:subway_station)
          @telecom = args[:telecom] if args.key?(:telecom)
          @toy_store = args[:toy_store] if args.key?(:toy_store)
          @train_station = args[:train_station] if args.key?(:train_station)
          @transit_line = args[:transit_line] if args.key?(:transit_line)
          @transit_operator = args[:transit_operator] if args.key?(:transit_operator)
          @transit_station = args[:transit_station] if args.key?(:transit_station)
          @university = args[:university] if args.key?(:university)
          @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
          @venue = args[:venue] if args.key?(:venue)
        end
      end
      
      # ChainMemberConstraint for chain filtering enabled queries.
      class NlpSemanticParsingLocalChainMemberConstraint
        include Google::Apis::Core::Hashable
      
        # Specifies which parent chain mids to filter by.
        # Corresponds to the JSON property `chainIds`
        # @return [Array<String>]
        attr_accessor :chain_ids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chain_ids = args[:chain_ids] if args.key?(:chain_ids)
        end
      end
      
      # 
      class NlpSemanticParsingLocalCompoundLocation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `joiner`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalJoiner]
        attr_accessor :joiner
      
        # There are a few types of locations: - Basic locations are sequences of
        # location elements which can be either actual locations or modifiers. E.g., "
        # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
        # location), "CA" (an actual location, and "94040" (a numeric modifier). -
        # Compound locations: these are two locations combined by a joiner. E.g., "
        # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
        # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
        # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
        # indicates an area around a certain location. The area can be defined by time
        # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
        # a few miles from here". Next ID: 14
        # Corresponds to the JSON property `location1`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocation]
        attr_accessor :location1
      
        # There are a few types of locations: - Basic locations are sequences of
        # location elements which can be either actual locations or modifiers. E.g., "
        # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
        # location), "CA" (an actual location, and "94040" (a numeric modifier). -
        # Compound locations: these are two locations combined by a joiner. E.g., "
        # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
        # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
        # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
        # indicates an area around a certain location. The area can be defined by time
        # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
        # a few miles from here". Next ID: 14
        # Corresponds to the JSON property `location2`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocation]
        attr_accessor :location2
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @joiner = args[:joiner] if args.key?(:joiner)
          @location1 = args[:location1] if args.key?(:location1)
          @location2 = args[:location2] if args.key?(:location2)
        end
      end
      
      # Contact information for the |contact_location| field in LocationElement.
      class NlpSemanticParsingLocalContactLocation
        include Google::Apis::Core::Hashable
      
        # It can be a contact (person name), a business name, an email address or a
        # phone number. NOTE: Unfortunately the name of this message is not generic
        # enough. Contact would be a better name.
        # Corresponds to the JSON property `contact`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsCommunicationRecipient]
        attr_accessor :contact
      
        # The type of contact (mobile, home, work, etc). NOTE: Unfortunately the name of
        # this message is a misnomer. Contact type would be a better name.
        # Corresponds to the JSON property `contactType`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsCommunicationPhoneType]
        attr_accessor :contact_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact = args[:contact] if args.key?(:contact)
          @contact_type = args[:contact_type] if args.key?(:contact_type)
        end
      end
      
      # Constraint for cuisine type, such as "chinese", "italian", "thai", "burgers",
      # etc.
      class NlpSemanticParsingLocalCuisineConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cuisineGcid`
        # @return [String]
        attr_accessor :cuisine_gcid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cuisine_gcid = args[:cuisine_gcid] if args.key?(:cuisine_gcid)
        end
      end
      
      # There is an implicit AND relation if multiple EVCS constraint types are
      # specified.
      class NlpSemanticParsingLocalEvChargingStationSpeedConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `chargingSpeed`
        # @return [String]
        attr_accessor :charging_speed
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @charging_speed = args[:charging_speed] if args.key?(:charging_speed)
        end
      end
      
      # 
      class NlpSemanticParsingLocalExtent
        include Google::Apis::Core::Hashable
      
        # True for values like "a few".
        # Corresponds to the JSON property `nonSpecificValue`
        # @return [Boolean]
        attr_accessor :non_specific_value
        alias_method :non_specific_value?, :non_specific_value
      
        # 
        # Corresponds to the JSON property `units`
        # @return [String]
        attr_accessor :units
      
        # String representation, e.g., for debug.
        # Corresponds to the JSON property `unitsString`
        # @return [String]
        attr_accessor :units_string
      
        # For approximate values such as "a few" or "several", we populate |value| with
        # a specific numeric value which is a generous (i.e., high) interpretation of
        # the text, and we set |non_specific_value| to true.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        # Can hold numbers as well as "a few".
        # Corresponds to the JSON property `valueString`
        # @return [String]
        attr_accessor :value_string
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @non_specific_value = args[:non_specific_value] if args.key?(:non_specific_value)
          @units = args[:units] if args.key?(:units)
          @units_string = args[:units_string] if args.key?(:units_string)
          @value = args[:value] if args.key?(:value)
          @value_string = args[:value_string] if args.key?(:value_string)
        end
      end
      
      # 
      class NlpSemanticParsingLocalGcidConstraint
        include Google::Apis::Core::Hashable
      
        # GCID - with the 'gcid:' prefix.
        # Corresponds to the JSON property `gcid`
        # @return [String]
        attr_accessor :gcid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcid = args[:gcid] if args.key?(:gcid)
        end
      end
      
      # Hotel Type used by the hotels team to differentiate sub classes of
      # accommodations. For any questions please contact hotel-search-quality@. Next
      # ID: 48
      class NlpSemanticParsingLocalHotelType
        include Google::Apis::Core::Hashable
      
        # Basic accommodation types variations.
        # Corresponds to the JSON property `allInclusiveResort`
        # @return [Boolean]
        attr_accessor :all_inclusive_resort
        alias_method :all_inclusive_resort?, :all_inclusive_resort
      
        # 
        # Corresponds to the JSON property `beachResort`
        # @return [Boolean]
        attr_accessor :beach_resort
        alias_method :beach_resort?, :beach_resort
      
        # 
        # Corresponds to the JSON property `bedAndBreakfast`
        # @return [Boolean]
        attr_accessor :bed_and_breakfast
        alias_method :bed_and_breakfast?, :bed_and_breakfast
      
        # 
        # Corresponds to the JSON property `boutiqueHotel`
        # @return [Boolean]
        attr_accessor :boutique_hotel
        alias_method :boutique_hotel?, :boutique_hotel
      
        # 
        # Corresponds to the JSON property `businessHotel`
        # @return [Boolean]
        attr_accessor :business_hotel
        alias_method :business_hotel?, :business_hotel
      
        # Other accommodation types.
        # Corresponds to the JSON property `cabin`
        # @return [Boolean]
        attr_accessor :cabin
        alias_method :cabin?, :cabin
      
        # 
        # Corresponds to the JSON property `campsite`
        # @return [Boolean]
        attr_accessor :campsite
        alias_method :campsite?, :campsite
      
        # 
        # Corresponds to the JSON property `capsuleHotel`
        # @return [Boolean]
        attr_accessor :capsule_hotel
        alias_method :capsule_hotel?, :capsule_hotel
      
        # 
        # Corresponds to the JSON property `casinoAccommodation`
        # @return [Boolean]
        attr_accessor :casino_accommodation
        alias_method :casino_accommodation?, :casino_accommodation
      
        # 
        # Corresponds to the JSON property `castleHotel`
        # @return [Boolean]
        attr_accessor :castle_hotel
        alias_method :castle_hotel?, :castle_hotel
      
        # 
        # Corresponds to the JSON property `chalet`
        # @return [Boolean]
        attr_accessor :chalet
        alias_method :chalet?, :chalet
      
        # 
        # Corresponds to the JSON property `commonLodgingHouse`
        # @return [Boolean]
        attr_accessor :common_lodging_house
        alias_method :common_lodging_house?, :common_lodging_house
      
        # 
        # Corresponds to the JSON property `condoHotel`
        # @return [Boolean]
        attr_accessor :condo_hotel
        alias_method :condo_hotel?, :condo_hotel
      
        # 
        # Corresponds to the JSON property `conventionHotel`
        # @return [Boolean]
        attr_accessor :convention_hotel
        alias_method :convention_hotel?, :convention_hotel
      
        # 
        # Corresponds to the JSON property `cottage`
        # @return [Boolean]
        attr_accessor :cottage
        alias_method :cottage?, :cottage
      
        # 
        # Corresponds to the JSON property `ecoHotel`
        # @return [Boolean]
        attr_accessor :eco_hotel
        alias_method :eco_hotel?, :eco_hotel
      
        # 
        # Corresponds to the JSON property `extendedStayHotel`
        # @return [Boolean]
        attr_accessor :extended_stay_hotel
        alias_method :extended_stay_hotel?, :extended_stay_hotel
      
        # 
        # Corresponds to the JSON property `farmstay`
        # @return [Boolean]
        attr_accessor :farmstay
        alias_method :farmstay?, :farmstay
      
        # 
        # Corresponds to the JSON property `gite`
        # @return [Boolean]
        attr_accessor :gite
        alias_method :gite?, :gite
      
        # 
        # Corresponds to the JSON property `golfResort`
        # @return [Boolean]
        attr_accessor :golf_resort
        alias_method :golf_resort?, :golf_resort
      
        # 
        # Corresponds to the JSON property `guestRanch`
        # @return [Boolean]
        attr_accessor :guest_ranch
        alias_method :guest_ranch?, :guest_ranch
      
        # 
        # Corresponds to the JSON property `guesthouse`
        # @return [Boolean]
        attr_accessor :guesthouse
        alias_method :guesthouse?, :guesthouse
      
        # 
        # Corresponds to the JSON property `hostel`
        # @return [Boolean]
        attr_accessor :hostel
        alias_method :hostel?, :hostel
      
        # Basic accommodation types.
        # Corresponds to the JSON property `hotel`
        # @return [Boolean]
        attr_accessor :hotel
        alias_method :hotel?, :hotel
      
        # 
        # Corresponds to the JSON property `houseboat`
        # @return [Boolean]
        attr_accessor :houseboat
        alias_method :houseboat?, :houseboat
      
        # 
        # Corresponds to the JSON property `inn`
        # @return [Boolean]
        attr_accessor :inn
        alias_method :inn?, :inn
      
        # Japanese accommodation types.
        # Corresponds to the JSON property `japaneseInn`
        # @return [Boolean]
        attr_accessor :japanese_inn
        alias_method :japanese_inn?, :japanese_inn
      
        # 
        # Corresponds to the JSON property `japaneseInnWithHotSpring`
        # @return [Boolean]
        attr_accessor :japanese_inn_with_hot_spring
        alias_method :japanese_inn_with_hot_spring?, :japanese_inn_with_hot_spring
      
        # 
        # Corresponds to the JSON property `lodge`
        # @return [Boolean]
        attr_accessor :lodge
        alias_method :lodge?, :lodge
      
        # 
        # Corresponds to the JSON property `lodging`
        # @return [Boolean]
        attr_accessor :lodging
        alias_method :lodging?, :lodging
      
        # 
        # Corresponds to the JSON property `loveHotel`
        # @return [Boolean]
        attr_accessor :love_hotel
        alias_method :love_hotel?, :love_hotel
      
        # 
        # Corresponds to the JSON property `motel`
        # @return [Boolean]
        attr_accessor :motel
        alias_method :motel?, :motel
      
        # 
        # Corresponds to the JSON property `mountainHut`
        # @return [Boolean]
        attr_accessor :mountain_hut
        alias_method :mountain_hut?, :mountain_hut
      
        # Any other lodging related type.
        # Corresponds to the JSON property `other`
        # @return [Boolean]
        attr_accessor :other
        alias_method :other?, :other
      
        # 
        # Corresponds to the JSON property `pension`
        # @return [Boolean]
        attr_accessor :pension
        alias_method :pension?, :pension
      
        # 
        # Corresponds to the JSON property `resort`
        # @return [Boolean]
        attr_accessor :resort
        alias_method :resort?, :resort
      
        # 
        # Corresponds to the JSON property `safariLodge`
        # @return [Boolean]
        attr_accessor :safari_lodge
        alias_method :safari_lodge?, :safari_lodge
      
        # 
        # Corresponds to the JSON property `seasideResort`
        # @return [Boolean]
        attr_accessor :seaside_resort
        alias_method :seaside_resort?, :seaside_resort
      
        # 
        # Corresponds to the JSON property `servicedApartment`
        # @return [Boolean]
        attr_accessor :serviced_apartment
        alias_method :serviced_apartment?, :serviced_apartment
      
        # 
        # Corresponds to the JSON property `skiResort`
        # @return [Boolean]
        attr_accessor :ski_resort
        alias_method :ski_resort?, :ski_resort
      
        # 
        # Corresponds to the JSON property `suite`
        # @return [Boolean]
        attr_accessor :suite
        alias_method :suite?, :suite
      
        # 
        # Corresponds to the JSON property `vacationApartment`
        # @return [Boolean]
        attr_accessor :vacation_apartment
        alias_method :vacation_apartment?, :vacation_apartment
      
        # 
        # Corresponds to the JSON property `vacationHouse`
        # @return [Boolean]
        attr_accessor :vacation_house
        alias_method :vacation_house?, :vacation_house
      
        # Vacation rental accommodation types.
        # Corresponds to the JSON property `vacationRental`
        # @return [Boolean]
        attr_accessor :vacation_rental
        alias_method :vacation_rental?, :vacation_rental
      
        # 
        # Corresponds to the JSON property `villa`
        # @return [Boolean]
        attr_accessor :villa
        alias_method :villa?, :villa
      
        # 
        # Corresponds to the JSON property `wellnessAndSpaAccommodation`
        # @return [Boolean]
        attr_accessor :wellness_and_spa_accommodation
        alias_method :wellness_and_spa_accommodation?, :wellness_and_spa_accommodation
      
        # 
        # Corresponds to the JSON property `youthHostel`
        # @return [Boolean]
        attr_accessor :youth_hostel
        alias_method :youth_hostel?, :youth_hostel
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_inclusive_resort = args[:all_inclusive_resort] if args.key?(:all_inclusive_resort)
          @beach_resort = args[:beach_resort] if args.key?(:beach_resort)
          @bed_and_breakfast = args[:bed_and_breakfast] if args.key?(:bed_and_breakfast)
          @boutique_hotel = args[:boutique_hotel] if args.key?(:boutique_hotel)
          @business_hotel = args[:business_hotel] if args.key?(:business_hotel)
          @cabin = args[:cabin] if args.key?(:cabin)
          @campsite = args[:campsite] if args.key?(:campsite)
          @capsule_hotel = args[:capsule_hotel] if args.key?(:capsule_hotel)
          @casino_accommodation = args[:casino_accommodation] if args.key?(:casino_accommodation)
          @castle_hotel = args[:castle_hotel] if args.key?(:castle_hotel)
          @chalet = args[:chalet] if args.key?(:chalet)
          @common_lodging_house = args[:common_lodging_house] if args.key?(:common_lodging_house)
          @condo_hotel = args[:condo_hotel] if args.key?(:condo_hotel)
          @convention_hotel = args[:convention_hotel] if args.key?(:convention_hotel)
          @cottage = args[:cottage] if args.key?(:cottage)
          @eco_hotel = args[:eco_hotel] if args.key?(:eco_hotel)
          @extended_stay_hotel = args[:extended_stay_hotel] if args.key?(:extended_stay_hotel)
          @farmstay = args[:farmstay] if args.key?(:farmstay)
          @gite = args[:gite] if args.key?(:gite)
          @golf_resort = args[:golf_resort] if args.key?(:golf_resort)
          @guest_ranch = args[:guest_ranch] if args.key?(:guest_ranch)
          @guesthouse = args[:guesthouse] if args.key?(:guesthouse)
          @hostel = args[:hostel] if args.key?(:hostel)
          @hotel = args[:hotel] if args.key?(:hotel)
          @houseboat = args[:houseboat] if args.key?(:houseboat)
          @inn = args[:inn] if args.key?(:inn)
          @japanese_inn = args[:japanese_inn] if args.key?(:japanese_inn)
          @japanese_inn_with_hot_spring = args[:japanese_inn_with_hot_spring] if args.key?(:japanese_inn_with_hot_spring)
          @lodge = args[:lodge] if args.key?(:lodge)
          @lodging = args[:lodging] if args.key?(:lodging)
          @love_hotel = args[:love_hotel] if args.key?(:love_hotel)
          @motel = args[:motel] if args.key?(:motel)
          @mountain_hut = args[:mountain_hut] if args.key?(:mountain_hut)
          @other = args[:other] if args.key?(:other)
          @pension = args[:pension] if args.key?(:pension)
          @resort = args[:resort] if args.key?(:resort)
          @safari_lodge = args[:safari_lodge] if args.key?(:safari_lodge)
          @seaside_resort = args[:seaside_resort] if args.key?(:seaside_resort)
          @serviced_apartment = args[:serviced_apartment] if args.key?(:serviced_apartment)
          @ski_resort = args[:ski_resort] if args.key?(:ski_resort)
          @suite = args[:suite] if args.key?(:suite)
          @vacation_apartment = args[:vacation_apartment] if args.key?(:vacation_apartment)
          @vacation_house = args[:vacation_house] if args.key?(:vacation_house)
          @vacation_rental = args[:vacation_rental] if args.key?(:vacation_rental)
          @villa = args[:villa] if args.key?(:villa)
          @wellness_and_spa_accommodation = args[:wellness_and_spa_accommodation] if args.key?(:wellness_and_spa_accommodation)
          @youth_hostel = args[:youth_hostel] if args.key?(:youth_hostel)
        end
      end
      
      # Message containing information about hyper-reliable categories. go/local-hyper-
      # reliable
      class NlpSemanticParsingLocalHyperReliableData
        include Google::Apis::Core::Hashable
      
        # Whether a location is a commodity (distance is an important metric), neutral
        # or non-commodity (distance is not important). Commodity locations are "atm", "
        # gas station", etc. Non-commodity locations are "restaurant", "hotel", etc, and
        # all others are neutral. The value is 1 for commodity queries, 0 for non-
        # commodity queries, no-value for neutral queries (when the field doesn't exist
        # in the grammar). The reason it is a float is to prepare for future changes
        # when we expand the signal value from discrete classes to a score, and the
        # score will be in the range of [0,1].
        # Corresponds to the JSON property `commodityStrength`
        # @return [Float]
        attr_accessor :commodity_strength
      
        # 
        # Corresponds to the JSON property `gcidsynsOverride`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalHyperReliableDataGcidSynsOverride>]
        attr_accessor :gcidsyns_override
      
        # 
        # Corresponds to the JSON property `hyperReliable`
        # @return [Boolean]
        attr_accessor :hyper_reliable
        alias_method :hyper_reliable?, :hyper_reliable
      
        # Categories used for retrieval and used in Artemis diversity tiers as restricts.
        # See https://ariane.googleplex.com/launch/190585 for details.
        # Corresponds to the JSON property `retrievalGcids`
        # @return [Array<String>]
        attr_accessor :retrieval_gcids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @commodity_strength = args[:commodity_strength] if args.key?(:commodity_strength)
          @gcidsyns_override = args[:gcidsyns_override] if args.key?(:gcidsyns_override)
          @hyper_reliable = args[:hyper_reliable] if args.key?(:hyper_reliable)
          @retrieval_gcids = args[:retrieval_gcids] if args.key?(:retrieval_gcids)
        end
      end
      
      # Set only when hyper_reliable is true. These are gcids and scores for hyper-
      # reliable categories in ariane/182060. These are overridden for a few hyper-
      # reliable categories, and may not be present everywhere.
      class NlpSemanticParsingLocalHyperReliableDataGcidSynsOverride
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `gcidScore`
        # @return [Float]
        attr_accessor :gcid_score
      
        # 
        # Corresponds to the JSON property `hyperReliableGcid`
        # @return [String]
        attr_accessor :hyper_reliable_gcid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gcid_score = args[:gcid_score] if args.key?(:gcid_score)
          @hyper_reliable_gcid = args[:hyper_reliable_gcid] if args.key?(:hyper_reliable_gcid)
        end
      end
      
      # Flags indiciating the specific implicit intent, e.g. dining, travel, etc. Next
      # ID = 13
      class NlpSemanticParsingLocalImplicitLocalCategory
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `airport`
        # @return [Boolean]
        attr_accessor :airport
        alias_method :airport?, :airport
      
        # 
        # Corresponds to the JSON property `bank`
        # @return [Boolean]
        attr_accessor :bank
        alias_method :bank?, :bank
      
        # 
        # Corresponds to the JSON property `chargingStation`
        # @return [Boolean]
        attr_accessor :charging_station
        alias_method :charging_station?, :charging_station
      
        # 
        # Corresponds to the JSON property `gasStation`
        # @return [Boolean]
        attr_accessor :gas_station
        alias_method :gas_station?, :gas_station
      
        # 
        # Corresponds to the JSON property `gym`
        # @return [Boolean]
        attr_accessor :gym
        alias_method :gym?, :gym
      
        # 
        # Corresponds to the JSON property `hairSalon`
        # @return [Boolean]
        attr_accessor :hair_salon
        alias_method :hair_salon?, :hair_salon
      
        # 
        # Corresponds to the JSON property `hospital`
        # @return [Boolean]
        attr_accessor :hospital
        alias_method :hospital?, :hospital
      
        # 
        # Corresponds to the JSON property `hotel`
        # @return [Boolean]
        attr_accessor :hotel
        alias_method :hotel?, :hotel
      
        # 
        # Corresponds to the JSON property `laundromat`
        # @return [Boolean]
        attr_accessor :laundromat
        alias_method :laundromat?, :laundromat
      
        # 
        # Corresponds to the JSON property `movieTheater`
        # @return [Boolean]
        attr_accessor :movie_theater
        alias_method :movie_theater?, :movie_theater
      
        # 
        # Corresponds to the JSON property `postOffice`
        # @return [Boolean]
        attr_accessor :post_office
        alias_method :post_office?, :post_office
      
        # 
        # Corresponds to the JSON property `spa`
        # @return [Boolean]
        attr_accessor :spa
        alias_method :spa?, :spa
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @airport = args[:airport] if args.key?(:airport)
          @bank = args[:bank] if args.key?(:bank)
          @charging_station = args[:charging_station] if args.key?(:charging_station)
          @gas_station = args[:gas_station] if args.key?(:gas_station)
          @gym = args[:gym] if args.key?(:gym)
          @hair_salon = args[:hair_salon] if args.key?(:hair_salon)
          @hospital = args[:hospital] if args.key?(:hospital)
          @hotel = args[:hotel] if args.key?(:hotel)
          @laundromat = args[:laundromat] if args.key?(:laundromat)
          @movie_theater = args[:movie_theater] if args.key?(:movie_theater)
          @post_office = args[:post_office] if args.key?(:post_office)
          @spa = args[:spa] if args.key?(:spa)
        end
      end
      
      # 
      class NlpSemanticParsingLocalJoiner
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # 
        # Corresponds to the JSON property `numBytesForConversion`
        # @return [Fixnum]
        attr_accessor :num_bytes_for_conversion
      
        # The raw input span corresponding to this joiner.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # Byte data added for conversion between this proto and IntentQuery in
        # LooseParser. Must not be used for downstream triggering.
        # Corresponds to the JSON property `startByteForConversion`
        # @return [Fixnum]
        attr_accessor :start_byte_for_conversion
      
        # The original joiner string from the tokenized query. Particularly important if
        # the type is OTHER.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @num_bytes_for_conversion = args[:num_bytes_for_conversion] if args.key?(:num_bytes_for_conversion)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @start_byte_for_conversion = args[:start_byte_for_conversion] if args.key?(:start_byte_for_conversion)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This message holds all info the local assistant team will need to lookup a
      # LocalResult in search.
      class NlpSemanticParsingLocalLocalResultId
        include Google::Apis::Core::Hashable
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # The full address of the result. This should be a verbose address string that
        # geocodes reliably.
        # Corresponds to the JSON property `geocodingAddress`
        # @return [String]
        attr_accessor :geocoding_address
      
        # The knowledge graph reference of the result.
        # Corresponds to the JSON property `kgMid`
        # @return [String]
        attr_accessor :kg_mid
      
        # The position of the result.
        # Corresponds to the JSON property `position`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :position
      
        # A latitude-longitude rectangle, represented as two diagonally opposite points "
        # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
        # includes its boundary. The latitude bounds must be in the range -90 to 90
        # degrees inclusive, and the longitude bounds must be in the range -180 to 180
        # degrees inclusive. Various cases include: - If lo == hi, the rectangle
        # consists of a single point. - If lo.longitude > hi.longitude, the longitude
        # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
        # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
        # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
        # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
        # latitude range is empty.
        # Corresponds to the JSON property `rect`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRectProto]
        attr_accessor :rect
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @geocoding_address = args[:geocoding_address] if args.key?(:geocoding_address)
          @kg_mid = args[:kg_mid] if args.key?(:kg_mid)
          @position = args[:position] if args.key?(:position)
          @rect = args[:rect] if args.key?(:rect)
        end
      end
      
      # There are a few types of locations: - Basic locations are sequences of
      # location elements which can be either actual locations or modifiers. E.g., "
      # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
      # location), "CA" (an actual location, and "94040" (a numeric modifier). -
      # Compound locations: these are two locations combined by a joiner. E.g., "
      # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
      # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
      # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
      # indicates an area around a certain location. The area can be defined by time
      # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
      # a few miles from here". Next ID: 14
      class NlpSemanticParsingLocalLocation
        include Google::Apis::Core::Hashable
      
        # Conceptually this describes one location. Technically, this is a sequence of
        # location elements with the intention that at least one element in the sequence
        # is an actual location (rather than a modifier).
        # Corresponds to the JSON property `basicLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalBasicLocation]
        attr_accessor :basic_location
      
        # 
        # Corresponds to the JSON property `compoundLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalCompoundLocation]
        attr_accessor :compound_location
      
        # Contact information for the |contact_location| field in LocationElement.
        # Corresponds to the JSON property `contactLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalContactLocation]
        attr_accessor :contact_location
      
        # True if the location is merged, for example by CombineLocationsFn.
        # Corresponds to the JSON property `isMerged`
        # @return [Boolean]
        attr_accessor :is_merged
        alias_method :is_merged?, :is_merged
      
        # The constraint includes various constraints on the location such as amenities,
        # price range, ratings, or attributes such as new, cheap, etc. These constraints
        # are a part of the location but are not modeled as location elements and are
        # not included in the location text. The (debatable) motivation is that they do
        # not stand on their own and are not an intrinsic part of the location. Note on
        # texts and spans. For a location such as "kid friendly hotels with an indoor
        # pool" we expect to get a basic location with a single location element and two
        # constraints: - For the location element: - Both text and span match "hotels" -
        # For the first constraint: - Both text and span match "kid friendly" - For the
        # second constraint: - Both text and span match "indoor pool" - For the full
        # location: - text: "hotels" - span covers "kid friendly hotels with an indoor
        # pool"
        # Corresponds to the JSON property `locationConstraint`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocationConstraint>]
        attr_accessor :location_constraint
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # A generic representation of a local result returned by a local backend. Next
        # ID: 33
        # Corresponds to the JSON property `resolvedLocalResult`
        # @return [Google::Apis::ContentwarehouseV1::QualityDialogManagerLocalResult]
        attr_accessor :resolved_local_result
      
        # The span, in the raw input, which corresponds to this location, expressed as a
        # byte offset and byte size. This allows the extraction of the location string
        # as it appears in the raw text.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # A string representation of the location. Depending on the annotators and the
        # location itself the string may represent the raw query, the pre-processed
        # query, or something else. As a non-trivial example, for [target address
        # mountain view] we will generate the text "target mountain view" without "
        # address". We make a best-effort to come up with a good string, but make no
        # formal guarantees. You should never present this text directly to outside
        # users.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # A user specified location to trigger weather for a specific location. Also it
        # can be generalized for other verticals.
        # Corresponds to the JSON property `userSpecifiedLocation`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeVerticalsWeatherProtoUserSpecifiedLocation]
        attr_accessor :user_specified_location
      
        # 
        # Corresponds to the JSON property `vicinityLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalVicinityLocation]
        attr_accessor :vicinity_location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @basic_location = args[:basic_location] if args.key?(:basic_location)
          @compound_location = args[:compound_location] if args.key?(:compound_location)
          @contact_location = args[:contact_location] if args.key?(:contact_location)
          @is_merged = args[:is_merged] if args.key?(:is_merged)
          @location_constraint = args[:location_constraint] if args.key?(:location_constraint)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @resolved_local_result = args[:resolved_local_result] if args.key?(:resolved_local_result)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @text = args[:text] if args.key?(:text)
          @user_specified_location = args[:user_specified_location] if args.key?(:user_specified_location)
          @vicinity_location = args[:vicinity_location] if args.key?(:vicinity_location)
        end
      end
      
      # All the possible location constraints. This message is associated with a
      # location and can be nested accordingly. E.g., for a compound location the
      # constraint may be associated with the entire location or with either of the
      # two internal locations (loc_1 and loc_2). There is an implicit AND relation
      # between the different constraints. Next ID: 23.
      class NlpSemanticParsingLocalLocationConstraint
        include Google::Apis::Core::Hashable
      
        # A list of amenity constraints. There is an implicit AND relationship between
        # the different constraints.
        # Corresponds to the JSON property `amenities`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalAmenities]
        attr_accessor :amenities
      
        # ChainMemberConstraint for chain filtering enabled queries.
        # Corresponds to the JSON property `chainMember`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalChainMemberConstraint]
        attr_accessor :chain_member
      
        # Constraint for cuisine type, such as "chinese", "italian", "thai", "burgers",
        # etc.
        # Corresponds to the JSON property `cuisine`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalCuisineConstraint]
        attr_accessor :cuisine
      
        # There is an implicit AND relation if multiple EVCS constraint types are
        # specified.
        # Corresponds to the JSON property `evcsSpeedConstraint`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalEvChargingStationSpeedConstraint]
        attr_accessor :evcs_speed_constraint
      
        # Used for GCID filter. Unlike other grammar, for now this is populated in
        # Superroot (currently based on QBLD classification, and an allowlist of GCID).
        # Corresponds to the JSON property `gcidConstraint`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalGcidConstraint]
        attr_accessor :gcid_constraint
      
        # Message containing information about hyper-reliable categories. go/local-hyper-
        # reliable
        # Corresponds to the JSON property `hyperReliableData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalHyperReliableData]
        attr_accessor :hyper_reliable_data
      
        # Specifies intent that corresponds to a menu item which is used as a location
        # constraint, e.g. [restaurants that serve thai curry] or as a standalone
        # categorical element, e.g. [thai curry].
        # Corresponds to the JSON property `menuItem`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalMenuItem]
        attr_accessor :menu_item
      
        # 
        # Corresponds to the JSON property `new`
        # @return [Boolean]
        attr_accessor :new
        alias_method :new?, :new
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # 
        # Corresponds to the JSON property `open24Hours`
        # @return [Boolean]
        attr_accessor :open24_hours
        alias_method :open24_hours?, :open24_hours
      
        # 
        # Corresponds to the JSON property `price`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalPriceConstraint]
        attr_accessor :price
      
        # Quality constraints about the establishment. In the future we can add to this
        # message Zagat ratings, user reviews, etc. Next ID: 6.
        # Corresponds to the JSON property `quality`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalQualityConstraint]
        attr_accessor :quality
      
        # Constraints for the occupancy of a hotel or vacation rental.
        # Corresponds to the JSON property `rooms`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalRoomConstraint]
        attr_accessor :rooms
      
        # Specifies intent that corresponds to a scalable attribute. This may be used as
        # a location constraint, e.g. [restaurants with outdoor seating] or as a
        # standalone categorical element, e.g. [happy hour] or [happy hour ny]. See go/
        # scalable-attributes for details about scalable attributes. NOTE(oksana):
        # LocalCategoryReliable grammar over-rides a few scalable attribute queries to
        # include hyper_reliable location element. If you change this, please make sure
        # that LocalCategoryReliable grammar reflects this too. LINT.IfChange This ID
        # corresponds to the id field in //geostore/attributes/proto/config.proto:
        # AttributeConfigProto This field holds the human readable ID for the KG topic
        # that represents the attribute. Example: "/geo/type/establishment_poi/
        # serves_breakfast"
        # Corresponds to the JSON property `scalableAttribute`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalScalableAttribute]
        attr_accessor :scalable_attribute
      
        # 
        # Corresponds to the JSON property `service`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalServiceConstraint]
        attr_accessor :service
      
        # The span, in the raw input, which corresponds to this constraint, expressed as
        # a byte offset and byte size.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Experimental, may change.
        # Corresponds to the JSON property `ungroundedConstraint`
        # @return [Boolean]
        attr_accessor :ungrounded_constraint
        alias_method :ungrounded_constraint?, :ungrounded_constraint
      
        # Used to remove all constraints, e.g. [forget all the filters]
        # Corresponds to the JSON property `unspecified`
        # @return [Boolean]
        attr_accessor :unspecified
        alias_method :unspecified?, :unspecified
      
        # Used for vaccine refinement: go/covid-vaccine-refinement.
        # Corresponds to the JSON property `vaccineType`
        # @return [String]
        attr_accessor :vaccine_type
      
        # Constraint for visited, as in if a location has been visited before.
        # Corresponds to the JSON property `visitHistory`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalVisitHistoryConstraint]
        attr_accessor :visit_history
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amenities = args[:amenities] if args.key?(:amenities)
          @chain_member = args[:chain_member] if args.key?(:chain_member)
          @cuisine = args[:cuisine] if args.key?(:cuisine)
          @evcs_speed_constraint = args[:evcs_speed_constraint] if args.key?(:evcs_speed_constraint)
          @gcid_constraint = args[:gcid_constraint] if args.key?(:gcid_constraint)
          @hyper_reliable_data = args[:hyper_reliable_data] if args.key?(:hyper_reliable_data)
          @menu_item = args[:menu_item] if args.key?(:menu_item)
          @new = args[:new] if args.key?(:new)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @open24_hours = args[:open24_hours] if args.key?(:open24_hours)
          @price = args[:price] if args.key?(:price)
          @quality = args[:quality] if args.key?(:quality)
          @rooms = args[:rooms] if args.key?(:rooms)
          @scalable_attribute = args[:scalable_attribute] if args.key?(:scalable_attribute)
          @service = args[:service] if args.key?(:service)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @text = args[:text] if args.key?(:text)
          @ungrounded_constraint = args[:ungrounded_constraint] if args.key?(:ungrounded_constraint)
          @unspecified = args[:unspecified] if args.key?(:unspecified)
          @vaccine_type = args[:vaccine_type] if args.key?(:vaccine_type)
          @visit_history = args[:visit_history] if args.key?(:visit_history)
        end
      end
      
      # Next ID: 26
      class NlpSemanticParsingLocalLocationElement
        include Google::Apis::Core::Hashable
      
        # For elements with a NICKNAME alias location, this field will hold all matching
        # alias icons, which are used in search to resolve the location.
        # Corresponds to the JSON property `aliasIcon`
        # @return [Array<Google::Apis::ContentwarehouseV1::PersonalizationMapsAliasIcon>]
        attr_accessor :alias_icon
      
        # The following fields (alias_location, qref_location, and saft_location) should
        # have at most one non-empty value between them.
        # Corresponds to the JSON property `aliasLocation`
        # @return [String]
        attr_accessor :alias_location
      
        # A high-level categorization of business types. Used for location elements that
        # are either BUSINESS_NAME or BUSINESS_CATEGORY. The business types roughly
        # correspond to QRef collections and should be interpreted broadly. E.g., hotel
        # also include motels, youth hostels, and guest houses; restaurants includes
        # bars and cafes, etc. Business types can be populated by QRef collections;
        # other population is done by grammar categories from local_categories.grammar.
        # It is expected that some business organizations will match more than one
        # business type. E.g., Safeway is both a grocery store and a pharmacy. Next ID:
        # 43 NOTE(oksana): LocalCategoryReliable grammar over-rides a few business type
        # queries to include hyper_reliable location element. If you change this, please
        # make sure that LocalCategoryReliable grammar reflects this too. LINT.IfChange
        # Corresponds to the JSON property `businessType`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalBusinessType]
        attr_accessor :business_type
      
        # Contact information for the |contact_location| field in LocationElement.
        # Corresponds to the JSON property `contactLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalContactLocation]
        attr_accessor :contact_location
      
        # This will hold semantics from the dialog_referents subgrammar with offsets and
        # indices relating to a list of results shown to the user. This field is
        # repeated while in the future we could support multiple item list selection. i.
        # e. [the starbucks] where multiple entries in the results will be indicated
        # here
        # Corresponds to the JSON property `dialogReferents`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDialogReferentsDialogReferents>]
        attr_accessor :dialog_referents
      
        # Set only when type is DIRECTIONAL_MODIFIER.
        # Corresponds to the JSON property `directionalModifier`
        # @return [String]
        attr_accessor :directional_modifier
      
        # DEPRECATED. See basic_location.element.type == LOCATION_REFERENT to determine
        # this instead. Populated by a type VISITED local action, this field is used to
        # indicate a location element is a general-case $PT_visited_location string.
        # Corresponds to the JSON property `genericLocation`
        # @return [Boolean]
        attr_accessor :generic_location
        alias_method :generic_location?, :generic_location
      
        # Hotel Type used by the hotels team to differentiate sub classes of
        # accommodations. For any questions please contact hotel-search-quality@. Next
        # ID: 48
        # Corresponds to the JSON property `hotelType`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalHotelType]
        attr_accessor :hotel_type
      
        # Message containing information about hyper-reliable categories. go/local-hyper-
        # reliable
        # Corresponds to the JSON property `hyperReliableData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalHyperReliableData]
        attr_accessor :hyper_reliable_data
      
        # Flags indiciating the specific implicit intent, e.g. dining, travel, etc. Next
        # ID = 13
        # Corresponds to the JSON property `implicitLocalCategory`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalImplicitLocalCategory]
        attr_accessor :implicit_local_category
      
        # This message holds all info the local assistant team will need to lookup a
        # LocalResult in search.
        # Corresponds to the JSON property `localResultId`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocalResultId]
        attr_accessor :local_result_id
      
        # 
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # Represents zip codes, street numbers, etc. that were detected directly by the
        # grammar (and not, e.g., by QRef). DEPRECATED. We ran into problems with zip
        # codes having leading zeroes. Now we store numbers only in the text field.
        # Corresponds to the JSON property `number`
        # @return [Fixnum]
        attr_accessor :number
      
        # A collection of any number of QRefAnnotations that designate a Copley Personal
        # Reference and its Resolutions. This is used to handle personalized intents
        # such as "navigate to my hotel" or "when is my mom's anniversary". See go/
        # copley. This Annotation may contain only a reference with no resolutions for
        # the failure case (go/copley-punts). TODO(bhorst) Rename this to remove the
        # Copley codename.
        # Corresponds to the JSON property `personalReferenceLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingPersonalReferenceAnnotation]
        attr_accessor :personal_reference_location
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qrefLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref_location
      
        # SaftMentionAnnotation(s) are used to identify a sub-span of the input with
        # some semantic relevance, for example PER (Person), LOC (Locations) or measure
        # etc. Each SaftMentionAnnotation will have exactly one non-empty field.
        # Corresponds to the JSON property `saftLocation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingSaftMentionAnnotation]
        attr_accessor :saft_location
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The byte span, in the raw query, which corresponds to this location element.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # A string representation of the location element. Typical, this field will be
        # populated by the MakeLocationElementFn semantic function with the substring of
        # the raw_query defined by start_byte and num_bytes. However, the field can also
        # be populated explicitly in the grammar, in which case MakeLocationElementFn
        # leaves it alone.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Train number associated with /collection/geo/transit_line. Populated when user
        # requests specific instance of a transit line. For example, long distance
        # trains in India have two numbers for each train, one for up direction and
        # other for down. And user use these numbers in queries along with name to
        # specify the specific trip of the train. More details in go/number-transit-line-
        # queries.
        # Corresponds to the JSON property `transitLineNumber`
        # @return [String]
        attr_accessor :transit_line_number
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alias_icon = args[:alias_icon] if args.key?(:alias_icon)
          @alias_location = args[:alias_location] if args.key?(:alias_location)
          @business_type = args[:business_type] if args.key?(:business_type)
          @contact_location = args[:contact_location] if args.key?(:contact_location)
          @dialog_referents = args[:dialog_referents] if args.key?(:dialog_referents)
          @directional_modifier = args[:directional_modifier] if args.key?(:directional_modifier)
          @generic_location = args[:generic_location] if args.key?(:generic_location)
          @hotel_type = args[:hotel_type] if args.key?(:hotel_type)
          @hyper_reliable_data = args[:hyper_reliable_data] if args.key?(:hyper_reliable_data)
          @implicit_local_category = args[:implicit_local_category] if args.key?(:implicit_local_category)
          @local_result_id = args[:local_result_id] if args.key?(:local_result_id)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @number = args[:number] if args.key?(:number)
          @personal_reference_location = args[:personal_reference_location] if args.key?(:personal_reference_location)
          @qref_location = args[:qref_location] if args.key?(:qref_location)
          @saft_location = args[:saft_location] if args.key?(:saft_location)
          @source = args[:source] if args.key?(:source)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @text = args[:text] if args.key?(:text)
          @transit_line_number = args[:transit_line_number] if args.key?(:transit_line_number)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Specifies intent that corresponds to a menu item which is used as a location
      # constraint, e.g. [restaurants that serve thai curry] or as a standalone
      # categorical element, e.g. [thai curry].
      class NlpSemanticParsingLocalMenuItem
        include Google::Apis::Core::Hashable
      
        # This ID corresponds to the name of the menu item in the query. For example [
        # restaurants that serve thai curry] has menu_item_id = "thai curry".
        # Corresponds to the JSON property `menuItemId`
        # @return [String]
        attr_accessor :menu_item_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @menu_item_id = args[:menu_item_id] if args.key?(:menu_item_id)
        end
      end
      
      # 
      class NlpSemanticParsingLocalPriceConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cheap`
        # @return [Boolean]
        attr_accessor :cheap
        alias_method :cheap?, :cheap
      
        # The currency codes are expected to be string from the list in i18n/identifiers/
        # currencycode.*
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        # 
        # Corresponds to the JSON property `expensive`
        # @return [Boolean]
        attr_accessor :expensive
        alias_method :expensive?, :expensive
      
        # 
        # Corresponds to the JSON property `maxPrice`
        # @return [Float]
        attr_accessor :max_price
      
        # 
        # Corresponds to the JSON property `minPrice`
        # @return [Float]
        attr_accessor :min_price
      
        # 
        # Corresponds to the JSON property `moderatelyPriced`
        # @return [Boolean]
        attr_accessor :moderately_priced
        alias_method :moderately_priced?, :moderately_priced
      
        # The user mentioned something about price, but didn't mention a specific
        # constraint. This is used to indicate an intent to remove all price constraints,
        # in queries like [forget the price].
        # Corresponds to the JSON property `unspecified`
        # @return [Boolean]
        attr_accessor :unspecified
        alias_method :unspecified?, :unspecified
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cheap = args[:cheap] if args.key?(:cheap)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
          @expensive = args[:expensive] if args.key?(:expensive)
          @max_price = args[:max_price] if args.key?(:max_price)
          @min_price = args[:min_price] if args.key?(:min_price)
          @moderately_priced = args[:moderately_priced] if args.key?(:moderately_priced)
          @unspecified = args[:unspecified] if args.key?(:unspecified)
        end
      end
      
      # Quality constraints about the establishment. In the future we can add to this
      # message Zagat ratings, user reviews, etc. Next ID: 6.
      class NlpSemanticParsingLocalQualityConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `best`
        # @return [Boolean]
        attr_accessor :best
        alias_method :best?, :best
      
        # 
        # Corresponds to the JSON property `highlyRated`
        # @return [Boolean]
        attr_accessor :highly_rated
        alias_method :highly_rated?, :highly_rated
      
        # 
        # Corresponds to the JSON property `starType`
        # @return [String]
        attr_accessor :star_type
      
        # Star ratings constraints, mostly relevant for hotels. There is an implicit OR
        # relation between these. E.g., for "three star or four star hotel" both three
        # and four would be set to true. Next Available ID: 13.
        # Corresponds to the JSON property `stars`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalStarRatings]
        attr_accessor :stars
      
        # The user mentioned something about quality, but didn't mention a specific
        # constraint. This is used to indicate an intent to remove all quality
        # constraints, in queries like [forget the rating].
        # Corresponds to the JSON property `unspecified`
        # @return [Boolean]
        attr_accessor :unspecified
        alias_method :unspecified?, :unspecified
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @best = args[:best] if args.key?(:best)
          @highly_rated = args[:highly_rated] if args.key?(:highly_rated)
          @star_type = args[:star_type] if args.key?(:star_type)
          @stars = args[:stars] if args.key?(:stars)
          @unspecified = args[:unspecified] if args.key?(:unspecified)
        end
      end
      
      # Constraints for the occupancy of a hotel or vacation rental.
      class NlpSemanticParsingLocalRoomConstraint
        include Google::Apis::Core::Hashable
      
        # It is possible to have fractional bathrooms.
        # Corresponds to the JSON property `minNumBathrooms`
        # @return [Float]
        attr_accessor :min_num_bathrooms
      
        # 
        # Corresponds to the JSON property `minNumBedrooms`
        # @return [Fixnum]
        attr_accessor :min_num_bedrooms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @min_num_bathrooms = args[:min_num_bathrooms] if args.key?(:min_num_bathrooms)
          @min_num_bedrooms = args[:min_num_bedrooms] if args.key?(:min_num_bedrooms)
        end
      end
      
      # Specifies intent that corresponds to a scalable attribute. This may be used as
      # a location constraint, e.g. [restaurants with outdoor seating] or as a
      # standalone categorical element, e.g. [happy hour] or [happy hour ny]. See go/
      # scalable-attributes for details about scalable attributes. NOTE(oksana):
      # LocalCategoryReliable grammar over-rides a few scalable attribute queries to
      # include hyper_reliable location element. If you change this, please make sure
      # that LocalCategoryReliable grammar reflects this too. LINT.IfChange This ID
      # corresponds to the id field in //geostore/attributes/proto/config.proto:
      # AttributeConfigProto This field holds the human readable ID for the KG topic
      # that represents the attribute. Example: "/geo/type/establishment_poi/
      # serves_breakfast"
      class NlpSemanticParsingLocalScalableAttribute
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
        end
      end
      
      # 
      class NlpSemanticParsingLocalServiceConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `serviceType`
        # @return [String]
        attr_accessor :service_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @service_type = args[:service_type] if args.key?(:service_type)
        end
      end
      
      # Star ratings constraints, mostly relevant for hotels. There is an implicit OR
      # relation between these. E.g., for "three star or four star hotel" both three
      # and four would be set to true. Next Available ID: 13.
      class NlpSemanticParsingLocalStarRatings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `five`
        # @return [Boolean]
        attr_accessor :five
        alias_method :five?, :five
      
        # 
        # Corresponds to the JSON property `four`
        # @return [Boolean]
        attr_accessor :four
        alias_method :four?, :four
      
        # 
        # Corresponds to the JSON property `fourAndAHalf`
        # @return [Boolean]
        attr_accessor :four_and_a_half
        alias_method :four_and_a_half?, :four_and_a_half
      
        # 
        # Corresponds to the JSON property `one`
        # @return [Boolean]
        attr_accessor :one
        alias_method :one?, :one
      
        # 
        # Corresponds to the JSON property `oneAndAHalf`
        # @return [Boolean]
        attr_accessor :one_and_a_half
        alias_method :one_and_a_half?, :one_and_a_half
      
        # 
        # Corresponds to the JSON property `orFewer`
        # @return [Boolean]
        attr_accessor :or_fewer
        alias_method :or_fewer?, :or_fewer
      
        # If this field is set, exactly one of the star classes above should be set, and
        # the interpretation should be that at least that many stars should be present.
        # Corresponds to the JSON property `orMore`
        # @return [Boolean]
        attr_accessor :or_more
        alias_method :or_more?, :or_more
      
        # 
        # Corresponds to the JSON property `three`
        # @return [Boolean]
        attr_accessor :three
        alias_method :three?, :three
      
        # 
        # Corresponds to the JSON property `threeAndAHalf`
        # @return [Boolean]
        attr_accessor :three_and_a_half
        alias_method :three_and_a_half?, :three_and_a_half
      
        # 
        # Corresponds to the JSON property `two`
        # @return [Boolean]
        attr_accessor :two
        alias_method :two?, :two
      
        # 
        # Corresponds to the JSON property `twoAndAHalf`
        # @return [Boolean]
        attr_accessor :two_and_a_half
        alias_method :two_and_a_half?, :two_and_a_half
      
        # 
        # Corresponds to the JSON property `unspecified`
        # @return [Boolean]
        attr_accessor :unspecified
        alias_method :unspecified?, :unspecified
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @five = args[:five] if args.key?(:five)
          @four = args[:four] if args.key?(:four)
          @four_and_a_half = args[:four_and_a_half] if args.key?(:four_and_a_half)
          @one = args[:one] if args.key?(:one)
          @one_and_a_half = args[:one_and_a_half] if args.key?(:one_and_a_half)
          @or_fewer = args[:or_fewer] if args.key?(:or_fewer)
          @or_more = args[:or_more] if args.key?(:or_more)
          @three = args[:three] if args.key?(:three)
          @three_and_a_half = args[:three_and_a_half] if args.key?(:three_and_a_half)
          @two = args[:two] if args.key?(:two)
          @two_and_a_half = args[:two_and_a_half] if args.key?(:two_and_a_half)
          @unspecified = args[:unspecified] if args.key?(:unspecified)
        end
      end
      
      # 
      class NlpSemanticParsingLocalVicinityLocation
        include Google::Apis::Core::Hashable
      
        # There are a few types of locations: - Basic locations are sequences of
        # location elements which can be either actual locations or modifiers. E.g., "
        # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
        # location), "CA" (an actual location, and "94040" (a numeric modifier). -
        # Compound locations: these are two locations combined by a joiner. E.g., "
        # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
        # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
        # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
        # indicates an area around a certain location. The area can be defined by time
        # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
        # a few miles from here". Next ID: 14
        # Corresponds to the JSON property `base`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocation]
        attr_accessor :base
      
        # The text between the extent and the base, e.g., for "50 miles from here" the
        # connector is "from".
        # Corresponds to the JSON property `connector`
        # @return [String]
        attr_accessor :connector
      
        # 
        # Corresponds to the JSON property `extent`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalExtent]
        attr_accessor :extent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base = args[:base] if args.key?(:base)
          @connector = args[:connector] if args.key?(:connector)
          @extent = args[:extent] if args.key?(:extent)
        end
      end
      
      # Constraint for visited, as in if a location has been visited before.
      class NlpSemanticParsingLocalVisitHistoryConstraint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `visitedType`
        # @return [String]
        attr_accessor :visited_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @visited_type = args[:visited_type] if args.key?(:visited_type)
        end
      end
      
      # The type of contact (mobile, home, work, etc). NOTE: Unfortunately the name of
      # this message is a misnomer. Contact type would be a better name.
      class NlpSemanticParsingModelsCommunicationPhoneType
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Whether the annotation is from $Text.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Normalized (canonicalized) text, e.g. "mobile".
        # Corresponds to the JSON property `normalizedText`
        # @return [String]
        attr_accessor :normalized_text
      
        # Original text in query, e.g. "cell".
        # Corresponds to the JSON property `originalText`
        # @return [String]
        attr_accessor :original_text
      
        # DEPRECATED. Used original_text instead.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @normalized_text = args[:normalized_text] if args.key?(:normalized_text)
          @original_text = args[:original_text] if args.key?(:original_text)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # It can be a contact (person name), a business name, an email address or a
      # phone number. NOTE: Unfortunately the name of this message is not generic
      # enough. Contact would be a better name.
      class NlpSemanticParsingModelsCommunicationRecipient
        include Google::Apis::Core::Hashable
      
        # This proto contains the information of a calendar event, including title,
        # start time, end time, etc. IMPORTANT: The definition of CalendarEvent proto is
        # being moved to //assistant/api/core_types/governed/calendar_event_type.proto.
        # All existing references will be updated to point to the new location. If you
        # are adding a reference, use the new one instead. LINT.IfChange(CalendarEvent)
        # NEXT_ID: 26
        # Corresponds to the JSON property `calendarEvent`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEvent]
        attr_accessor :calendar_event
      
        # This empty type allows us to publish sensitive calendar events to go/
        # attentional-entities, while maintaining BUILD visibility protection for their
        # contents. The BUILD-visibility-protected extension to this message is defined
        # at http://google3/assistant/verticals/calendar/proto/
        # multi_account_calendar_event.proto IMPORTANT: The definition of
        # CalendarEventWrapper proto is being moved to //assistant/api/core_types/
        # governed/calendar_event_type.proto. All existing references will be updated to
        # point to the new location. If you are adding a reference, use the new one
        # instead.
        # Corresponds to the JSON property `calendarEventWrapper`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesCalendarEventWrapper]
        attr_accessor :calendar_event_wrapper
      
        # Contact details (e.g. gaia_id, phone, etc). Replaces 'focus_name' above.
        # Corresponds to the JSON property `contact`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsPersonPerson]
        attr_accessor :contact
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Deprecated in favor of recipient.contact.name_annotation_source.
        # Corresponds to the JSON property `nameAnnotationSource`
        # @return [String]
        attr_accessor :name_annotation_source
      
        # 
        # Corresponds to the JSON property `numberAnnotationSource`
        # @return [String]
        attr_accessor :number_annotation_source
      
        # NOTE: for CONTACT recipient, this is *NOT* the real raw text of the recipient
        # span of historical reasons. Major differences includes: - stripping possessive
        # suffix, e.g. "John's" -> "John" - stripping prefix/suffix/title, e.g. "Mr.
        # John" -> "John" - uninflect name for languages like Russian, e.g. "Андрею" -> "
        # Андрей" Currently this is the same as .contact.name, and is used as the string
        # shown to the user on clientside UI. If you're looking for real raw text, use .
        # contact.raw_text
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # 
        # Corresponds to the JSON property `recipientType`
        # @return [String]
        attr_accessor :recipient_type
      
        # A relationship contact.
        # Corresponds to the JSON property `relationship`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsCommunicationRelationshipArgument]
        attr_accessor :relationship
      
        # 
        # Corresponds to the JSON property `sensitiveNumBytes`
        # @return [Fixnum]
        attr_accessor :sensitive_num_bytes
      
        # The beginning and end of the recipient name that should be removed before
        # logging.
        # Corresponds to the JSON property `sensitiveStartByte`
        # @return [Fixnum]
        attr_accessor :sensitive_start_byte
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calendar_event = args[:calendar_event] if args.key?(:calendar_event)
          @calendar_event_wrapper = args[:calendar_event_wrapper] if args.key?(:calendar_event_wrapper)
          @contact = args[:contact] if args.key?(:contact)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @name_annotation_source = args[:name_annotation_source] if args.key?(:name_annotation_source)
          @number_annotation_source = args[:number_annotation_source] if args.key?(:number_annotation_source)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @recipient_type = args[:recipient_type] if args.key?(:recipient_type)
          @relationship = args[:relationship] if args.key?(:relationship)
          @sensitive_num_bytes = args[:sensitive_num_bytes] if args.key?(:sensitive_num_bytes)
          @sensitive_start_byte = args[:sensitive_start_byte] if args.key?(:sensitive_start_byte)
        end
      end
      
      # A relationship contact.
      class NlpSemanticParsingModelsCommunicationRelationshipArgument
        include Google::Apis::Core::Hashable
      
        # The alias of the relationship in the query, e.g. "mom".
        # Corresponds to the JSON property `alias`
        # @return [String]
        attr_accessor :alias
      
        # The canonical format of the relationship, e.g. "Mother".
        # Corresponds to the JSON property `canonical`
        # @return [String]
        attr_accessor :canonical
      
        # Mid for an entity that has lexical data (a LexiconEntry). See https://g3doc.
        # corp.google.com/nlp/generation/g3doc/lexical_data.md for for more information
        # about lexical data. This is the canonical mid for this entity (eg. it would be
        # /m/0lbxz for "mother" in EN even if user referred to "mom").
        # Corresponds to the JSON property `canonicalLexicalMid`
        # @return [String]
        attr_accessor :canonical_lexical_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alias = args[:alias] if args.key?(:alias)
          @canonical = args[:canonical] if args.key?(:canonical)
          @canonical_lexical_mid = args[:canonical_lexical_mid] if args.key?(:canonical_lexical_mid)
        end
      end
      
      # The device to perform an action. Both device_type and device_name are optional
      # and they can coexist: [on my phone]: device_type = PHONE [on my nexus 4]:
      # device_name = "nexus 4" [on my nexus phone]: device_type = PHONE, device_name =
      # "nexus"
      class NlpSemanticParsingModelsDevice
        include Google::Apis::Core::Hashable
      
        # The name of the device (Nexus 5, Nexus 10, etc).
        # Corresponds to the JSON property `deviceName`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDeviceName]
        attr_accessor :device_name
      
        # The type of the device (phone, tablet, watch, etc).
        # Corresponds to the JSON property `deviceType`
        # @return [String]
        attr_accessor :device_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_name = args[:device_name] if args.key?(:device_name)
          @device_type = args[:device_type] if args.key?(:device_type)
        end
      end
      
      # The name of the device (Nexus 5, Nexus 10, etc).
      class NlpSemanticParsingModelsDeviceName
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Will be used by dialog_referent subgrammar to emit types annotations from
      # DialogReferentsAnnotator and $DialogReferentOrdinal rules.
      class NlpSemanticParsingModelsDialogReferentsDialogReferents
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Represents the user's selection from a list of alternatives.
        # Corresponds to the JSON property `field`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDialogReferentsListSelection]
        attr_accessor :field
      
        # Used for a grammar mention of an index.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # Will be used by dialog_referent subgrammar to emit types annotations from
        # DialogReferentsAnnotator and $DialogReferentOrdinal rules.
        # Corresponds to the JSON property `next`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDialogReferentsDialogReferents]
        attr_accessor :next
      
        # The requested value(s) for selection from a list of alternatives.
        # Corresponds to the JSON property `selection`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDialogReferentsListSelection>]
        attr_accessor :selection
      
        # Set when the user's utterance refers to the (an) overall task/goal of the
        # dialog (e.g. "the meeting starts at 10 am" mentions the goal, "meeting"). The
        # field is repeated in case the user ambiguously identifies a task (two tasks
        # named 'meeting').
        # Corresponds to the JSON property `taskMention`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDialogReferentsListSelection>]
        attr_accessor :task_mention
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @field = args[:field] if args.key?(:field)
          @index = args[:index] if args.key?(:index)
          @next = args[:next] if args.key?(:next)
          @selection = args[:selection] if args.key?(:selection)
          @task_mention = args[:task_mention] if args.key?(:task_mention)
        end
      end
      
      # Represents the user's selection from a list of alternatives.
      class NlpSemanticParsingModelsDialogReferentsListSelection
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # A unique identifier that is the canonical value for the chosen list item. If
        # we are selecting among fields, this is the field_id specified in the
        # corresponding DialogField.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # If true, semantic function should look at watch actions in the following
        # display entity if the first one is not playable. This is useful for "Play it"
        # on entity page.
        # Corresponds to the JSON property `looseOffsetRestriction`
        # @return [Boolean]
        attr_accessor :loose_offset_restriction
        alias_method :loose_offset_restriction?, :loose_offset_restriction
      
        # The offset within the list, if know. If the list of values wasn't known (e.g.
        # from the discourse context) then the offset is a zero-based mapping of the
        # ordinal value of the selection ("first one" maps to zero; "last one" to minus
        # one).
        # Corresponds to the JSON property `offset`
        # @return [Fixnum]
        attr_accessor :offset
      
        # When the user selects a list value by name then this is the matched text from
        # the utterance. Note that, if the list of values is known, then the aqua
        # annotator should have mapped it to an offset.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @id = args[:id] if args.key?(:id)
          @loose_offset_restriction = args[:loose_offset_restriction] if args.key?(:loose_offset_restriction)
          @offset = args[:offset] if args.key?(:offset)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "The White Album"
      class NlpSemanticParsingModelsMediaAlbumTitle
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # If true, indicates the user wants their favorite album. Like [play my favorite
        # album my Eminem]
        # Corresponds to the JSON property `favorite`
        # @return [Boolean]
        attr_accessor :favorite
        alias_method :favorite?, :favorite
      
        # If true, indicates the user wants the first album. Like [play adele's first
        # album]
        # Corresponds to the JSON property `first`
        # @return [Boolean]
        attr_accessor :first
        alias_method :first?, :first
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # If true, indicates the user wants the latest album. Like, [play adele's latest
        # album]
        # Corresponds to the JSON property `latest`
        # @return [Boolean]
        attr_accessor :latest
        alias_method :latest?, :latest
      
        # More from this album.
        # Corresponds to the JSON property `playMore`
        # @return [Boolean]
        attr_accessor :play_more
        alias_method :play_more?, :play_more
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "The White Album."
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @favorite = args[:favorite] if args.key?(:favorite)
          @first = args[:first] if args.key?(:first)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @latest = args[:latest] if args.key?(:latest)
          @play_more = args[:play_more] if args.key?(:play_more)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Represents a music recording (usually a song). Each populated field can be
      # thought of as additional constraint about the song's identity. For instance,
      # if no fields are set, then this represents "some song." If only the
      # music_artist is set, then it represents "some song by the specified
      # music_artist." Inspired (but not strictly adhered to) http://schema.org/
      # MusicRecording Next ID: 22
      class NlpSemanticParsingModelsMediaAudio
        include Google::Apis::Core::Hashable
      
        # Example: "The White Album"
        # Corresponds to the JSON property `album`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaAlbumTitle]
        attr_accessor :album
      
        # Example: "The Beatles"
        # Corresponds to the JSON property `artist`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMusicArtist]
        attr_accessor :artist
      
        # Example: "East of Eden"
        # Corresponds to the JSON property `book`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaBook]
        attr_accessor :book
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `dateTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :date_time
      
        # Constraining the query to some detail about the episode. Example: "listen to
        # episode (13) of this american life with (mike birbiglia)" would have the 2
        # constraints in parens.
        # Corresponds to the JSON property `episodeConstraint`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaEpisodeConstraint>]
        attr_accessor :episode_constraint
      
        # Example: "Deus Ex Human Revolution"
        # Corresponds to the JSON property `game`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaGame]
        attr_accessor :game
      
        # Example: "my library", "some music".
        # Corresponds to the JSON property `genericMusic`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaGenericMusic]
        attr_accessor :generic_music
      
        # Example: "British Invasion"
        # Corresponds to the JSON property `genre`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMusicGenre]
        attr_accessor :genre
      
        # Example: "Casablanca"
        # Corresponds to the JSON property `movie`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMovie]
        attr_accessor :movie
      
        # Example: "ukraine" in a query like "read me news about Ukraine"
        # Corresponds to the JSON property `newsTopic`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaNewsTopic]
        attr_accessor :news_topic
      
        # True when the query does not contains an explict audio name. E.g. When user
        # says "play" or "listen to".
        # Corresponds to the JSON property `noExplicitAudio`
        # @return [Boolean]
        attr_accessor :no_explicit_audio
        alias_method :no_explicit_audio?, :no_explicit_audio
      
        # Example: "gym playlist"
        # Corresponds to the JSON property `playlist`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMusicPlaylist]
        attr_accessor :playlist
      
        # Example: "This American Life"
        # Corresponds to the JSON property `podcast`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaPodcast]
        attr_accessor :podcast
      
        # Example: "107.7 the bone"
        # Corresponds to the JSON property `radio`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaRadio]
        attr_accessor :radio
      
        # Example: "npr", "bbc", etc.
        # Corresponds to the JSON property `radioNetwork`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaRadioNetwork]
        attr_accessor :radio_network
      
        # The query for backends to use in search. e.g. for an user query of "play kids
        # song video on tv" from assistant, this field would be "kids song". Note: there
        # is no guarantee this field is populated; when it is not, backends should fall
        # back to "raw_text" fields in song, artist, album etc.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # If any of movie, game or tv show fields is populated this field indicates
        # specific score type requested in the query. E.g. for [play soundtrack from
        # frozen] this field is SOUNDTRACK, for [play frozen song] this field is
        # THEME_SONG.
        # Corresponds to the JSON property `scoreType`
        # @return [String]
        attr_accessor :score_type
      
        # Example: "season 2" of serial
        # Corresponds to the JSON property `seasonConstraint`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaSeasonConstraint]
        attr_accessor :season_constraint
      
        # Example: "Hey Jude"
        # Corresponds to the JSON property `song`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaSong]
        attr_accessor :song
      
        # Optional tags associated with how the media entity should be played. For
        # example, this can be set to SEED_RADIO to signify that the user wants to play
        # a radio station seeded by the entity.
        # Corresponds to the JSON property `tag`
        # @return [Array<String>]
        attr_accessor :tag
      
        # Example: "Breaking Bad"
        # Corresponds to the JSON property `tvShow`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaTvShow]
        attr_accessor :tv_show
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @album = args[:album] if args.key?(:album)
          @artist = args[:artist] if args.key?(:artist)
          @book = args[:book] if args.key?(:book)
          @date_time = args[:date_time] if args.key?(:date_time)
          @episode_constraint = args[:episode_constraint] if args.key?(:episode_constraint)
          @game = args[:game] if args.key?(:game)
          @generic_music = args[:generic_music] if args.key?(:generic_music)
          @genre = args[:genre] if args.key?(:genre)
          @movie = args[:movie] if args.key?(:movie)
          @news_topic = args[:news_topic] if args.key?(:news_topic)
          @no_explicit_audio = args[:no_explicit_audio] if args.key?(:no_explicit_audio)
          @playlist = args[:playlist] if args.key?(:playlist)
          @podcast = args[:podcast] if args.key?(:podcast)
          @radio = args[:radio] if args.key?(:radio)
          @radio_network = args[:radio_network] if args.key?(:radio_network)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @score_type = args[:score_type] if args.key?(:score_type)
          @season_constraint = args[:season_constraint] if args.key?(:season_constraint)
          @song = args[:song] if args.key?(:song)
          @tag = args[:tag] if args.key?(:tag)
          @tv_show = args[:tv_show] if args.key?(:tv_show)
        end
      end
      
      # Metadata for an audiobook.
      class NlpSemanticParsingModelsMediaAudiobookInfo
        include Google::Apis::Core::Hashable
      
        # The MID of the audiobook entity (/book/book_edition).
        # Corresponds to the JSON property `audiobookMid`
        # @return [String]
        attr_accessor :audiobook_mid
      
        # 
        # Corresponds to the JSON property `authors`
        # @return [Array<String>]
        attr_accessor :authors
      
        # The MID of the book entity (/book/book) which this audiobook is associated
        # with.
        # Corresponds to the JSON property `bookMid`
        # @return [String]
        attr_accessor :book_mid
      
        # 
        # Corresponds to the JSON property `narrators`
        # @return [Array<String>]
        attr_accessor :narrators
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audiobook_mid = args[:audiobook_mid] if args.key?(:audiobook_mid)
          @authors = args[:authors] if args.key?(:authors)
          @book_mid = args[:book_mid] if args.key?(:book_mid)
          @narrators = args[:narrators] if args.key?(:narrators)
        end
      end
      
      # Example: "East of Eden"
      class NlpSemanticParsingModelsMediaBook
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # If true, indicates the user wants the latest book. Like, [play Dan Brown's
        # latest book]
        # Corresponds to the JSON property `latest`
        # @return [Boolean]
        attr_accessor :latest
        alias_method :latest?, :latest
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "East of Eden"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @latest = args[:latest] if args.key?(:latest)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Media device. Like, Chromecast, TV or Chirp. When emitted from the cast_device
      # domain, you should expect it to be one of 3 different forms: 1) Personal
      # Device: The annotation comes from a device we found in the user's home.
      # device_id and name should be set, cast_device_type is set if device type is
      # mentioned in query. e.g. "Dima's Pineapple Chirp" device_id: FOOBAR name: "
      # Dima's Pineapple" cast_device_type: CHIRP 2) Common Device Name: The
      # annotation comes from a model of the common names of user's device. name and
      # cast_device_type should be set but device_id will not be. cast_device_type can
      # be UNKNOWN. e.g. "John's Living Room" name: "John's Living Room"
      # cast_device_type: UNKNOWN 3) Device Type: The annotation comes from a model of
      # common cast device types. Only cast_device_type will be set. e.g. "TV" or "
      # chromecast" cast_device_type: CHROMECAST Next ID: 9
      class NlpSemanticParsingModelsMediaCastDeviceAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `castDeviceSource`
        # @return [String]
        attr_accessor :cast_device_source
      
        # This field is populated when the user says [play X on $cast_device] and we
        # know the type of $cast_device but cannot identify the exact device.
        # Corresponds to the JSON property `castDeviceType`
        # @return [String]
        attr_accessor :cast_device_type
      
        # The timestamp that the device is linked with the user in milliseconds. This is
        # inherited from the corresponding assistant DeviceSettings as is.
        # Corresponds to the JSON property `creationTimestampMs`
        # @return [Fixnum]
        attr_accessor :creation_timestamp_ms
      
        # DEPRECATED: Please use device_identifier instead.
        # Corresponds to the JSON property `deviceId`
        # @return [String]
        attr_accessor :device_id
      
        # LINT.IfChange(DeviceId) Specifies identifier of a device AKA surface. Note
        # there may be multiple device ids for the same physical device E.g. Allo app
        # and Assistant app on Nexus. Note: DeviceId usage is complicated. Please do not
        # depend on it for surface specific logic. Please use google3/assistant/api/
        # capabilities.proto instead. IMPORTANT: When checking for equality between two `
        # DeviceId`s, you should always use an `isSameDevice`As`` function to check for
        # equality, as deep equality between `DeviceId`'s is not guaranteed. * C++: http:
        # //google3/assistant/assistant_server/util/device_id_util.cc;l=23;rcl=421295740
        # * Dart: http://google3/assistant/context/util/lib/device_id.dart;l=26;rcl=
        # 442126145 * Java: http://google3/java/com/google/assistant/assistantserver/
        # utils/DeviceIdHelper.java;l=9;rcl=390378522 See http://go/deviceid-equality
        # for more details. Next ID: 14
        # Corresponds to the JSON property `deviceIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesDeviceId]
        attr_accessor :device_identifier
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The quantification of device(s) in the query. For example, "three speakers", "
        # all TVs", etc. Usually, we should have either lexical field or number field.
        # However, there are some special words which we will set both fields. For
        # example, "all 3" will have the semantic: `lexical=ALL, number=3`. Note that "
        # both" is simply modeled as `lexical=ALL`.
        # Corresponds to the JSON property `quantification`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaQuantification]
        attr_accessor :quantification
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cast_device_source = args[:cast_device_source] if args.key?(:cast_device_source)
          @cast_device_type = args[:cast_device_type] if args.key?(:cast_device_type)
          @creation_timestamp_ms = args[:creation_timestamp_ms] if args.key?(:creation_timestamp_ms)
          @device_id = args[:device_id] if args.key?(:device_id)
          @device_identifier = args[:device_identifier] if args.key?(:device_identifier)
          @name = args[:name] if args.key?(:name)
          @quantification = args[:quantification] if args.key?(:quantification)
        end
      end
      
      # Represents a localized price. Next ID: 3
      class NlpSemanticParsingModelsMediaCost
        include Google::Apis::Core::Hashable
      
        # Contains the standard code for the given type of currency. The value must
        # represent a valid i18n_identifiers::CurrencyCode.
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        # Contains the price in a particular currency.
        # Corresponds to the JSON property `price`
        # @return [Float]
        attr_accessor :price
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
          @price = args[:price] if args.key?(:price)
        end
      end
      
      # Provider deeplink and associated metadata, in particular restrictions on
      # platform and user's subscription. Next ID: 18
      class NlpSemanticParsingModelsMediaDeeplinkInfo
        include Google::Apis::Core::Hashable
      
        # The type of the deeplink. Sometimes the deeplink is not only used for playing
        # media, but also used for other actions. For example, the deeplink could be for
        # playing a movie trailer from YouTube or recording a movie from YouTube TV.
        # Corresponds to the JSON property `actionType`
        # @return [String]
        attr_accessor :action_type
      
        # The upper-case, III country code, e.g., "US", in which the deeplink cannot
        # play. For possible values, see: google3/i18n/identifiers/regioncode.h google3/
        # java/com/google/i18n/identifiers/RegionCode.java For details on converting to
        # and from ISO country codes, see http://iii-howto#GettingCanonRegionCodes.
        # Corresponds to the JSON property `blacklistedCountry`
        # @return [Array<String>]
        attr_accessor :blacklisted_country
      
        # The upper-case, III country code, e.g., "US", in which the deeplink can play.
        # If unset or has "earth" (b/72566951), means the deeplink can be used world-
        # wide except in |blacklisted_country| list. For possible values, see: google3/
        # i18n/identifiers/regioncode.h google3/java/com/google/i18n/identifiers/
        # RegionCode.java For details on converting to and from ISO country codes, see
        # http://iii-howto#GettingCanonRegionCodes.
        # Corresponds to the JSON property `country`
        # @return [Array<String>]
        attr_accessor :country
      
        # Deeplink to the media. This deeplink is meant to be send to the provider app
        # on available platforms without any modifications. Required.
        # Corresponds to the JSON property `deeplink`
        # @return [String]
        attr_accessor :deeplink
      
        # Some providers give us an opaque, unstable deeplink to use at execution-time.
        # E.g. see http://go/collab-ranking-nl-uri#heading=h.ndmdfw388tk3 Such a
        # deeplink is not useful for logging, caching, comparing to other candidate
        # deeplinks, etc. So most fulfillment code will want the traditional, stable
        # deeplink that can be interpreted, parsed, cached, etc (found in the "deeplink"
        # field, above). But this opaque, unstable deeplink (if non-empty) must be
        # included in the music initiation clientop.
        # Corresponds to the JSON property `deeplinkForExecution`
        # @return [String]
        attr_accessor :deeplink_for_execution
      
        # Indicate whether the deeplink is compatible with credentials. If true, CCS
        # will not send the credentials to cast app. Currently this field is only used
        # for voice-follow on cases on smart displays.
        # Corresponds to the JSON property `incompatibleWithCredentials`
        # @return [Boolean]
        attr_accessor :incompatible_with_credentials
        alias_method :incompatible_with_credentials?, :incompatible_with_credentials
      
        # List of offers that allow user to access the deeplink, that is if the list
        # contains PREMIUM_SUBSCRIPTION and BASIC_SUBSCRIPTION users that have either
        # premium or basic subscription can use the deeplink. If the list is empty it
        # means that there are no subscription restrictions.
        # Corresponds to the JSON property `offer`
        # @return [Array<String>]
        attr_accessor :offer
      
        # This field is only used when "offer" includes a PAY_PER_USE. When "offer"
        # includes a PAY_PER_USE, paid_offer_detail will contain offers for BUY and RENT
        # offer_types with associated cost info.
        # Corresponds to the JSON property `paidOfferDetail`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaPaidOfferDetail>]
        attr_accessor :paid_offer_detail
      
        # List of platforms that support the deeplink. If the list is empty it means
        # that there are no platform restrictions.
        # Corresponds to the JSON property `platform`
        # @return [Array<String>]
        attr_accessor :platform
      
        # Document scores which are used for ranking action links. Document scores might
        # come from CDOC in Raffia or other indexing systems. For example, for web pages,
        # the score shows how likely the web page (composite doc) which generated this
        # link refers to the given entity or how close a particular entity is with the
        # given composite doc. For the larger design, please see go/ma_dedup. For
        # PACIFIC_COLLAB_RANKING deeplink, the score is the normalized confidence score
        # returned by partner for fulfillment candidate. For pivot candidates, the score
        # is calculated with the index of the alternative results.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Name of subscription packages which are granted access to this deeplink. This
        # is to match exactly the end users authentication system. This is to be used if
        # the offer is BASIC_SUBSCRIPTION or PREMIUM_SUBSCRIPTION. There can be multiple
        # packages -- the user needs only to authenticate with a single package. For
        # more information please see: go/subscription-package
        # Corresponds to the JSON property `subscriptionPackageName`
        # @return [Array<String>]
        attr_accessor :subscription_package_name
      
        # Tags associated with the content played by this deeplink. In the common case,
        # the deeplink is supposed to specify a music entity within the provider's
        # inventory, and the provider app should decide the actual content based on the
        # user's account profile (e.g., for a deeplink to an artist, playing tracks from
        # the artist or similar artists, and for a song, playing the official album
        # recording of the song). But in some cases, the deeplink belong to special
        # content. For example, for an artist a seed radio based on the artist, and a
        # live or karaoke version of a song. We use this field to mark such special
        # content types.
        # Corresponds to the JSON property `tag`
        # @return [Array<String>]
        attr_accessor :tag
      
        # Represents a time window expressed as a time range.
        # Corresponds to the JSON property `validTimeWindow`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaDeeplinkInfoTimeWindow]
        attr_accessor :valid_time_window
      
        # DEPRECATED: This field is ignored by understanding and fulfillment.
        # Corresponds to the JSON property `vuiId`
        # @return [String]
        attr_accessor :vui_id
      
        # Provide the deeplink information specific to YouTube PMAs. Next ID: 3
        # Corresponds to the JSON property `youtubeDeeplinkInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaYouTubeDeeplinkInfo]
        attr_accessor :youtube_deeplink_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @action_type = args[:action_type] if args.key?(:action_type)
          @blacklisted_country = args[:blacklisted_country] if args.key?(:blacklisted_country)
          @country = args[:country] if args.key?(:country)
          @deeplink = args[:deeplink] if args.key?(:deeplink)
          @deeplink_for_execution = args[:deeplink_for_execution] if args.key?(:deeplink_for_execution)
          @incompatible_with_credentials = args[:incompatible_with_credentials] if args.key?(:incompatible_with_credentials)
          @offer = args[:offer] if args.key?(:offer)
          @paid_offer_detail = args[:paid_offer_detail] if args.key?(:paid_offer_detail)
          @platform = args[:platform] if args.key?(:platform)
          @score = args[:score] if args.key?(:score)
          @subscription_package_name = args[:subscription_package_name] if args.key?(:subscription_package_name)
          @tag = args[:tag] if args.key?(:tag)
          @valid_time_window = args[:valid_time_window] if args.key?(:valid_time_window)
          @vui_id = args[:vui_id] if args.key?(:vui_id)
          @youtube_deeplink_info = args[:youtube_deeplink_info] if args.key?(:youtube_deeplink_info)
        end
      end
      
      # Represents a time window expressed as a time range.
      class NlpSemanticParsingModelsMediaDeeplinkInfoTimeWindow
        include Google::Apis::Core::Hashable
      
        # Time in seconds since epoch.
        # Corresponds to the JSON property `endTimestamp`
        # @return [Fixnum]
        attr_accessor :end_timestamp
      
        # Time in seconds since epoch.
        # Corresponds to the JSON property `startTimestamp`
        # @return [Fixnum]
        attr_accessor :start_timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp)
          @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
        end
      end
      
      # Example: "the episode with all of the comedians". A free-form text description
      # of a media.
      class NlpSemanticParsingModelsMediaDescription
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "latest" would constrain the episode to a certain ordinal.
      class NlpSemanticParsingModelsMediaEpisodeConstraint
        include Google::Apis::Core::Hashable
      
        # The absolute index of the episode. 1 is the first element and -1 is the last
        # element in the sequence, -2 is the second-to-last element, and so on. Examples:
        # "first episode" => 1 "3rd episode" => 3 "last episode" => -1
        # Corresponds to the JSON property `absoluteIndex`
        # @return [Fixnum]
        attr_accessor :absolute_index
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `dateTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :date_time
      
        # Example: "the episode with all of the comedians". A free-form text description
        # of a media.
        # Corresponds to the JSON property `description`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaDescription]
        attr_accessor :description
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # The relative index of the episode. Examples: "previous episode" => -1 "current
        # episode" => 0 "next episode" => 1
        # Corresponds to the JSON property `relativeIndex`
        # @return [Fixnum]
        attr_accessor :relative_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @absolute_index = args[:absolute_index] if args.key?(:absolute_index)
          @date_time = args[:date_time] if args.key?(:date_time)
          @description = args[:description] if args.key?(:description)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @relative_index = args[:relative_index] if args.key?(:relative_index)
        end
      end
      
      # Defines a frequency for a terrestrial radio station. For instance, 99.1 FM,
      # 730 AM, etc. Next ID: 4
      class NlpSemanticParsingModelsMediaFrequency
        include Google::Apis::Core::Hashable
      
        # The broadcast band used by the radio station.
        # Corresponds to the JSON property `band`
        # @return [String]
        attr_accessor :band
      
        # Frequency in MHz (for FM) and KHz (for AM).
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @band = args[:band] if args.key?(:band)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Example: "Deus Ex Human Revolution"
      class NlpSemanticParsingModelsMediaGame
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "Deus Ex Human Revolution"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "my library", "some music".
      class NlpSemanticParsingModelsMediaGenericMusic
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # New music.
        # Corresponds to the JSON property `newMusic`
        # @return [Boolean]
        attr_accessor :new_music
        alias_method :new_music?, :new_music
      
        # Required, corresponds to the raw text, like "my tracks"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @new_music = args[:new_music] if args.key?(:new_music)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # An object representing a latitude/longitude pair. More info in https://cs.corp.
      # google.com/piper///depot/google3/google/type/latlng.proto
      class NlpSemanticParsingModelsMediaLatLng
        include Google::Apis::Core::Hashable
      
        # The latitude in degrees. It must be in the range [-90.0, +90.0].
        # Corresponds to the JSON property `latitude`
        # @return [Float]
        attr_accessor :latitude
      
        # The longitude in degrees. It must be in the range [-180.0, +180.0].
        # Corresponds to the JSON property `longitude`
        # @return [Float]
        attr_accessor :longitude
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @latitude = args[:latitude] if args.key?(:latitude)
          @longitude = args[:longitude] if args.key?(:longitude)
        end
      end
      
      # Annotation for media entities. Next ID: 17
      class NlpSemanticParsingModelsMediaMediaAnnotation
        include Google::Apis::Core::Hashable
      
        # Name of the artist (if applicable). Used for songs and albums.
        # Corresponds to the JSON property `artistName`
        # @return [String]
        attr_accessor :artist_name
      
        # Metadata for an audiobook.
        # Corresponds to the JSON property `audiobookInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaAudiobookInfo]
        attr_accessor :audiobook_info
      
        # Type of the media content. This field is not always populated, but only when
        # this annotation is used to represent an individual media item, e.g., when it
        # is the value of an intent argument storing a media object to play.
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # Images of the media.
        # Corresponds to the JSON property `image`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesImage>]
        attr_accessor :image
      
        # Name of the media. Required.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Additional info specific to a news audio/video stream (if applicable).
        # Corresponds to the JSON property `newsInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaNewsInfo]
        attr_accessor :news_info
      
        # The personal ingestion engine.
        # Corresponds to the JSON property `personalDataIngestionEngine`
        # @return [String]
        attr_accessor :personal_data_ingestion_engine
      
        # Visibility setting of the retrieved playlist.
        # Corresponds to the JSON property `playlistVisibility`
        # @return [String]
        attr_accessor :playlist_visibility
      
        # Additional info specific to podcast stream (if applicable).
        # Corresponds to the JSON property `podcastInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaPodcastInfo]
        attr_accessor :podcast_info
      
        # 
        # Corresponds to the JSON property `primaryEntityMid`
        # @return [String]
        attr_accessor :primary_entity_mid
      
        # List of providers and their deeplinks.
        # Corresponds to the JSON property `providerInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaProviderInfo>]
        attr_accessor :provider_info
      
        # Purchase info for purchased or preordered movies, episodes, seasons, tv shows.
        # Corresponds to the JSON property `purchaseInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaPurchaseInfo]
        attr_accessor :purchase_info
      
        # Metadata for a radio station (both terrestrial and internet). Next ID: 4
        # Corresponds to the JSON property `radioInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaRadioInfo]
        attr_accessor :radio_info
      
        # Rental info for rented movies.
        # Corresponds to the JSON property `rentalInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaRentalInfo]
        attr_accessor :rental_info
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # Additional info specific to YouTube playlist (if applicable).
        # Corresponds to the JSON property `youtubePlaylistInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaYouTubePlaylistInfo]
        attr_accessor :youtube_playlist_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @artist_name = args[:artist_name] if args.key?(:artist_name)
          @audiobook_info = args[:audiobook_info] if args.key?(:audiobook_info)
          @content_type = args[:content_type] if args.key?(:content_type)
          @image = args[:image] if args.key?(:image)
          @name = args[:name] if args.key?(:name)
          @news_info = args[:news_info] if args.key?(:news_info)
          @personal_data_ingestion_engine = args[:personal_data_ingestion_engine] if args.key?(:personal_data_ingestion_engine)
          @playlist_visibility = args[:playlist_visibility] if args.key?(:playlist_visibility)
          @podcast_info = args[:podcast_info] if args.key?(:podcast_info)
          @primary_entity_mid = args[:primary_entity_mid] if args.key?(:primary_entity_mid)
          @provider_info = args[:provider_info] if args.key?(:provider_info)
          @purchase_info = args[:purchase_info] if args.key?(:purchase_info)
          @radio_info = args[:radio_info] if args.key?(:radio_info)
          @rental_info = args[:rental_info] if args.key?(:rental_info)
          @source = args[:source] if args.key?(:source)
          @youtube_playlist_info = args[:youtube_playlist_info] if args.key?(:youtube_playlist_info)
        end
      end
      
      # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
      # to annotate spans instead of MediaAnnotation. This prevents exponential
      # explosion of interpretations (consider [play $song by $artist on $device]) and
      # allows us to have simpler tests for grammar.
      class NlpSemanticParsingModelsMediaMediaAnnotationList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotation`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotation>]
        attr_accessor :annotation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation = args[:annotation] if args.key?(:annotation)
        end
      end
      
      # A media provider and the deeplinks provided by the provider. MediaProviderInfo
      # is an abstraction for topics of multiple media related KG types under /base/
      # mediaasset domain and /media_common. It's often eligible for topics of media
      # related KG types like /broadcast/radio_station, /film/film, /music/artist, /
      # music/album, /music/recording_cluster, /music/recording, /tv/tv_program, etc.
      # See go/media-pq for design details. Next ID: 6
      class NlpSemanticParsingModelsMediaMediaProviderInfo
        include Google::Apis::Core::Hashable
      
        # Deeplinks provided by the provider. If empty it indicates that the media is
        # unavailable with the provider, e.g. due to country restrictions or limited
        # catalog.
        # Corresponds to the JSON property `deeplinkInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaDeeplinkInfo>]
        attr_accessor :deeplink_info
      
        # The unique and reverse unique provider enumerator in KG (e.g., "ORANGE_SPAIN"
        # for /g/11h6nkfyrm). It is more stable than the KG mid. See go/kema-api#keys.
        # Some mids cannot have the enumerator property due to historical reason (e.g.,
        # multiple media providers were created for iTunes and only ""/g/11fhyxjwt5" has
        # provider enumerator as "ITUNES_NEW" in KG). These entities need to have hard-
        # coded key (e.g., "/m/019g58" has key "ITUNES") kept outside of KG.
        # Corresponds to the JSON property `kgProviderKey`
        # @return [String]
        attr_accessor :kg_provider_key
      
        # Media ID of a MediaItem in a MediaBrowseTree (MBT). This field is used to play
        # a specific media item from MBT using playFromMediaId API.
        # Corresponds to the JSON property `mediaId`
        # @return [String]
        attr_accessor :media_id
      
        # The machine ID (MID) of the media provider.
        # Corresponds to the JSON property `providerMid`
        # @return [String]
        attr_accessor :provider_mid
      
        # The name of the media provider.
        # Corresponds to the JSON property `providerName`
        # @return [String]
        attr_accessor :provider_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deeplink_info = args[:deeplink_info] if args.key?(:deeplink_info)
          @kg_provider_key = args[:kg_provider_key] if args.key?(:kg_provider_key)
          @media_id = args[:media_id] if args.key?(:media_id)
          @provider_mid = args[:provider_mid] if args.key?(:provider_mid)
          @provider_name = args[:provider_name] if args.key?(:provider_name)
        end
      end
      
      # Example: "Casablanca"
      class NlpSemanticParsingModelsMediaMovie
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # 
        # Corresponds to the JSON property `providerMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaProviderMetadata>]
        attr_accessor :provider_metadata
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "Casablanca"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @provider_metadata = args[:provider_metadata] if args.key?(:provider_metadata)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "The Beatles"
      class NlpSemanticParsingModelsMediaMusicArtist
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # If true, indicates the user wants their favorite album. Like [play my favorite
        # album my Eminem]
        # Corresponds to the JSON property `favorite`
        # @return [Boolean]
        attr_accessor :favorite
        alias_method :favorite?, :favorite
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # More from this artist.
        # Corresponds to the JSON property `playMore`
        # @return [Boolean]
        attr_accessor :play_more
        alias_method :play_more?, :play_more
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "The Beatles"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @favorite = args[:favorite] if args.key?(:favorite)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @play_more = args[:play_more] if args.key?(:play_more)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "British Invasion"
      class NlpSemanticParsingModelsMediaMusicGenre
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # More from this genre.
        # Corresponds to the JSON property `playMore`
        # @return [Boolean]
        attr_accessor :play_more
        alias_method :play_more?, :play_more
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "British Invasion"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @play_more = args[:play_more] if args.key?(:play_more)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "gym playlist"
      class NlpSemanticParsingModelsMediaMusicPlaylist
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # If the model is confident that this is a bizarre long-tail mood-based playlist,
        # it can send a signal to downstream systems (that might do things like
        # generate random music) Example: * [play music for brushing my teeth with the
        # lights off on tuesday] This is pretty much an 'easter egg' -- it is not
        # critical.
        # Corresponds to the JSON property `longtailMood`
        # @return [Boolean]
        attr_accessor :longtail_mood
        alias_method :longtail_mood?, :longtail_mood
      
        # Optional, some canonical name for the playlist.
        # Corresponds to the JSON property `normalizedText`
        # @return [String]
        attr_accessor :normalized_text
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "80s remix" (tokenized)
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # 
        # Corresponds to the JSON property `special`
        # @return [String]
        attr_accessor :special
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @longtail_mood = args[:longtail_mood] if args.key?(:longtail_mood)
          @normalized_text = args[:normalized_text] if args.key?(:normalized_text)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @special = args[:special] if args.key?(:special)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMediaNewsInfo
        include Google::Apis::Core::Hashable
      
        # The docid of the news result from News360 backend.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # Indicates how the type of the news result.
        # Corresponds to the JSON property `newsContentType`
        # @return [String]
        attr_accessor :news_content_type
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `publicationTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :publication_time
      
        # The publisher of the news.
        # Corresponds to the JSON property `publisher`
        # @return [String]
        attr_accessor :publisher
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @news_content_type = args[:news_content_type] if args.key?(:news_content_type)
          @publication_time = args[:publication_time] if args.key?(:publication_time)
          @publisher = args[:publisher] if args.key?(:publisher)
        end
      end
      
      # Example: "ukraine" in a query like "read me news about Ukraine"
      class NlpSemanticParsingModelsMediaNewsTopic
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Represents BUY and RENT offers and associated cost info. Next ID: 3
      class NlpSemanticParsingModelsMediaPaidOfferDetail
        include Google::Apis::Core::Hashable
      
        # Represents the price of this offer according to the locale and region.
        # Corresponds to the JSON property `cost`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaCost>]
        attr_accessor :cost
      
        # Specifies the type of offer.
        # Corresponds to the JSON property `paidOfferType`
        # @return [String]
        attr_accessor :paid_offer_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cost = args[:cost] if args.key?(:cost)
          @paid_offer_type = args[:paid_offer_type] if args.key?(:paid_offer_type)
        end
      end
      
      # Example: "This American Life"
      class NlpSemanticParsingModelsMediaPodcast
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Optional, some canonical name for the playlist.
        # Corresponds to the JSON property `normalizedText`
        # @return [String]
        attr_accessor :normalized_text
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "this american life"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @normalized_text = args[:normalized_text] if args.key?(:normalized_text)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMediaPodcastInfo
        include Google::Apis::Core::Hashable
      
        # An internal identifier for the wernicke database that identifies a cluster of
        # multiple sources for a particular podcast.
        # Corresponds to the JSON property `clusterId`
        # @return [String]
        attr_accessor :cluster_id
      
        # GUID of the given podcast episode.
        # Corresponds to the JSON property `episodeGuid`
        # @return [String]
        attr_accessor :episode_guid
      
        # The url for the rss feed providing this podcast.
        # Corresponds to the JSON property `feedUrl`
        # @return [String]
        attr_accessor :feed_url
      
        # LINT.IfChange Next ID: 101
        # Corresponds to the JSON property `podcastRecsFeatures`
        # @return [Google::Apis::ContentwarehouseV1::SuperrootPodcastsRecommendationsPodcastRecsFeatures]
        attr_accessor :podcast_recs_features
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @episode_guid = args[:episode_guid] if args.key?(:episode_guid)
          @feed_url = args[:feed_url] if args.key?(:feed_url)
          @podcast_recs_features = args[:podcast_recs_features] if args.key?(:podcast_recs_features)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Provider metadata associated with video.
      class NlpSemanticParsingModelsMediaProviderMetadata
        include Google::Apis::Core::Hashable
      
        # URL like https://www.netflix.com/title/70305883 -- this is used as a deeplink
        # to play the video.
        # Corresponds to the JSON property `deeplinkUrl`
        # @return [String]
        attr_accessor :deeplink_url
      
        # Provider MID.
        # Corresponds to the JSON property `providerMid`
        # @return [String]
        attr_accessor :provider_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deeplink_url = args[:deeplink_url] if args.key?(:deeplink_url)
          @provider_mid = args[:provider_mid] if args.key?(:provider_mid)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMediaPurchaseInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `orderType`
        # @return [String]
        attr_accessor :order_type
      
        # The time at which the item is purchased.
        # Corresponds to the JSON property `purchaseTimestampSec`
        # @return [Fixnum]
        attr_accessor :purchase_timestamp_sec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @order_type = args[:order_type] if args.key?(:order_type)
          @purchase_timestamp_sec = args[:purchase_timestamp_sec] if args.key?(:purchase_timestamp_sec)
        end
      end
      
      # The quantification of device(s) in the query. For example, "three speakers", "
      # all TVs", etc. Usually, we should have either lexical field or number field.
      # However, there are some special words which we will set both fields. For
      # example, "all 3" will have the semantic: `lexical=ALL, number=3`. Note that "
      # both" is simply modeled as `lexical=ALL`.
      class NlpSemanticParsingModelsMediaQuantification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lexical`
        # @return [String]
        attr_accessor :lexical
      
        # Numerical quantification. E.g., "three speakers".
        # Corresponds to the JSON property `number`
        # @return [Fixnum]
        attr_accessor :number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lexical = args[:lexical] if args.key?(:lexical)
          @number = args[:number] if args.key?(:number)
        end
      end
      
      # Example: "107.7 the bone"
      class NlpSemanticParsingModelsMediaRadio
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # If true, indicates the user wants their favorite radio station to be played.
        # Ex: [play my favorites on radio]
        # Corresponds to the JSON property `favorite`
        # @return [Boolean]
        attr_accessor :favorite
        alias_method :favorite?, :favorite
      
        # Defines a frequency for a terrestrial radio station. For instance, 99.1 FM,
        # 730 AM, etc. Next ID: 4
        # Corresponds to the JSON property `frequency`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaFrequency]
        attr_accessor :frequency
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "107.7"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @favorite = args[:favorite] if args.key?(:favorite)
          @frequency = args[:frequency] if args.key?(:frequency)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Metadata for a radio station (both terrestrial and internet). Next ID: 4
      class NlpSemanticParsingModelsMediaRadioInfo
        include Google::Apis::Core::Hashable
      
        # Defines a frequency for a terrestrial radio station. For instance, 99.1 FM,
        # 730 AM, etc. Next ID: 4
        # Corresponds to the JSON property `frequency`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaFrequency]
        attr_accessor :frequency
      
        # An object representing a latitude/longitude pair. More info in https://cs.corp.
        # google.com/piper///depot/google3/google/type/latlng.proto
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaLatLng]
        attr_accessor :location
      
        # Popularity of the radio station. This will be used in ranking of the radio
        # stations. This value should be between 0 (least popular) and 5 (most popular).
        # Corresponds to the JSON property `popularity`
        # @return [Float]
        attr_accessor :popularity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frequency = args[:frequency] if args.key?(:frequency)
          @location = args[:location] if args.key?(:location)
          @popularity = args[:popularity] if args.key?(:popularity)
        end
      end
      
      # Example: "npr", "bbc", etc.
      class NlpSemanticParsingModelsMediaRadioNetwork
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "npr"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMediaRentalInfo
        include Google::Apis::Core::Hashable
      
        # Time period for users to continue watching.
        # Corresponds to the JSON property `activatePeriodSec`
        # @return [Fixnum]
        attr_accessor :activate_period_sec
      
        # Time period for users to begin watching.
        # Corresponds to the JSON property `grantPeriodSec`
        # @return [Fixnum]
        attr_accessor :grant_period_sec
      
        # The time at which the item is purchased.
        # Corresponds to the JSON property `purchaseTimestampSec`
        # @return [Fixnum]
        attr_accessor :purchase_timestamp_sec
      
        # Time until which ownership is granted
        # Corresponds to the JSON property `validUntilTimestampSec`
        # @return [Fixnum]
        attr_accessor :valid_until_timestamp_sec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @activate_period_sec = args[:activate_period_sec] if args.key?(:activate_period_sec)
          @grant_period_sec = args[:grant_period_sec] if args.key?(:grant_period_sec)
          @purchase_timestamp_sec = args[:purchase_timestamp_sec] if args.key?(:purchase_timestamp_sec)
          @valid_until_timestamp_sec = args[:valid_until_timestamp_sec] if args.key?(:valid_until_timestamp_sec)
        end
      end
      
      # Example: "season 2" of serial
      class NlpSemanticParsingModelsMediaSeasonConstraint
        include Google::Apis::Core::Hashable
      
        # The absolute index of the season. 1 is the first element and -1 is the last
        # element in the sequence, -2 is the second-to-last element, and so on. Examples:
        # "first season" => 1 "3rd season" => 3 "last season" => -1
        # Corresponds to the JSON property `absoluteIndex`
        # @return [Fixnum]
        attr_accessor :absolute_index
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # The relative index of the season. Examples: "previous season" => -1 "current
        # season" => 0 "next season" => 1
        # Corresponds to the JSON property `relativeIndex`
        # @return [Fixnum]
        attr_accessor :relative_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @absolute_index = args[:absolute_index] if args.key?(:absolute_index)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @relative_index = args[:relative_index] if args.key?(:relative_index)
        end
      end
      
      # Example: "Hey Jude"
      class NlpSemanticParsingModelsMediaSong
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # If true, indicates the user wants their favorite album. Like [play my favorite
        # song]
        # Corresponds to the JSON property `favorite`
        # @return [Boolean]
        attr_accessor :favorite
        alias_method :favorite?, :favorite
      
        # If true, indicates the user wants the first song. Like [play adele's first
        # song]
        # Corresponds to the JSON property `first`
        # @return [Boolean]
        attr_accessor :first
        alias_method :first?, :first
      
        # Annotation comes from a text annotator. Needed to boost recall. Typically need
        # to be verified in superroot, and have separate scoring.
        # Corresponds to the JSON property `isAnnotatedFromText`
        # @return [Boolean]
        attr_accessor :is_annotated_from_text
        alias_method :is_annotated_from_text?, :is_annotated_from_text
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # If true, indicates the user wants the latest song. Like, [play adele's latest
        # song]
        # Corresponds to the JSON property `latest`
        # @return [Boolean]
        attr_accessor :latest
        alias_method :latest?, :latest
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "Hey Jude."
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @favorite = args[:favorite] if args.key?(:favorite)
          @first = args[:first] if args.key?(:first)
          @is_annotated_from_text = args[:is_annotated_from_text] if args.key?(:is_annotated_from_text)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @latest = args[:latest] if args.key?(:latest)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Example: "Breaking Bad"
      class NlpSemanticParsingModelsMediaTvShow
        include Google::Apis::Core::Hashable
      
        # List of MediaAnnotation. Media annotators should use the MediaAnnotationList
        # to annotate spans instead of MediaAnnotation. This prevents exponential
        # explosion of interpretations (consider [play $song by $artist on $device]) and
        # allows us to have simpler tests for grammar.
        # Corresponds to the JSON property `annotationList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaMediaAnnotationList]
        attr_accessor :annotation_list
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Is annotated by Nimble for the media Fast Path.
        # Corresponds to the JSON property `isFromFastPath`
        # @return [Boolean]
        attr_accessor :is_from_fast_path
        alias_method :is_from_fast_path?, :is_from_fast_path
      
        # 
        # Corresponds to the JSON property `providerMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMediaProviderMetadata>]
        attr_accessor :provider_metadata
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qref`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref
      
        # Required, corresponds to the raw text, like "Breaking Bad"
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_list = args[:annotation_list] if args.key?(:annotation_list)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_from_fast_path = args[:is_from_fast_path] if args.key?(:is_from_fast_path)
          @provider_metadata = args[:provider_metadata] if args.key?(:provider_metadata)
          @qref = args[:qref] if args.key?(:qref)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Provide the deeplink information specific to YouTube PMAs. Next ID: 3
      class NlpSemanticParsingModelsMediaYouTubeDeeplinkInfo
        include Google::Apis::Core::Hashable
      
        # See go/yt-clicktracking. Serialized youtube.api.innertube.
        # InnerTubeClickTrackingProto.
        # Corresponds to the JSON property `clickTrackingId`
        # @return [String]
        attr_accessor :click_tracking_id
      
        # For YouTube Channels, by default the deeplink is set to be the playlist of all
        # uploads from the channel. This field is used for YouTube in-app browse when we
        # need the YouTube channel's main page url. We will use the uploader_channel_id
        # to construct the needed channel deeplink.
        # Corresponds to the JSON property `uploaderChannelId`
        # @return [String]
        attr_accessor :uploader_channel_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @click_tracking_id = args[:click_tracking_id] if args.key?(:click_tracking_id)
          @uploader_channel_id = args[:uploader_channel_id] if args.key?(:uploader_channel_id)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMediaYouTubePlaylistInfo
        include Google::Apis::Core::Hashable
      
        # Count of videos in the YouTube playlist that are playable in WoodStock. For
        # performance reasons the maximum value this field can reach is capped, see:
        # kMaxVideosPerPlaylistForSearchMetadata.
        # Corresponds to the JSON property `numVidsPlayableInWoodstock`
        # @return [Fixnum]
        attr_accessor :num_vids_playable_in_woodstock
      
        # Total number of videos present in the retrieved playlist.
        # Corresponds to the JSON property `videoCount`
        # @return [Fixnum]
        attr_accessor :video_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_vids_playable_in_woodstock = args[:num_vids_playable_in_woodstock] if args.key?(:num_vids_playable_in_woodstock)
          @video_count = args[:video_count] if args.key?(:video_count)
        end
      end
      
      # 
      class NlpSemanticParsingModelsMoneyCurrency
        include Google::Apis::Core::Hashable
      
        # KG Currency mid
        # Corresponds to the JSON property `freebaseMid`
        # @return [String]
        attr_accessor :freebase_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @freebase_mid = args[:freebase_mid] if args.key?(:freebase_mid)
        end
      end
      
      # Represent a money quantity
      class NlpSemanticParsingModelsMoneyMoney
        include Google::Apis::Core::Hashable
      
        # Next ID: 9
        # Corresponds to the JSON property `amount`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberNumber]
        attr_accessor :amount
      
        # 
        # Corresponds to the JSON property `currency`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMoneyCurrency]
        attr_accessor :currency
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amount = args[:amount] if args.key?(:amount)
          @currency = args[:currency] if args.key?(:currency)
        end
      end
      
      # Corresponds to an entry in our hand-curated Nimble table of providers.
      class NlpSemanticParsingModelsNarrativeNewsNewsProvider
        include Google::Apis::Core::Hashable
      
        # Aqua annotation data for news provider. This proto is added as an extension to
        # NimbleAnnotationData.semantics_proto for nimble annotation.
        # Corresponds to the JSON property `data`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsNewsProviderAnnotationData]
        attr_accessor :data
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # OnDevice describes the device(s) to perform an action. This message type can
      # be imported in action messages as an argument.
      class NlpSemanticParsingModelsOnDevice
        include Google::Apis::Core::Hashable
      
        # The device(s) to perform an action.
        # Corresponds to the JSON property `device`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsDevice>]
        attr_accessor :device
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device = args[:device] if args.key?(:device)
        end
      end
      
      # 
      class NlpSemanticParsingModelsPersonPerson
        include Google::Apis::Core::Hashable
      
        # Alternative names like "John" for "Joan", with info such as
        # RecognitionAlternateSource indicating where is it from.
        # Corresponds to the JSON property `alternativeNameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewriteAlternativeNameInfo>]
        attr_accessor :alternative_name_info
      
        # Alternative names, e.g., names with similar pronunciation, Kathy and Cathy.
        # Corresponds to the JSON property `alternativeNames`
        # @return [Array<String>]
        attr_accessor :alternative_names
      
        # 
        # Corresponds to the JSON property `annotationSource`
        # @return [Array<String>]
        attr_accessor :annotation_source
      
        # Contact metadata. Only available for personal contact.
        # Corresponds to the JSON property `contactData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewritePersonalContactData>]
        attr_accessor :contact_data
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Indicates whether $Person is used for person-group reference. If true, then
        # the PersonalContactData in repeated contact_data field probably correspond to
        # a group of different persons, where $Person is used to represent family, kids,
        # parents, etc.
        # Corresponds to the JSON property `isPersonGroupReference`
        # @return [Boolean]
        attr_accessor :is_person_group_reference
        alias_method :is_person_group_reference?, :is_person_group_reference
      
        # Whether the person is from personal contacts (e.g. Focus contacts or device
        # contacts) or the person is constructed from a Gaia profile visible to the user
        # (e.g. via Family Service).
        # Corresponds to the JSON property `isPersonalContact`
        # @return [Boolean]
        attr_accessor :is_personal_contact
        alias_method :is_personal_contact?, :is_personal_contact
      
        # The name of the person without normalizations, preserves casing of the raw
        # text, but removes possible prefix/suffix. For example: raw_text: "Mr. John"
        # normalized_text: "john" name: "John" raw_text: "Tüll" normalized_text: "tuell"
        # name: "Tüll"
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Normalized text produced by annotator. Some annotators generate a normalized
        # version to help better match with contact list.
        # Corresponds to the JSON property `normalizedText`
        # @return [String]
        attr_accessor :normalized_text
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `pkgSemantics`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :pkg_semantics
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternative_name_info = args[:alternative_name_info] if args.key?(:alternative_name_info)
          @alternative_names = args[:alternative_names] if args.key?(:alternative_names)
          @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
          @contact_data = args[:contact_data] if args.key?(:contact_data)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @is_person_group_reference = args[:is_person_group_reference] if args.key?(:is_person_group_reference)
          @is_personal_contact = args[:is_personal_contact] if args.key?(:is_personal_contact)
          @name = args[:name] if args.key?(:name)
          @normalized_text = args[:normalized_text] if args.key?(:normalized_text)
          @pkg_semantics = args[:pkg_semantics] if args.key?(:pkg_semantics)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # Recurrence rule for specifying date- and time-based repetition for tasks. Next
      # id: 12.
      class NlpSemanticParsingModelsRecurrence
        include Google::Apis::Core::Hashable
      
        # Pattern for when in the day the repeating task should trigger. Applies to all
        # frequencies greater than or equal to DAILY. Exactly one of the containing
        # fields should be set (i.e. a specific time or period).
        # Corresponds to the JSON property `dailyPattern`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceDailyPattern]
        attr_accessor :daily_pattern
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Multiplier on the frequency of the recurrence. Use this to specify patterns
        # that recur every X days, months, years, etc. Example: [remind me to call mom
        # every 2nd week]. Default is 1 (every day, every month, every year). Floating
        # point numbers are understood and rounded to the nearest integer. E.g. "every 2.
        # 8 months" => (every 3)
        # Corresponds to the JSON property `every`
        # @return [Fixnum]
        attr_accessor :every
      
        # Required. The high-level frequency of the recurrence.
        # Corresponds to the JSON property `frequency`
        # @return [String]
        attr_accessor :frequency
      
        # Pattern for a MONTHLY recurrence. A MONTHLY recurrence may be specified in
        # four different ways. These fields should be set in a mutually exclusive way, i.
        # e.: ((month_day OR last_day) XOR (week_day AND (week_day_number OR last_week)))
        # 1. Absolute days of the month (i.e. the 1st and 15th) or relative day from
        # the end of the month (i.e. -1 for last day, -2 for second-to-last day). Set
        # month_day. 2. [Deprecated] Relative last day of the month. Represented as a
        # boolean since the last absolute day number is dependent on the month. This is
        # just a short-cut for month_day=-1 and is deprecated. Set last_day=true. 3. The
        # nth (or nth-last) specific weekday of the month. For example, the 3rd
        # Wednesday of the month. This represents the 3rd instance of a Wednesday of the
        # month, regardless of what weekday the month started on. It does not
        # necessarily mean the Wednesday on the 3rd week of the month. 4. [Deprecated]
        # The last specific weekday of the month. For example, the last Thursday of the
        # month. This is a short-cut for week_day_number=-1.
        # Corresponds to the JSON property `monthlyPattern`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceMonthlyPattern]
        attr_accessor :monthly_pattern
      
        # How many times the task should be repeated within the frequency interval.
        # Floating point numbers are understood and rounded to the nearest integer. E.g.
        # "3.8 times per week" => (num_instances_in_frequency 4)
        # Corresponds to the JSON property `numInstancesInFrequency`
        # @return [Fixnum]
        attr_accessor :num_instances_in_frequency
      
        # The end of the recurrence can be represented in one of three ways. 1. An
        # abstract DateTime. (inclusive) 2. An absolute timestamp, in milliseconds from
        # UTC epoch. 3. A number of occurrences. Exactly one of the fields [
        # end_date_time, end_millis, num_occurrences] in this message must be set.
        # Repeating tasks for which the user did not specify an end date are
        # automatically given a reasonable end conditions by the system and auto_renew
        # will be set to true. Similarly, if the user- provided end date is too far in
        # the future to reasonably create all instances, the server will set an
        # auto_renew_until end condition.
        # Corresponds to the JSON property `recurrenceEnd`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceRecurrenceEnd]
        attr_accessor :recurrence_end
      
        # The start of the recurrence can be represented either as a DateTime or a
        # timestamp in milliseconds from UTC epoch. Exactly one of the fields of this
        # message must be set.
        # Corresponds to the JSON property `recurrenceStart`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceRecurrenceStart]
        attr_accessor :recurrence_start
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `time`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :time
      
        # Pattern for a WEEKLY recurrence. You must specify at least one week_day.
        # Corresponds to the JSON property `weeklyPattern`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceWeeklyPattern]
        attr_accessor :weekly_pattern
      
        # Pattern for a YEARLY recurrence. A YEARLY recurrence is specified using a
        # monthly pattern and a set of months the pattern applies to. Some examples: "
        # Every January 16" : monthly_pattern ` month_day = 16; ` year_month = JANUARY; "
        # Last day of every April and August" : monthly_pattern ` last_day = true; `
        # year_month = APRIL, AUGUST
        # Corresponds to the JSON property `yearlyPattern`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceYearlyPattern]
        attr_accessor :yearly_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @daily_pattern = args[:daily_pattern] if args.key?(:daily_pattern)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @every = args[:every] if args.key?(:every)
          @frequency = args[:frequency] if args.key?(:frequency)
          @monthly_pattern = args[:monthly_pattern] if args.key?(:monthly_pattern)
          @num_instances_in_frequency = args[:num_instances_in_frequency] if args.key?(:num_instances_in_frequency)
          @recurrence_end = args[:recurrence_end] if args.key?(:recurrence_end)
          @recurrence_start = args[:recurrence_start] if args.key?(:recurrence_start)
          @time = args[:time] if args.key?(:time)
          @weekly_pattern = args[:weekly_pattern] if args.key?(:weekly_pattern)
          @yearly_pattern = args[:yearly_pattern] if args.key?(:yearly_pattern)
        end
      end
      
      # Pattern for when in the day the repeating task should trigger. Applies to all
      # frequencies greater than or equal to DAILY. Exactly one of the containing
      # fields should be set (i.e. a specific time or period).
      class NlpSemanticParsingModelsRecurrenceDailyPattern
        include Google::Apis::Core::Hashable
      
        # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
        # overlapping and unrelated annotations. One would have a start_date = Friday
        # and the other would have start_time = 9am. It's possible for Friday to be one
        # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
        # Corresponds to the JSON property `dayPeriod`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDateTimeAnnotation]
        attr_accessor :day_period
      
        # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
        # overlapping and unrelated annotations. One would have a start_date = Friday
        # and the other would have start_time = 9am. It's possible for Friday to be one
        # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
        # Corresponds to the JSON property `timeOfDay`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDateTimeAnnotation]
        attr_accessor :time_of_day
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @day_period = args[:day_period] if args.key?(:day_period)
          @time_of_day = args[:time_of_day] if args.key?(:time_of_day)
        end
      end
      
      # Pattern for a MONTHLY recurrence. A MONTHLY recurrence may be specified in
      # four different ways. These fields should be set in a mutually exclusive way, i.
      # e.: ((month_day OR last_day) XOR (week_day AND (week_day_number OR last_week)))
      # 1. Absolute days of the month (i.e. the 1st and 15th) or relative day from
      # the end of the month (i.e. -1 for last day, -2 for second-to-last day). Set
      # month_day. 2. [Deprecated] Relative last day of the month. Represented as a
      # boolean since the last absolute day number is dependent on the month. This is
      # just a short-cut for month_day=-1 and is deprecated. Set last_day=true. 3. The
      # nth (or nth-last) specific weekday of the month. For example, the 3rd
      # Wednesday of the month. This represents the 3rd instance of a Wednesday of the
      # month, regardless of what weekday the month started on. It does not
      # necessarily mean the Wednesday on the 3rd week of the month. 4. [Deprecated]
      # The last specific weekday of the month. For example, the last Thursday of the
      # month. This is a short-cut for week_day_number=-1.
      class NlpSemanticParsingModelsRecurrenceMonthlyPattern
        include Google::Apis::Core::Hashable
      
        # Special flag to indicate the last day of the month, equivalent to setting
        # month_day to -1. Deprecated, use month_day=-1 instead.
        # Corresponds to the JSON property `lastDay`
        # @return [Boolean]
        attr_accessor :last_day
        alias_method :last_day?, :last_day
      
        # Special flag to indicate a week_day in the last week of the month, as this
        # cannot be captured by week_day_number. Deprecated, use week_day_number=-1
        # instead.
        # Corresponds to the JSON property `lastWeek`
        # @return [Boolean]
        attr_accessor :last_week
        alias_method :last_week?, :last_week
      
        # Absolute day of the month (if positive) or relative day from the end of the
        # month (if negative). Example: 2nd and 20th of the month [2, 20]. Example: Last
        # day of the month [-1]. Positive values should correspond to actual calendar
        # day number (indexing starts at 1).
        # Corresponds to the JSON property `monthDay`
        # @return [Array<Fixnum>]
        attr_accessor :month_day
      
        # For capturing the nth weekday of the month. Use together with week_day_number
        # or last_week to specify n.
        # Corresponds to the JSON property `weekDay`
        # @return [String]
        attr_accessor :week_day
      
        # The nth occurrence of week_day to match. I.e. For 3rd Wednesday of the month,
        # week_day = WEDNESDAY and week_day_number = 3. Values beyond the end of the
        # month are skipped. If negative, this is interpreted as the nth-to-last
        # occurrence of the week day in the month. I.e. for last Thursday of the month,
        # week_day = THURSDAY and week_day_number = -1.
        # Corresponds to the JSON property `weekDayNumber`
        # @return [Fixnum]
        attr_accessor :week_day_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_day = args[:last_day] if args.key?(:last_day)
          @last_week = args[:last_week] if args.key?(:last_week)
          @month_day = args[:month_day] if args.key?(:month_day)
          @week_day = args[:week_day] if args.key?(:week_day)
          @week_day_number = args[:week_day_number] if args.key?(:week_day_number)
        end
      end
      
      # The end of the recurrence can be represented in one of three ways. 1. An
      # abstract DateTime. (inclusive) 2. An absolute timestamp, in milliseconds from
      # UTC epoch. 3. A number of occurrences. Exactly one of the fields [
      # end_date_time, end_millis, num_occurrences] in this message must be set.
      # Repeating tasks for which the user did not specify an end date are
      # automatically given a reasonable end conditions by the system and auto_renew
      # will be set to true. Similarly, if the user- provided end date is too far in
      # the future to reasonably create all instances, the server will set an
      # auto_renew_until end condition.
      class NlpSemanticParsingModelsRecurrenceRecurrenceEnd
        include Google::Apis::Core::Hashable
      
        # Should be used in cases where the size of the recurrence is infinite (no end
        # date specified), in which case we rely on an offline process to extend. Set by
        # server only, setting it on a new recurrence will throw an exception.
        # Corresponds to the JSON property `autoRenew`
        # @return [Boolean]
        attr_accessor :auto_renew
        alias_method :auto_renew?, :auto_renew
      
        # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
        # overlapping and unrelated annotations. One would have a start_date = Friday
        # and the other would have start_time = 9am. It's possible for Friday to be one
        # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
        # Corresponds to the JSON property `autoRenewUntil`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDateTimeAnnotation]
        attr_accessor :auto_renew_until
      
        # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
        # overlapping and unrelated annotations. One would have a start_date = Friday
        # and the other would have start_time = 9am. It's possible for Friday to be one
        # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
        # Corresponds to the JSON property `endDateTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDateTimeAnnotation]
        attr_accessor :end_date_time
      
        # Deprecated - prefer end_date_time.absolute_time_ms.
        # Corresponds to the JSON property `endMillis`
        # @return [Fixnum]
        attr_accessor :end_millis
      
        # Note that auto-renewing is not supported in conjunction with num_occurrences.
        # Therefore we impose a hard limit of 1000 when using this field.
        # Corresponds to the JSON property `numOccurrences`
        # @return [Fixnum]
        attr_accessor :num_occurrences
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
          @auto_renew_until = args[:auto_renew_until] if args.key?(:auto_renew_until)
          @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
          @end_millis = args[:end_millis] if args.key?(:end_millis)
          @num_occurrences = args[:num_occurrences] if args.key?(:num_occurrences)
        end
      end
      
      # The start of the recurrence can be represented either as a DateTime or a
      # timestamp in milliseconds from UTC epoch. Exactly one of the fields of this
      # message must be set.
      class NlpSemanticParsingModelsRecurrenceRecurrenceStart
        include Google::Apis::Core::Hashable
      
        # Example: "Remind me to go to the store on (Friday) (9am)" would output two non-
        # overlapping and unrelated annotations. One would have a start_date = Friday
        # and the other would have start_time = 9am. It's possible for Friday to be one
        # of several upcoming Friday's, so start_date is a repeated field. Next ID: 10
        # Corresponds to the JSON property `startDateTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDateTimeAnnotation]
        attr_accessor :start_date_time
      
        # Deprecated - prefer start_date_time.absolute_time_ms.
        # Corresponds to the JSON property `startMillis`
        # @return [Fixnum]
        attr_accessor :start_millis
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
          @start_millis = args[:start_millis] if args.key?(:start_millis)
        end
      end
      
      # Pattern for a WEEKLY recurrence. You must specify at least one week_day.
      class NlpSemanticParsingModelsRecurrenceWeeklyPattern
        include Google::Apis::Core::Hashable
      
        # Set of weekdays the recurrence applies to.
        # Corresponds to the JSON property `weekDay`
        # @return [Array<String>]
        attr_accessor :week_day
      
        # 
        # Corresponds to the JSON property `weeklyPatternEnd`
        # @return [String]
        attr_accessor :weekly_pattern_end
      
        # 
        # Corresponds to the JSON property `weeklyPatternStart`
        # @return [String]
        attr_accessor :weekly_pattern_start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @week_day = args[:week_day] if args.key?(:week_day)
          @weekly_pattern_end = args[:weekly_pattern_end] if args.key?(:weekly_pattern_end)
          @weekly_pattern_start = args[:weekly_pattern_start] if args.key?(:weekly_pattern_start)
        end
      end
      
      # Pattern for a YEARLY recurrence. A YEARLY recurrence is specified using a
      # monthly pattern and a set of months the pattern applies to. Some examples: "
      # Every January 16" : monthly_pattern ` month_day = 16; ` year_month = JANUARY; "
      # Last day of every April and August" : monthly_pattern ` last_day = true; `
      # year_month = APRIL, AUGUST
      class NlpSemanticParsingModelsRecurrenceYearlyPattern
        include Google::Apis::Core::Hashable
      
        # Pattern for a MONTHLY recurrence. A MONTHLY recurrence may be specified in
        # four different ways. These fields should be set in a mutually exclusive way, i.
        # e.: ((month_day OR last_day) XOR (week_day AND (week_day_number OR last_week)))
        # 1. Absolute days of the month (i.e. the 1st and 15th) or relative day from
        # the end of the month (i.e. -1 for last day, -2 for second-to-last day). Set
        # month_day. 2. [Deprecated] Relative last day of the month. Represented as a
        # boolean since the last absolute day number is dependent on the month. This is
        # just a short-cut for month_day=-1 and is deprecated. Set last_day=true. 3. The
        # nth (or nth-last) specific weekday of the month. For example, the 3rd
        # Wednesday of the month. This represents the 3rd instance of a Wednesday of the
        # month, regardless of what weekday the month started on. It does not
        # necessarily mean the Wednesday on the 3rd week of the month. 4. [Deprecated]
        # The last specific weekday of the month. For example, the last Thursday of the
        # month. This is a short-cut for week_day_number=-1.
        # Corresponds to the JSON property `monthlyPattern`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsRecurrenceMonthlyPattern]
        attr_accessor :monthly_pattern
      
        # The months of the year to apply the pattern.
        # Corresponds to the JSON property `yearMonth`
        # @return [Array<String>]
        attr_accessor :year_month
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @monthly_pattern = args[:monthly_pattern] if args.key?(:monthly_pattern)
          @year_month = args[:year_month] if args.key?(:year_month)
        end
      end
      
      # A brand can be any combination of text or mid.
      class NlpSemanticParsingModelsShoppingAssistantBrandPhrase
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # A merchant that sells products.
      class NlpSemanticParsingModelsShoppingAssistantMerchant
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # Merchant Center identifier for LIA merchants.
        # Corresponds to the JSON property `localMerchantId`
        # @return [Fixnum]
        attr_accessor :local_merchant_id
      
        # 
        # Corresponds to the JSON property `mcid`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantMerchantMerchantCenterId>]
        attr_accessor :mcid
      
        # Merchant Center identifier for GSX merchants. Deprecated: use MerchantCenterId.
        # Corresponds to the JSON property `merchantId`
        # @return [Array<Fixnum>]
        attr_accessor :merchant_id
      
        # Optional. Knowledge Graph identifier for the merchant.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # A name for the merchant. Example: Walmart
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @local_merchant_id = args[:local_merchant_id] if args.key?(:local_merchant_id)
          @mcid = args[:mcid] if args.key?(:mcid)
          @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Note: A merchant may have multiple merchant center ids, and each one can have
      # multiple purposes. The existing fields merchant_id, local_merchant_id fields
      # are not enough to capture this. Instead we will have a repeated field name
      # mcid with this structure.
      class NlpSemanticParsingModelsShoppingAssistantMerchantMerchantCenterId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `isGsx`
        # @return [Boolean]
        attr_accessor :is_gsx
        alias_method :is_gsx?, :is_gsx
      
        # 
        # Corresponds to the JSON property `isLocal`
        # @return [Boolean]
        attr_accessor :is_local
        alias_method :is_local?, :is_local
      
        # 
        # Corresponds to the JSON property `isPla`
        # @return [Boolean]
        attr_accessor :is_pla
        alias_method :is_pla?, :is_pla
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @is_gsx = args[:is_gsx] if args.key?(:is_gsx)
          @is_local = args[:is_local] if args.key?(:is_local)
          @is_pla = args[:is_pla] if args.key?(:is_pla)
        end
      end
      
      # A product for sale from a particular merchant, possibly available at a
      # specific store.
      class NlpSemanticParsingModelsShoppingAssistantOffer
        include Google::Apis::Core::Hashable
      
        # The offer document id as used in Shopping's metadata.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # A merchant that sells products.
        # Corresponds to the JSON property `merchant`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantMerchant]
        attr_accessor :merchant
      
        # Represent a money quantity
        # Corresponds to the JSON property `price`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMoneyMoney]
        attr_accessor :price
      
        # A product that can be purchased.
        # Corresponds to the JSON property `product`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProduct]
        attr_accessor :product
      
        # A merchant's physical store.
        # Corresponds to the JSON property `store`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantStore]
        attr_accessor :store
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @merchant = args[:merchant] if args.key?(:merchant)
          @price = args[:price] if args.key?(:price)
          @product = args[:product] if args.key?(:product)
          @store = args[:store] if args.key?(:store)
        end
      end
      
      # A phrase parsed from a user query.
      class NlpSemanticParsingModelsShoppingAssistantPhrase
        include Google::Apis::Core::Hashable
      
        # A brand can be any combination of text or mid.
        # Corresponds to the JSON property `brand`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantBrandPhrase]
        attr_accessor :brand
      
        # A product for sale from a particular merchant, possibly available at a
        # specific store.
        # Corresponds to the JSON property `offer`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantOffer]
        attr_accessor :offer
      
        # A product can be any combination of raw_text and metadata (including mid,
        # shopping product catalog title/id, and media attributes). A product phrase
        # refers to a product at the catalog entry level and/or a media product. Media
        # product contains information about author and media title TODO(ppoudyal) Add
        # genre and order_in_series to MediaProduct
        # Corresponds to the JSON property `product`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductPhrase]
        attr_accessor :product
      
        # A span in a user query that could not be identified as any other type of `
        # Phrase`.
        # Corresponds to the JSON property `unrecognized`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantUnrecognizedPhrase]
        attr_accessor :unrecognized
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @brand = args[:brand] if args.key?(:brand)
          @offer = args[:offer] if args.key?(:offer)
          @product = args[:product] if args.key?(:product)
          @unrecognized = args[:unrecognized] if args.key?(:unrecognized)
        end
      end
      
      # A product that can be purchased.
      class NlpSemanticParsingModelsShoppingAssistantProduct
        include Google::Apis::Core::Hashable
      
        # The shopping catalog identifier.
        # Corresponds to the JSON property `catalogId`
        # @return [Fixnum]
        attr_accessor :catalog_id
      
        # Represent a money quantity
        # Corresponds to the JSON property `maxPrice`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMoneyMoney]
        attr_accessor :max_price
      
        # A media product that can be purchased
        # Corresponds to the JSON property `mediaProduct`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProduct]
        attr_accessor :media_product
      
        # Optional. Knowledge Graph identifier for the product.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Represent a money quantity
        # Corresponds to the JSON property `minPrice`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsMoneyMoney]
        attr_accessor :min_price
      
        # Title of the product. Example: Moto X Blue 64GB Note: This refers to only the
        # catalog title not user specified phrase
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @catalog_id = args[:catalog_id] if args.key?(:catalog_id)
          @max_price = args[:max_price] if args.key?(:max_price)
          @media_product = args[:media_product] if args.key?(:media_product)
          @mid = args[:mid] if args.key?(:mid)
          @min_price = args[:min_price] if args.key?(:min_price)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Whether the product being described fits into specific categories (e.g., "
      # video games").
      class NlpSemanticParsingModelsShoppingAssistantProductClassification
        include Google::Apis::Core::Hashable
      
        # TODO(ppoudyal) Expand confidence to cases where the product phrase might be a
        # book/movie/video_game but isn't just a title The score (between 0 - 1)
        # measuring the confidence that product
        # Corresponds to the JSON property `bookConfidence`
        # @return [Float]
        attr_accessor :book_confidence
      
        # TODO(ppoudyal) Deprecate is_video_game once the score covers all cases covered
        # by $VideoGameProductPhrase The product phrase contains a video game title.
        # Corresponds to the JSON property `isVideoGame`
        # @return [Boolean]
        attr_accessor :is_video_game
        alias_method :is_video_game?, :is_video_game
      
        # phrase mentions a book title The score (between 0 - 1) measuring the
        # confidence that product
        # Corresponds to the JSON property `movieConfidence`
        # @return [Float]
        attr_accessor :movie_confidence
      
        # phrase mentions a movie title The score (between 0 - 1) measuring the
        # confidence that product
        # Corresponds to the JSON property `videoGameConfidence`
        # @return [Float]
        attr_accessor :video_game_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @book_confidence = args[:book_confidence] if args.key?(:book_confidence)
          @is_video_game = args[:is_video_game] if args.key?(:is_video_game)
          @movie_confidence = args[:movie_confidence] if args.key?(:movie_confidence)
          @video_game_confidence = args[:video_game_confidence] if args.key?(:video_game_confidence)
        end
      end
      
      # An expression parsed from a user query that describes a product or set of
      # products.
      class NlpSemanticParsingModelsShoppingAssistantProductExpression
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `grammaticalGender`
        # @return [String]
        attr_accessor :grammatical_gender
      
        # 
        # Corresponds to the JSON property `grammaticalNumber`
        # @return [String]
        attr_accessor :grammatical_number
      
        # Ordered list of phrases that the user used to describe a product.
        # Corresponds to the JSON property `phrases`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantPhrase>]
        attr_accessor :phrases
      
        # Whether the product being described fits into specific categories (e.g., "
        # video games").
        # Corresponds to the JSON property `productClassification`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductClassification]
        attr_accessor :product_classification
      
        # Associated shopping list item info. Only set when the product is come from a
        # shopping list item.
        # Corresponds to the JSON property `shoppingListItemInfo`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantShoppingListItemInfo]
        attr_accessor :shopping_list_item_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @grammatical_gender = args[:grammatical_gender] if args.key?(:grammatical_gender)
          @grammatical_number = args[:grammatical_number] if args.key?(:grammatical_number)
          @phrases = args[:phrases] if args.key?(:phrases)
          @product_classification = args[:product_classification] if args.key?(:product_classification)
          @shopping_list_item_info = args[:shopping_list_item_info] if args.key?(:shopping_list_item_info)
        end
      end
      
      # A media product that can be purchased
      class NlpSemanticParsingModelsShoppingAssistantProductMediaProduct
        include Google::Apis::Core::Hashable
      
        # The author of the media
        # Corresponds to the JSON property `author`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue]
        attr_accessor :author
      
        # The genre of the media
        # Corresponds to the JSON property `genre`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue]
        attr_accessor :genre
      
        # The title of the media Example: The assasin's creed
        # Corresponds to the JSON property `mediaTitle`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue]
        attr_accessor :media_title
      
        # Order in media series (series title is given by the product title)
        # Corresponds to the JSON property `orderInSeries`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue]
        attr_accessor :order_in_series
      
        # The topic of the media
        # Corresponds to the JSON property `topic`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue]
        attr_accessor :topic
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author = args[:author] if args.key?(:author)
          @genre = args[:genre] if args.key?(:genre)
          @media_title = args[:media_title] if args.key?(:media_title)
          @order_in_series = args[:order_in_series] if args.key?(:order_in_series)
          @topic = args[:topic] if args.key?(:topic)
        end
      end
      
      # 
      class NlpSemanticParsingModelsShoppingAssistantProductMediaProductMediaAttributeValue
        include Google::Apis::Core::Hashable
      
        # The knowledge graph identifier for the attribute
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Raw text of the media attribute (eg. author)
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # A product can be any combination of raw_text and metadata (including mid,
      # shopping product catalog title/id, and media attributes). A product phrase
      # refers to a product at the catalog entry level and/or a media product. Media
      # product contains information about author and media title TODO(ppoudyal) Add
      # genre and order_in_series to MediaProduct
      class NlpSemanticParsingModelsShoppingAssistantProductPhrase
        include Google::Apis::Core::Hashable
      
        # A product that can be purchased.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsShoppingAssistantProduct]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metadata = args[:metadata] if args.key?(:metadata)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # 
      class NlpSemanticParsingModelsShoppingAssistantShoppingListItemInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `itemId`
        # @return [String]
        attr_accessor :item_id
      
        # 
        # Corresponds to the JSON property `listId`
        # @return [String]
        attr_accessor :list_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @item_id = args[:item_id] if args.key?(:item_id)
          @list_id = args[:list_id] if args.key?(:list_id)
        end
      end
      
      # A merchant's physical store.
      class NlpSemanticParsingModelsShoppingAssistantStore
        include Google::Apis::Core::Hashable
      
        # Local store identifier.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # There are a few types of locations: - Basic locations are sequences of
        # location elements which can be either actual locations or modifiers. E.g., "
        # Mountain View CA 94040" may be the sequence "Mountain View" (an actual
        # location), "CA" (an actual location, and "94040" (a numeric modifier). -
        # Compound locations: these are two locations combined by a joiner. E.g., "
        # Target in Mountain View CA 94040" has the joiner "in" and two basic locations (
        # "Target", and "Mountain View CA 94040"). Note that the definition is recursive,
        # e.g., "Parking garage near Target in Mountain View". - Vicinity location:
        # indicates an area around a certain location. The area can be defined by time
        # or space. E.g., "within 1 hour of Palo Alto", "10 blocks from Union Square", "
        # a few miles from here". Next ID: 14
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocation]
        attr_accessor :location
      
        # A name for the store. Example: Walmart - Cranberry
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @location = args[:location] if args.key?(:location)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # A span in a user query that could not be identified as any other type of `
      # Phrase`.
      class NlpSemanticParsingModelsShoppingAssistantUnrecognizedPhrase
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # 
      class NlpSemanticParsingNumberFractionNumber
        include Google::Apis::Core::Hashable
      
        # Next ID: 8
        # Corresponds to the JSON property `denominator`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberSimpleNumber]
        attr_accessor :denominator
      
        # Next ID: 8
        # Corresponds to the JSON property `numerator`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberSimpleNumber]
        attr_accessor :numerator
      
        # This field is used to indicate the number of digits after the decimal point in
        # the normalized_value field in number.proto, which contains the floating point
        # representation of the fraction
        # Corresponds to the JSON property `precision`
        # @return [Fixnum]
        attr_accessor :precision
      
        # Next ID: 8
        # Corresponds to the JSON property `wholeNumber`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberSimpleNumber]
        attr_accessor :whole_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @denominator = args[:denominator] if args.key?(:denominator)
          @numerator = args[:numerator] if args.key?(:numerator)
          @precision = args[:precision] if args.key?(:precision)
          @whole_number = args[:whole_number] if args.key?(:whole_number)
        end
      end
      
      # Next ID: 9
      class NlpSemanticParsingNumberNumber
        include Google::Apis::Core::Hashable
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # 
        # Corresponds to the JSON property `fractionNumber`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberFractionNumber]
        attr_accessor :fraction_number
      
        # An optional field that holds whether the number_type number is a normalized
        # spelled-out number or not. This field will not be set in cases when this
        # information is not available.
        # Corresponds to the JSON property `isSpelledOut`
        # @return [Boolean]
        attr_accessor :is_spelled_out
        alias_method :is_spelled_out?, :is_spelled_out
      
        # NumberModifier is used to capture when the expression is not an absolute
        # number, but a number expression to represent an increase/decrease/comparison.
        # E.g. [10 more percent], [5 less].
        # Corresponds to the JSON property `modifier`
        # @return [String]
        attr_accessor :modifier
      
        # Contains a normalized string representation of the numeric value that has: *
        # No digit grouping delimiter (e.g. "," in english). * Decimal mark (if present)
        # as "." (dot). For fraction_number, this contains the floating point
        # representation of the fraction. The number of digits after the decimal point
        # is defined in the precision field of fraction_number.proto.
        # Corresponds to the JSON property `normalizedValue`
        # @return [String]
        attr_accessor :normalized_value
      
        # The raw text of the annotation.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # Next ID: 8
        # Corresponds to the JSON property `simpleNumber`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingNumberSimpleNumber]
        attr_accessor :simple_number
      
        # We expect this field to be set only when is_spelled_out is true.
        # Corresponds to the JSON property `spelledOutType`
        # @return [String]
        attr_accessor :spelled_out_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @fraction_number = args[:fraction_number] if args.key?(:fraction_number)
          @is_spelled_out = args[:is_spelled_out] if args.key?(:is_spelled_out)
          @modifier = args[:modifier] if args.key?(:modifier)
          @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @simple_number = args[:simple_number] if args.key?(:simple_number)
          @spelled_out_type = args[:spelled_out_type] if args.key?(:spelled_out_type)
        end
      end
      
      # Next ID: 8
      class NlpSemanticParsingNumberSimpleNumber
        include Google::Apis::Core::Hashable
      
        # The type of decimal mark that was present before normalization. Note:
        # different locales may use different decimal marks.
        # Corresponds to the JSON property `decimalMark`
        # @return [String]
        attr_accessor :decimal_mark
      
        # The type of digit grouping delimiter that was present before normalization.
        # Note: different locales may use different digit grouping delimiters.
        # Corresponds to the JSON property `groupingDelimiter`
        # @return [String]
        attr_accessor :grouping_delimiter
      
        # We expect this field to be set only when grouping_delimiter is set.
        # Corresponds to the JSON property `groupingSystem`
        # @return [String]
        attr_accessor :grouping_system
      
        # Contains a normalized string representation of the numeric value that has: *
        # No digit grouping delimiter (e.g. "," in english). * Decimal mark (if present)
        # as "." (dot). This field is kept for backward compatibility. The field is also
        # available in number.proto
        # Corresponds to the JSON property `normalizedValue`
        # @return [String]
        attr_accessor :normalized_value
      
        # Stores prefix output by the GRM number grammar (http://b/28623478).
        # Corresponds to the JSON property `prefix`
        # @return [String]
        attr_accessor :prefix
      
        # Stores suffix output
        # Corresponds to the JSON property `suffix`
        # @return [String]
        attr_accessor :suffix
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @decimal_mark = args[:decimal_mark] if args.key?(:decimal_mark)
          @grouping_delimiter = args[:grouping_delimiter] if args.key?(:grouping_delimiter)
          @grouping_system = args[:grouping_system] if args.key?(:grouping_system)
          @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
          @prefix = args[:prefix] if args.key?(:prefix)
          @suffix = args[:suffix] if args.key?(:suffix)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # This message should be wire-equivalent to the Entity proto defined in nlp/
      # semantic_parsing/models/personal_intelligence.proto. The message is cloned
      # here to allow legacy intents to extract entities to slots; trying to add
      # Entity to knowledge_answers::intent_query::ArgumentValue creates a BUILD
      # dependency loop. For the proto used for GwsLogs, see logs/proto/knowledge/
      # interpretation/personal_intelligence.proto.
      class NlpSemanticParsingPersonalIntelligenceEntity
        include Google::Apis::Core::Hashable
      
        # Next ID: 26
        # Corresponds to the JSON property `airlineConfig`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsAirlineConfig]
        attr_accessor :airline_config
      
        # Annotators whose semantics are represented via a protocol message should add
        # to that message a field or extension of this type and set it using Annotator::
        # PopulateAnnotationEvalData to enable span-based evaluation metrics in training.
        # Evaluation is done based on token spans. The byte span aligns with the token
        # span and is used when saving examples. Background: In some settings, the
        # examples used to induce/train a grammar do not specify complete semantics of
        # an annotation. For example, some examples that come from Ewok specify only the
        # span associated with each annotation. This message allows evaluation metrics
        # to test the span by embedding it in the semantics. LINT.IfChange
        # Corresponds to the JSON property `evalData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingAnnotationEvalData]
        attr_accessor :eval_data
      
        # raw string representation
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `qrefAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :qref_annotation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @airline_config = args[:airline_config] if args.key?(:airline_config)
          @eval_data = args[:eval_data] if args.key?(:eval_data)
          @name = args[:name] if args.key?(:name)
          @qref_annotation = args[:qref_annotation] if args.key?(:qref_annotation)
        end
      end
      
      # A collection of any number of QRefAnnotations that designate a Copley Personal
      # Reference and its Resolutions. This is used to handle personalized intents
      # such as "navigate to my hotel" or "when is my mom's anniversary". See go/
      # copley. This Annotation may contain only a reference with no resolutions for
      # the failure case (go/copley-punts). TODO(bhorst) Rename this to remove the
      # Copley codename.
      class NlpSemanticParsingPersonalReferenceAnnotation
        include Google::Apis::Core::Hashable
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `reference`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :reference
      
        # A Copley Personal Resolution represents the resolution of a Reference, e.g. if
        # the user has a reservation at The Kendall Hotel, the reference "my hotel"
        # could be resolved to The Kendall Hotel, and there would be a QRefAnnotation
        # containing the mid and other data. It is possible for there to be zero
        # resolutions for a given reference.
        # Corresponds to the JSON property `resolutions`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation>]
        attr_accessor :resolutions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reference = args[:reference] if args.key?(:reference)
          @resolutions = args[:resolutions] if args.key?(:resolutions)
        end
      end
      
      # In simple cases, each NLU slot will contain one or multiple possible values.
      # But in the case of a composite entity - slots can have a complex tree
      # structure. Each slot can represent a List parameter. List parameters are only
      # allowed at the top level, i.e. lists can't ne nested in maps. Next Id: 9 LINT.
      # IfChange
      class NlpSemanticParsingProtoActionsOnGoogleAogSlot
        include Google::Apis::Core::Hashable
      
        # ID of the entity of this slot.
        # Corresponds to the JSON property `entityId`
        # @return [String]
        attr_accessor :entity_id
      
        # Number of bytes of this slot in resolved query.
        # Corresponds to the JSON property `numBytes`
        # @return [Fixnum]
        attr_accessor :num_bytes
      
        # Part of input text, matched by that slot. In the case of composite slots, each
        # slot should have its own original.
        # Corresponds to the JSON property `original`
        # @return [String]
        attr_accessor :original
      
        # Name of parameter of this slot.
        # Corresponds to the JSON property `parameterName`
        # @return [String]
        attr_accessor :parameter_name
      
        # Oneof doesn't allow list, this message is used to inject list as a possible
        # value into Slot.
        # Corresponds to the JSON property `slotList`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleSlotList]
        attr_accessor :slot_list
      
        # Oneof doesn't allow maps, this message is used to inject map as a possible
        # value into Slot.
        # Corresponds to the JSON property `slotMap`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleSlotMap]
        attr_accessor :slot_map
      
        # Start byte position of this slot in resolved query.
        # Corresponds to the JSON property `startByte`
        # @return [Fixnum]
        attr_accessor :start_byte
      
        # Contains one or more possible values.
        # Corresponds to the JSON property `value`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleSlotValue]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_id = args[:entity_id] if args.key?(:entity_id)
          @num_bytes = args[:num_bytes] if args.key?(:num_bytes)
          @original = args[:original] if args.key?(:original)
          @parameter_name = args[:parameter_name] if args.key?(:parameter_name)
          @slot_list = args[:slot_list] if args.key?(:slot_list)
          @slot_map = args[:slot_map] if args.key?(:slot_map)
          @start_byte = args[:start_byte] if args.key?(:start_byte)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Represents datetime. It can be @sys.date, @sys.time or, in some cases, @sys.
      # date-time. Our platform doesn't track seconds, so this field is omitted.
      # Number of seconds should be considered 0. Hour and minute can be 0 in case of
      # dates. In case of time and dateTime, hours and minutes will represent actual
      # time, even if both of them are 0.
      class NlpSemanticParsingProtoActionsOnGoogleDateTime
        include Google::Apis::Core::Hashable
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `date`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :date
      
        # Represents properties about a matched DateTime value. Will only be populated
        # for @sys.date-time, @sys.date and @sys.time.
        # Corresponds to the JSON property `property`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleDateTimeProperty]
        attr_accessor :property
      
        # Represents a time of day. The date and time zone are either not significant or
        # are specified elsewhere. An API may choose to allow leap seconds. Related
        # types are google.type.Date and `google.protobuf.Timestamp`.
        # Corresponds to the JSON property `time`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeOfDay]
        attr_accessor :time
      
        # Represents a time zone from the [IANA Time Zone Database](https://www.iana.org/
        # time-zones).
        # Corresponds to the JSON property `timeZone`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeTimeZone]
        attr_accessor :time_zone
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date = args[:date] if args.key?(:date)
          @property = args[:property] if args.key?(:property)
          @time = args[:time] if args.key?(:time)
          @time_zone = args[:time_zone] if args.key?(:time_zone)
        end
      end
      
      # Represents properties about a matched DateTime value. Will only be populated
      # for @sys.date-time, @sys.date and @sys.time.
      class NlpSemanticParsingProtoActionsOnGoogleDateTimeProperty
        include Google::Apis::Core::Hashable
      
        # Since datetime is a superset of date, time and date&time, this field is used
        # to indicate which type the associated DateTime object belongs to.
        # Corresponds to the JSON property `datetimeType`
        # @return [String]
        attr_accessor :datetime_type
      
        # The relative relationship between this DateTime value and DateTime&Timezone
        # info provided in ClassifyRequest.
        # Corresponds to the JSON property `relativeDatetimeType`
        # @return [String]
        attr_accessor :relative_datetime_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @datetime_type = args[:datetime_type] if args.key?(:datetime_type)
          @relative_datetime_type = args[:relative_datetime_type] if args.key?(:relative_datetime_type)
        end
      end
      
      # Oneof doesn't allow list, this message is used to inject list as a possible
      # value into Slot.
      class NlpSemanticParsingProtoActionsOnGoogleSlotList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slots`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleAogSlot>]
        attr_accessor :slots
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slots = args[:slots] if args.key?(:slots)
        end
      end
      
      # Oneof doesn't allow maps, this message is used to inject map as a possible
      # value into Slot.
      class NlpSemanticParsingProtoActionsOnGoogleSlotMap
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `slots`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleAogSlot>]
        attr_accessor :slots
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @slots = args[:slots] if args.key?(:slots)
        end
      end
      
      # Contains one or more possible values.
      class NlpSemanticParsingProtoActionsOnGoogleSlotValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `values`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleSlotValueSingleValue>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # Represents an actual value.
      class NlpSemanticParsingProtoActionsOnGoogleSlotValueSingleValue
        include Google::Apis::Core::Hashable
      
        # Represents datetime. It can be @sys.date, @sys.time or, in some cases, @sys.
        # date-time. Our platform doesn't track seconds, so this field is omitted.
        # Number of seconds should be considered 0. Hour and minute can be 0 in case of
        # dates. In case of time and dateTime, hours and minutes will represent actual
        # time, even if both of them are 0.
        # Corresponds to the JSON property `dateTimeValue`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleDateTime]
        attr_accessor :date_time_value
      
        # Represents a string value.
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        # Used by on-device Heron. Contains information about the type of slot value
        # returned.
        # Corresponds to the JSON property `typeValue`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleTypedValue]
        attr_accessor :type_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date_time_value = args[:date_time_value] if args.key?(:date_time_value)
          @string_value = args[:string_value] if args.key?(:string_value)
          @type_value = args[:type_value] if args.key?(:type_value)
        end
      end
      
      # Used by on-device Heron. Contains information about the type of slot value
      # returned.
      class NlpSemanticParsingProtoActionsOnGoogleTypedValue
        include Google::Apis::Core::Hashable
      
        # Represents a boolean value.
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # Represents datetime. It can be @sys.date, @sys.time or, in some cases, @sys.
        # date-time. Our platform doesn't track seconds, so this field is omitted.
        # Number of seconds should be considered 0. Hour and minute can be 0 in case of
        # dates. In case of time and dateTime, hours and minutes will represent actual
        # time, even if both of them are 0.
        # Corresponds to the JSON property `dateTimeValue`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingProtoActionsOnGoogleDateTime]
        attr_accessor :date_time_value
      
        # Represents number value. In accordance to ParamValue fields(https://source.
        # corp.google.com/piper///depot/google3/third_party/java_src/appactions/proto/
        # app_actions_data.proto;rcl=431529042;l=12)
        # Corresponds to the JSON property `numberValue`
        # @return [Float]
        attr_accessor :number_value
      
        # Represents a string value.
        # Corresponds to the JSON property `stringValue`
        # @return [String]
        attr_accessor :string_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @date_time_value = args[:date_time_value] if args.key?(:date_time_value)
          @number_value = args[:number_value] if args.key?(:number_value)
          @string_value = args[:string_value] if args.key?(:string_value)
        end
      end
      
      # The QRefAnnotator annotates spans of input with freebase-ids and collection-
      # information. NEXT ID TO USE: 41
      class NlpSemanticParsingQRefAnnotation
        include Google::Apis::Core::Hashable
      
        # Whether this qref annotation was created by CloseAnswers on Postref.
        # Annotations of this type don't correspond to a particular mention of the
        # entity on the query but rather to an interpretation of the full query.
        # Corresponds to the JSON property `addedByCloseAnswers`
        # @return [Boolean]
        attr_accessor :added_by_close_answers
        alias_method :added_by_close_answers?, :added_by_close_answers
      
        # A copy of the span of canonical (raw) parser input text corresponding to this
        # annotation.
        # Corresponds to the JSON property `annotatedSpan`
        # @return [String]
        attr_accessor :annotated_span
      
        # Attribute ID of a personal_summary_node_child.
        # Corresponds to the JSON property `attributeId`
        # @return [String]
        attr_accessor :attribute_id
      
        # The ID of the cluster (set entity) this entity belongs to.
        # Corresponds to the JSON property `clusterId`
        # @return [String]
        attr_accessor :cluster_id
      
        # Cluster set qref confidence score.
        # Corresponds to the JSON property `clusterSetScore`
        # @return [Float]
        attr_accessor :cluster_set_score
      
        # The set of mids that are members of the same cluster.
        # Corresponds to the JSON property `clusterSiblingMid`
        # @return [Array<String>]
        attr_accessor :cluster_sibling_mid
      
        # 
        # Corresponds to the JSON property `collectionMembership`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotationCollectionMembership>]
        attr_accessor :collection_membership
      
        # The confidence (in [0, 1]) of the entity being correctly annotated.
        # Corresponds to the JSON property `confidenceScore`
        # @return [Float]
        attr_accessor :confidence_score
      
        # DEPRECATED: Equivalent ids (e.g. de-duped mids) for this entity.
        # Corresponds to the JSON property `deprecatedEquivalentMids`
        # @return [Array<String>]
        attr_accessor :deprecated_equivalent_mids
      
        # DEPRECATED: Higher level id's that support the given id. This field has been
        # deprecated in favor of related_entity. b/27363861
        # Corresponds to the JSON property `deprecatedMdvcSupportingMid`
        # @return [Array<String>]
        attr_accessor :deprecated_mdvc_supporting_mid
      
        # Copy the display info. This can be used by annotators to give grammars a
        # canonical name for an entity. For instance, the media grammar could use it to
        # output the same canonical name for "rock music" and "rock".
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # The index of the entity from which this annotation is obtained, within the
        # WebrefEntities message in the interpretation defined by interpretation_number,
        # above.
        # Corresponds to the JSON property `entityNumber`
        # @return [Fixnum]
        attr_accessor :entity_number
      
        # The relationship information from QRef. Only included if the QRefAnnotator is
        # initialised with include_annotated_relationships.
        # Corresponds to the JSON property `entityRelationship`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotationEntityRelationship>]
        attr_accessor :entity_relationship
      
        # Holds information about the backends which contributed to this entity.
        # Corresponds to the JSON property `entitySourceData`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingEntitySourceData]
        attr_accessor :entity_source_data
      
        # The mid of the entity in freebase associated with this span.
        # Corresponds to the JSON property `freebaseMid`
        # @return [String]
        attr_accessor :freebase_mid
      
        # The Gaia ID for this entity. This is populated generally for people and
        # businesses.
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # The shopping global product cluster id(s) of the annotated entity (in KG, the
        # key(s) of type /business/variant_cluster).
        # Corresponds to the JSON property `globalProductClusterId`
        # @return [Array<Fixnum>]
        attr_accessor :global_product_cluster_id
      
        # The index of the QueryJoin interpretation from which this annotation was
        # obtained. This field is not used for entities coming from low-confidence
        # annotations, since such entities are not included in any interpretation.
        # Corresponds to the JSON property `interpretationNumber`
        # @return [Fixnum]
        attr_accessor :interpretation_number
      
        # True if this entity is an mdvc dimension of some other annotated entity. Only
        # included if the QRefAnnotator is initialised with
        # include_annotated_relationships.
        # Corresponds to the JSON property `isMdvcDimension`
        # @return [Boolean]
        attr_accessor :is_mdvc_dimension
        alias_method :is_mdvc_dimension?, :is_mdvc_dimension
      
        # Whether this annotation originates from nimble. (go/nimble-annotator)
        # Corresponds to the JSON property `isNimbleAnnotation`
        # @return [Boolean]
        attr_accessor :is_nimble_annotation
        alias_method :is_nimble_annotation?, :is_nimble_annotation
      
        # The center point of this location. This is either directly provided by the
        # FeatureProto.center field or the centroid using the points of the polygon in
        # the FeatureProto.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :location
      
        # The location type of the entity, as an int32 representing a TypeCategory enum
        # value. For example, this could be TYPE_LOCALITY (37) or TYPE_COUNTRY (33). We
        # store this type as an int because including FeatureProto would cause java/com/
        # google/ads/adh/pipeline/bigquery:ProtoCatalog to become too large, resulting
        # in OOM errors.
        # Corresponds to the JSON property `locationType`
        # @return [Fixnum]
        attr_accessor :location_type
      
        # Whether this entity is low confidence. Not used. Currently whitelisted
        # entities below min_confidence threshold are marked as low confidence and maybe
        # not trusted by downstreams.
        # Corresponds to the JSON property `lowConfidence`
        # @return [Boolean]
        attr_accessor :low_confidence
        alias_method :low_confidence?, :low_confidence
      
        # 
        # Corresponds to the JSON property `matchedLightweightToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLightweightTokensMatchedLightweightToken>]
        attr_accessor :matched_lightweight_token
      
        # Nested annotations that represent subparts of the given mdvc full annotation.
        # An MDVC full annotation is outputted as the summary node as the root node, and
        # all the children of it as leaves (mdvc_child). QRef outputs a graph of
        # relationships between the mdvc enties, and for mdvc full the aquatator nests
        # the relevant children inside the summary node's proto.
        # Corresponds to the JSON property `mdvcChild`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation>]
        attr_accessor :mdvc_child
      
        # The set of verticals this summary node belongs to.
        # Corresponds to the JSON property `mdvcVerticals`
        # @return [Array<String>]
        attr_accessor :mdvc_verticals
      
        # A list of any implied entities merged into this annotation during parsing.
        # Order is derivation-dependent.
        # Corresponds to the JSON property `mergedImpliedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation>]
        attr_accessor :merged_implied_entity
      
        # 
        # Corresponds to the JSON property `merlotCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotationMerlotCategoryData>]
        attr_accessor :merlot_category
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `otherMetadata`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :other_metadata
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `oysterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :oyster_id
      
        # Personal summary nodes are compound entities made up of entities and their
        # attributes, where the entities can be compound too. E.g., "my father's mother"
        # can have a summary node annotation of "Mother(Father(Myself))".
        # Corresponds to the JSON property `personalSummaryNodeChild`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation>]
        attr_accessor :personal_summary_node_child
      
        # The shopping product line id(s) of the annotated /business/
        # shopping_product_line entity.
        # Corresponds to the JSON property `productLineId`
        # @return [Array<Fixnum>]
        attr_accessor :product_line_id
      
        # The confidence (in [0, 1]) that the annotation is reference that implies
        # another entity. (eg "my hotel" in "navigate to my hotel" is reference to
        # explicit hotel from user hotel reservation).
        # Corresponds to the JSON property `referenceScore`
        # @return [Float]
        attr_accessor :reference_score
      
        # Mids related to the given entity
        # Corresponds to the JSON property `relatedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingRelatedEntity>]
        attr_accessor :related_entity
      
        # The confidence (in [0, 1]) that the annotation was created on an implicit
        # mention (eg my hotel) as opposed to an explicit mention (eg: the westin copley
        # square)
        # Corresponds to the JSON property `resolutionScore`
        # @return [Float]
        attr_accessor :resolution_score
      
        # If the annotation was created by using personal data, we record the provenance
        # for that data here.
        # Corresponds to the JSON property `sourceTypeList`
        # @return [Google::Apis::ContentwarehouseV1::CopleySourceTypeList]
        attr_accessor :source_type_list
      
        # 
        # Corresponds to the JSON property `subCluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotationSubCluster>]
        attr_accessor :sub_cluster
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @added_by_close_answers = args[:added_by_close_answers] if args.key?(:added_by_close_answers)
          @annotated_span = args[:annotated_span] if args.key?(:annotated_span)
          @attribute_id = args[:attribute_id] if args.key?(:attribute_id)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_set_score = args[:cluster_set_score] if args.key?(:cluster_set_score)
          @cluster_sibling_mid = args[:cluster_sibling_mid] if args.key?(:cluster_sibling_mid)
          @collection_membership = args[:collection_membership] if args.key?(:collection_membership)
          @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
          @deprecated_equivalent_mids = args[:deprecated_equivalent_mids] if args.key?(:deprecated_equivalent_mids)
          @deprecated_mdvc_supporting_mid = args[:deprecated_mdvc_supporting_mid] if args.key?(:deprecated_mdvc_supporting_mid)
          @display_name = args[:display_name] if args.key?(:display_name)
          @entity_number = args[:entity_number] if args.key?(:entity_number)
          @entity_relationship = args[:entity_relationship] if args.key?(:entity_relationship)
          @entity_source_data = args[:entity_source_data] if args.key?(:entity_source_data)
          @freebase_mid = args[:freebase_mid] if args.key?(:freebase_mid)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @global_product_cluster_id = args[:global_product_cluster_id] if args.key?(:global_product_cluster_id)
          @interpretation_number = args[:interpretation_number] if args.key?(:interpretation_number)
          @is_mdvc_dimension = args[:is_mdvc_dimension] if args.key?(:is_mdvc_dimension)
          @is_nimble_annotation = args[:is_nimble_annotation] if args.key?(:is_nimble_annotation)
          @location = args[:location] if args.key?(:location)
          @location_type = args[:location_type] if args.key?(:location_type)
          @low_confidence = args[:low_confidence] if args.key?(:low_confidence)
          @matched_lightweight_token = args[:matched_lightweight_token] if args.key?(:matched_lightweight_token)
          @mdvc_child = args[:mdvc_child] if args.key?(:mdvc_child)
          @mdvc_verticals = args[:mdvc_verticals] if args.key?(:mdvc_verticals)
          @merged_implied_entity = args[:merged_implied_entity] if args.key?(:merged_implied_entity)
          @merlot_category = args[:merlot_category] if args.key?(:merlot_category)
          @other_metadata = args[:other_metadata] if args.key?(:other_metadata)
          @oyster_id = args[:oyster_id] if args.key?(:oyster_id)
          @personal_summary_node_child = args[:personal_summary_node_child] if args.key?(:personal_summary_node_child)
          @product_line_id = args[:product_line_id] if args.key?(:product_line_id)
          @reference_score = args[:reference_score] if args.key?(:reference_score)
          @related_entity = args[:related_entity] if args.key?(:related_entity)
          @resolution_score = args[:resolution_score] if args.key?(:resolution_score)
          @source_type_list = args[:source_type_list] if args.key?(:source_type_list)
          @sub_cluster = args[:sub_cluster] if args.key?(:sub_cluster)
        end
      end
      
      # 
      class NlpSemanticParsingQRefAnnotationCollectionMembership
        include Google::Apis::Core::Hashable
      
        # Identifier of the collection. Usually something like "/collection/us_states".
        # Corresponds to the JSON property `collectionId`
        # @return [String]
        attr_accessor :collection_id
      
        # A value in [0, 1] indicating the relevance of the collection given this entity.
        # NOTE: This field is deprecated and will stop being populated soon. In the
        # meantime, it will always be populated with 1.0.
        # Corresponds to the JSON property `collectionScore`
        # @return [Float]
        attr_accessor :collection_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection_id = args[:collection_id] if args.key?(:collection_id)
          @collection_score = args[:collection_score] if args.key?(:collection_score)
        end
      end
      
      # 
      class NlpSemanticParsingQRefAnnotationEntityRelationship
        include Google::Apis::Core::Hashable
      
        # The index of the other entity in the relationship.
        # Corresponds to the JSON property `entityIndex`
        # @return [Fixnum]
        attr_accessor :entity_index
      
        # True if this entity is implied by the other (includes geo contains).
        # Corresponds to the JSON property `impliedBy`
        # @return [Boolean]
        attr_accessor :implied_by
        alias_method :implied_by?, :implied_by
      
        # True if this entity implies the other (includes geo contained by).
        # Corresponds to the JSON property `implies`
        # @return [Boolean]
        attr_accessor :implies
        alias_method :implies?, :implies
      
        # Names of the relationship links.
        # Corresponds to the JSON property `linkPropertyName`
        # @return [Array<String>]
        attr_accessor :link_property_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_index = args[:entity_index] if args.key?(:entity_index)
          @implied_by = args[:implied_by] if args.key?(:implied_by)
          @implies = args[:implies] if args.key?(:implies)
          @link_property_name = args[:link_property_name] if args.key?(:link_property_name)
        end
      end
      
      # Merlot category information. As of Sep2015, this is derived from collection
      # membership, but as that information is planned for deprecation and may need to
      # be replaced as a source for this data, it is extracted separately.
      class NlpSemanticParsingQRefAnnotationMerlotCategoryData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `categoryId`
        # @return [Fixnum]
        attr_accessor :category_id
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_id = args[:category_id] if args.key?(:category_id)
          @confidence = args[:confidence] if args.key?(:confidence)
        end
      end
      
      # Keeps track of any individual clusters this mid is a member of. Cluster_id and
      # cluster_sibling_mid stores the cluster all together, while the subcluster
      # keeps track of each individual cluster information separately.
      class NlpSemanticParsingQRefAnnotationSubCluster
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `clusterId`
        # @return [String]
        attr_accessor :cluster_id
      
        # 
        # Corresponds to the JSON property `clusterSetScore`
        # @return [Float]
        attr_accessor :cluster_set_score
      
        # 
        # Corresponds to the JSON property `clusterSiblingMid`
        # @return [Array<String>]
        attr_accessor :cluster_sibling_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_set_score = args[:cluster_set_score] if args.key?(:cluster_set_score)
          @cluster_sibling_mid = args[:cluster_sibling_mid] if args.key?(:cluster_sibling_mid)
        end
      end
      
      # A message that stores relations between this annotation and another entity.
      # Stores the mid and the kind of relationship. These links may be consumed
      # downstream for various purposes, including support transfer and other business
      # logic. An example is for the Honda Civic entity. It may have an mdvc_relation
      # that is a generalization_of the 2015 Honda Civic entity. So the Honda Civic
      # would have the following: RelatedEntity ` mid = 2015 Honda Civic Mid
      # mdvc_relation = GENERALIZATION_OF ` It has no equivalent_relation because it
      # is by default NO_EQUIVALENT. The Honda Civic entity might then have a separate
      # relation to the Old Honda Civic entity, as they are considered the same entity,
      # or the following relation: RelatedEntity ` mid = Old Honda Civic Mid
      # equivalent_relation = EQUIVALENT `
      class NlpSemanticParsingRelatedEntity
        include Google::Apis::Core::Hashable
      
        # Denotes whether or not the related entity is derived from cluster support
        # transfer.
        # Corresponds to the JSON property `clusterSupportTransferRelation`
        # @return [String]
        attr_accessor :cluster_support_transfer_relation
      
        # Denotes whether or not the related entity composes a compound entity together
        # with other related entities.
        # Corresponds to the JSON property `composedFromRelation`
        # @return [String]
        attr_accessor :composed_from_relation
      
        # Whether or not the given mid is related to the other mid. Equivalent mids are
        # usually mutually exclusive with other kinds of relations.
        # Corresponds to the JSON property `equivalentRelation`
        # @return [String]
        attr_accessor :equivalent_relation
      
        # The mdvc relation with the related mid.
        # Corresponds to the JSON property `mdvcRelation`
        # @return [String]
        attr_accessor :mdvc_relation
      
        # Mid that is related.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Denotes whether or not there was support transfer between the two entities.
        # Corresponds to the JSON property `supportTransferRelation`
        # @return [String]
        attr_accessor :support_transfer_relation
      
        # Set if the related entity is the source of an STBR rule and the target is not
        # this one.
        # Corresponds to the JSON property `targetIsStbrSource`
        # @return [Boolean]
        attr_accessor :target_is_stbr_source
        alias_method :target_is_stbr_source?, :target_is_stbr_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_support_transfer_relation = args[:cluster_support_transfer_relation] if args.key?(:cluster_support_transfer_relation)
          @composed_from_relation = args[:composed_from_relation] if args.key?(:composed_from_relation)
          @equivalent_relation = args[:equivalent_relation] if args.key?(:equivalent_relation)
          @mdvc_relation = args[:mdvc_relation] if args.key?(:mdvc_relation)
          @mid = args[:mid] if args.key?(:mid)
          @support_transfer_relation = args[:support_transfer_relation] if args.key?(:support_transfer_relation)
          @target_is_stbr_source = args[:target_is_stbr_source] if args.key?(:target_is_stbr_source)
        end
      end
      
      # Identifies a coreference mention (pronoun or nominal) resolved to an entity.
      class NlpSemanticParsingSaftCoreference
        include Google::Apis::Core::Hashable
      
        # Categories can be either a $PronounMention or $NominalMention.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The substring of the raw query spanned by this annotation.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # The name of the entity this mentions refers to.
        # Corresponds to the JSON property `referentText`
        # @return [String]
        attr_accessor :referent_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @referent_text = args[:referent_text] if args.key?(:referent_text)
        end
      end
      
      # Identifies a measure, like '53 pounds' in a query.
      class NlpSemanticParsingSaftMeasure
        include Google::Apis::Core::Hashable
      
        # Defines the category of measure, like $Mass.
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The substring of the raw query spanned by this annotation.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        # The numerical value of the measure.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # SaftMentionAnnotation(s) are used to identify a sub-span of the input with
      # some semantic relevance, for example PER (Person), LOC (Locations) or measure
      # etc. Each SaftMentionAnnotation will have exactly one non-empty field.
      class NlpSemanticParsingSaftMentionAnnotation
        include Google::Apis::Core::Hashable
      
        # Identifies a coreference mention (pronoun or nominal) resolved to an entity.
        # Corresponds to the JSON property `coreference`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingSaftCoreference]
        attr_accessor :coreference
      
        # The lowest common denominator of a SAFT annotation is simply the definition of
        # some |category| for a sub-span of the |raw_text| of the query.
        # Corresponds to the JSON property `entity`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingSaftSpan]
        attr_accessor :entity
      
        # Identifies a measure, like '53 pounds' in a query.
        # Corresponds to the JSON property `measure`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingSaftMeasure]
        attr_accessor :measure
      
        # The lowest common denominator of a SAFT annotation is simply the definition of
        # some |category| for a sub-span of the |raw_text| of the query.
        # Corresponds to the JSON property `title`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingSaftSpan]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @coreference = args[:coreference] if args.key?(:coreference)
          @entity = args[:entity] if args.key?(:entity)
          @measure = args[:measure] if args.key?(:measure)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # The lowest common denominator of a SAFT annotation is simply the definition of
      # some |category| for a sub-span of the |raw_text| of the query.
      class NlpSemanticParsingSaftSpan
        include Google::Apis::Core::Hashable
      
        # Categories can be either syntactic (NNS for fine-grained-POS) or semantics ($
        # Mass for measures).
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The substring of the raw query spanned by this annotation.
        # Corresponds to the JSON property `rawText`
        # @return [String]
        attr_accessor :raw_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @raw_text = args[:raw_text] if args.key?(:raw_text)
        end
      end
      
      # A single byte, such as that from a utf8-encoded character sequence.
      class NlxDataSchemaByte
        include Google::Apis::Core::Hashable
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document = args[:document] if args.key?(:document)
        end
      end
      
      # A single Unicode character.
      class NlxDataSchemaCharacter
        include Google::Apis::Core::Hashable
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `paragraph`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :paragraph
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `sentence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :sentence
      
        # The character itself. Must contain valid UTF-8. Must be exactly one Unicode
        # character.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `token`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document = args[:document] if args.key?(:document)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @sentence = args[:sentence] if args.key?(:sentence)
          @text = args[:text] if args.key?(:text)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # A single document.
      class NlxDataSchemaDocument
        include Google::Apis::Core::Hashable
      
        # The author(s) of this document.
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::MultiscalePointerIndex>]
        attr_accessor :author
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `characters`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :characters
      
        # The identifier of this document.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # A set of BCP-47 codes indicating the language(s) of this document.
        # Corresponds to the JSON property `languageCode`
        # @return [Array<String>]
        attr_accessor :language_code
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `languageSpans`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :language_spans
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `mentions`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :mentions
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `paragraphs`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :paragraphs
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `sentences`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :sentences
      
        # The text of this document. Must contain valid UTF-8.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `tokens`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :tokens
      
        # The url of this document.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author = args[:author] if args.key?(:author)
          @bytes = args[:bytes] if args.key?(:bytes)
          @characters = args[:characters] if args.key?(:characters)
          @id = args[:id] if args.key?(:id)
          @language_code = args[:language_code] if args.key?(:language_code)
          @language_spans = args[:language_spans] if args.key?(:language_spans)
          @mentions = args[:mentions] if args.key?(:mentions)
          @paragraphs = args[:paragraphs] if args.key?(:paragraphs)
          @sentences = args[:sentences] if args.key?(:sentences)
          @text = args[:text] if args.key?(:text)
          @tokens = args[:tokens] if args.key?(:tokens)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # An entity, which may occur multiple times in the text.
      class NlxDataSchemaEntity
        include Google::Apis::Core::Hashable
      
        # Entity gender. Default label set is 'masculine', 'feminine', or 'neuter'. (
        # Perhaps in the future we can split 'neuter' into 'inanimate', 'unknown', and '
        # non-binary'.)
        # Corresponds to the JSON property `gender`
        # @return [String]
        attr_accessor :gender
      
        # Machine identifier, such as those from the Freebase database (or similar
        # entity database).
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Free-form entity name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Entity type, typically something like person/location/organization. The schema
        # for types is not specified. If this entity has a MID, use the mid field
        # instead or in conjunction with the type.
        # Corresponds to the JSON property `type`
        # @return [Array<String>]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gender = args[:gender] if args.key?(:gender)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A span of text that is written using a specified language (or languages).
      # language_spans do not need to cover all of the characters in a text -- in
      # particular, some pieces of text may not use any language. Depending on the
      # model used to generate them, multilingual text can be encoded using
      # overlapping or non- overlapping language_spans; and using one or multiple
      # language_codes per language_span.
      class NlxDataSchemaLanguageSpan
        include Google::Apis::Core::Hashable
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `characters`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :characters
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # A set of BCP-47 codes indicating the language(s) of this span of text.
        # Corresponds to the JSON property `languageCode`
        # @return [Array<String>]
        attr_accessor :language_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes = args[:bytes] if args.key?(:bytes)
          @characters = args[:characters] if args.key?(:characters)
          @document = args[:document] if args.key?(:document)
          @language_code = args[:language_code] if args.key?(:language_code)
        end
      end
      
      # A mention of an entity. A single entity might be mentioned multiple times.
      class NlxDataSchemaMention
        include Google::Apis::Core::Hashable
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `entity`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :entity
      
        # Mention kind, typically 'referential', 'attributive', or 'modifier'.
        # Corresponds to the JSON property `kind`
        # @return [String]
        attr_accessor :kind
      
        # The mention text itself. Must contain valid UTF-8.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `tokens`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :tokens
      
        # Mention type, typically 'named' (for name mentions) or 'nominal'. More types
        # include 'pronominal', 'conjoined' for conjoined mention construction, and 'non-
        # referential' for non-referential pronoun mentions.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes = args[:bytes] if args.key?(:bytes)
          @document = args[:document] if args.key?(:document)
          @entity = args[:entity] if args.key?(:entity)
          @kind = args[:kind] if args.key?(:kind)
          @text = args[:text] if args.key?(:text)
          @tokens = args[:tokens] if args.key?(:tokens)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A single paragraph.
      class NlxDataSchemaParagraph
        include Google::Apis::Core::Hashable
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `characters`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :characters
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `sentences`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :sentences
      
        # The text of this paragraph. Must contain valid UTF-8.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `tokens`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes = args[:bytes] if args.key?(:bytes)
          @characters = args[:characters] if args.key?(:characters)
          @document = args[:document] if args.key?(:document)
          @sentences = args[:sentences] if args.key?(:sentences)
          @text = args[:text] if args.key?(:text)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # Standard NLX data schema.
      class NlxDataSchemaScaleSet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `byte`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaByte>]
        attr_accessor :byte
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `byteDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :byte_document_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `bytePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :byte_presence
      
        # 
        # Corresponds to the JSON property `character`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaCharacter>]
        attr_accessor :character
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `characterDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :character_document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `characterParagraphPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :character_paragraph_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `characterPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :character_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `characterSentencePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :character_sentence_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `characterTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :character_text_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `characterTokenPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :character_token_presence
      
        # 
        # Corresponds to the JSON property `document`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaDocument>]
        attr_accessor :document
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentAuthorPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_author_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentCharactersPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_characters_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentIdPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_id_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentLanguageCodePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_language_code_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentLanguageSpansPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_language_spans_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentMentionsPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_mentions_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentParagraphsPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_paragraphs_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `documentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentSentencesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_sentences_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_text_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentTokensPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_tokens_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `documentUrlPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :document_url_presence
      
        # 
        # Corresponds to the JSON property `entity`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaEntity>]
        attr_accessor :entity
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `entityGenderPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :entity_gender_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `entityMidPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :entity_mid_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `entityNamePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :entity_name_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `entityPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :entity_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `entityTypePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :entity_type_presence
      
        # 
        # Corresponds to the JSON property `languageSpan`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaLanguageSpan>]
        attr_accessor :language_span
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `languageSpanBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :language_span_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `languageSpanCharactersPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :language_span_characters_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `languageSpanDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :language_span_document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `languageSpanLanguageCodePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :language_span_language_code_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `languageSpanPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :language_span_presence
      
        # 
        # Corresponds to the JSON property `mention`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaMention>]
        attr_accessor :mention
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionEntityPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_entity_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionKindPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_kind_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `mentionPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :mention_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_text_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionTokensPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_tokens_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `mentionTypePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :mention_type_presence
      
        # 
        # Corresponds to the JSON property `paragraph`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaParagraph>]
        attr_accessor :paragraph
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphCharactersPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_characters_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_document_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `paragraphPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :paragraph_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphSentencesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_sentences_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_text_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `paragraphTokensPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :paragraph_tokens_presence
      
        # 
        # Corresponds to the JSON property `sentence`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaSentence>]
        attr_accessor :sentence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceCharactersPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_characters_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceParagraphPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_paragraph_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `sentencePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :sentence_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_text_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `sentenceTokensPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :sentence_tokens_presence
      
        # 
        # Corresponds to the JSON property `token`
        # @return [Array<Google::Apis::ContentwarehouseV1::NlxDataSchemaToken>]
        attr_accessor :token
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenBytesPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_bytes_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenCharactersPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_characters_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenDependencyHeadPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_dependency_head_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenDependencyLabelPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_dependency_label_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenDependencyPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_dependency_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenDocumentPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_document_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenParagraphPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_paragraph_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenPosPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_pos_presence
      
        # Defines the presence of a layer (previously called "scale").
        # Corresponds to the JSON property `tokenPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleLayerPresence]
        attr_accessor :token_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenSentencePresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_sentence_presence
      
        # Defines the presence of a field. This can help distinguish between empty vs.
        # not-present annotations.
        # Corresponds to the JSON property `tokenTextPresence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscaleFieldPresence]
        attr_accessor :token_text_presence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte = args[:byte] if args.key?(:byte)
          @byte_document_presence = args[:byte_document_presence] if args.key?(:byte_document_presence)
          @byte_presence = args[:byte_presence] if args.key?(:byte_presence)
          @character = args[:character] if args.key?(:character)
          @character_document_presence = args[:character_document_presence] if args.key?(:character_document_presence)
          @character_paragraph_presence = args[:character_paragraph_presence] if args.key?(:character_paragraph_presence)
          @character_presence = args[:character_presence] if args.key?(:character_presence)
          @character_sentence_presence = args[:character_sentence_presence] if args.key?(:character_sentence_presence)
          @character_text_presence = args[:character_text_presence] if args.key?(:character_text_presence)
          @character_token_presence = args[:character_token_presence] if args.key?(:character_token_presence)
          @document = args[:document] if args.key?(:document)
          @document_author_presence = args[:document_author_presence] if args.key?(:document_author_presence)
          @document_bytes_presence = args[:document_bytes_presence] if args.key?(:document_bytes_presence)
          @document_characters_presence = args[:document_characters_presence] if args.key?(:document_characters_presence)
          @document_id_presence = args[:document_id_presence] if args.key?(:document_id_presence)
          @document_language_code_presence = args[:document_language_code_presence] if args.key?(:document_language_code_presence)
          @document_language_spans_presence = args[:document_language_spans_presence] if args.key?(:document_language_spans_presence)
          @document_mentions_presence = args[:document_mentions_presence] if args.key?(:document_mentions_presence)
          @document_paragraphs_presence = args[:document_paragraphs_presence] if args.key?(:document_paragraphs_presence)
          @document_presence = args[:document_presence] if args.key?(:document_presence)
          @document_sentences_presence = args[:document_sentences_presence] if args.key?(:document_sentences_presence)
          @document_text_presence = args[:document_text_presence] if args.key?(:document_text_presence)
          @document_tokens_presence = args[:document_tokens_presence] if args.key?(:document_tokens_presence)
          @document_url_presence = args[:document_url_presence] if args.key?(:document_url_presence)
          @entity = args[:entity] if args.key?(:entity)
          @entity_gender_presence = args[:entity_gender_presence] if args.key?(:entity_gender_presence)
          @entity_mid_presence = args[:entity_mid_presence] if args.key?(:entity_mid_presence)
          @entity_name_presence = args[:entity_name_presence] if args.key?(:entity_name_presence)
          @entity_presence = args[:entity_presence] if args.key?(:entity_presence)
          @entity_type_presence = args[:entity_type_presence] if args.key?(:entity_type_presence)
          @language_span = args[:language_span] if args.key?(:language_span)
          @language_span_bytes_presence = args[:language_span_bytes_presence] if args.key?(:language_span_bytes_presence)
          @language_span_characters_presence = args[:language_span_characters_presence] if args.key?(:language_span_characters_presence)
          @language_span_document_presence = args[:language_span_document_presence] if args.key?(:language_span_document_presence)
          @language_span_language_code_presence = args[:language_span_language_code_presence] if args.key?(:language_span_language_code_presence)
          @language_span_presence = args[:language_span_presence] if args.key?(:language_span_presence)
          @mention = args[:mention] if args.key?(:mention)
          @mention_bytes_presence = args[:mention_bytes_presence] if args.key?(:mention_bytes_presence)
          @mention_document_presence = args[:mention_document_presence] if args.key?(:mention_document_presence)
          @mention_entity_presence = args[:mention_entity_presence] if args.key?(:mention_entity_presence)
          @mention_kind_presence = args[:mention_kind_presence] if args.key?(:mention_kind_presence)
          @mention_presence = args[:mention_presence] if args.key?(:mention_presence)
          @mention_text_presence = args[:mention_text_presence] if args.key?(:mention_text_presence)
          @mention_tokens_presence = args[:mention_tokens_presence] if args.key?(:mention_tokens_presence)
          @mention_type_presence = args[:mention_type_presence] if args.key?(:mention_type_presence)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @paragraph_bytes_presence = args[:paragraph_bytes_presence] if args.key?(:paragraph_bytes_presence)
          @paragraph_characters_presence = args[:paragraph_characters_presence] if args.key?(:paragraph_characters_presence)
          @paragraph_document_presence = args[:paragraph_document_presence] if args.key?(:paragraph_document_presence)
          @paragraph_presence = args[:paragraph_presence] if args.key?(:paragraph_presence)
          @paragraph_sentences_presence = args[:paragraph_sentences_presence] if args.key?(:paragraph_sentences_presence)
          @paragraph_text_presence = args[:paragraph_text_presence] if args.key?(:paragraph_text_presence)
          @paragraph_tokens_presence = args[:paragraph_tokens_presence] if args.key?(:paragraph_tokens_presence)
          @sentence = args[:sentence] if args.key?(:sentence)
          @sentence_bytes_presence = args[:sentence_bytes_presence] if args.key?(:sentence_bytes_presence)
          @sentence_characters_presence = args[:sentence_characters_presence] if args.key?(:sentence_characters_presence)
          @sentence_document_presence = args[:sentence_document_presence] if args.key?(:sentence_document_presence)
          @sentence_paragraph_presence = args[:sentence_paragraph_presence] if args.key?(:sentence_paragraph_presence)
          @sentence_presence = args[:sentence_presence] if args.key?(:sentence_presence)
          @sentence_text_presence = args[:sentence_text_presence] if args.key?(:sentence_text_presence)
          @sentence_tokens_presence = args[:sentence_tokens_presence] if args.key?(:sentence_tokens_presence)
          @token = args[:token] if args.key?(:token)
          @token_bytes_presence = args[:token_bytes_presence] if args.key?(:token_bytes_presence)
          @token_characters_presence = args[:token_characters_presence] if args.key?(:token_characters_presence)
          @token_dependency_head_presence = args[:token_dependency_head_presence] if args.key?(:token_dependency_head_presence)
          @token_dependency_label_presence = args[:token_dependency_label_presence] if args.key?(:token_dependency_label_presence)
          @token_dependency_presence = args[:token_dependency_presence] if args.key?(:token_dependency_presence)
          @token_document_presence = args[:token_document_presence] if args.key?(:token_document_presence)
          @token_paragraph_presence = args[:token_paragraph_presence] if args.key?(:token_paragraph_presence)
          @token_pos_presence = args[:token_pos_presence] if args.key?(:token_pos_presence)
          @token_presence = args[:token_presence] if args.key?(:token_presence)
          @token_sentence_presence = args[:token_sentence_presence] if args.key?(:token_sentence_presence)
          @token_text_presence = args[:token_text_presence] if args.key?(:token_text_presence)
        end
      end
      
      # A single sentence or utterance.
      class NlxDataSchemaSentence
        include Google::Apis::Core::Hashable
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `characters`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :characters
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `paragraph`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :paragraph
      
        # The text of this sentence. Must contain valid UTF-8.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `tokens`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes = args[:bytes] if args.key?(:bytes)
          @characters = args[:characters] if args.key?(:characters)
          @document = args[:document] if args.key?(:document)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @text = args[:text] if args.key?(:text)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # A word, punctuation mark, or other small piece of text.
      class NlxDataSchemaToken
        include Google::Apis::Core::Hashable
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `bytes`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :bytes
      
        # Pointer to a contiguous range of nodes in a target scale. `pointer.Span`
        # fields should be annotated with a `(pointer.to)` annotation, indicating what
        # scale they point at.
        # Corresponds to the JSON property `characters`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerSpan]
        attr_accessor :characters
      
        # DEPRECATED: PLEASE USE dependency_head AND dependency_label FIELDS. One edge
        # of the dependency parse.
        # Corresponds to the JSON property `dependency`
        # @return [Google::Apis::ContentwarehouseV1::NlxDataSchemaTokenDependencyEdge]
        attr_accessor :dependency
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `dependencyHead`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :dependency_head
      
        # Relation label for this dependency. Generally this should be using the
        # Universal Dependencies label format, using fine-grained labels like nsubj:pass.
        # Corresponds to the JSON property `dependencyLabel`
        # @return [String]
        attr_accessor :dependency_label
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `document`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :document
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `paragraph`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :paragraph
      
        # Coarse part-of-speech tag.
        # Corresponds to the JSON property `pos`
        # @return [String]
        attr_accessor :pos
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `sentence`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :sentence
      
        # The text of this token. Must contain valid UTF-8.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bytes = args[:bytes] if args.key?(:bytes)
          @characters = args[:characters] if args.key?(:characters)
          @dependency = args[:dependency] if args.key?(:dependency)
          @dependency_head = args[:dependency_head] if args.key?(:dependency_head)
          @dependency_label = args[:dependency_label] if args.key?(:dependency_label)
          @document = args[:document] if args.key?(:document)
          @paragraph = args[:paragraph] if args.key?(:paragraph)
          @pos = args[:pos] if args.key?(:pos)
          @sentence = args[:sentence] if args.key?(:sentence)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # DEPRECATED: PLEASE USE dependency_head AND dependency_label FIELDS. One edge
      # of the dependency parse.
      class NlxDataSchemaTokenDependencyEdge
        include Google::Apis::Core::Hashable
      
        # Relation label for this dependency. Generally this should be using the
        # Universal Dependencies label format, using fine- grained labels like nsubj:
        # pass.
        # Corresponds to the JSON property `deprel`
        # @return [String]
        attr_accessor :deprel
      
        # Pointer to a single node in a target scale. `pointer.Index` fields should be
        # annotated with a `(pointer.to)` annotation, indicating what scale they point
        # at.
        # Corresponds to the JSON property `head`
        # @return [Google::Apis::ContentwarehouseV1::MultiscalePointerIndex]
        attr_accessor :head
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprel = args[:deprel] if args.key?(:deprel)
          @head = args[:head] if args.key?(:head)
        end
      end
      
      # Metadata describing an 'item' (article) in a Woodwing file.
      class OceanDataDocinfoWoodwingItemMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `author`
        # @return [String]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author = args[:author] if args.key?(:author)
          @category = args[:category] if args.key?(:category)
          @description = args[:description] if args.key?(:description)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # Ocean data in docserver results (whole documents)
      class OceanDocInfo
        include Google::Apis::Core::Hashable
      
        # ============> Next available number: 102 (ksridhara) <================
        # Corresponds to the JSON property `docTag`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTag]
        attr_accessor :doc_tag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_tag = args[:doc_tag] if args.key?(:doc_tag)
        end
      end
      
      # ============> Next available number: 102 (ksridhara) <================
      class OceanDocTag
        include Google::Apis::Core::Hashable
      
        # this is in ONIX format.
        # Corresponds to the JSON property `DEPRECATEDApplicationDate`
        # @return [String]
        attr_accessor :deprecated_application_date
      
        # this is in ONIX format.
        # Corresponds to the JSON property `DEPRECATEDIssueDate`
        # @return [String]
        attr_accessor :deprecated_issue_date
      
        # 
        # Corresponds to the JSON property `DEPRECATEDPatentAssignee`
        # @return [String]
        attr_accessor :deprecated_patent_assignee
      
        # patent-specific fields. ALL DEPRECATED, moved into PatentSpecific group, above.
        # Corresponds to the JSON property `DEPRECATEDPatentNumber`
        # @return [String]
        attr_accessor :deprecated_patent_number
      
        # Percent rights granted by publisher. This should only be set, and definitely
        # should only be considered, if source_type == BoundVolumeSource::PUBLISHER. '0'
        # may mean we have no info on publisher rights so we have to just assume 0%.
        # Deprecated as this is taken into account by viewability
        # Corresponds to the JSON property `DEPRECATEDPublisherPercentVisible`
        # @return [Fixnum]
        attr_accessor :deprecated_publisher_percent_visible
      
        # TODO(leonid) Deprecate these Authors string for front end.
        # Corresponds to the JSON property `authors`
        # @return [String]
        attr_accessor :authors
      
        # A bitmap containing all available download formats (values defined in
        # AvaialableDownloadFormats enum) NOTE: Only populated for Volume level docs
        # Corresponds to the JSON property `availableDownloads`
        # @return [Fixnum]
        attr_accessor :available_downloads
      
        # 
        # Corresponds to the JSON property `blockSnippet`
        # @return [Boolean]
        attr_accessor :block_snippet
        alias_method :block_snippet?, :block_snippet
      
        # Book specific fields.
        # Corresponds to the JSON property `bookspecific`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagBookSpecific]
        attr_accessor :bookspecific
      
        # catalog-specific fields.
        # Corresponds to the JSON property `catalogspecific`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagCatalogSpecific]
        attr_accessor :catalogspecific
      
        # The content type of the document. See BoundVolumeSource::ContentType in ocean/
        # data/volume_types.protodevel for possible values.
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # 
        # Corresponds to the JSON property `contributor`
        # @return [Array<Google::Apis::ContentwarehouseV1::OceanDocTagContributor>]
        attr_accessor :contributor
      
        # cover page (PrintedAsSeen string), to generate results snippet thumbnail image
        # urls
        # Corresponds to the JSON property `coverPage`
        # @return [String]
        attr_accessor :cover_page
      
        # Size info of an image.
        # Corresponds to the JSON property `coverPageSize`
        # @return [Google::Apis::ContentwarehouseV1::OceanImageSize]
        attr_accessor :cover_page_size
      
        # Editors string for front end.
        # Corresponds to the JSON property `editors`
        # @return [String]
        attr_accessor :editors
      
        # 
        # Corresponds to the JSON property `encryptedExpressionId`
        # @return [String]
        attr_accessor :encrypted_expression_id
      
        # 
        # Corresponds to the JSON property `encryptedVolumeId`
        # @return [String]
        attr_accessor :encrypted_volume_id
      
        # DEPRECATED! Being replaced in favor of viewability, below. geo restrict info (
        # from OceanRights::geo_restrict) In CAv2: geo restrict info (from ocean::
        # VolumeImprintRights::geo_restrict)
        # Corresponds to the JSON property `geoRestrict`
        # @return [Array<String>]
        attr_accessor :geo_restrict
      
        # Text quality as defined in CA_VolumeScoreResult::OACapabilities::
        # TextQualityAssessment Note - This is only populated if good_text() and
        # is_ge_quality() are true
        # Corresponds to the JSON property `goodTextDetail`
        # @return [Fixnum]
        attr_accessor :good_text_detail
      
        # List of locales for which this book can be bought from a publisher, and read
        # as a Google eBook. Each locale is a lowercase, two-letter country-code (eg "ca"
        # ), and is copied from PublisherGrantability.Locale.locale, defined in ocean/
        # data/docinfo/volume_viewability.proto.
        # Corresponds to the JSON property `grantableLocale`
        # @return [Array<String>]
        attr_accessor :grantable_locale
      
        # Set to true if volume has ge quality
        # Corresponds to the JSON property `isGeQuality`
        # @return [Boolean]
        attr_accessor :is_ge_quality
        alias_method :is_ge_quality?, :is_ge_quality
      
        # whether this a landing page chosen at indexing time.
        # Corresponds to the JSON property `isLandingPage`
        # @return [Boolean]
        attr_accessor :is_landing_page
        alias_method :is_landing_page?, :is_landing_page
      
        # Magazine-specific fields. See https://www.corp.google.com/eng/designdocs/
        # scanning/magazines/designdoc.html for magazine design doc.
        # Corresponds to the JSON property `magazinespecific`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagMagazineSpecific]
        attr_accessor :magazinespecific
      
        # metadata_cover_exists will be set if there's a metadata-provided cover
        # thumbnail. the thumbnail will be used for scanless books or when a scanned
        # book is in metadata-only view.
        # Corresponds to the JSON property `metadataCoverExists`
        # @return [Boolean]
        attr_accessor :metadata_cover_exists
        alias_method :metadata_cover_exists?, :metadata_cover_exists
      
        # Size info of an image.
        # Corresponds to the JSON property `metadataCoverSize`
        # @return [Google::Apis::ContentwarehouseV1::OceanImageSize]
        attr_accessor :metadata_cover_size
      
        # Newspaper-specific fields.
        # Corresponds to the JSON property `newspaperspecific`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagNewspaperSpecific]
        attr_accessor :newspaperspecific
      
        # Number of pages in this volume (usually as specified in metadata)
        # Corresponds to the JSON property `numPages`
        # @return [Fixnum]
        attr_accessor :num_pages
      
        # A bitmap indicating whether content may be objectionable NOTE: Only populated
        # for volume level docs
        # Corresponds to the JSON property `objectionableContentBitmap`
        # @return [Fixnum]
        attr_accessor :objectionable_content_bitmap
      
        # page_number of the page (OceanTypes::PageNumberType) In CAv2: page_number of
        # the page ocean::PageNumber::T
        # Corresponds to the JSON property `pageNumber`
        # @return [Fixnum]
        attr_accessor :page_number
      
        # pageid of the page (OceanTypes::PageIdType)
        # Corresponds to the JSON property `pageid`
        # @return [Fixnum]
        attr_accessor :pageid
      
        # the page rank value of the book page
        # Corresponds to the JSON property `pagerank`
        # @return [Float]
        attr_accessor :pagerank
      
        # Patent specific fields. Currently empty, but need to move the fields below
        # into here at a later date
        # Corresponds to the JSON property `patentspecific`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagPatentSpecific]
        attr_accessor :patentspecific
      
        # GE sale related data
        # Corresponds to the JSON property `price`
        # @return [Google::Apis::ContentwarehouseV1::OceanGePrice]
        attr_accessor :price
      
        # printed page number (OceanPrintedPageNumber; from OceanPageInfoMap::Page::
        # printed_page_number)
        # Corresponds to the JSON property `printedPageNumber`
        # @return [String]
        attr_accessor :printed_page_number
      
        # the URL of the reference page (About this book)
        # Corresponds to the JSON property `refPageUrl`
        # @return [String]
        attr_accessor :ref_page_url
      
        # the URL for the "search in book"
        # Corresponds to the JSON property `searchInBookUrl`
        # @return [String]
        attr_accessor :search_in_book_url
      
        # 
        # Corresponds to the JSON property `segmentTime`
        # @return [Fixnum]
        attr_accessor :segment_time
      
        # The source type of the document. See BoundVolumeSource::SourceType in ocean/
        # data/volume_types.protodevel for possible values.
        # Corresponds to the JSON property `sourceType`
        # @return [Fixnum]
        attr_accessor :source_type
      
        # In CAv2 only: structured page number (printed number as we understand it) (
        # result of ocean::StructuredPageNumberProto::AppendToString)
        # Corresponds to the JSON property `structuredPageNumber`
        # @return [String]
        attr_accessor :structured_page_number
      
        # Sub title string for front end
        # Corresponds to the JSON property `subTitle`
        # @return [String]
        attr_accessor :sub_title
      
        # Bitmap indicating top-level subjects associated with this document. See ocean/
        # metadata/subjects/util.h for more detail.
        # Corresponds to the JSON property `subjectBitmap`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :subject_bitmap
      
        # the URL of the cover page.
        # Corresponds to the JSON property `thumbnailUrl`
        # @return [String]
        attr_accessor :thumbnail_url
      
        # Title string for front end.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Bibkey to be used as part of the URL (to make them persistent in some sense).
        # This is obtained by doing a GetURLKey() on the bibdata which returns the main
        # bibkey associated with the volume based on priority. This is parseable into an
        # OceanVolumeBibKey (ocean/metadata/bibkeys.h) Note: This should ideally be a
        # required field longer term but for now keeping it optional for compatibility.
        # In case of this being absent, we don't include the key in the URL (just use
        # volumeId as before). Note: For content type books, this key is supplemented by
        # other bibkeys for this volumes(the field is aux_bibkeys)
        # Corresponds to the JSON property `urlKey`
        # @return [String]
        attr_accessor :url_key
      
        # using_actual_cover will be set if we are using the actual cover of the book (
        # instead of the table of content, etc.). This is particularly useful to
        # identify books where we inserted a generated cover via Coverups.
        # Corresponds to the JSON property `usingActualCover`
        # @return [Boolean]
        attr_accessor :using_actual_cover
        alias_method :using_actual_cover?, :using_actual_cover
      
        # Volume viewability, which defines how/if the volume should be displayed in
        # various locales.
        # Corresponds to the JSON property `viewability`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeViewability]
        attr_accessor :viewability
      
        # 
        # Corresponds to the JSON property `volumeType`
        # @return [Fixnum]
        attr_accessor :volume_type
      
        # The version of the volume (serialized form). ONLY populated for Volume level
        # docs
        # Corresponds to the JSON property `volumeVersion`
        # @return [String]
        attr_accessor :volume_version
      
        # Details of the work cluster for this Volume.
        # Corresponds to the JSON property `workcluster`
        # @return [Google::Apis::ContentwarehouseV1::OceanDocTagWorkCluster]
        attr_accessor :workcluster
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_application_date = args[:deprecated_application_date] if args.key?(:deprecated_application_date)
          @deprecated_issue_date = args[:deprecated_issue_date] if args.key?(:deprecated_issue_date)
          @deprecated_patent_assignee = args[:deprecated_patent_assignee] if args.key?(:deprecated_patent_assignee)
          @deprecated_patent_number = args[:deprecated_patent_number] if args.key?(:deprecated_patent_number)
          @deprecated_publisher_percent_visible = args[:deprecated_publisher_percent_visible] if args.key?(:deprecated_publisher_percent_visible)
          @authors = args[:authors] if args.key?(:authors)
          @available_downloads = args[:available_downloads] if args.key?(:available_downloads)
          @block_snippet = args[:block_snippet] if args.key?(:block_snippet)
          @bookspecific = args[:bookspecific] if args.key?(:bookspecific)
          @catalogspecific = args[:catalogspecific] if args.key?(:catalogspecific)
          @content_type = args[:content_type] if args.key?(:content_type)
          @contributor = args[:contributor] if args.key?(:contributor)
          @cover_page = args[:cover_page] if args.key?(:cover_page)
          @cover_page_size = args[:cover_page_size] if args.key?(:cover_page_size)
          @editors = args[:editors] if args.key?(:editors)
          @encrypted_expression_id = args[:encrypted_expression_id] if args.key?(:encrypted_expression_id)
          @encrypted_volume_id = args[:encrypted_volume_id] if args.key?(:encrypted_volume_id)
          @geo_restrict = args[:geo_restrict] if args.key?(:geo_restrict)
          @good_text_detail = args[:good_text_detail] if args.key?(:good_text_detail)
          @grantable_locale = args[:grantable_locale] if args.key?(:grantable_locale)
          @is_ge_quality = args[:is_ge_quality] if args.key?(:is_ge_quality)
          @is_landing_page = args[:is_landing_page] if args.key?(:is_landing_page)
          @magazinespecific = args[:magazinespecific] if args.key?(:magazinespecific)
          @metadata_cover_exists = args[:metadata_cover_exists] if args.key?(:metadata_cover_exists)
          @metadata_cover_size = args[:metadata_cover_size] if args.key?(:metadata_cover_size)
          @newspaperspecific = args[:newspaperspecific] if args.key?(:newspaperspecific)
          @num_pages = args[:num_pages] if args.key?(:num_pages)
          @objectionable_content_bitmap = args[:objectionable_content_bitmap] if args.key?(:objectionable_content_bitmap)
          @page_number = args[:page_number] if args.key?(:page_number)
          @pageid = args[:pageid] if args.key?(:pageid)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @patentspecific = args[:patentspecific] if args.key?(:patentspecific)
          @price = args[:price] if args.key?(:price)
          @printed_page_number = args[:printed_page_number] if args.key?(:printed_page_number)
          @ref_page_url = args[:ref_page_url] if args.key?(:ref_page_url)
          @search_in_book_url = args[:search_in_book_url] if args.key?(:search_in_book_url)
          @segment_time = args[:segment_time] if args.key?(:segment_time)
          @source_type = args[:source_type] if args.key?(:source_type)
          @structured_page_number = args[:structured_page_number] if args.key?(:structured_page_number)
          @sub_title = args[:sub_title] if args.key?(:sub_title)
          @subject_bitmap = args[:subject_bitmap] if args.key?(:subject_bitmap)
          @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url)
          @title = args[:title] if args.key?(:title)
          @url_key = args[:url_key] if args.key?(:url_key)
          @using_actual_cover = args[:using_actual_cover] if args.key?(:using_actual_cover)
          @viewability = args[:viewability] if args.key?(:viewability)
          @volume_type = args[:volume_type] if args.key?(:volume_type)
          @volume_version = args[:volume_version] if args.key?(:volume_version)
          @workcluster = args[:workcluster] if args.key?(:workcluster)
        end
      end
      
      # Book specific fields.
      class OceanDocTagBookSpecific
        include Google::Apis::Core::Hashable
      
        # These are other bibkeys for this book beside the url_key, which is the primary
        # key. For example, a book may have ISBN, OCLC num etc. In that case ISBN is the
        # url_key and the OCLC number is the auxillary bibkey. The aux_bibkeys should
        # have the same form as the url_key
        # Corresponds to the JSON property `auxBibkeys`
        # @return [Array<String>]
        attr_accessor :aux_bibkeys
      
        # 
        # Corresponds to the JSON property `imprint`
        # @return [String]
        attr_accessor :imprint
      
        # 
        # Corresponds to the JSON property `numRatingHalfStars`
        # @return [Fixnum]
        attr_accessor :num_rating_half_stars
      
        # 
        # Corresponds to the JSON property `numberingrange`
        # @return [Array<Google::Apis::ContentwarehouseV1::OceanDocTagBookSpecificNumberingRange>]
        attr_accessor :numberingrange
      
        # publisher id, if available
        # Corresponds to the JSON property `partnerId`
        # @return [Fixnum]
        attr_accessor :partner_id
      
        # Set if the book is one of several editions or versions. Used by OFE to show
        # numbered editions. The value is copied from clustering information. See also
        # ocean/metadata/proto/bibdata_components.proto The value there is from metadata
        # records by ocean/metadata/parsing/parse_utils.cc, and is a 1-based value.
        # Corresponds to the JSON property `productEditionNumber`
        # @return [Fixnum]
        attr_accessor :product_edition_number
      
        # In the format yyyy.mm.dd, or possibly just yyyy.
        # Corresponds to the JSON property `publicationDate`
        # @return [String]
        attr_accessor :publication_date
      
        # 
        # Corresponds to the JSON property `publisherName`
        # @return [String]
        attr_accessor :publisher_name
      
        # Subject (from Bisac)
        # Corresponds to the JSON property `subject`
        # @return [String]
        attr_accessor :subject
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aux_bibkeys = args[:aux_bibkeys] if args.key?(:aux_bibkeys)
          @imprint = args[:imprint] if args.key?(:imprint)
          @num_rating_half_stars = args[:num_rating_half_stars] if args.key?(:num_rating_half_stars)
          @numberingrange = args[:numberingrange] if args.key?(:numberingrange)
          @partner_id = args[:partner_id] if args.key?(:partner_id)
          @product_edition_number = args[:product_edition_number] if args.key?(:product_edition_number)
          @publication_date = args[:publication_date] if args.key?(:publication_date)
          @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
          @subject = args[:subject] if args.key?(:subject)
        end
      end
      
      # These are copies of MetadataNumberingRange's from ocean/metadata/
      # metadata_range.proto. They should be used for rendering volume numbering
      # information in search results (as this protobuf is the only piece of data
      # available at that point). The numbering can look like "Volume 1" or "Parts A-D"
      # Schema is volume/part/etc, type arabic number/roman number/letter/etc (these
      # are both enums from ocean/metadata/metadata_enums.proto). In most cases there
      # is only one numbering range (e.g. "Volume 1, Issue 2"), but in general the
      # ranges may be disjoint (e.g. "Volumes 2, 3 and 7")
      class OceanDocTagBookSpecificNumberingRange
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `endNumbering`
        # @return [Array<Fixnum>]
        attr_accessor :end_numbering
      
        # 
        # Corresponds to the JSON property `numberType`
        # @return [Array<Fixnum>]
        attr_accessor :number_type
      
        # 
        # Corresponds to the JSON property `numberingSchema`
        # @return [Array<Fixnum>]
        attr_accessor :numbering_schema
      
        # 
        # Corresponds to the JSON property `startNumbering`
        # @return [Array<Fixnum>]
        attr_accessor :start_numbering
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_numbering = args[:end_numbering] if args.key?(:end_numbering)
          @number_type = args[:number_type] if args.key?(:number_type)
          @numbering_schema = args[:numbering_schema] if args.key?(:numbering_schema)
          @start_numbering = args[:start_numbering] if args.key?(:start_numbering)
        end
      end
      
      # catalog-specific fields.
      class OceanDocTagCatalogSpecific
        include Google::Apis::Core::Hashable
      
        # Is this the latest issue of this catalog series? This is required to filter
        # results if the latest restrict is on.
        # Corresponds to the JSON property `latest`
        # @return [Boolean]
        attr_accessor :latest
        alias_method :latest?, :latest
      
        # time_t date corresponding to the catalog publication date. Approximate when
        # the catalog does not have an exact "date" of publication, e.g. For "Spring
        # 2002", year, month and day are 2002, 03 and 21, respectivley. This value is
        # used to compare catalog issues to determine the latest. The value is stored in
        # seconds-since-epoch, 1/1/1970. This is not a problem for catalogs because we
        # are not dealing with any catalogs from before the 70's.
        # Corresponds to the JSON property `publicationDate`
        # @return [Fixnum]
        attr_accessor :publication_date
      
        # String to be displayed as catalog publication time, e.g. "Spring 2002".
        # Corresponds to the JSON property `publicationTimeToDisplay`
        # @return [String]
        attr_accessor :publication_time_to_display
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @latest = args[:latest] if args.key?(:latest)
          @publication_date = args[:publication_date] if args.key?(:publication_date)
          @publication_time_to_display = args[:publication_time_to_display] if args.key?(:publication_time_to_display)
        end
      end
      
      # The composite descriptor of the contributors that should be known to search
      # and front end. Both fields are required. Replaces authors and editors strings.
      class OceanDocTagContributor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # ContributionType enum from ocean/metadata/metadata_enums.proto Note that we
        # pick only the "highest-ranking" contribution (i.e. writer and editor would
        # collapse to "writer".
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Magazine-specific fields. See https://www.corp.google.com/eng/designdocs/
      # scanning/magazines/designdoc.html for magazine design doc.
      class OceanDocTagMagazineSpecific
        include Google::Apis::Core::Hashable
      
        # A human-readable date for display in the UI. Unlike "publication_date_" above,
        # this should not be parsed into structured data, but should only be displayed
        # as is.
        # Corresponds to the JSON property `displayDate`
        # @return [String]
        attr_accessor :display_date
      
        # Description specific to a magazine issue, such as featured articles and
        # article summaries.
        # Corresponds to the JSON property `issueDescription`
        # @return [String]
        attr_accessor :issue_description
      
        # 
        # Corresponds to the JSON property `issueEnd`
        # @return [Fixnum]
        attr_accessor :issue_end
      
        # 
        # Corresponds to the JSON property `issueStart`
        # @return [Fixnum]
        attr_accessor :issue_start
      
        # Items within a magazine issue.
        # Corresponds to the JSON property `item`
        # @return [Array<Google::Apis::ContentwarehouseV1::OceanDataDocinfoWoodwingItemMetadata>]
        attr_accessor :item
      
        # 
        # Corresponds to the JSON property `otherNumberingEnd`
        # @return [Fixnum]
        attr_accessor :other_numbering_end
      
        # NOTE: These should to be values from MetadataNumberingSchema; when this
        # becomes a proto2, we can use MetadataEnums values.
        # Corresponds to the JSON property `otherNumberingSchema`
        # @return [Fixnum]
        attr_accessor :other_numbering_schema
      
        # For season or quarter dates.
        # Corresponds to the JSON property `otherNumberingStart`
        # @return [Fixnum]
        attr_accessor :other_numbering_start
      
        # For each page of a magazine, maps to the item index of "item".
        # Corresponds to the JSON property `pageToItem`
        # @return [Array<Fixnum>]
        attr_accessor :page_to_item
      
        # 
        # Corresponds to the JSON property `publicationDateEnd`
        # @return [String]
        attr_accessor :publication_date_end
      
        # 
        # Corresponds to the JSON property `publicationDateStart`
        # @return [String]
        attr_accessor :publication_date_start
      
        # This is used to render the metadata line of the snippet and should be present
        # in all magazine documents.
        # Corresponds to the JSON property `serialTitle`
        # @return [String]
        attr_accessor :serial_title
      
        # 
        # Corresponds to the JSON property `serialVolumeid`
        # @return [Fixnum]
        attr_accessor :serial_volumeid
      
        # 
        # Corresponds to the JSON property `volume`
        # @return [Fixnum]
        attr_accessor :volume
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_date = args[:display_date] if args.key?(:display_date)
          @issue_description = args[:issue_description] if args.key?(:issue_description)
          @issue_end = args[:issue_end] if args.key?(:issue_end)
          @issue_start = args[:issue_start] if args.key?(:issue_start)
          @item = args[:item] if args.key?(:item)
          @other_numbering_end = args[:other_numbering_end] if args.key?(:other_numbering_end)
          @other_numbering_schema = args[:other_numbering_schema] if args.key?(:other_numbering_schema)
          @other_numbering_start = args[:other_numbering_start] if args.key?(:other_numbering_start)
          @page_to_item = args[:page_to_item] if args.key?(:page_to_item)
          @publication_date_end = args[:publication_date_end] if args.key?(:publication_date_end)
          @publication_date_start = args[:publication_date_start] if args.key?(:publication_date_start)
          @serial_title = args[:serial_title] if args.key?(:serial_title)
          @serial_volumeid = args[:serial_volumeid] if args.key?(:serial_volumeid)
          @volume = args[:volume] if args.key?(:volume)
        end
      end
      
      # Newspaper-specific fields.
      class OceanDocTagNewspaperSpecific
        include Google::Apis::Core::Hashable
      
        # Newspaper Article Roll Coordinates used to figure out the location of the
        # article wrt the page. It is of the form x,y.
        # Corresponds to the JSON property `articleRollCoords`
        # @return [String]
        attr_accessor :article_roll_coords
      
        # Atlantis specific. Deprecated.
        # Corresponds to the JSON property `newspaperDate`
        # @return [Float]
        attr_accessor :newspaper_date
      
        # 
        # Corresponds to the JSON property `newspaperName`
        # @return [String]
        attr_accessor :newspaper_name
      
        # Atlantis specific. Deprecated.
        # Corresponds to the JSON property `newspaperUrl`
        # @return [String]
        attr_accessor :newspaper_url
      
        # These fields are only populated for Santorini (newspapers on goovols)
        # formatted newspapers, not for Atlantis: YYYY.MM.DD format.
        # Corresponds to the JSON property `publicationDate`
        # @return [String]
        attr_accessor :publication_date
      
        # Atlantis specific. Deprecated.
        # Corresponds to the JSON property `publisher`
        # @return [String]
        attr_accessor :publisher
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @article_roll_coords = args[:article_roll_coords] if args.key?(:article_roll_coords)
          @newspaper_date = args[:newspaper_date] if args.key?(:newspaper_date)
          @newspaper_name = args[:newspaper_name] if args.key?(:newspaper_name)
          @newspaper_url = args[:newspaper_url] if args.key?(:newspaper_url)
          @publication_date = args[:publication_date] if args.key?(:publication_date)
          @publisher = args[:publisher] if args.key?(:publisher)
        end
      end
      
      # Patent specific fields. Currently empty, but need to move the fields below
      # into here at a later date
      class OceanDocTagPatentSpecific
        include Google::Apis::Core::Hashable
      
        # this is in ONIX format.
        # Corresponds to the JSON property `applicationDate`
        # @return [String]
        attr_accessor :application_date
      
        # 2-letter language of the document such as "en" or "fr" This field was created
        # for plumbing in the OFE API intl patent flow, and is probably not otherwise
        # filled in.
        # Corresponds to the JSON property `contentLanguage`
        # @return [String]
        attr_accessor :content_language
      
        # 
        # Corresponds to the JSON property `docType`
        # @return [Fixnum]
        attr_accessor :doc_type
      
        # Just the number, no bibkey prefix. Called 'doc number' b/c it could be patent
        # number for patents, application number for applications.
        # Corresponds to the JSON property `documentNumber`
        # @return [String]
        attr_accessor :document_number
      
        # US and Int'l patent classification codes for "related patents".
        # Corresponds to the JSON property `domesticClassification`
        # @return [Array<String>]
        attr_accessor :domestic_classification
      
        # 
        # Corresponds to the JSON property `internationalClassification`
        # @return [Array<String>]
        attr_accessor :international_classification
      
        # this is in ONIX format.
        # Corresponds to the JSON property `issueDate`
        # @return [String]
        attr_accessor :issue_date
      
        # 
        # Corresponds to the JSON property `patentAssignee`
        # @return [String]
        attr_accessor :patent_assignee
      
        # For applications, the 'publication number' Something like US20071234567A1: 'US'
        # prefix, 4 digit year, 7 digit serial number, 2 character code, all stuck
        # together.
        # Corresponds to the JSON property `publicationNumber`
        # @return [String]
        attr_accessor :publication_number
      
        # Path identifying the image used for the thumbnail of this patent. e.g. "
        # EP1234567B1/imgf0001.png" The client is expected to fill in the rest of the
        # url such as: https://patentimages.storage.googleapis.com/thumbnails/
        # EP1234567B1/imgf0001.png
        # Corresponds to the JSON property `relativeThumbnailPath`
        # @return [String]
        attr_accessor :relative_thumbnail_path
      
        # 
        # Corresponds to the JSON property `tenCharUsClassification`
        # @return [Array<String>]
        attr_accessor :ten_char_us_classification
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_date = args[:application_date] if args.key?(:application_date)
          @content_language = args[:content_language] if args.key?(:content_language)
          @doc_type = args[:doc_type] if args.key?(:doc_type)
          @document_number = args[:document_number] if args.key?(:document_number)
          @domestic_classification = args[:domestic_classification] if args.key?(:domestic_classification)
          @international_classification = args[:international_classification] if args.key?(:international_classification)
          @issue_date = args[:issue_date] if args.key?(:issue_date)
          @patent_assignee = args[:patent_assignee] if args.key?(:patent_assignee)
          @publication_number = args[:publication_number] if args.key?(:publication_number)
          @relative_thumbnail_path = args[:relative_thumbnail_path] if args.key?(:relative_thumbnail_path)
          @ten_char_us_classification = args[:ten_char_us_classification] if args.key?(:ten_char_us_classification)
        end
      end
      
      # Details of the work cluster for this Volume.
      class OceanDocTagWorkCluster
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `clusterSize`
        # @return [Fixnum]
        attr_accessor :cluster_size
      
        # 
        # Corresponds to the JSON property `workId`
        # @return [Fixnum]
        attr_accessor :work_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_size = args[:cluster_size] if args.key?(:cluster_size)
          @work_id = args[:work_id] if args.key?(:work_id)
        end
      end
      
      # A container proto to store prices for GE
      class OceanGeMoney
        include Google::Apis::Core::Hashable
      
        # amount in micros. 1 is represented 1000000
        # Corresponds to the JSON property `amountInMicros`
        # @return [Fixnum]
        attr_accessor :amount_in_micros
      
        # The currency codes come from google3/i18n/identifiers/currencycode.h.
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amount_in_micros = args[:amount_in_micros] if args.key?(:amount_in_micros)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
        end
      end
      
      # GE sale related data
      class OceanGePrice
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [Array<Google::Apis::ContentwarehouseV1::OceanGePriceLocale>]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # 
      class OceanGePriceLocale
        include Google::Apis::Core::Hashable
      
        # The two character ISO country code
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # A container proto to store prices for GE
        # Corresponds to the JSON property `offerPrice`
        # @return [Google::Apis::ContentwarehouseV1::OceanGeMoney]
        attr_accessor :offer_price
      
        # The time (in secs from epoch) the content goes on sale (only set when the book
        # is not already sellable at the time of indexing).
        # Corresponds to the JSON property `onSaleTimeSecs`
        # @return [Fixnum]
        attr_accessor :on_sale_time_secs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
          @offer_price = args[:offer_price] if args.key?(:offer_price)
          @on_sale_time_secs = args[:on_sale_time_secs] if args.key?(:on_sale_time_secs)
        end
      end
      
      # Size info of an image.
      class OceanImageSize
        include Google::Apis::Core::Hashable
      
        # pixels
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # pixels
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # How a volume may be viewed in a particular locale. Next available ID: 25 (
      # ikkwong)
      class OceanLocaleViewability
        include Google::Apis::Core::Hashable
      
        # These capture "commercial" contract related access rights provided by partners
        # for a volume.
        # Corresponds to the JSON property `accessRights`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeAccessRights]
        attr_accessor :access_rights
      
        # Are we allowed to add all the front matter to the preview in addition to the
        # preview amount that is from percent_book_shown? This means the front matter
        # becomes freely previewable and does not count towards the previewable amount
        # based on the percentage.
        # Corresponds to the JSON property `allowAddingFrontmatterToPreview`
        # @return [Boolean]
        attr_accessor :allow_adding_frontmatter_to_preview
        alias_method :allow_adding_frontmatter_to_preview?, :allow_adding_frontmatter_to_preview
      
        # By default, we allow continuous browse. PFE provides a means for partners to
        # opt out entirely or just specific books.
        # Corresponds to the JSON property `allowContinuousBrowse`
        # @return [Boolean]
        attr_accessor :allow_continuous_browse
        alias_method :allow_continuous_browse?, :allow_continuous_browse
      
        # whether OFE should display this volume in syndicated search results
        # Corresponds to the JSON property `allowRetailSyndication`
        # @return [Boolean]
        attr_accessor :allow_retail_syndication
        alias_method :allow_retail_syndication?, :allow_retail_syndication
      
        # The bibkey upon which this viewability information is based.
        # Corresponds to the JSON property `bibkey`
        # @return [String]
        attr_accessor :bibkey
      
        # Whether we can show ads with this book in this locale.
        # Corresponds to the JSON property `canDisplayAds`
        # @return [Boolean]
        attr_accessor :can_display_ads
        alias_method :can_display_ads?, :can_display_ads
      
        # In future, we will generate epub iff can_download_epub = true irrespective of
        # viewability or download pdf state.
        # Corresponds to the JSON property `canDownloadEpub`
        # @return [Boolean]
        attr_accessor :can_download_epub
        alias_method :can_download_epub?, :can_download_epub
      
        # In future, we will generate PDF iff can_download_pdf = true irrespective of
        # viewability.
        # Corresponds to the JSON property `canDownloadPdf`
        # @return [Boolean]
        attr_accessor :can_download_pdf
        alias_method :can_download_pdf?, :can_download_pdf
      
        # Whether to show library links for the books in this imprint.
        # Corresponds to the JSON property `canShowLibraryLinks`
        # @return [Boolean]
        attr_accessor :can_show_library_links
        alias_method :can_show_library_links?, :can_show_library_links
      
        # Whether we can show photos for this book in this locale.
        # Corresponds to the JSON property `canShowPhotos`
        # @return [Boolean]
        attr_accessor :can_show_photos
        alias_method :can_show_photos?, :can_show_photos
      
        # It should be OK to use metadata covers normally, but we allow publishers to
        # explicitly disallow them.
        # Corresponds to the JSON property `canUseMetadataCover`
        # @return [Boolean]
        attr_accessor :can_use_metadata_cover
        alias_method :can_use_metadata_cover?, :can_use_metadata_cover
      
        # The client who provided the rights for this bibkey, and who should receive
        # revenue derived from this book in this locale. This will only be present when
        # we receive explicit rights from a publisher.
        # Corresponds to the JSON property `clientId`
        # @return [String]
        attr_accessor :client_id
      
        # Volume related access rights that are computed by Goovols Syncher from partner
        # and book metadata. This complements VolumeAccessRights. Next available ID: 4 (
        # kblass)
        # Corresponds to the JSON property `computedAccessRights`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeComputedAccessRights]
        attr_accessor :computed_access_rights
      
        # Viewability related dates.
        # Corresponds to the JSON property `dates`
        # @return [Google::Apis::ContentwarehouseV1::OceanLocaleViewabilityDates]
        attr_accessor :dates
      
        # This message describes display attributes. The attributes which are applicable
        # to OFE not indexing (mustang), should be added in this proto.
        # Corresponds to the JSON property `displayDetails`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeDisplayDetails]
        attr_accessor :display_details
      
        # This only applies when view_type == VIEW_METADATA and controls whether we're
        # allowed to include scanned info (keywords, toc, etc). in the metadata-view.
        # For books in metadata view because they have been opted out, this would be
        # false.
        # Corresponds to the JSON property `metadataViewMayIncludeInfoFromScans`
        # @return [Boolean]
        attr_accessor :metadata_view_may_include_info_from_scans
        alias_method :metadata_view_may_include_info_from_scans?, :metadata_view_may_include_info_from_scans
      
        # This only applies when view_type == VIEW_METADATA and controls whether we're
        # allowed to include a text sample even for a metadata view book.
        # Corresponds to the JSON property `metadataViewSampleAllowed`
        # @return [Boolean]
        attr_accessor :metadata_view_sample_allowed
        alias_method :metadata_view_sample_allowed?, :metadata_view_sample_allowed
      
        # How much of the book can be viewed in this locale. Will be 100 for VIEW_FULL;
        # 0 for VIEW_SNIPPET_, VIEW_NONE and VIEW_METADATA; and some value between 0 and
        # 100 (exclusive) for VIEW_PARTIAL.
        # Corresponds to the JSON property `percentBookShown`
        # @return [Fixnum]
        attr_accessor :percent_book_shown
      
        # If present, this is the rights policy's determination of the public domain
        # status. (Of course, this determination is generally conservative (i.e. false
        # negatives are likely), though exactly how conservative may depend on
        # parameters to the rights policy.) If absent, public domain status can be
        # inferred from view_type and view_reason, but that isn't quite perfectly
        # reliable: view_type should always be VIEW_FULL for public domain, but
        # view_reason might be REASON_PUBLIC_DOMAIN (definitely public domain, obviously)
        # , some other value, or absent. In the future, new viewabilities should always
        # have this field whenever possible.
        # Corresponds to the JSON property `publicDomain`
        # @return [Boolean]
        attr_accessor :public_domain
        alias_method :public_domain?, :public_domain
      
        # How did we derive this viewability for this locale+volume? For "partner" books,
        # this includes details about the "Imprint" that provided the rights. These
        # details specify things such as preferred buy-the-book-url to show in the
        # frontend.
        # Corresponds to the JSON property `sourcedetails`
        # @return [Google::Apis::ContentwarehouseV1::OceanLocaleViewabilitySourceDetails]
        attr_accessor :sourcedetails
      
        # The reason for the view_type.
        # Corresponds to the JSON property `viewReason`
        # @return [String]
        attr_accessor :view_reason
      
        # The viewability specified for this locale.
        # Corresponds to the JSON property `viewType`
        # @return [String]
        attr_accessor :view_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_rights = args[:access_rights] if args.key?(:access_rights)
          @allow_adding_frontmatter_to_preview = args[:allow_adding_frontmatter_to_preview] if args.key?(:allow_adding_frontmatter_to_preview)
          @allow_continuous_browse = args[:allow_continuous_browse] if args.key?(:allow_continuous_browse)
          @allow_retail_syndication = args[:allow_retail_syndication] if args.key?(:allow_retail_syndication)
          @bibkey = args[:bibkey] if args.key?(:bibkey)
          @can_display_ads = args[:can_display_ads] if args.key?(:can_display_ads)
          @can_download_epub = args[:can_download_epub] if args.key?(:can_download_epub)
          @can_download_pdf = args[:can_download_pdf] if args.key?(:can_download_pdf)
          @can_show_library_links = args[:can_show_library_links] if args.key?(:can_show_library_links)
          @can_show_photos = args[:can_show_photos] if args.key?(:can_show_photos)
          @can_use_metadata_cover = args[:can_use_metadata_cover] if args.key?(:can_use_metadata_cover)
          @client_id = args[:client_id] if args.key?(:client_id)
          @computed_access_rights = args[:computed_access_rights] if args.key?(:computed_access_rights)
          @dates = args[:dates] if args.key?(:dates)
          @display_details = args[:display_details] if args.key?(:display_details)
          @metadata_view_may_include_info_from_scans = args[:metadata_view_may_include_info_from_scans] if args.key?(:metadata_view_may_include_info_from_scans)
          @metadata_view_sample_allowed = args[:metadata_view_sample_allowed] if args.key?(:metadata_view_sample_allowed)
          @percent_book_shown = args[:percent_book_shown] if args.key?(:percent_book_shown)
          @public_domain = args[:public_domain] if args.key?(:public_domain)
          @sourcedetails = args[:sourcedetails] if args.key?(:sourcedetails)
          @view_reason = args[:view_reason] if args.key?(:view_reason)
          @view_type = args[:view_type] if args.key?(:view_type)
        end
      end
      
      # Viewability related dates.
      class OceanLocaleViewabilityDates
        include Google::Apis::Core::Hashable
      
        # If specified, the LocaleViewability will become effective on this date. This
        # field is used to allow pre-indexing of future books which will become viewable
        # and searchable according to the LocaleViewability on the specified date.
        # Before the effective date, the volume will have scanless-like VIEW_METADATA
        # viewability. For details, see the design document at http://go/
        # oceanviewabilityeffectivedate. The date is expressed as the number of seconds
        # since the Unix epoch.
        # Corresponds to the JSON property `effectiveDate`
        # @return [Fixnum]
        attr_accessor :effective_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @effective_date = args[:effective_date] if args.key?(:effective_date)
        end
      end
      
      # How did we derive this viewability for this locale+volume? For "partner" books,
      # this includes details about the "Imprint" that provided the rights. These
      # details specify things such as preferred buy-the-book-url to show in the
      # frontend.
      class OceanLocaleViewabilitySourceDetails
        include Google::Apis::Core::Hashable
      
        # Commercial information for a volume (data from the Imprint
        # PublishersVolumeInfo table in the db). An imprint is a subdivision of a
        # publisher (for example, Bantam Books is an imprint of Randon House), or can
        # even be just a grouping of volumes with common commercial attributes.
        # Corresponds to the JSON property `imprint`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeImprint]
        attr_accessor :imprint
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @imprint = args[:imprint] if args.key?(:imprint)
        end
      end
      
      # Per-doc data in the Ocean index. Ocean indexing details are in https://www/eng/
      # designdocs/scanning/ocean-indexing.html
      class OceanPerDocData
        include Google::Apis::Core::Hashable
      
        # rights, mask-availability, porn, etc.
        # Corresponds to the JSON property `flags`
        # @return [Fixnum]
        attr_accessor :flags
      
        # 
        # Corresponds to the JSON property `numPages`
        # @return [Fixnum]
        attr_accessor :num_pages
      
        # 1-based
        # Corresponds to the JSON property `pageNumber`
        # @return [Fixnum]
        attr_accessor :page_number
      
        # 
        # Corresponds to the JSON property `pageid`
        # @return [Fixnum]
        attr_accessor :pageid
      
        # 
        # Corresponds to the JSON property `volumeid`
        # @return [Fixnum]
        attr_accessor :volumeid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flags = args[:flags] if args.key?(:flags)
          @num_pages = args[:num_pages] if args.key?(:num_pages)
          @page_number = args[:page_number] if args.key?(:page_number)
          @pageid = args[:pageid] if args.key?(:pageid)
          @volumeid = args[:volumeid] if args.key?(:volumeid)
        end
      end
      
      # 
      class OceanVolumeAccessRights
        include Google::Apis::Core::Hashable
      
        # If false, then we can only provide text layer generated from publisher
        # provided epub.
        # Corresponds to the JSON property `allowAutoGeneratedText`
        # @return [Boolean]
        attr_accessor :allow_auto_generated_text
        alias_method :allow_auto_generated_text?, :allow_auto_generated_text
      
        # Whether we can show info cards inside this book.
        # Corresponds to the JSON property `canShowInfoCards`
        # @return [Boolean]
        attr_accessor :can_show_info_cards
        alias_method :can_show_info_cards?, :can_show_info_cards
      
        # Whether we can show photos inside this book.
        # Corresponds to the JSON property `canShowPhotos`
        # @return [Boolean]
        attr_accessor :can_show_photos
        alias_method :can_show_photos?, :can_show_photos
      
        # Maximum number of Adobe Digital Editions device per sale item allowed. 0 means
        # no download allowed. -1 means unlimited download.
        # Corresponds to the JSON property `numAdeDeviceAllowed`
        # @return [Fixnum]
        attr_accessor :num_ade_device_allowed
      
        # Maximum number of Adobe id per sale item allowed. 0 means no download allowed.
        # -1 means unlimited download.
        # Corresponds to the JSON property `numAdobeIdAllowed`
        # @return [Fixnum]
        attr_accessor :num_adobe_id_allowed
      
        # Max. number of Google eBooks downloads allowed. This is related to iPhone/iPad/
        # Androrid/WebReader reading, not to epub/pdf downloads. 0 means no download
        # allowed. This is related to bug #3094719.
        # Corresponds to the JSON property `numDownloadsAllowed`
        # @return [Fixnum]
        attr_accessor :num_downloads_allowed
      
        # Number of readers can read the Google eBooks simultaneously
        # Corresponds to the JSON property `numSimultaneousAccess`
        # @return [Fixnum]
        attr_accessor :num_simultaneous_access
      
        # Download type for offline reading
        # Corresponds to the JSON property `offlineDownload`
        # @return [String]
        attr_accessor :offline_download
      
        # How much of a volume we allow user to extract as text (for copy+paste)
        # Corresponds to the JSON property `percentCopyable`
        # @return [Fixnum]
        attr_accessor :percent_copyable
      
        # How much of a volume we allow user to print
        # Corresponds to the JSON property `percentPrintable`
        # @return [Fixnum]
        attr_accessor :percent_printable
      
        # True iff restrict view only to epub text. Don't show page images if this is
        # true. Some pubs don't have copyright for page layout and fonts.
        # Corresponds to the JSON property `restrictOnlyToText`
        # @return [Boolean]
        attr_accessor :restrict_only_to_text
        alias_method :restrict_only_to_text?, :restrict_only_to_text
      
        # Whether we sell fixed layout as image only.
        # Corresponds to the JSON property `sellFixedLayoutAsImageOnly`
        # @return [Boolean]
        attr_accessor :sell_fixed_layout_as_image_only
        alias_method :sell_fixed_layout_as_image_only?, :sell_fixed_layout_as_image_only
      
        # Whether text to speech is allowed
        # Corresponds to the JSON property `textToSpeech`
        # @return [Boolean]
        attr_accessor :text_to_speech
        alias_method :text_to_speech?, :text_to_speech
      
        # Whether we treat this book as public domain.
        # Corresponds to the JSON property `treatAsPublicDomain`
        # @return [Boolean]
        attr_accessor :treat_as_public_domain
        alias_method :treat_as_public_domain?, :treat_as_public_domain
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_auto_generated_text = args[:allow_auto_generated_text] if args.key?(:allow_auto_generated_text)
          @can_show_info_cards = args[:can_show_info_cards] if args.key?(:can_show_info_cards)
          @can_show_photos = args[:can_show_photos] if args.key?(:can_show_photos)
          @num_ade_device_allowed = args[:num_ade_device_allowed] if args.key?(:num_ade_device_allowed)
          @num_adobe_id_allowed = args[:num_adobe_id_allowed] if args.key?(:num_adobe_id_allowed)
          @num_downloads_allowed = args[:num_downloads_allowed] if args.key?(:num_downloads_allowed)
          @num_simultaneous_access = args[:num_simultaneous_access] if args.key?(:num_simultaneous_access)
          @offline_download = args[:offline_download] if args.key?(:offline_download)
          @percent_copyable = args[:percent_copyable] if args.key?(:percent_copyable)
          @percent_printable = args[:percent_printable] if args.key?(:percent_printable)
          @restrict_only_to_text = args[:restrict_only_to_text] if args.key?(:restrict_only_to_text)
          @sell_fixed_layout_as_image_only = args[:sell_fixed_layout_as_image_only] if args.key?(:sell_fixed_layout_as_image_only)
          @text_to_speech = args[:text_to_speech] if args.key?(:text_to_speech)
          @treat_as_public_domain = args[:treat_as_public_domain] if args.key?(:treat_as_public_domain)
        end
      end
      
      # Volume related access rights that are computed by Goovols Syncher from partner
      # and book metadata. This complements VolumeAccessRights. Next available ID: 4 (
      # kblass)
      class OceanVolumeComputedAccessRights
        include Google::Apis::Core::Hashable
      
        # Whether this book can be shared with family members.
        # Corresponds to the JSON property `canFamilyShare`
        # @return [Boolean]
        attr_accessor :can_family_share
        alias_method :can_family_share?, :can_family_share
      
        # Whether the panelization feature is enabled for internal users only.
        # Corresponds to the JSON property `panelizationFeatureInternalOnly`
        # @return [Boolean]
        attr_accessor :panelization_feature_internal_only
        alias_method :panelization_feature_internal_only?, :panelization_feature_internal_only
      
        # Whether the book is viewable for internal users only.
        # Corresponds to the JSON property `viewableInternalOnly`
        # @return [Boolean]
        attr_accessor :viewable_internal_only
        alias_method :viewable_internal_only?, :viewable_internal_only
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @can_family_share = args[:can_family_share] if args.key?(:can_family_share)
          @panelization_feature_internal_only = args[:panelization_feature_internal_only] if args.key?(:panelization_feature_internal_only)
          @viewable_internal_only = args[:viewable_internal_only] if args.key?(:viewable_internal_only)
        end
      end
      
      # This message describes display attributes. The attributes which are applicable
      # to OFE not indexing (mustang), should be added in this proto.
      class OceanVolumeDisplayDetails
        include Google::Apis::Core::Hashable
      
        # The creative commons license specified, Please refer ocean.
        # CreativeCommonsLicenseType.Type for enum values Not exposed in Partner
        # Frontend anymore.
        # Corresponds to the JSON property `ccLicense`
        # @return [Fixnum]
        attr_accessor :cc_license
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cc_license = args[:cc_license] if args.key?(:cc_license)
        end
      end
      
      # Commercial information for a volume (data from the Imprint
      # PublishersVolumeInfo table in the db). An imprint is a subdivision of a
      # publisher (for example, Bantam Books is an imprint of Randon House), or can
      # even be just a grouping of volumes with common commercial attributes.
      class OceanVolumeImprint
        include Google::Apis::Core::Hashable
      
        # These capture "commercial" contract related access rights provided by partners
        # for a volume.
        # Corresponds to the JSON property `accessRights`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeAccessRights]
        attr_accessor :access_rights
      
        # Id used in the google ads system
        # Corresponds to the JSON property `adsId`
        # @return [String]
        attr_accessor :ads_id
      
        # Are we allowed to add all the front matter to the preview in addition to the
        # preview amount that is from percent_book_shown?
        # Corresponds to the JSON property `allowAddingFrontmatterToPreview`
        # @return [Boolean]
        attr_accessor :allow_adding_frontmatter_to_preview
        alias_method :allow_adding_frontmatter_to_preview?, :allow_adding_frontmatter_to_preview
      
        # By default, we allow continuous browse. PFE provides a means for partners to
        # opt out entirely or just specific books. This will be deprecated once
        # UpdateVolumesReqHandler returns VolumeViewability.
        # Corresponds to the JSON property `allowContinuousBrowse`
        # @return [Boolean]
        attr_accessor :allow_continuous_browse
        alias_method :allow_continuous_browse?, :allow_continuous_browse
      
        # By default, we allow retailer syndication. PFE provides a means for partner to
        # opt out. This will be deprecated once UpdateVolumesReqHandler returns
        # VolumeViewability.
        # Corresponds to the JSON property `allowRetailSyndication`
        # @return [Boolean]
        attr_accessor :allow_retail_syndication
        alias_method :allow_retail_syndication?, :allow_retail_syndication
      
        # Beware: the author strings are not in fixed format..these can be comma
        # separated or 'and' separated or have extra terms like 'et al' and sometimes
        # have weird ones like 'no author' as these are fed in via a somewhat flexible
        # free text tool.
        # Corresponds to the JSON property `author`
        # @return [String]
        attr_accessor :author
      
        # Commercial info comes with book identifiers like ISBN(or some bibkey), Title,
        # Author. Passing these along as well with the commercials for better book
        # identification/link up with rights.
        # Corresponds to the JSON property `bibkey`
        # @return [String]
        attr_accessor :bibkey
      
        # Text to display in the buy-the-book blurb
        # Corresponds to the JSON property `buyTheBookText`
        # @return [String]
        attr_accessor :buy_the_book_text
      
        # ISBN/ISSN-parameterized URL to the imprint's site for buying a book. For ISBN-
        # parameterized links, the ISBN value will be substituted in the cannonical 13-
        # digit form.
        # Corresponds to the JSON property `buyTheBookUrl`
        # @return [String]
        attr_accessor :buy_the_book_url
      
        # iff true volume is available as Google Edition. This will be deprecated once
        # UpdateVolumesReqHandler returns VolumeViewability.
        # Corresponds to the JSON property `canDownloadEpub`
        # @return [Boolean]
        attr_accessor :can_download_epub
        alias_method :can_download_epub?, :can_download_epub
      
        # iff true and VIEW_TYPE=FULL_VIEW, then we will allow PDF download This will be
        # deprecated once UpdateVolumesReqHandler returns VolumeViewability.
        # Corresponds to the JSON property `canDownloadPdf`
        # @return [Boolean]
        attr_accessor :can_download_pdf
        alias_method :can_download_pdf?, :can_download_pdf
      
        # Whether to show library links for the books in this imprint. This will be
        # deprecated once UpdateVolumesReqHandler returns VolumeViewability.
        # Corresponds to the JSON property `canShowLibraryLinks`
        # @return [Boolean]
        attr_accessor :can_show_library_links
        alias_method :can_show_library_links?, :can_show_library_links
      
        # It should be OK to use metadata covers normally, but we allow publishers to
        # explicitly disallow them. This will be deprecated once UpdateVolumesReqHandler
        # returns VolumeViewability.
        # Corresponds to the JSON property `canUseMetadataCover`
        # @return [Boolean]
        attr_accessor :can_use_metadata_cover
        alias_method :can_use_metadata_cover?, :can_use_metadata_cover
      
        # Whether to disable other btb links for the books in this imprint. Show only
        # btb link from this partner and remove everything else.
        # Corresponds to the JSON property `disableOtherBuyTheBookLinks`
        # @return [Boolean]
        attr_accessor :disable_other_buy_the_book_links
        alias_method :disable_other_buy_the_book_links?, :disable_other_buy_the_book_links
      
        # This message describes display attributes. The attributes which are applicable
        # to OFE not indexing (mustang), should be added in this proto.
        # Corresponds to the JSON property `displayDetails`
        # @return [Google::Apis::ContentwarehouseV1::OceanVolumeDisplayDetails]
        attr_accessor :display_details
      
        # The ISBN supplied by publisher (or Google) for the Google Edition e-book. One
        # day it should be an attribute of the tome cluster.
        # Corresponds to the JSON property `geBibkey`
        # @return [String]
        attr_accessor :ge_bibkey
      
        # The imprint id from the ocean devel db for this imprint.
        # Corresponds to the JSON property `imprintId`
        # @return [Fixnum]
        attr_accessor :imprint_id
      
        # 
        # Corresponds to the JSON property `imprintName`
        # @return [String]
        attr_accessor :imprint_name
      
        # URL to the imprint's website, to go to upon a click on the logo
        # Corresponds to the JSON property `imprintUrl`
        # @return [String]
        attr_accessor :imprint_url
      
        # 
        # Corresponds to the JSON property `logoHeight`
        # @return [Fixnum]
        attr_accessor :logo_height
      
        # URL/location for the imprint's logo to display
        # Corresponds to the JSON property `logoLocation`
        # @return [String]
        attr_accessor :logo_location
      
        # The logo image's geometry
        # Corresponds to the JSON property `logoWidth`
        # @return [Fixnum]
        attr_accessor :logo_width
      
        # Percentage of book we are allowed to display This will be deprecated once
        # UpdateVolumesReqHandler returns VolumeViewability.
        # Corresponds to the JSON property `percentBookShown`
        # @return [Fixnum]
        attr_accessor :percent_book_shown
      
        # 
        # Corresponds to the JSON property `promotionalText`
        # @return [String]
        attr_accessor :promotional_text
      
        # We may allow imprints to run promotional campaigns. The following fields
        # capture the blurb to display and the URL (ISBN-parameterized) link to provide.
        # Corresponds to the JSON property `promotionalUrl`
        # @return [String]
        attr_accessor :promotional_url
      
        # Sometimes the Publisher/Imprint Name the book is published under is different
        # from the current name and we may have this information.
        # Corresponds to the JSON property `publishedImprintName`
        # @return [String]
        attr_accessor :published_imprint_name
      
        # Need a unique identifier for PFE records, using PVI ID
        # Corresponds to the JSON property `pviRowid`
        # @return [Fixnum]
        attr_accessor :pvi_rowid
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Some records are deactivated, suppressed or excluded; we still want to hear
        # about them, but we aren't going to be using their bibdata
        # Corresponds to the JSON property `useBibdata`
        # @return [Boolean]
        attr_accessor :use_bibdata
        alias_method :use_bibdata?, :use_bibdata
      
        # 
        # Corresponds to the JSON property `verticalType`
        # @return [String]
        attr_accessor :vertical_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_rights = args[:access_rights] if args.key?(:access_rights)
          @ads_id = args[:ads_id] if args.key?(:ads_id)
          @allow_adding_frontmatter_to_preview = args[:allow_adding_frontmatter_to_preview] if args.key?(:allow_adding_frontmatter_to_preview)
          @allow_continuous_browse = args[:allow_continuous_browse] if args.key?(:allow_continuous_browse)
          @allow_retail_syndication = args[:allow_retail_syndication] if args.key?(:allow_retail_syndication)
          @author = args[:author] if args.key?(:author)
          @bibkey = args[:bibkey] if args.key?(:bibkey)
          @buy_the_book_text = args[:buy_the_book_text] if args.key?(:buy_the_book_text)
          @buy_the_book_url = args[:buy_the_book_url] if args.key?(:buy_the_book_url)
          @can_download_epub = args[:can_download_epub] if args.key?(:can_download_epub)
          @can_download_pdf = args[:can_download_pdf] if args.key?(:can_download_pdf)
          @can_show_library_links = args[:can_show_library_links] if args.key?(:can_show_library_links)
          @can_use_metadata_cover = args[:can_use_metadata_cover] if args.key?(:can_use_metadata_cover)
          @disable_other_buy_the_book_links = args[:disable_other_buy_the_book_links] if args.key?(:disable_other_buy_the_book_links)
          @display_details = args[:display_details] if args.key?(:display_details)
          @ge_bibkey = args[:ge_bibkey] if args.key?(:ge_bibkey)
          @imprint_id = args[:imprint_id] if args.key?(:imprint_id)
          @imprint_name = args[:imprint_name] if args.key?(:imprint_name)
          @imprint_url = args[:imprint_url] if args.key?(:imprint_url)
          @logo_height = args[:logo_height] if args.key?(:logo_height)
          @logo_location = args[:logo_location] if args.key?(:logo_location)
          @logo_width = args[:logo_width] if args.key?(:logo_width)
          @percent_book_shown = args[:percent_book_shown] if args.key?(:percent_book_shown)
          @promotional_text = args[:promotional_text] if args.key?(:promotional_text)
          @promotional_url = args[:promotional_url] if args.key?(:promotional_url)
          @published_imprint_name = args[:published_imprint_name] if args.key?(:published_imprint_name)
          @pvi_rowid = args[:pvi_rowid] if args.key?(:pvi_rowid)
          @title = args[:title] if args.key?(:title)
          @use_bibdata = args[:use_bibdata] if args.key?(:use_bibdata)
          @vertical_type = args[:vertical_type] if args.key?(:vertical_type)
        end
      end
      
      # 
      class OceanVolumeViewability
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDDefaultViewType`
        # @return [Fixnum]
        attr_accessor :deprecated_default_view_type
      
        # How a volume may be viewed in a particular locale. Next available ID: 25 (
        # ikkwong)
        # Corresponds to the JSON property `defaultViewability`
        # @return [Google::Apis::ContentwarehouseV1::OceanLocaleViewability]
        attr_accessor :default_viewability
      
        # DEPRECATED: Viewability-Limbo was a state that prevented indexing from running
        # if the viewability of a volume had dropped significantly. It was removed
        # during viewability refactoring: http://go/viewability
        # Corresponds to the JSON property `inViewabilityLimbo`
        # @return [Boolean]
        attr_accessor :in_viewability_limbo
        alias_method :in_viewability_limbo?, :in_viewability_limbo
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [Array<Google::Apis::ContentwarehouseV1::OceanVolumeViewabilityLocale>]
        attr_accessor :locale
      
        # Whether the volume viewability was updated by the indexer as opposed to a
        # direct update in goovols. The absense of this bit will indicate to the indexer
        # that it should not short-circuit indexing side effects that should occur when
        # viewability changes.
        # Corresponds to the JSON property `updatedByIndexer`
        # @return [Boolean]
        attr_accessor :updated_by_indexer
        alias_method :updated_by_indexer?, :updated_by_indexer
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_default_view_type = args[:deprecated_default_view_type] if args.key?(:deprecated_default_view_type)
          @default_viewability = args[:default_viewability] if args.key?(:default_viewability)
          @in_viewability_limbo = args[:in_viewability_limbo] if args.key?(:in_viewability_limbo)
          @locale = args[:locale] if args.key?(:locale)
          @updated_by_indexer = args[:updated_by_indexer] if args.key?(:updated_by_indexer)
        end
      end
      
      # 
      class OceanVolumeViewabilityLocale
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDViewType`
        # @return [Fixnum]
        attr_accessor :deprecated_view_type
      
        # The two-character ISO country code for the locale.
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # How a volume may be viewed in a particular locale. Next available ID: 25 (
        # ikkwong)
        # Corresponds to the JSON property `viewability`
        # @return [Google::Apis::ContentwarehouseV1::OceanLocaleViewability]
        attr_accessor :viewability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_view_type = args[:deprecated_view_type] if args.key?(:deprecated_view_type)
          @locale = args[:locale] if args.key?(:locale)
          @viewability = args[:viewability] if args.key?(:viewability)
        end
      end
      
      # Bounding box of patch containing line, word or symbol.
      class OcrPhotoBoundingBox
        include Google::Apis::Core::Hashable
      
        # Angle of rotation of (in degrees, clockwise is positive) of the box about the
        # top-left corner.
        # Corresponds to the JSON property `angle`
        # @return [Float]
        attr_accessor :angle
      
        # Sequence of rotated boxes that tightly enclose the text.
        # Corresponds to the JSON property `curvedBox`
        # @return [Google::Apis::ContentwarehouseV1::OcrPhotoCurvedBoundingBox]
        attr_accessor :curved_box
      
        # Box height (bottom pixels at top + height - 1).
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # x coordinate of top-left corner
        # Corresponds to the JSON property `left`
        # @return [Fixnum]
        attr_accessor :left
      
        # y coordinate of top-left corner
        # Corresponds to the JSON property `top`
        # @return [Fixnum]
        attr_accessor :top
      
        # Box width (rightmost pixels at left + width - 1).
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @angle = args[:angle] if args.key?(:angle)
          @curved_box = args[:curved_box] if args.key?(:curved_box)
          @height = args[:height] if args.key?(:height)
          @left = args[:left] if args.key?(:left)
          @top = args[:top] if args.key?(:top)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Copy of ocr/goodoc/layout-common.proto:CurvedBoundingBox, temporary duplicated
      # here to allow for on-device builds.
      class OcrPhotoCurve
        include Google::Apis::Core::Hashable
      
        # The sequence of points that approximate the curve.
        # Corresponds to the JSON property `points`
        # @return [Array<Google::Apis::ContentwarehouseV1::OcrPhotoCurvePoint>]
        attr_accessor :points
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @points = args[:points] if args.key?(:points)
        end
      end
      
      # 
      class OcrPhotoCurvePoint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `x`
        # @return [Float]
        attr_accessor :x
      
        # NOTE: if we wish to support perspective (varying thickness), later on we could
        # extend this message with a thickness field. In that case, CurvedBoundingBox.
        # thickness() would be used as a default if !Point.has_thickness().
        # Corresponds to the JSON property `y`
        # @return [Float]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # 
      class OcrPhotoCurvedBoundingBox
        include Google::Apis::Core::Hashable
      
        # Copy of ocr/goodoc/layout-common.proto:CurvedBoundingBox, temporary duplicated
        # here to allow for on-device builds.
        # Corresponds to the JSON property `midLineCurve`
        # @return [Google::Apis::ContentwarehouseV1::OcrPhotoCurve]
        attr_accessor :mid_line_curve
      
        # If top_to_bottom is true, this is the width of the curved box. Otherwise, it
        # is the height of the curved box.
        # Corresponds to the JSON property `thickness`
        # @return [Float]
        attr_accessor :thickness
      
        # If true, the curve is interpreted as top to bottom of the line image.
        # Otherwise, it is from left to right.
        # Corresponds to the JSON property `topToBottom`
        # @return [Boolean]
        attr_accessor :top_to_bottom
        alias_method :top_to_bottom?, :top_to_bottom
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid_line_curve = args[:mid_line_curve] if args.key?(:mid_line_curve)
          @thickness = args[:thickness] if args.key?(:thickness)
          @top_to_bottom = args[:top_to_bottom] if args.key?(:top_to_bottom)
        end
      end
      
      # Text with bounding box.
      class OcrPhotoTextBox
        include Google::Apis::Core::Hashable
      
        # ID of the text block that this line belongs to.
        # Corresponds to the JSON property `blockId`
        # @return [Fixnum]
        attr_accessor :block_id
      
        # Bounding box of patch containing line, word or symbol.
        # Corresponds to the JSON property `box`
        # @return [Google::Apis::ContentwarehouseV1::OcrPhotoBoundingBox]
        attr_accessor :box
      
        # Content type for this box.
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # Optional width of characters in the text.
        # Corresponds to the JSON property `symbolWidths`
        # @return [Array<Fixnum>]
        attr_accessor :symbol_widths
      
        # Text string.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @block_id = args[:block_id] if args.key?(:block_id)
          @box = args[:box] if args.key?(:box)
          @content_type = args[:content_type] if args.key?(:content_type)
          @symbol_widths = args[:symbol_widths] if args.key?(:symbol_widths)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # This proto is used as the key for official pages data. WARNING WARNING WARNING
      # WARNING WARNING PAY ATTENTION HERE! The query field contains a specially
      # NORMALIZED query, NOT a raw one. You can get a normalized query in several
      # ways: 1. from an squery with NormalizedQueryFromSquery 2. from a CJK-segmented
      # and punctuation-stripped query with NormalizeText (NOTE: navboost queries are
      # already CJK-segmented and punctuation-stripped, you can just pass them to
      # NormalizeText) 3. from user text/query with CanonicalizeText (this will do the
      # CJK segmenting, punctuation stripping and character normalization for you) All
      # of these functions are in ./utils/external-utils.h
      class OfficialPagesOfficialKey
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country = args[:country] if args.key?(:country)
          @language = args[:language] if args.key?(:language)
          @query = args[:query] if args.key?(:query)
        end
      end
      
      # 
      class OfficialPagesQuerySet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `queries`
        # @return [Array<Google::Apis::ContentwarehouseV1::OfficialPagesOfficialKey>]
        attr_accessor :queries
      
        # This is the fingerprint of the OfficialKey queries in the queries field. The
        # index of a fingerprint in this field corresponds to the index of the
        # fingerprinted query in the queries field. The fingerprint is produced with the
        # QueryCountryLanguageFingerprint function in external-utils.h
        # Corresponds to the JSON property `queryCountryLanguageFingerprints`
        # @return [Array<Fixnum>]
        attr_accessor :query_country_language_fingerprints
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @queries = args[:queries] if args.key?(:queries)
          @query_country_language_fingerprints = args[:query_country_language_fingerprints] if args.key?(:query_country_language_fingerprints)
        end
      end
      
      # 
      class OrionDocEntitiesProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # This is encoded using EntityCandidate::Encode
        # Corresponds to the JSON property `encodedEntity`
        # @return [Array<Fixnum>]
        attr_accessor :encoded_entity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @encoded_entity = args[:encoded_entity] if args.key?(:encoded_entity)
        end
      end
      
      # 
      class PairwiseQScoringData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `confidenceValue`
        # @return [Float]
        attr_accessor :confidence_value
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence_value = args[:confidence_value] if args.key?(:confidence_value)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Message representing a versioned PairwiseQ scores used for experimentation.
      # This protobuf is copied from quality_nsr_pairwiseq::PairwiseQVersionedItem.
      class PairwiseQVersionedItem
        include Google::Apis::Core::Hashable
      
        # The PairwiseQ confidence value corresponding to this version.
        # Corresponds to the JSON property `confidenceValue`
        # @return [Float]
        attr_accessor :confidence_value
      
        # The PairwiseQ value corresponding to this version.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        # The version id.
        # Corresponds to the JSON property `versionId`
        # @return [Fixnum]
        attr_accessor :version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence_value = args[:confidence_value] if args.key?(:confidence_value)
          @value = args[:value] if args.key?(:value)
          @version_id = args[:version_id] if args.key?(:version_id)
        end
      end
      
      # 
      class PeoplestackFlexorgsProtoInternalExternal
        include Google::Apis::Core::Hashable
      
        # All evaluations are done within the context of a given application, e.g., "
        # Gmail" and should not be reused in other apps.
        # Corresponds to the JSON property `application`
        # @return [String]
        attr_accessor :application
      
        # * There can be multiple states based on the context: 1. AUTOCOMPLETE + Gmail -
        # context 1 2. AUTOCOMPLETE + Chat/Dynamite - context 2 3. "SOME OTHER ACTION" +
        # Gmail - context 3 A client should identify whether a patrticular context is
        # present in the list and only if one is found - use the state that goes alogn
        # with the context, otherwise the client should default to whatever is the safe
        # assumption about "internality/externality" the application should be making (
        # likely, consider everything not explicitly "internal" as "external").
        # Corresponds to the JSON property `stateStatus`
        # @return [Array<Google::Apis::ContentwarehouseV1::PeoplestackFlexorgsProtoInternalExternalStateStatus>]
        attr_accessor :state_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application = args[:application] if args.key?(:application)
          @state_status = args[:state_status] if args.key?(:state_status)
        end
      end
      
      # 
      class PeoplestackFlexorgsProtoInternalExternalStateStatus
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contextType`
        # @return [String]
        attr_accessor :context_type
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @context_type = args[:context_type] if args.key?(:context_type)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # =========================================================================== #
      # Make sure you read the comments in the bottom before you add any new field. NB:
      # As noted in the comments, this protocol buffer is used in both indexing and
      # serving. In mustang serving implementations we only decode perdocdata during
      # the search phase, and so this protocol should only contain data used during
      # search. See mustang/repos_www/attachments.proto:`MustangBasicInfo,
      # MustangContentInfo` for protocols used during search and/or docinfo. Next
      # available tag deprecated, use this (and look for commented out fields): blaze-
      # bin/net/proto_compiler/protocol-compiler --freetags \ indexer/perdocdata/
      # perdocdata.proto Next tag: 217
      class PerDocData
        include Google::Apis::Core::Hashable
      
        # Additional data for Blog/Posts
        # Corresponds to the JSON property `BlogData`
        # @return [Google::Apis::ContentwarehouseV1::BlogPerDocData]
        attr_accessor :blog_data
      
        # Per-doc data for the web page about the cited book Approximate size is on
        # average ~10bytes
        # Corresponds to the JSON property `BookCitationData`
        # @return [Google::Apis::ContentwarehouseV1::BookCitationPerDocData]
        attr_accessor :book_citation_data
      
        # The obfuscated google profile gaia id(s) of the author(s) of the document.
        # This field is deprecated, use the string version.
        # Corresponds to the JSON property `DEPRECATEDAuthorObfuscatedGaia`
        # @return [Array<Fixnum>]
        attr_accessor :deprecated_author_obfuscated_gaia
      
        # 
        # Corresponds to the JSON property `DEPRECATEDQuarantineWhitelist`
        # @return [Boolean]
        attr_accessor :deprecated_quarantine_whitelist
        alias_method :deprecated_quarantine_whitelist?, :deprecated_quarantine_whitelist
      
        # The document spam score is represented as a 7-bits, going from 0 to 127.
        # Corresponds to the JSON property `DocLevelSpamScore`
        # @return [Fixnum]
        attr_accessor :doc_level_spam_score
      
        # Free form debug info. NB2: consider carefully what to save here. It's easy to
        # eat lots of gfs space with debug info that nobody needs...
        # Corresponds to the JSON property `Event`
        # @return [Array<Google::Apis::ContentwarehouseV1::PerDocDebugEvent>]
        attr_accessor :event
      
        # The gibberish score is represented in 7 bits, going from 0 to 127.
        # Corresponds to the JSON property `GibberishScore`
        # @return [Fixnum]
        attr_accessor :gibberish_score
      
        # 16 bytes of groups2 data: used only in groups2 index
        # Corresponds to the JSON property `GroupsData`
        # @return [Google::Apis::ContentwarehouseV1::GroupsPerDocData]
        attr_accessor :groups_data
      
        # Is this document considered spam by the anchor bayes classifier?
        # Corresponds to the JSON property `IsAnchorBayesSpam`
        # @return [Boolean]
        attr_accessor :is_anchor_bayes_spam
        alias_method :is_anchor_bayes_spam?, :is_anchor_bayes_spam
      
        # The keyword stuffing score is represented in 7 bits, going from 0 to 127.
        # Corresponds to the JSON property `KeywordStuffingScore`
        # @return [Fixnum]
        attr_accessor :keyword_stuffing_score
      
        # Note: This message is also in the RTUpdate protocol buffer.
        # Corresponds to the JSON property `MobileData`
        # @return [Google::Apis::ContentwarehouseV1::MobilePerDocData]
        attr_accessor :mobile_data
      
        # The original content score is represented as a 7-bits, going from 0 to 127.
        # Only pages with little content have this field. The actual original content
        # score ranges from 0 to 512. It is encoded with quality_q2::OriginalContentUtil:
        # :EncodeOriginalContentScore(). To decode the value, use quality_q2::
        # OriginalContentUtil::DecodeOriginalContentScore().
        # Corresponds to the JSON property `OriginalContentScore`
        # @return [Fixnum]
        attr_accessor :original_content_score
      
        # Per-doc data for premium documents in the Google index.
        # Corresponds to the JSON property `PremiumData`
        # @return [Google::Apis::ContentwarehouseV1::PremiumPerDocData]
        attr_accessor :premium_data
      
        # bitmask of QuarantineBits (or'd together) used to store quarantine related
        # information. For example: QUARANTINE_WHITELIST | QUARANTINE_URLINURL.
        # Corresponds to the JSON property `QuarantineInfo`
        # @return [Fixnum]
        attr_accessor :quarantine_info
      
        # DEPRECATED ----------------------------------------------------------------
        # Please do not use these fields in any new code. experimental
        # Corresponds to the JSON property `ScaledExptIndyRank`
        # @return [Fixnum]
        attr_accessor :scaled_expt_indy_rank
      
        # experimental
        # Corresponds to the JSON property `ScaledExptIndyRank2`
        # @return [Fixnum]
        attr_accessor :scaled_expt_indy_rank2
      
        # experimental
        # Corresponds to the JSON property `ScaledExptIndyRank3`
        # @return [Fixnum]
        attr_accessor :scaled_expt_indy_rank3
      
        # 
        # Corresponds to the JSON property `ScaledExptSpamScoreEric`
        # @return [Fixnum]
        attr_accessor :scaled_expt_spam_score_eric
      
        # 
        # Corresponds to the JSON property `ScaledExptSpamScoreYoram`
        # @return [Fixnum]
        attr_accessor :scaled_expt_spam_score_yoram
      
        # The independence rank is represented as a 16-bit integer, which is multiplied
        # by (max_indy_rank / 65536) to produce actual independence rank values.
        # max_indy_rank is typically 0.84.
        # Corresponds to the JSON property `ScaledIndyRank`
        # @return [Fixnum]
        attr_accessor :scaled_indy_rank
      
        # End DEPRECATED ------------------------------------------------------------
        # Link age score is represented as a 7-bit integer, going from 0 to 127.
        # Corresponds to the JSON property `ScaledLinkAgeSpamScore`
        # @return [Fixnum]
        attr_accessor :scaled_link_age_spam_score
      
        # 
        # Corresponds to the JSON property `ScaledSpamScoreEric`
        # @return [Fixnum]
        attr_accessor :scaled_spam_score_eric
      
        # Spamscores are represented as a 7-bit integer, going from 0 to 127.
        # Corresponds to the JSON property `ScaledSpamScoreYoram`
        # @return [Fixnum]
        attr_accessor :scaled_spam_score_yoram
      
        # Next tag: 43
        # Corresponds to the JSON property `ScienceData`
        # @return [Google::Apis::ContentwarehouseV1::SciencePerDocData]
        attr_accessor :science_data
      
        # The spamword score is represented in 7-bits, going from 0 to 127.
        # Corresponds to the JSON property `SpamWordScore`
        # @return [Fixnum]
        attr_accessor :spam_word_score
      
        # Tag-site-ness of a page, repesented in 7-bits range from 0 to 100. Smaller
        # value means worse tag page.
        # Corresponds to the JSON property `TagPageScore`
        # @return [Fixnum]
        attr_accessor :tag_page_score
      
        # DO NOT USE THIS FOR ANYTHING LIVE WITHOUT PERMISSION! If you want to use this
        # for anything user-facing file a logs-access ticket describing what you want to
        # do. This data is currently only available in the freshdocs pipeline, so it
        # will only be present in instant mustang and certain librarian shards. Email
        # freshdocs-indexing with questions.
        # Corresponds to the JSON property `ToolBarData`
        # @return [Google::Apis::ContentwarehouseV1::ToolBarPerDocData]
        attr_accessor :tool_bar_data
      
        # 
        # Corresponds to the JSON property `WhirlpoolDiscount`
        # @return [Float]
        attr_accessor :whirlpool_discount
      
        # AppsLink contains Android application IDs in outlinks. It is used to improve
        # results ranking within applications universal. See http://go/apps-universal
        # for the project details.
        # Corresponds to the JSON property `appsLink`
        # @return [Google::Apis::ContentwarehouseV1::QualityCalypsoAppsLink]
        attr_accessor :apps_link
      
        # For indexing Asteroid Belt intent scores. See go/asteroid-belt for details.
        # Corresponds to the JSON property `asteroidBeltIntents`
        # @return [Google::Apis::ContentwarehouseV1::QualityOrbitAsteroidBeltDocumentIntentScores]
        attr_accessor :asteroid_belt_intents
      
        # 
        # Corresponds to the JSON property `authorObfuscatedGaiaStr`
        # @return [Array<String>]
        attr_accessor :author_obfuscated_gaia_str
      
        # This data is expected to appear in approximately 2 out of every 1,000
        # documents with an average of 2 fields per document. Rough order of size is in
        # the hundreds of kilobytes per Mustang shard.
        # Corresponds to the JSON property `biasingdata`
        # @return [Google::Apis::ContentwarehouseV1::BiasingPerDocData]
        attr_accessor :biasingdata
      
        # A replacement for BiasingPerDocData that is more efficient wrt size in the
        # index.
        # Corresponds to the JSON property `biasingdata2`
        # @return [Google::Apis::ContentwarehouseV1::BiasingPerDocData2]
        attr_accessor :biasingdata2
      
        # The body words over tokens ratios for the beginning part and whole doc. NB: To
        # save space, field body_words_to_tokens_ratio_total is not set if it has the
        # same value as body_words_to_tokens_ratio_begin (e.g., short docs).
        # Corresponds to the JSON property `bodyWordsToTokensRatioBegin`
        # @return [Float]
        attr_accessor :body_words_to_tokens_ratio_begin
      
        # 
        # Corresponds to the JSON property `bodyWordsToTokensRatioTotal`
        # @return [Float]
        attr_accessor :body_words_to_tokens_ratio_total
      
        # Compressed version of quality_geo_brainloc.goldmine.BrainlocAnnotation for
        # indexing. (See BrainlocAnnotation for detailed documentation.) Next ID: 10
        # Corresponds to the JSON property `brainloc`
        # @return [Google::Apis::ContentwarehouseV1::QualityGeoBrainlocBrainlocAttachment]
        attr_accessor :brainloc
      
        # A measure of commerciality of the document Score > 0 indicates document is
        # commercial (i.e. sells something) Computed by repository/pageclassifiers/
        # parsehandler-commercial.cc
        # Corresponds to the JSON property `commercialScore`
        # @return [Float]
        attr_accessor :commercial_score
      
        # A message containing per doc signals that are compressed and included in
        # Mustang and TeraGoogle. For TeraGoogle, this message is included in perdocdata
        # which means it can be used in preliminary scoring. CAREFUL: For TeraGoogle,
        # this data resides in very limited serving memory (Flash storage) for a huge
        # number of documents. Next id: 40
        # Corresponds to the JSON property `compressedQualitySignals`
        # @return [Google::Apis::ContentwarehouseV1::CompressedQualitySignals]
        attr_accessor :compressed_quality_signals
      
        # Compressed URL string used for SETI.
        # Corresponds to the JSON property `compressedUrl`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :compressed_url
      
        # The following protobuf is used to store an attribution from one page to (
        # usually) one other page, giving credit for the content. This information is
        # used during ranking to promote the attributed page. This protobuf is copied
        # from a quality_contra::SelectedAttribution. See //quality/contra/authorship/
        # attribution and https://qwiki.corp.google.com/display/Q/
        # ContentTrackingContentAttribution.
        # Corresponds to the JSON property `contentAttributions`
        # @return [Google::Apis::ContentwarehouseV1::ContentAttributions]
        attr_accessor :content_attributions
      
        # If you add new fields to this message, do not use any tag value less than the "
        # Next free tag" below. The lower tag values might be missing in this file, but
        # they were used in past for some field, so cannot be used again. Next free tag:
        # 44
        # Corresponds to the JSON property `countryInfo`
        # @return [Google::Apis::ContentwarehouseV1::CountryCountryAttachment]
        attr_accessor :country_info
      
        # This field is used internally by the docjoiner to forward the crawl pageranks
        # from original canonicals to canonicals we actually chose; outside sources
        # should not set it, and it should not be present in actual docjoins or the
        # index.
        # Corresponds to the JSON property `crawlPagerank`
        # @return [Fixnum]
        attr_accessor :crawl_pagerank
      
        # Proto-representation of the Crawler-ID in Web-Search (Alexandria-Scope). The
        # string-representation (covered in //indexing/crawler_id/scope/alexandria/
        # crawler_id.h) and the proto-representation are identical in meaning. For more
        # information in regard to the crawler_id, please look at //depot/google3/
        # indexing/crawler_id Used within the following components: - WebMirror: To
        # understand the parsed crawler-ID and apply attributes within their own tables.
        # - Serving : to identify the crawler-ID within the GenericSearchResponse, which
        # implies being stored in the MDU and returned by ascorer to Superroot. -
        # QSessions: To store the crawler-ID in all logged events for analysis. The
        # default values represent the 'empty string' crawler-ID for the Alexandria-
        # scope.
        # Corresponds to the JSON property `crawlerIdProto`
        # @return [Google::Apis::ContentwarehouseV1::LogsProtoIndexingCrawlerIdCrawlerIdProto]
        attr_accessor :crawler_id_proto
      
        # 
        # Corresponds to the JSON property `crowdingdata`
        # @return [Google::Apis::ContentwarehouseV1::CrowdingPerDocData]
        attr_accessor :crowdingdata
      
        # Stores dates-related info (e.g. page is old based on its date annotations).
        # Used in FreshnessTwiddler. Use encode/decode functions from quality/timebased/
        # utils/dates-info-helper-inl.h
        # Corresponds to the JSON property `datesInfo`
        # @return [Fixnum]
        attr_accessor :dates_info
      
        # Desktop interstitials signal. The message contains both fields for site-level
        # signal lookup in Index Signals (go/index-signals) and fields for final
        # attachment in DocJoin.
        # Corresponds to the JSON property `desktopInterstitials`
        # @return [Google::Apis::ContentwarehouseV1::IndexingMobileInterstitialsProtoDesktopInterstitials]
        attr_accessor :desktop_interstitials
      
        # 16-bit
        # Corresponds to the JSON property `domainAge`
        # @return [Fixnum]
        attr_accessor :domain_age
      
        # Date for Events. A web page might list multiple events with different dates.
        # We only take one date (start date) per event.
        # Corresponds to the JSON property `eventsDate`
        # @return [Array<Fixnum>]
        attr_accessor :events_date
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `extraData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :extra_data
      
        # Proto message containing site-level signal for search stack. Because
        # firefly_stats.proto depends on "//segindexer:compositedoc_proto", we cannot
        # make perdocdata contain it.
        # Corresponds to the JSON property `fireflySiteSignal`
        # @return [Google::Apis::ContentwarehouseV1::QualityCopiaFireflySiteSignal]
        attr_accessor :firefly_site_signal
      
        # Stores scores of freshness-related classifiers: freshbox article score, live
        # blog score and host-level article score. The encoding/decoding API is in
        # quality/freshness/freshbox/goldmine/freshbox_annotation_encoder.h. To use this
        # field, you MUST join g/pq-classifiers-announce and add your use case at http://
        # shortn/_RYXS2lX2IV.
        # Corresponds to the JSON property `freshboxArticleScores`
        # @return [Fixnum]
        attr_accessor :freshbox_article_scores
      
        # Stores freshness and aging related data, such as time-related quality metrics
        # predicted from url-pattern level signals. Use the encoding decoding API in
        # quality/freshness/docclassifier/aging/encoded-pattern-signals.h
        # Corresponds to the JSON property `freshnessEncodedSignals`
        # @return [Fixnum]
        attr_accessor :freshness_encoded_signals
      
        # PerDocData for fringe-query-prior (built into the shards for eventual
        # consumption at Fringe classification time). Not stored in DocJoins. NEXT ID:
        # 11
        # Corresponds to the JSON property `fringeQueryPrior`
        # @return [Google::Apis::ContentwarehouseV1::QualityFringeFringeQueryPriorPerDocData]
        attr_accessor :fringe_query_prior
      
        # geo data; approx 24 bytes for 23M U.S. pages
        # Corresponds to the JSON property `geodata`
        # @return [String]
        attr_accessor :geodata
      
        # 
        # Corresponds to the JSON property `homePageInfo`
        # @return [Fixnum]
        attr_accessor :home_page_info
      
        # The page-rank of the homepage of the site. Copied from the cdoc.doc().
        # pagerank_ns() of the homepage.
        # Corresponds to the JSON property `homepagePagerankNs`
        # @return [Fixnum]
        attr_accessor :homepage_pagerank_ns
      
        # The earliest firstseen date of all pages in this host/domain. These data are
        # used in twiddler to sandbox fresh spam in serving time. It is 16 bit and the
        # time is day number after 2005-12-31, and all the previous time are set to 0.
        # If this url's host_age == domain_age, then omit domain_age Please use //spam/
        # content/siteage-util.h to convert the day between epoch second. Regarding
        # usage of Sentinel values: We would like to check if a value exists in scoring
        # bundle while using in Ranklab AST. For this having a sentinel value will help
        # us know if the field exists or has a sentinel value (in the case it does not
        # exist). 16-bit
        # Corresponds to the JSON property `hostAge`
        # @return [Fixnum]
        attr_accessor :host_age
      
        # Site rank computed for host-level sitechunks. This value encodes nsr, site_pr
        # and new_nsr. See NsrUtil::ConvertNsrDataToHostNsr and go/nsr.
        # Corresponds to the JSON property `hostNsr`
        # @return [Fixnum]
        attr_accessor :host_nsr
      
        # 
        # Corresponds to the JSON property `imagedata`
        # @return [Google::Apis::ContentwarehouseV1::ImagePerDocData]
        attr_accessor :imagedata
      
        # This field indicates whether the document is in the newsstand corpus.
        # Corresponds to the JSON property `inNewsstand`
        # @return [Boolean]
        attr_accessor :in_newsstand
        alias_method :in_newsstand?, :in_newsstand
      
        # Set by the FreshDocs instant doc joiner. See //indexing/instant/hotdocs/README
        # and http://go/freshdocs-hotdocs.
        # Corresponds to the JSON property `isHotdoc`
        # @return [Boolean]
        attr_accessor :is_hotdoc
        alias_method :is_hotdoc?, :is_hotdoc
      
        # 
        # Corresponds to the JSON property `kaltixdata`
        # @return [Google::Apis::ContentwarehouseV1::KaltixPerDocData]
        attr_accessor :kaltixdata
      
        # For indexing k'nex annotations for FreshDocs.
        # Corresponds to the JSON property `knexAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::SocialPersonalizationKnexAnnotation]
        attr_accessor :knex_annotation
      
        # Plausible languages in order of decreasing plausibility. Language values are
        # small, IE < 127 so this should compress to one byte each.
        # Corresponds to the JSON property `languages`
        # @return [Array<Fixnum>]
        attr_accessor :languages
      
        # Last significant update of the document. This is sourced from the
        # quality_timebased.LastSignificantUpdate proto as computed by the LSUSelector
        # from various signals. The value is a UNIX timestamp in seconds.
        # Corresponds to the JSON property `lastSignificantUpdate`
        # @return [Fixnum]
        attr_accessor :last_significant_update
      
        # Metadata about last significant update. Currently this only encodes the
        # quality_timebased.LastSignificantUpdate.source field which contains the info
        # on the source of the signal. NOTE: Please do not read the value directly. Use
        # helpers from quality/timebased/lastsignificantupdate/lsu-helper.h instead.
        # Corresponds to the JSON property `lastSignificantUpdateInfo`
        # @return [Fixnum]
        attr_accessor :last_significant_update_info
      
        # Info on how to launch a mobile app to consume this document's content, if
        # applicable (see go/calypso).
        # Corresponds to the JSON property `launchAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityRichsnippetsAppsProtosLaunchAppInfoPerDocData]
        attr_accessor :launch_app_info
      
        # Message to which we attach to web documents in order to decide which
        # LiveResult to trigger. Next ID: 3
        # Corresponds to the JSON property `liveResultsData`
        # @return [Google::Apis::ContentwarehouseV1::WeboftrustLiveResultsDocAttachments]
        attr_accessor :live_results_data
      
        # Information on localized clusters, which is the relationship of translated and/
        # or localized pages.
        # Corresponds to the JSON property `localizedCluster`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDupsLocalizedLocalizedCluster]
        attr_accessor :localized_cluster
      
        # If not 0, we should not show the image in overlay mode in image snippets
        # Corresponds to the JSON property `noimageframeoverlayreason`
        # @return [Fixnum]
        attr_accessor :noimageframeoverlayreason
      
        # NOTE: When adding a new field to be propagated to Raffia check if
        # NsrPatternSignalSpec needs to be updated. Next ID: 31
        # Corresponds to the JSON property `nsrDataProto`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrNsrData]
        attr_accessor :nsr_data_proto
      
        # This field is propagated to shards. In addition, it is populated at serving
        # time by go/web-signal-joins.
        # Corresponds to the JSON property `nsrIsCovidLocalAuthority`
        # @return [Boolean]
        attr_accessor :nsr_is_covid_local_authority
        alias_method :nsr_is_covid_local_authority?, :nsr_is_covid_local_authority
      
        # This field is propagated to shards. It will also be populated at serving time
        # by go/web-signal-joins (see b/168114815).
        # Corresponds to the JSON property `nsrIsElectionAuthority`
        # @return [Boolean]
        attr_accessor :nsr_is_election_authority
        alias_method :nsr_is_election_authority?, :nsr_is_election_authority
      
        # This field is propagated to shards. It will also be populated at serving time
        # by go/web-signal-joins (see b/170607253). Bit indicating whether this site is
        # video-focused, but not hosted on any major known video hosting domains.
        # Corresponds to the JSON property `nsrIsVideoFocusedSite`
        # @return [Boolean]
        attr_accessor :nsr_is_video_focused_site
        alias_method :nsr_is_video_focused_site?, :nsr_is_video_focused_site
      
        # SiteChunk computed for nsr. It some cases it can use more information than
        # just url (e.g. youtube channels). See NsrAnnotator for details. If sitechunk
        # is longer than --populate_nsr_sitechunk_max_length (default=100), it will not
        # get populated. This field might be compressed and needs to be decoded with
        # NsrUtil::DecodeNsrSitechunk. See go/nsr-chunks for more details. This field
        # contains only nontrivial primary chunks.
        # Corresponds to the JSON property `nsrSitechunk`
        # @return [String]
        attr_accessor :nsr_sitechunk
      
        # Total number of urls encoded in the url section = # of alternate urls + 1
        # Corresponds to the JSON property `numUrls`
        # @return [Fixnum]
        attr_accessor :num_urls
      
        # Per-doc data in the Ocean index. Ocean indexing details are in https://www/eng/
        # designdocs/scanning/ocean-indexing.html
        # Corresponds to the JSON property `oceandata`
        # @return [Google::Apis::ContentwarehouseV1::OceanPerDocData]
        attr_accessor :oceandata
      
        # Onsite prominence measures the importance of the document within its site. It
        # is computed by propagating simulated traffic from the homepage and high craps
        # click pages. It is a 13-bit int.
        # Corresponds to the JSON property `onsiteProminence`
        # @return [Fixnum]
        attr_accessor :onsite_prominence
      
        # 
        # Corresponds to the JSON property `origin`
        # @return [Fixnum]
        attr_accessor :origin
      
        # The number of hard tokens in the title.
        # Corresponds to the JSON property `originalTitleHardTokenCount`
        # @return [Fixnum]
        attr_accessor :original_title_hard_token_count
      
        # 
        # Corresponds to the JSON property `pageTags`
        # @return [Array<Fixnum>]
        attr_accessor :page_tags
      
        # Experimental pageranks (DEPRECATED; only pagerank in MustangBasicInfo is used).
        # Corresponds to the JSON property `pagerank`
        # @return [Float]
        attr_accessor :pagerank
      
        # 
        # Corresponds to the JSON property `pagerank0`
        # @return [Float]
        attr_accessor :pagerank0
      
        # 
        # Corresponds to the JSON property `pagerank1`
        # @return [Float]
        attr_accessor :pagerank1
      
        # 
        # Corresponds to the JSON property `pagerank2`
        # @return [Float]
        attr_accessor :pagerank2
      
        # String that encodes the position ranges for different regions of the document.
        # See "indexer/pageregion.h" for an explanation, and how to decode the string
        # Corresponds to the JSON property `pageregions`
        # @return [String]
        attr_accessor :pageregions
      
        # 
        # Corresponds to the JSON property `phildata`
        # @return [Google::Apis::ContentwarehouseV1::PhilPerDocData]
        attr_accessor :phildata
      
        # Protocol message for data related to product sites. This data is stored as
        # signals data in docjoins.
        # Corresponds to the JSON property `productSitesInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityProductProductSiteData]
        attr_accessor :product_sites_info
      
        # The set of (query, country, language) triples for which this document is
        # considered to be the official page. For example, www.britneyspears.com would
        # be official for ("britney spears", "us", 0) and others (0 is English).
        # Corresponds to the JSON property `queriesForWhichOfficial`
        # @return [Google::Apis::ContentwarehouseV1::OfficialPagesQuerySet]
        attr_accessor :queries_for_which_official
      
        # Top two document language BCP-47 codes as generated by the
        # RosettaLanguageAnnotator in the decreasing order of probability.
        # Corresponds to the JSON property `rosettaLanguages`
        # @return [Array<String>]
        attr_accessor :rosetta_languages
      
        # This structure holds data for application information for rich snippets Next
        # ID: 48
        # Corresponds to the JSON property `rsApplication`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryAnnotationsRdfaRdfaRichSnippetsApplication]
        attr_accessor :rs_application
      
        # Top document language as generated by SAFT LangID. For now we store bare
        # minimum: just the top 1 language value, converted to the language enum, and
        # only when different from the first value in 'languages'.
        # Corresponds to the JSON property `saftLanguageInt`
        # @return [Array<Fixnum>]
        attr_accessor :saft_language_int
      
        # Selection tier rank is a language normalized score ranging from 0-32767 over
        # the serving tier (Base, Zeppelins, Landfills) for this document. This is
        # converted back to fractional position within the index tier by
        # scaled_selection_tier_rank/32767.
        # Corresponds to the JSON property `scaledSelectionTierRank`
        # @return [Fixnum]
        attr_accessor :scaled_selection_tier_rank
      
        # Scholar/Science Document type: <0 == not a Science Document -- default 0 ==
        # Science doc fully visible >0 == Science doc but limited visibility, the number
        # is the visible terms
        # Corresponds to the JSON property `scienceDoctype`
        # @return [Fixnum]
        attr_accessor :science_doctype
      
        # Deprecated 2016/01/14.
        # Corresponds to the JSON property `scienceHoldingsIds`
        # @return [Array<Fixnum>]
        attr_accessor :science_holdings_ids
      
        # SemanticDate, estimated date of the content of a document based on the
        # contents of the document (via parsing), anchors and related documents. Date is
        # encoded as a 32-bits UNIX date (1970 Jan 1 epoch). Confidence is encoded using
        # a SemanticDate specific format. For details of encoding, please refer to
        # quality/freshness/docclassifier/semanticdate/public/semantic_date.proto
        # Corresponds to the JSON property `semanticDate`
        # @return [Fixnum]
        attr_accessor :semantic_date
      
        # DEPRECATED: semantic_date_confidence replaced by semantic_date_info.
        # Corresponds to the JSON property `semanticDateConfidence`
        # @return [Fixnum]
        attr_accessor :semantic_date_confidence
      
        # Info is encoded using a SemanticDate specific format. Contains confidence
        # scores for day/month/year components as well as various meta data required by
        # the freshness twiddlers.
        # Corresponds to the JSON property `semanticDateInfo`
        # @return [Fixnum]
        attr_accessor :semantic_date_info
      
        # This message contains a set of cluster ids used to de-dup at serving time. A
        # document could be clustered into different clusters according to different
        # properties.
        # Corresponds to the JSON property `servingTimeClusterIds`
        # @return [Google::Apis::ContentwarehouseV1::IndexingDocjoinerServingTimeClusterIds]
        attr_accessor :serving_time_cluster_ids
      
        # This message represents shingle-related information obtained from a document.
        # Corresponds to the JSON property `shingleInfo`
        # @return [Google::Apis::ContentwarehouseV1::ShingleInfoPerDocData]
        attr_accessor :shingle_info
      
        # This message is used for storing smartphone related information. Note:
        # MobilePerDocData is a similar message, but it's for lowend mobile.
        # Corresponds to the JSON property `smartphoneData`
        # @return [Google::Apis::ContentwarehouseV1::SmartphonePerDocData]
        attr_accessor :smartphone_data
      
        # 
        # Corresponds to the JSON property `smearingMaxTotalOffdomainAnchors`
        # @return [Fixnum]
        attr_accessor :smearing_max_total_offdomain_anchors
      
        # For Social Search we store the fingerprint of the SG node name. This is used
        # in one of the superroot's PRE_DOC twiddlers as a lookup key for the full
        # Social Search data. PRE_DOC = twiddlers firing before the DocInfo request is
        # sent to the mustang backend.
        # Corresponds to the JSON property `socialgraphNodeNameFp`
        # @return [Fixnum]
        attr_accessor :socialgraph_node_name_fp
      
        # This protocol buffer indicates actions that we take based on Cookbook recipes (
        # see http://cookbook/) matching a particular document.
        # Corresponds to the JSON property `spamCookbookAction`
        # @return [Google::Apis::ContentwarehouseV1::SpamCookbookAction]
        attr_accessor :spam_cookbook_action
      
        # Contains hacked site signals which will be used in query time joins. As of Oct'
        # 19, the field is stored in a separate corpus. It'll only be populated for in-
        # flight requests between retrieve and full-score in perdocdata. So no extra
        # storage is needed on muppet side.
        # Corresponds to the JSON property `spamMuppetSignals`
        # @return [Google::Apis::ContentwarehouseV1::SpamMuppetjoinsMuppetSignals]
        attr_accessor :spam_muppet_signals
      
        # The spamrank measures the likelihood that this document links to known
        # spammers. Its value is between 0 and 65535.
        # Corresponds to the JSON property `spamrank`
        # @return [Fixnum]
        attr_accessor :spamrank
      
        # For SpamTokens content scores. Used in SiteBoostTwiddler to determine whether
        # a page is UGC Spam. See go/spamtokens-dd for details.
        # Corresponds to the JSON property `spamtokensContentScore`
        # @return [Float]
        attr_accessor :spamtokens_content_score
      
        # Encoded Document Time Sensitivity signal.
        # Corresponds to the JSON property `timeSensitivity`
        # @return [Fixnum]
        attr_accessor :time_sensitivity
      
        # Number of hard tokens originally in title without counting the stopwords.
        # Corresponds to the JSON property `titleHardTokenCountWithoutStopwords`
        # @return [Fixnum]
        attr_accessor :title_hard_token_count_without_stopwords
      
        # A copy of the value stored in /namespace/indexing/wwwglobal//fakepr/* for this
        # document. A value of quality_bakery::FakeprUtils::kUnknownToolbarPagerank
        # indicates that we don't have toolbar pagerank for this document. A value
        # between 0 and 10 (inclusive) means that this is the toolbar pagerank of the
        # page. Finally, if this value is not set it means that the toolbar pagerank is
        # equivalent to: quality_bakery::FakeprUtils::
        # EstimatePreDemotionFromPagerankNearestSeeds( basic_info.pagerank_ns()) called
        # on the MustangBasicInfo attachment for the same document.
        # Corresponds to the JSON property `toolbarPagerank`
        # @return [Fixnum]
        attr_accessor :toolbar_pagerank
      
        # Top petacat of the site. Used in SiteboostTwiddler to determine result/query
        # matching.
        # Corresponds to the JSON property `topPetacatTaxId`
        # @return [Fixnum]
        attr_accessor :top_petacat_tax_id
      
        # 
        # Corresponds to the JSON property `topPetacatWeight`
        # @return [Float]
        attr_accessor :top_petacat_weight
      
        # Protocol message for data related to good travel sites. This data is stored as
        # signals data in docjoins.
        # Corresponds to the JSON property `travelGoodSitesInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityTravelGoodSitesData]
        attr_accessor :travel_good_sites_info
      
        # For now, the count of matching trendspam queries.
        # Corresponds to the JSON property `trendspamScore`
        # @return [Fixnum]
        attr_accessor :trendspam_score
      
        # This field is propagated to shards. Stores clustering information on a site
        # level for the Tundra project.
        # Corresponds to the JSON property `tundraClusterId`
        # @return [Fixnum]
        attr_accessor :tundra_cluster_id
      
        # The uac spam score is represented in 7 bits, going from 0 to 127. Threshold is
        # 64. Score >= 64 is considered as uac spam.
        # Corresponds to the JSON property `uacSpamScore`
        # @return [Fixnum]
        attr_accessor :uac_spam_score
      
        # These two fingerprints are used for de-duping results in a twiddler. They
        # should only be populated by freshdocs, and will only be present for documents
        # that are chosen to be canonicals in a cluster whose previous canonical is also
        # in the index. Additionally, url_after_redirects_fp is only present if it is
        # different from a fingerprint of the URL.
        # Corresponds to the JSON property `urlAfterRedirectsFp`
        # @return [Fixnum]
        attr_accessor :url_after_redirects_fp
      
        # Url poisoning information. This information is sparse: if num_spam_siblings is
        # not populated, none of the following fields will be populated. Next tag: 6
        # Corresponds to the JSON property `urlPoisoningData`
        # @return [Google::Apis::ContentwarehouseV1::UrlPoisoningData]
        attr_accessor :url_poisoning_data
      
        # For indexing v2 k'nex, see/go/knex-v2-doc-annotation for details.
        # Corresponds to the JSON property `v2KnexAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::QualitySherlockKnexAnnotation]
        attr_accessor :v2_knex_annotation
      
        # 
        # Corresponds to the JSON property `videoCorpusDocid`
        # @return [Fixnum]
        attr_accessor :video_corpus_docid
      
        # Audio-based language information about a Watch Page. For more information:
        # https://g3doc.corp.google.com/video/timedtext/g3doc/ali.md
        # Corresponds to the JSON property `videoLanguage`
        # @return [Google::Apis::ContentwarehouseV1::QualityVidyaVideoLanguageVideoLanguage]
        attr_accessor :video_language
      
        # 
        # Corresponds to the JSON property `videodata`
        # @return [Google::Apis::ContentwarehouseV1::VideoPerDocData]
        attr_accessor :videodata
      
        # The protocol buffer stored in the legacyperdocdata muppet attachment for VOLT (
        # go/volt). The data is used for ranking changes. Only CWV signals and secure
        # signal are stored. MobileFriendliness is stored separately in the
        # legacyperdocdata. Safe browsing and BAS/AER conditions are not used for
        # ranking.
        # Corresponds to the JSON property `voltData`
        # @return [Google::Apis::ContentwarehouseV1::IndexingMobileVoltVoltPerDocData]
        attr_accessor :volt_data
      
        # Language classified by the WatchPageLanguage Model (go/watchpage-language).
        # Only present for watch pages.
        # Corresponds to the JSON property `watchpageLanguageResult`
        # @return [Google::Apis::ContentwarehouseV1::WatchpageLanguageWatchPageLanguageResult]
        attr_accessor :watchpage_language_result
      
        # 
        # Corresponds to the JSON property `webmirrorEcnFp`
        # @return [Fixnum]
        attr_accessor :webmirror_ecn_fp
      
        # *** THIS ATTACHMENT IS DEPRECATED, SEE go/udr/migrate-wma. ***. We still allow
        # legacy use case to exist (no forced migration), but we will not accept any new
        # usage of WMA, incl. from existing clients. UDR has the same features and can
        # be used similarly: - To consume the topical entities (+properties, incl.
        # hitcat, browsy, ...) go/udr/migrate-wma provides a migration with minimal
        # changes. - To consume IQL, please consult go/udr/superroot#access and go/
        # pianno team. The top-level proto used to store WebRef entities and IQL
        # expressions in Mustang/TG. The proto uses packed repeated fields and variable-
        # length integers in order to be as compact as possible. See http://b/5802389
        # and b/7473898 for details on other approaches that were considered and space/
        # readability/extensibility trade-offs made. Note: It is not recommeded to read
        # this proto directly. Clients of the attachment should use the decoder instead:
        # repository/webref/tools/kc/indexing/webref-attachment-decoder.h Next available
        # tag: 25
        # Corresponds to the JSON property `webrefEntities`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefMustangAttachment]
        attr_accessor :webref_entities
      
        # Stores scores of ymyl health classifier as defined at go/ymyl-classifier-dd.
        # To use this field, you MUST join g/pq-classifiers-announce and add your use
        # case at http://shortn/_nfg9oAldou.
        # Corresponds to the JSON property `ymylHealthScore`
        # @return [Fixnum]
        attr_accessor :ymyl_health_score
      
        # Stores scores of ymyl news classifier as defined at go/ymyl-classifier-dd. To
        # use this field, you MUST join g/pq-classifiers-announce and add your use case
        # at http://shortn/_nfg9oAldou.
        # Corresponds to the JSON property `ymylNewsScore`
        # @return [Fixnum]
        attr_accessor :ymyl_news_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blog_data = args[:blog_data] if args.key?(:blog_data)
          @book_citation_data = args[:book_citation_data] if args.key?(:book_citation_data)
          @deprecated_author_obfuscated_gaia = args[:deprecated_author_obfuscated_gaia] if args.key?(:deprecated_author_obfuscated_gaia)
          @deprecated_quarantine_whitelist = args[:deprecated_quarantine_whitelist] if args.key?(:deprecated_quarantine_whitelist)
          @doc_level_spam_score = args[:doc_level_spam_score] if args.key?(:doc_level_spam_score)
          @event = args[:event] if args.key?(:event)
          @gibberish_score = args[:gibberish_score] if args.key?(:gibberish_score)
          @groups_data = args[:groups_data] if args.key?(:groups_data)
          @is_anchor_bayes_spam = args[:is_anchor_bayes_spam] if args.key?(:is_anchor_bayes_spam)
          @keyword_stuffing_score = args[:keyword_stuffing_score] if args.key?(:keyword_stuffing_score)
          @mobile_data = args[:mobile_data] if args.key?(:mobile_data)
          @original_content_score = args[:original_content_score] if args.key?(:original_content_score)
          @premium_data = args[:premium_data] if args.key?(:premium_data)
          @quarantine_info = args[:quarantine_info] if args.key?(:quarantine_info)
          @scaled_expt_indy_rank = args[:scaled_expt_indy_rank] if args.key?(:scaled_expt_indy_rank)
          @scaled_expt_indy_rank2 = args[:scaled_expt_indy_rank2] if args.key?(:scaled_expt_indy_rank2)
          @scaled_expt_indy_rank3 = args[:scaled_expt_indy_rank3] if args.key?(:scaled_expt_indy_rank3)
          @scaled_expt_spam_score_eric = args[:scaled_expt_spam_score_eric] if args.key?(:scaled_expt_spam_score_eric)
          @scaled_expt_spam_score_yoram = args[:scaled_expt_spam_score_yoram] if args.key?(:scaled_expt_spam_score_yoram)
          @scaled_indy_rank = args[:scaled_indy_rank] if args.key?(:scaled_indy_rank)
          @scaled_link_age_spam_score = args[:scaled_link_age_spam_score] if args.key?(:scaled_link_age_spam_score)
          @scaled_spam_score_eric = args[:scaled_spam_score_eric] if args.key?(:scaled_spam_score_eric)
          @scaled_spam_score_yoram = args[:scaled_spam_score_yoram] if args.key?(:scaled_spam_score_yoram)
          @science_data = args[:science_data] if args.key?(:science_data)
          @spam_word_score = args[:spam_word_score] if args.key?(:spam_word_score)
          @tag_page_score = args[:tag_page_score] if args.key?(:tag_page_score)
          @tool_bar_data = args[:tool_bar_data] if args.key?(:tool_bar_data)
          @whirlpool_discount = args[:whirlpool_discount] if args.key?(:whirlpool_discount)
          @apps_link = args[:apps_link] if args.key?(:apps_link)
          @asteroid_belt_intents = args[:asteroid_belt_intents] if args.key?(:asteroid_belt_intents)
          @author_obfuscated_gaia_str = args[:author_obfuscated_gaia_str] if args.key?(:author_obfuscated_gaia_str)
          @biasingdata = args[:biasingdata] if args.key?(:biasingdata)
          @biasingdata2 = args[:biasingdata2] if args.key?(:biasingdata2)
          @body_words_to_tokens_ratio_begin = args[:body_words_to_tokens_ratio_begin] if args.key?(:body_words_to_tokens_ratio_begin)
          @body_words_to_tokens_ratio_total = args[:body_words_to_tokens_ratio_total] if args.key?(:body_words_to_tokens_ratio_total)
          @brainloc = args[:brainloc] if args.key?(:brainloc)
          @commercial_score = args[:commercial_score] if args.key?(:commercial_score)
          @compressed_quality_signals = args[:compressed_quality_signals] if args.key?(:compressed_quality_signals)
          @compressed_url = args[:compressed_url] if args.key?(:compressed_url)
          @content_attributions = args[:content_attributions] if args.key?(:content_attributions)
          @country_info = args[:country_info] if args.key?(:country_info)
          @crawl_pagerank = args[:crawl_pagerank] if args.key?(:crawl_pagerank)
          @crawler_id_proto = args[:crawler_id_proto] if args.key?(:crawler_id_proto)
          @crowdingdata = args[:crowdingdata] if args.key?(:crowdingdata)
          @dates_info = args[:dates_info] if args.key?(:dates_info)
          @desktop_interstitials = args[:desktop_interstitials] if args.key?(:desktop_interstitials)
          @domain_age = args[:domain_age] if args.key?(:domain_age)
          @events_date = args[:events_date] if args.key?(:events_date)
          @extra_data = args[:extra_data] if args.key?(:extra_data)
          @firefly_site_signal = args[:firefly_site_signal] if args.key?(:firefly_site_signal)
          @freshbox_article_scores = args[:freshbox_article_scores] if args.key?(:freshbox_article_scores)
          @freshness_encoded_signals = args[:freshness_encoded_signals] if args.key?(:freshness_encoded_signals)
          @fringe_query_prior = args[:fringe_query_prior] if args.key?(:fringe_query_prior)
          @geodata = args[:geodata] if args.key?(:geodata)
          @home_page_info = args[:home_page_info] if args.key?(:home_page_info)
          @homepage_pagerank_ns = args[:homepage_pagerank_ns] if args.key?(:homepage_pagerank_ns)
          @host_age = args[:host_age] if args.key?(:host_age)
          @host_nsr = args[:host_nsr] if args.key?(:host_nsr)
          @imagedata = args[:imagedata] if args.key?(:imagedata)
          @in_newsstand = args[:in_newsstand] if args.key?(:in_newsstand)
          @is_hotdoc = args[:is_hotdoc] if args.key?(:is_hotdoc)
          @kaltixdata = args[:kaltixdata] if args.key?(:kaltixdata)
          @knex_annotation = args[:knex_annotation] if args.key?(:knex_annotation)
          @languages = args[:languages] if args.key?(:languages)
          @last_significant_update = args[:last_significant_update] if args.key?(:last_significant_update)
          @last_significant_update_info = args[:last_significant_update_info] if args.key?(:last_significant_update_info)
          @launch_app_info = args[:launch_app_info] if args.key?(:launch_app_info)
          @live_results_data = args[:live_results_data] if args.key?(:live_results_data)
          @localized_cluster = args[:localized_cluster] if args.key?(:localized_cluster)
          @noimageframeoverlayreason = args[:noimageframeoverlayreason] if args.key?(:noimageframeoverlayreason)
          @nsr_data_proto = args[:nsr_data_proto] if args.key?(:nsr_data_proto)
          @nsr_is_covid_local_authority = args[:nsr_is_covid_local_authority] if args.key?(:nsr_is_covid_local_authority)
          @nsr_is_election_authority = args[:nsr_is_election_authority] if args.key?(:nsr_is_election_authority)
          @nsr_is_video_focused_site = args[:nsr_is_video_focused_site] if args.key?(:nsr_is_video_focused_site)
          @nsr_sitechunk = args[:nsr_sitechunk] if args.key?(:nsr_sitechunk)
          @num_urls = args[:num_urls] if args.key?(:num_urls)
          @oceandata = args[:oceandata] if args.key?(:oceandata)
          @onsite_prominence = args[:onsite_prominence] if args.key?(:onsite_prominence)
          @origin = args[:origin] if args.key?(:origin)
          @original_title_hard_token_count = args[:original_title_hard_token_count] if args.key?(:original_title_hard_token_count)
          @page_tags = args[:page_tags] if args.key?(:page_tags)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @pagerank0 = args[:pagerank0] if args.key?(:pagerank0)
          @pagerank1 = args[:pagerank1] if args.key?(:pagerank1)
          @pagerank2 = args[:pagerank2] if args.key?(:pagerank2)
          @pageregions = args[:pageregions] if args.key?(:pageregions)
          @phildata = args[:phildata] if args.key?(:phildata)
          @product_sites_info = args[:product_sites_info] if args.key?(:product_sites_info)
          @queries_for_which_official = args[:queries_for_which_official] if args.key?(:queries_for_which_official)
          @rosetta_languages = args[:rosetta_languages] if args.key?(:rosetta_languages)
          @rs_application = args[:rs_application] if args.key?(:rs_application)
          @saft_language_int = args[:saft_language_int] if args.key?(:saft_language_int)
          @scaled_selection_tier_rank = args[:scaled_selection_tier_rank] if args.key?(:scaled_selection_tier_rank)
          @science_doctype = args[:science_doctype] if args.key?(:science_doctype)
          @science_holdings_ids = args[:science_holdings_ids] if args.key?(:science_holdings_ids)
          @semantic_date = args[:semantic_date] if args.key?(:semantic_date)
          @semantic_date_confidence = args[:semantic_date_confidence] if args.key?(:semantic_date_confidence)
          @semantic_date_info = args[:semantic_date_info] if args.key?(:semantic_date_info)
          @serving_time_cluster_ids = args[:serving_time_cluster_ids] if args.key?(:serving_time_cluster_ids)
          @shingle_info = args[:shingle_info] if args.key?(:shingle_info)
          @smartphone_data = args[:smartphone_data] if args.key?(:smartphone_data)
          @smearing_max_total_offdomain_anchors = args[:smearing_max_total_offdomain_anchors] if args.key?(:smearing_max_total_offdomain_anchors)
          @socialgraph_node_name_fp = args[:socialgraph_node_name_fp] if args.key?(:socialgraph_node_name_fp)
          @spam_cookbook_action = args[:spam_cookbook_action] if args.key?(:spam_cookbook_action)
          @spam_muppet_signals = args[:spam_muppet_signals] if args.key?(:spam_muppet_signals)
          @spamrank = args[:spamrank] if args.key?(:spamrank)
          @spamtokens_content_score = args[:spamtokens_content_score] if args.key?(:spamtokens_content_score)
          @time_sensitivity = args[:time_sensitivity] if args.key?(:time_sensitivity)
          @title_hard_token_count_without_stopwords = args[:title_hard_token_count_without_stopwords] if args.key?(:title_hard_token_count_without_stopwords)
          @toolbar_pagerank = args[:toolbar_pagerank] if args.key?(:toolbar_pagerank)
          @top_petacat_tax_id = args[:top_petacat_tax_id] if args.key?(:top_petacat_tax_id)
          @top_petacat_weight = args[:top_petacat_weight] if args.key?(:top_petacat_weight)
          @travel_good_sites_info = args[:travel_good_sites_info] if args.key?(:travel_good_sites_info)
          @trendspam_score = args[:trendspam_score] if args.key?(:trendspam_score)
          @tundra_cluster_id = args[:tundra_cluster_id] if args.key?(:tundra_cluster_id)
          @uac_spam_score = args[:uac_spam_score] if args.key?(:uac_spam_score)
          @url_after_redirects_fp = args[:url_after_redirects_fp] if args.key?(:url_after_redirects_fp)
          @url_poisoning_data = args[:url_poisoning_data] if args.key?(:url_poisoning_data)
          @v2_knex_annotation = args[:v2_knex_annotation] if args.key?(:v2_knex_annotation)
          @video_corpus_docid = args[:video_corpus_docid] if args.key?(:video_corpus_docid)
          @video_language = args[:video_language] if args.key?(:video_language)
          @videodata = args[:videodata] if args.key?(:videodata)
          @volt_data = args[:volt_data] if args.key?(:volt_data)
          @watchpage_language_result = args[:watchpage_language_result] if args.key?(:watchpage_language_result)
          @webmirror_ecn_fp = args[:webmirror_ecn_fp] if args.key?(:webmirror_ecn_fp)
          @webref_entities = args[:webref_entities] if args.key?(:webref_entities)
          @ymyl_health_score = args[:ymyl_health_score] if args.key?(:ymyl_health_score)
          @ymyl_news_score = args[:ymyl_news_score] if args.key?(:ymyl_news_score)
        end
      end
      
      # Free form debug information from various components.
      class PerDocDebugEvent
        include Google::Apis::Core::Hashable
      
        # depends on the source
        # Corresponds to the JSON property `Message`
        # @return [String]
        attr_accessor :message
      
        # source tag, helps interpret value/message
        # Corresponds to the JSON property `Source`
        # @return [String]
        attr_accessor :source
      
        # seconds since the epoch
        # Corresponds to the JSON property `Timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        # depends on the source
        # Corresponds to the JSON property `Value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @message = args[:message] if args.key?(:message)
          @source = args[:source] if args.key?(:source)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # A unique association of an AliasType and a number to identify this alias.
      class PersonalizationMapsAliasAliasId
        include Google::Apis::Core::Hashable
      
        # A unique identifier for this alias, this identifier is unique to the type of
        # this Alias. This means that aliases of different types can have the same
        # sub_id, hence always use the full AliasId message to refer to an alias, not
        # this field only. Because HOME and WORK aliases are unique, aliases of type
        # HOME or WORK always have sub_id 0.
        # Corresponds to the JSON property `subId`
        # @return [Fixnum]
        attr_accessor :sub_id
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @sub_id = args[:sub_id] if args.key?(:sub_id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A subset of an Alias that is stored on kansas max. It is used in Search for
      # alias resolution and in Maps to show icons quickly on basetiles.
      class PersonalizationMapsAliasIcon
        include Google::Apis::Core::Hashable
      
        # A unique association of an AliasType and a number to identify this alias.
        # Corresponds to the JSON property `aliasId`
        # @return [Google::Apis::ContentwarehouseV1::PersonalizationMapsAliasAliasId]
        attr_accessor :alias_id
      
        # If this is a dropped pin alias, the leaf (level 30) S2 cell ID corresponding
        # to the aliased lat/lng. Calculated once and stored here so that it can safely
        # be used as an identifier across clients without risk of rounding differences
        # leading to different values.
        # Corresponds to the JSON property `droppedPinS2cellId`
        # @return [Fixnum]
        attr_accessor :dropped_pin_s2cell_id
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        # For non-address feature aliases (e.g. businesses), the name of the feature (
        # formatted from the FeatureProto) when it was saved.
        # Corresponds to the JSON property `featureName`
        # @return [String]
        attr_accessor :feature_name
      
        # The type of the feature associated with the alias.
        # Corresponds to the JSON property `featureType`
        # @return [String]
        attr_accessor :feature_type
      
        # One-line geocoded address that this lat/lng represents at the time this alias
        # was created by the user.
        # Corresponds to the JSON property `formattedAddress`
        # @return [String]
        attr_accessor :formatted_address
      
        # Free-text alias if alias type is NICKNAME. Otherwise unset. Limited to 40
        # characters.
        # Corresponds to the JSON property `nickname`
        # @return [String]
        attr_accessor :nickname
      
        # lat/lng the icon is to be shown at.
        # Corresponds to the JSON property `point`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :point
      
        # The id of the sticker asset chosen by the user to replace the default asset
        # for the alias.
        # Corresponds to the JSON property `stickerId`
        # @return [Fixnum]
        attr_accessor :sticker_id
      
        # If the feature associated with the alias has synthetic_geometry.
        # Corresponds to the JSON property `syntheticFeature`
        # @return [Boolean]
        attr_accessor :synthetic_feature
        alias_method :synthetic_feature?, :synthetic_feature
      
        # [INTERNAL ONLY] Last update of bigtable by kansas, in microseconds. Volatile
        # only and not saved in kansas column. inmemory only because >= 16.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alias_id = args[:alias_id] if args.key?(:alias_id)
          @dropped_pin_s2cell_id = args[:dropped_pin_s2cell_id] if args.key?(:dropped_pin_s2cell_id)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
          @feature_name = args[:feature_name] if args.key?(:feature_name)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @formatted_address = args[:formatted_address] if args.key?(:formatted_address)
          @nickname = args[:nickname] if args.key?(:nickname)
          @point = args[:point] if args.key?(:point)
          @sticker_id = args[:sticker_id] if args.key?(:sticker_id)
          @synthetic_feature = args[:synthetic_feature] if args.key?(:synthetic_feature)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # Metadata related to LocalDiscoverySettings,e.g., dietary_restriction, cuisine
      # and ingredient.
      class PersonalizationSettingsApiProtoLocalDiscoveryLocalDiscoverySettingsMetadata
        include Google::Apis::Core::Hashable
      
        # LINT.IfChange Contexts regarding the preferences from OPA_RECIPES. For example,
        # users can click a recipes and say they don't like one cuisine.
        # OpaRecipesContext will contain the doc_id/url of that recipes.
        # Corresponds to the JSON property `opaRecipesContext`
        # @return [Google::Apis::ContentwarehouseV1::PersonalizationSettingsApiProtoLocalDiscoveryOpaRecipesContext]
        attr_accessor :opa_recipes_context
      
        # The UI entry point from which the entity preference was set.
        # Corresponds to the JSON property `uiEntryPoint`
        # @return [String]
        attr_accessor :ui_entry_point
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @opa_recipes_context = args[:opa_recipes_context] if args.key?(:opa_recipes_context)
          @ui_entry_point = args[:ui_entry_point] if args.key?(:ui_entry_point)
        end
      end
      
      # LINT.IfChange Contexts regarding the preferences from OPA_RECIPES. For example,
      # users can click a recipes and say they don't like one cuisine.
      # OpaRecipesContext will contain the doc_id/url of that recipes.
      class PersonalizationSettingsApiProtoLocalDiscoveryOpaRecipesContext
        include Google::Apis::Core::Hashable
      
        # The recipe doc id where the setting comes from.
        # Corresponds to the JSON property `docId`
        # @return [String]
        attr_accessor :doc_id
      
        # The recipe url where the setting comes from.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_id = args[:doc_id] if args.key?(:doc_id)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class PhilPerDocData
        include Google::Apis::Core::Hashable
      
        # phil data , approx 70 bytes for top 500M
        # Corresponds to the JSON property `PhilString`
        # @return [String]
        attr_accessor :phil_string
      
        # 
        # Corresponds to the JSON property `PhilVersion`
        # @return [Fixnum]
        attr_accessor :phil_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @phil_string = args[:phil_string] if args.key?(:phil_string)
          @phil_version = args[:phil_version] if args.key?(:phil_version)
        end
      end
      
      # 
      class PhotosAnimationMetadata
        include Google::Apis::Core::Hashable
      
        # The duration of the animation or movie (not including any looping), in
        # milliseconds. If there is only a single frame (and thus not animated), the
        # duration will be 0.
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        # 
        # Corresponds to the JSON property `numFrames`
        # @return [Fixnum]
        attr_accessor :num_frames
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @num_frames = args[:num_frames] if args.key?(:num_frames)
        end
      end
      
      # Metadata pertaining to nested Dynamic Depth metadata. Currently this message
      # is used to indicate the presence of dynamic depth.
      class PhotosDynamicDepthMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class PhotosFourCMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `caption`
        # @return [String]
        attr_accessor :caption
      
        # 
        # Corresponds to the JSON property `copyright`
        # @return [String]
        attr_accessor :copyright
      
        # 
        # Corresponds to the JSON property `creator`
        # @return [Array<String>]
        attr_accessor :creator
      
        # 
        # Corresponds to the JSON property `credit`
        # @return [String]
        attr_accessor :credit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @caption = args[:caption] if args.key?(:caption)
          @copyright = args[:copyright] if args.key?(:copyright)
          @creator = args[:creator] if args.key?(:creator)
          @credit = args[:credit] if args.key?(:credit)
        end
      end
      
      # Metadata in the GDepth XMP block. Note that GDepth::Data is not copied into
      # this message.
      class PhotosGDepthMetadata
        include Google::Apis::Core::Hashable
      
        # Depth map far plane distance.
        # Corresponds to the JSON property `far`
        # @return [Float]
        attr_accessor :far
      
        # Depth map format.
        # Corresponds to the JSON property `format`
        # @return [String]
        attr_accessor :format
      
        # Depth map source image height.
        # Corresponds to the JSON property `imageHeight`
        # @return [Fixnum]
        attr_accessor :image_height
      
        # Depth map source image width.
        # Corresponds to the JSON property `imageWidth`
        # @return [Fixnum]
        attr_accessor :image_width
      
        # Depth map mime type.
        # Corresponds to the JSON property `mime`
        # @return [String]
        attr_accessor :mime
      
        # Depth map near plane distance.
        # Corresponds to the JSON property `near`
        # @return [Float]
        attr_accessor :near
      
        # Depth map units of distance.
        # Corresponds to the JSON property `units`
        # @return [String]
        attr_accessor :units
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @far = args[:far] if args.key?(:far)
          @format = args[:format] if args.key?(:format)
          @image_height = args[:image_height] if args.key?(:image_height)
          @image_width = args[:image_width] if args.key?(:image_width)
          @mime = args[:mime] if args.key?(:mime)
          @near = args[:near] if args.key?(:near)
          @units = args[:units] if args.key?(:units)
        end
      end
      
      # Next tag value: 381.
      class PhotosImageMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDBlendingtype`
        # @return [String]
        attr_accessor :deprecated_blendingtype
      
        # This field was originally marked incorrectly as optional (rather than repeated)
        # . In order to fix it, the first field has been marked as deprecated and
        # replaced with a field with a new name and tag number.
        # Corresponds to the JSON property `DEPRECATEDGpstimestamp`
        # @return [Float]
        attr_accessor :deprecated_gpstimestamp
      
        # 
        # Corresponds to the JSON property `DEPRECATEDIscolor`
        # @return [Fixnum]
        attr_accessor :deprecated_iscolor
      
        # 
        # Corresponds to the JSON property `DEPRECATEDLargestvalidinteriorrectheight`
        # @return [Fixnum]
        attr_accessor :deprecated_largestvalidinteriorrectheight
      
        # 
        # Corresponds to the JSON property `DEPRECATEDLargestvalidinteriorrectleft`
        # @return [Fixnum]
        attr_accessor :deprecated_largestvalidinteriorrectleft
      
        # 
        # Corresponds to the JSON property `DEPRECATEDLargestvalidinteriorrecttop`
        # @return [Fixnum]
        attr_accessor :deprecated_largestvalidinteriorrecttop
      
        # 
        # Corresponds to the JSON property `DEPRECATEDLargestvalidinteriorrectwidth`
        # @return [Fixnum]
        attr_accessor :deprecated_largestvalidinteriorrectwidth
      
        # 
        # Corresponds to the JSON property `DEPRECATEDProcess`
        # @return [Fixnum]
        attr_accessor :deprecated_process
      
        # 
        # Corresponds to the JSON property `actionadvised`
        # @return [String]
        attr_accessor :actionadvised
      
        # 
        # Corresponds to the JSON property `addlmodelinfo`
        # @return [String]
        attr_accessor :addlmodelinfo
      
        # 
        # Corresponds to the JSON property `advisory`
        # @return [Array<String>]
        attr_accessor :advisory
      
        # 
        # Corresponds to the JSON property `altitude`
        # @return [Float]
        attr_accessor :altitude
      
        # 
        # Corresponds to the JSON property `animationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::PhotosAnimationMetadata]
        attr_accessor :animation_metadata
      
        # 
        # Corresponds to the JSON property `aperturefnumber`
        # @return [Float]
        attr_accessor :aperturefnumber
      
        # 
        # Corresponds to the JSON property `aperturevalue`
        # @return [Float]
        attr_accessor :aperturevalue
      
        # 
        # Corresponds to the JSON property `artworkorobject`
        # @return [Array<String>]
        attr_accessor :artworkorobject
      
        # 
        # Corresponds to the JSON property `audioduration`
        # @return [String]
        attr_accessor :audioduration
      
        # 
        # Corresponds to the JSON property `audiooutcue`
        # @return [String]
        attr_accessor :audiooutcue
      
        # 
        # Corresponds to the JSON property `audiosamplingrate`
        # @return [String]
        attr_accessor :audiosamplingrate
      
        # 
        # Corresponds to the JSON property `audiosamplingresolution`
        # @return [String]
        attr_accessor :audiosamplingresolution
      
        # 
        # Corresponds to the JSON property `audiotype`
        # @return [String]
        attr_accessor :audiotype
      
        # 
        # Corresponds to the JSON property `author`
        # @return [String]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `authorposition`
        # @return [String]
        attr_accessor :authorposition
      
        # Indicates whether auto-enhance has been applied to the image.
        # Corresponds to the JSON property `autoenhance`
        # @return [Boolean]
        attr_accessor :autoenhance
        alias_method :autoenhance?, :autoenhance
      
        # 
        # Corresponds to the JSON property `baseurl`
        # @return [String]
        attr_accessor :baseurl
      
        # The number of bits per pixel used to express a color. Most images have 8-bit
        # depth and Photos/thumbnailer currently do not support more than 8 bits (except
        # RAW).
        # Corresponds to the JSON property `bitDepth`
        # @return [Fixnum]
        attr_accessor :bit_depth
      
        # Start of reflected fields. These do not duplicate the above fields.
        # Corresponds to the JSON property `bitspersample`
        # @return [Fixnum]
        attr_accessor :bitspersample
      
        # 
        # Corresponds to the JSON property `brightnessvalue`
        # @return [Float]
        attr_accessor :brightnessvalue
      
        # 
        # Corresponds to the JSON property `burstuuid`
        # @return [String]
        attr_accessor :burstuuid
      
        # 
        # Corresponds to the JSON property `cameraid`
        # @return [String]
        attr_accessor :cameraid
      
        # Exif camera make
        # Corresponds to the JSON property `cameramake`
        # @return [String]
        attr_accessor :cameramake
      
        # Exif camera model
        # Corresponds to the JSON property `cameramodel`
        # @return [String]
        attr_accessor :cameramodel
      
        # Caption embedded in IPTC
        # Corresponds to the JSON property `caption`
        # @return [String]
        attr_accessor :caption
      
        # 
        # Corresponds to the JSON property `captionwriter`
        # @return [String]
        attr_accessor :captionwriter
      
        # 
        # Corresponds to the JSON property `capturesoftware`
        # @return [String]
        attr_accessor :capturesoftware
      
        # 
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `ccdwidth`
        # @return [Float]
        attr_accessor :ccdwidth
      
        # 
        # Corresponds to the JSON property `celllength`
        # @return [Fixnum]
        attr_accessor :celllength
      
        # 
        # Corresponds to the JSON property `cellwidth`
        # @return [Fixnum]
        attr_accessor :cellwidth
      
        # 
        # Corresponds to the JSON property `certificate`
        # @return [String]
        attr_accessor :certificate
      
        # A typed representation that translates the values from ycbcrsubsampling.
        # Corresponds to the JSON property `chromasubsampling`
        # @return [String]
        attr_accessor :chromasubsampling
      
        # 
        # Corresponds to the JSON property `ciadrcity`
        # @return [String]
        attr_accessor :ciadrcity
      
        # 
        # Corresponds to the JSON property `ciadrctry`
        # @return [String]
        attr_accessor :ciadrctry
      
        # 
        # Corresponds to the JSON property `ciadrextadr`
        # @return [Array<String>]
        attr_accessor :ciadrextadr
      
        # 
        # Corresponds to the JSON property `ciadrpcode`
        # @return [String]
        attr_accessor :ciadrpcode
      
        # 
        # Corresponds to the JSON property `ciadrregion`
        # @return [String]
        attr_accessor :ciadrregion
      
        # 
        # Corresponds to the JSON property `ciemailwork`
        # @return [String]
        attr_accessor :ciemailwork
      
        # 
        # Corresponds to the JSON property `citelwork`
        # @return [String]
        attr_accessor :citelwork
      
        # 
        # Corresponds to the JSON property `city`
        # @return [String]
        attr_accessor :city
      
        # 
        # Corresponds to the JSON property `ciurlwork`
        # @return [String]
        attr_accessor :ciurlwork
      
        # 
        # Corresponds to the JSON property `colormap`
        # @return [Fixnum]
        attr_accessor :colormap
      
        # Indicates whether or not the source image had an embedded color profile.
        # Corresponds to the JSON property `colorprofile`
        # @return [Boolean]
        attr_accessor :colorprofile
        alias_method :colorprofile?, :colorprofile
      
        # 
        # Corresponds to the JSON property `colorspace`
        # @return [Fixnum]
        attr_accessor :colorspace
      
        # 
        # Corresponds to the JSON property `compressedbitsperpixel`
        # @return [Float]
        attr_accessor :compressedbitsperpixel
      
        # 
        # Corresponds to the JSON property `compressionlevel`
        # @return [Fixnum]
        attr_accessor :compressionlevel
      
        # 
        # Corresponds to the JSON property `contact`
        # @return [String]
        attr_accessor :contact
      
        # 
        # Corresponds to the JSON property `contentlocationcode`
        # @return [Array<String>]
        attr_accessor :contentlocationcode
      
        # 
        # Corresponds to the JSON property `contentlocationname`
        # @return [Array<String>]
        attr_accessor :contentlocationname
      
        # 
        # Corresponds to the JSON property `contrast`
        # @return [Fixnum]
        attr_accessor :contrast
      
        # 
        # Corresponds to the JSON property `contributor`
        # @return [Array<String>]
        attr_accessor :contributor
      
        # 
        # Corresponds to the JSON property `copyrightnotice`
        # @return [String]
        attr_accessor :copyrightnotice
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `countrycode`
        # @return [String]
        attr_accessor :countrycode
      
        # 
        # Corresponds to the JSON property `coverage`
        # @return [String]
        attr_accessor :coverage
      
        # 
        # Corresponds to the JSON property `createdate`
        # @return [String]
        attr_accessor :createdate
      
        # 
        # Corresponds to the JSON property `credits`
        # @return [String]
        attr_accessor :credits
      
        # 
        # Corresponds to the JSON property `croppedareaimageheightpixels`
        # @return [Fixnum]
        attr_accessor :croppedareaimageheightpixels
      
        # 
        # Corresponds to the JSON property `croppedareaimagewidthpixels`
        # @return [Fixnum]
        attr_accessor :croppedareaimagewidthpixels
      
        # 
        # Corresponds to the JSON property `croppedarealeftpixels`
        # @return [Fixnum]
        attr_accessor :croppedarealeftpixels
      
        # 
        # Corresponds to the JSON property `croppedareatoppixels`
        # @return [Fixnum]
        attr_accessor :croppedareatoppixels
      
        # 
        # Corresponds to the JSON property `customrendered`
        # @return [Fixnum]
        attr_accessor :customrendered
      
        # 
        # Corresponds to the JSON property `cvterm`
        # @return [Array<String>]
        attr_accessor :cvterm
      
        # 
        # Corresponds to the JSON property `date`
        # @return [String]
        attr_accessor :date
      
        # 
        # Corresponds to the JSON property `datecreated`
        # @return [String]
        attr_accessor :datecreated
      
        # 
        # Corresponds to the JSON property `datesent`
        # @return [String]
        attr_accessor :datesent
      
        # 
        # Corresponds to the JSON property `datetime`
        # @return [String]
        attr_accessor :datetime
      
        # 
        # Corresponds to the JSON property `datetimedigitized`
        # @return [String]
        attr_accessor :datetimedigitized
      
        # 0 = no daylight savings, 1 = daylight savings enabled. Note that this field
        # only represents whether the setting in the camera was turned on or off. It
        # must not be used to modify the timestamp of the photo. That is, the capture
        # time is already completely determined by exif_time, timezoneoffset and
        # timezoneminutes.
        # Corresponds to the JSON property `daylightsavings`
        # @return [Array<Fixnum>]
        attr_accessor :daylightsavings
      
        # 
        # Corresponds to the JSON property `destination`
        # @return [Array<String>]
        attr_accessor :destination
      
        # +/- 90 inclusive
        # Corresponds to the JSON property `destinationLatitude`
        # @return [Float]
        attr_accessor :destination_latitude
      
        # +/- 180 inclusive
        # Corresponds to the JSON property `destinationLongitude`
        # @return [Float]
        attr_accessor :destination_longitude
      
        # 
        # Corresponds to the JSON property `digimageguid`
        # @return [String]
        attr_accessor :digimageguid
      
        # 
        # Corresponds to the JSON property `digitalsourcefiletype`
        # @return [String]
        attr_accessor :digitalsourcefiletype
      
        # 
        # Corresponds to the JSON property `digitalsourcetype`
        # @return [String]
        attr_accessor :digitalsourcetype
      
        # 
        # Corresponds to the JSON property `digitalzoomratio`
        # @return [Float]
        attr_accessor :digitalzoomratio
      
        # 
        # Corresponds to the JSON property `distance`
        # @return [Float]
        attr_accessor :distance
      
        # Metadata pertaining to nested Dynamic Depth metadata. Currently this message
        # is used to indicate the presence of dynamic depth.
        # Corresponds to the JSON property `dynamicDepthMetadata`
        # @return [Google::Apis::ContentwarehouseV1::PhotosDynamicDepthMetadata]
        attr_accessor :dynamic_depth_metadata
      
        # 
        # Corresponds to the JSON property `editorialupdate`
        # @return [String]
        attr_accessor :editorialupdate
      
        # 
        # Corresponds to the JSON property `editstatus`
        # @return [String]
        attr_accessor :editstatus
      
        # 
        # Corresponds to the JSON property `envelopenumber`
        # @return [String]
        attr_accessor :envelopenumber
      
        # 
        # Corresponds to the JSON property `envelopepriority`
        # @return [String]
        attr_accessor :envelopepriority
      
        # 
        # Corresponds to the JSON property `event`
        # @return [String]
        attr_accessor :event
      
        # 4C metadata (caption, copyright, creator, credit) specific to each of the
        # three metadata segments (EXIF, XMP, IPTC). These are used to keep separate the
        # 4C data from each segment so that we can properly preserve the per-segment 4C
        # data on write (when PreserveLevel is set appropriately).
        # Corresponds to the JSON property `exif4c`
        # @return [Google::Apis::ContentwarehouseV1::PhotosFourCMetadata]
        attr_accessor :exif4c
      
        # Timestamp embedded in the image. The value comes from the first valid date-
        # time field extracted from the metadata in the order: 1) datecreated (ie.
        # DateTimeOriginal) 2) datetimedigitized (ie. DateTimeDigitized) 3) datetime (ie.
        # DateTime or last modified date) The type of this field is equivalent to a
        # time_t (ie. number of seconds since the epoch - 00:00 hours, Jan 1, 1970)
        # except that it is an int64 rather than an int.
        # Corresponds to the JSON property `exifTime`
        # @return [Fixnum]
        attr_accessor :exif_time
      
        # The exif_time_utc field is a UTC-based alternative to the exif_time field,
        # which is in local time, rather than UTC. If they were not separate, clients
        # would be unable to distinguish if the source were UTC- or local-based.
        # Corresponds to the JSON property `exifTimeUtc`
        # @return [Fixnum]
        attr_accessor :exif_time_utc
      
        # The exif_time_utc_source indicates the source from which the exif_time_utc
        # field is calculated.
        # Corresponds to the JSON property `exifTimeUtcSource`
        # @return [String]
        attr_accessor :exif_time_utc_source
      
        # 
        # Corresponds to the JSON property `expirationdate`
        # @return [String]
        attr_accessor :expirationdate
      
        # 
        # Corresponds to the JSON property `expirationtime`
        # @return [String]
        attr_accessor :expirationtime
      
        # 
        # Corresponds to the JSON property `exposurebias`
        # @return [Float]
        attr_accessor :exposurebias
      
        # 
        # Corresponds to the JSON property `exposureindex`
        # @return [Float]
        attr_accessor :exposureindex
      
        # 
        # Corresponds to the JSON property `exposurelockused`
        # @return [Boolean]
        attr_accessor :exposurelockused
        alias_method :exposurelockused?, :exposurelockused
      
        # 
        # Corresponds to the JSON property `exposuremode`
        # @return [Fixnum]
        attr_accessor :exposuremode
      
        # 
        # Corresponds to the JSON property `exposureprogram`
        # @return [Fixnum]
        attr_accessor :exposureprogram
      
        # 
        # Corresponds to the JSON property `exposuretime`
        # @return [Float]
        attr_accessor :exposuretime
      
        # 
        # Corresponds to the JSON property `extrasamples`
        # @return [Fixnum]
        attr_accessor :extrasamples
      
        # 
        # Corresponds to the JSON property `fillorder`
        # @return [Fixnum]
        attr_accessor :fillorder
      
        # 
        # Corresponds to the JSON property `firmware`
        # @return [String]
        attr_accessor :firmware
      
        # 
        # Corresponds to the JSON property `firstphotodate`
        # @return [String]
        attr_accessor :firstphotodate
      
        # 
        # Corresponds to the JSON property `fixtureidentifier`
        # @return [String]
        attr_accessor :fixtureidentifier
      
        # 
        # Corresponds to the JSON property `flashcompensation`
        # @return [Float]
        attr_accessor :flashcompensation
      
        # 
        # Corresponds to the JSON property `flashenergy`
        # @return [Float]
        attr_accessor :flashenergy
      
        # 
        # Corresponds to the JSON property `flashreturn`
        # @return [Fixnum]
        attr_accessor :flashreturn
      
        # 
        # Corresponds to the JSON property `flashused`
        # @return [Fixnum]
        attr_accessor :flashused
      
        # 
        # Corresponds to the JSON property `focallength`
        # @return [Float]
        attr_accessor :focallength
      
        # 
        # Corresponds to the JSON property `focallengthin35mmfilm`
        # @return [Fixnum]
        attr_accessor :focallengthin35mmfilm
      
        # 
        # Corresponds to the JSON property `focalplaneunits`
        # @return [Float]
        attr_accessor :focalplaneunits
      
        # 
        # Corresponds to the JSON property `focalplanexres`
        # @return [Float]
        attr_accessor :focalplanexres
      
        # 
        # Corresponds to the JSON property `format`
        # @return [String]
        attr_accessor :format
      
        # 
        # Corresponds to the JSON property `freebytecounts`
        # @return [Fixnum]
        attr_accessor :freebytecounts
      
        # 
        # Corresponds to the JSON property `freeoffsets`
        # @return [Fixnum]
        attr_accessor :freeoffsets
      
        # 
        # Corresponds to the JSON property `fullpanoheightpixels`
        # @return [Fixnum]
        attr_accessor :fullpanoheightpixels
      
        # 
        # Corresponds to the JSON property `fullpanowidthpixels`
        # @return [Fixnum]
        attr_accessor :fullpanowidthpixels
      
        # 
        # Corresponds to the JSON property `function`
        # @return [Boolean]
        attr_accessor :function
        alias_method :function?, :function
      
        # 
        # Corresponds to the JSON property `gaincontrol`
        # @return [Fixnum]
        attr_accessor :gaincontrol
      
        # 
        # Corresponds to the JSON property `gaudiomime`
        # @return [String]
        attr_accessor :gaudiomime
      
        # A unique String. The property should be present and identical for all images
        # that make up a burst. It should be unique across devices (UUID recommended).
        # Unlike GCreations:CameraBurstId, we should use images with this property to
        # create auto collages and animations.
        # Corresponds to the JSON property `gcameraburstid`
        # @return [String]
        attr_accessor :gcameraburstid
      
        # A value of 1 indicates that this was the primary (“best shot”) at capture time.
        # Within Photos we should only treat this image as the best shot if the user
        # hasn’t made an explicit choice. Defining the initial primary allows
        # consistency between OEMs, Photos clients, and the Photos backend. This value
        # is optional, cameras are not required to set it on any photo in a burst.
        # Clients will default to the 0th frame, but may run an algorithm to pick a
        # better default.
        # Corresponds to the JSON property `gcameraburstprimary`
        # @return [Fixnum]
        attr_accessor :gcameraburstprimary
      
        # The possible values are: “Animation”, “Collage”, “Pano”, “Movies”. Photos will
        # avoid creating the listed types using the containing image or video. The
        # property is optional. The property can be included multiple times to disable
        # creation of multiple different types.
        # Corresponds to the JSON property `gcameradisableautocreation`
        # @return [Array<String>]
        attr_accessor :gcameradisableautocreation
      
        # The following XMP metadata are used specifically for MicroVideo. More
        # information about MicroVideo format can be found at go/photos-microvideo-
        # format A value of 1 indicates that this file was a MicroVideo at capture time.
        # Otherwise, this is not a MicroVideo (not set or 0).
        # Corresponds to the JSON property `gcameramicrovideo`
        # @return [Fixnum]
        attr_accessor :gcameramicrovideo
      
        # The offset in bytes from the end of the file to the point where the appended
        # mp4 begins (equivalent to the length of the compressed mp4). This field might
        # be provided in the original MicroVideo from client, but it might become
        # invalid when the image component is edited, so it is expected that the
        # thumbnailer will validate it and find the correct value (by scanning through
        # the JPEG) if it is invalid. In other words, only a valid offset should be
        # returned by thumbnailer.
        # Corresponds to the JSON property `gcameramicrovideooffset`
        # @return [Fixnum]
        attr_accessor :gcameramicrovideooffset
      
        # The presentation timestamp in microseconds of the video frame corresponding to
        # the image still. Value may be -1 to denote unset/unspecified.
        # Corresponds to the JSON property `gcameramicrovideopresentationtimestampus`
        # @return [Fixnum]
        attr_accessor :gcameramicrovideopresentationtimestampus
      
        # Indicates the file format version of the MicroVideo (initially 1).
        # Corresponds to the JSON property `gcameramicrovideoversion`
        # @return [Fixnum]
        attr_accessor :gcameramicrovideoversion
      
        # An indication that this item should be treated as a Motion Photo. 0 -> Not
        # Motion Photo, 1 -> Motion Photo, everything else is undefined per the spec. If
        # it's a motion photo, the previous gcamera fields should be ignored.
        # Corresponds to the JSON property `gcameramotionphoto`
        # @return [Fixnum]
        attr_accessor :gcameramotionphoto
      
        # The presentation timestamp in microseconds of the video frame corresponding to
        # the image still. Value may be -1 to denote unset/unspecified.
        # Corresponds to the JSON property `gcameramotionphotopresentationtimestampus`
        # @return [Fixnum]
        attr_accessor :gcameramotionphotopresentationtimestampus
      
        # Indicates the Motion Photo version of the spec (initially 1).
        # Corresponds to the JSON property `gcameramotionphotoversion`
        # @return [Fixnum]
        attr_accessor :gcameramotionphotoversion
      
        # Camera creations metadata. The opaque id string created by the OEM. For bursts,
        # this field should not be present. Instead, the two properties below will
        # allow Photos to identify and provide special treatment for bursts.
        # Corresponds to the JSON property `gcameraspecialtypeid`
        # @return [String]
        attr_accessor :gcameraspecialtypeid
      
        # 
        # Corresponds to the JSON property `gcreationscameraburstid`
        # @return [String]
        attr_accessor :gcreationscameraburstid
      
        # String representation of creation type. Should be one of `"GCameraCollage", "
        # GCameraAnimation", "GCameraGroupSmiles", "GPhotosCollage", "GPhotosAnimation"`.
        # Corresponds to the JSON property `gcreationstype`
        # @return [String]
        attr_accessor :gcreationstype
      
        # Metadata in the GDepth XMP block. Note that GDepth::Data is not copied into
        # this message.
        # Corresponds to the JSON property `gdepthMetadata`
        # @return [Google::Apis::ContentwarehouseV1::PhotosGDepthMetadata]
        attr_accessor :gdepth_metadata
      
        # 
        # Corresponds to the JSON property `gimagemime`
        # @return [String]
        attr_accessor :gimagemime
      
        # This is in UTC time. Format is YYYY:mm:dd.
        # Corresponds to the JSON property `gpsdatestamp`
        # @return [String]
        attr_accessor :gpsdatestamp
      
        # 
        # Corresponds to the JSON property `gpsdestbearing`
        # @return [Float]
        attr_accessor :gpsdestbearing
      
        # 
        # Corresponds to the JSON property `gpsdestbearingref`
        # @return [String]
        attr_accessor :gpsdestbearingref
      
        # 
        # Corresponds to the JSON property `gpsdestdistance`
        # @return [Float]
        attr_accessor :gpsdestdistance
      
        # 
        # Corresponds to the JSON property `gpsdestdistanceref`
        # @return [String]
        attr_accessor :gpsdestdistanceref
      
        # 
        # Corresponds to the JSON property `gpsdestlatitude`
        # @return [Float]
        attr_accessor :gpsdestlatitude
      
        # 
        # Corresponds to the JSON property `gpsdestlatituderef`
        # @return [String]
        attr_accessor :gpsdestlatituderef
      
        # 
        # Corresponds to the JSON property `gpsdestlongitude`
        # @return [Float]
        attr_accessor :gpsdestlongitude
      
        # 
        # Corresponds to the JSON property `gpsdestlongituderef`
        # @return [String]
        attr_accessor :gpsdestlongituderef
      
        # 
        # Corresponds to the JSON property `gpsdifferential`
        # @return [Fixnum]
        attr_accessor :gpsdifferential
      
        # 
        # Corresponds to the JSON property `gpsdop`
        # @return [Float]
        attr_accessor :gpsdop
      
        # 
        # Corresponds to the JSON property `gpsimgdirection`
        # @return [Float]
        attr_accessor :gpsimgdirection
      
        # 
        # Corresponds to the JSON property `gpsimgdirectionref`
        # @return [String]
        attr_accessor :gpsimgdirectionref
      
        # 
        # Corresponds to the JSON property `gpsmapdatum`
        # @return [String]
        attr_accessor :gpsmapdatum
      
        # 
        # Corresponds to the JSON property `gpsmeasuremode`
        # @return [String]
        attr_accessor :gpsmeasuremode
      
        # 
        # Corresponds to the JSON property `gpssatellites`
        # @return [String]
        attr_accessor :gpssatellites
      
        # 
        # Corresponds to the JSON property `gpsspeed`
        # @return [Float]
        attr_accessor :gpsspeed
      
        # 
        # Corresponds to the JSON property `gpsspeedref`
        # @return [String]
        attr_accessor :gpsspeedref
      
        # 
        # Corresponds to the JSON property `gpsstatus`
        # @return [String]
        attr_accessor :gpsstatus
      
        # This is in UTC Time. Contains three floats: hour, minute and second. Supports
        # subsecond resolution.
        # Corresponds to the JSON property `gpstime`
        # @return [Array<Float>]
        attr_accessor :gpstime
      
        # 
        # Corresponds to the JSON property `gpstrack`
        # @return [Float]
        attr_accessor :gpstrack
      
        # 
        # Corresponds to the JSON property `gpstrackref`
        # @return [String]
        attr_accessor :gpstrackref
      
        # 
        # Corresponds to the JSON property `grayresponsecurve`
        # @return [Fixnum]
        attr_accessor :grayresponsecurve
      
        # 
        # Corresponds to the JSON property `grayresponseunit`
        # @return [Fixnum]
        attr_accessor :grayresponseunit
      
        # The image has an alpha channel (potential transparency). If the image is
        # decoded, this will be updated to indicate whether there is any active
        # transparency. Formats supporting alpha: png, webp, gif, heif.
        # Corresponds to the JSON property `hasAlpha`
        # @return [Boolean]
        attr_accessor :has_alpha
        alias_method :has_alpha?, :has_alpha
      
        # 
        # Corresponds to the JSON property `headline`
        # @return [String]
        attr_accessor :headline
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `hostcomputer`
        # @return [String]
        attr_accessor :hostcomputer
      
        # 
        # Corresponds to the JSON property `identifier`
        # @return [Array<String>]
        attr_accessor :identifier
      
        # 
        # Corresponds to the JSON property `imagenumber`
        # @return [String]
        attr_accessor :imagenumber
      
        # 
        # Corresponds to the JSON property `imageorientation`
        # @return [String]
        attr_accessor :imageorientation
      
        # 
        # Corresponds to the JSON property `imagetype`
        # @return [String]
        attr_accessor :imagetype
      
        # 
        # Corresponds to the JSON property `initialhorizontalfovdegrees`
        # @return [Float]
        attr_accessor :initialhorizontalfovdegrees
      
        # 
        # Corresponds to the JSON property `initialverticalfovdegrees`
        # @return [Float]
        attr_accessor :initialverticalfovdegrees
      
        # 
        # Corresponds to the JSON property `initialviewheadingdegrees`
        # @return [Fixnum]
        attr_accessor :initialviewheadingdegrees
      
        # 
        # Corresponds to the JSON property `initialviewpitchdegrees`
        # @return [Fixnum]
        attr_accessor :initialviewpitchdegrees
      
        # 
        # Corresponds to the JSON property `initialviewrolldegrees`
        # @return [Fixnum]
        attr_accessor :initialviewrolldegrees
      
        # 
        # Corresponds to the JSON property `instructions`
        # @return [String]
        attr_accessor :instructions
      
        # 
        # Corresponds to the JSON property `intellectualgenre`
        # @return [String]
        attr_accessor :intellectualgenre
      
        # 
        # Corresponds to the JSON property `interoperabilityindex`
        # @return [String]
        attr_accessor :interoperabilityindex
      
        # 
        # Corresponds to the JSON property `iptc4c`
        # @return [Google::Apis::ContentwarehouseV1::PhotosFourCMetadata]
        attr_accessor :iptc4c
      
        # 
        # Corresponds to the JSON property `iptclastedited`
        # @return [String]
        attr_accessor :iptclastedited
      
        # The image is a Multi-Picture Object.
        # Corresponds to the JSON property `ismpformat`
        # @return [Boolean]
        attr_accessor :ismpformat
        alias_method :ismpformat?, :ismpformat
      
        # 
        # Corresponds to the JSON property `isoequivalent`
        # @return [Fixnum]
        attr_accessor :isoequivalent
      
        # 
        # Corresponds to the JSON property `keyword`
        # @return [Array<String>]
        attr_accessor :keyword
      
        # 
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Array<String>]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `languageidentifier`
        # @return [String]
        attr_accessor :languageidentifier
      
        # 
        # Corresponds to the JSON property `lastphotodate`
        # @return [String]
        attr_accessor :lastphotodate
      
        # GPS Info: +/- 90 inclusive
        # Corresponds to the JSON property `latitude`
        # @return [Float]
        attr_accessor :latitude
      
        # 
        # Corresponds to the JSON property `lens`
        # @return [String]
        attr_accessor :lens
      
        # 
        # Corresponds to the JSON property `lensid`
        # @return [String]
        attr_accessor :lensid
      
        # 
        # Corresponds to the JSON property `lensinfo`
        # @return [String]
        attr_accessor :lensinfo
      
        # 
        # Corresponds to the JSON property `lightsource`
        # @return [Fixnum]
        attr_accessor :lightsource
      
        # 
        # Corresponds to the JSON property `location`
        # @return [String]
        attr_accessor :location
      
        # 
        # Corresponds to the JSON property `locationshown`
        # @return [Array<String>]
        attr_accessor :locationshown
      
        # +/- 180 inclusive
        # Corresponds to the JSON property `longitude`
        # @return [Float]
        attr_accessor :longitude
      
        # 
        # Corresponds to the JSON property `marked`
        # @return [Boolean]
        attr_accessor :marked
        alias_method :marked?, :marked
      
        # 
        # Corresponds to the JSON property `maxaperturevalue`
        # @return [Float]
        attr_accessor :maxaperturevalue
      
        # 
        # Corresponds to the JSON property `maxavailheight`
        # @return [Fixnum]
        attr_accessor :maxavailheight
      
        # 
        # Corresponds to the JSON property `maxavailwidth`
        # @return [Fixnum]
        attr_accessor :maxavailwidth
      
        # 
        # Corresponds to the JSON property `maxsamplevalue`
        # @return [Fixnum]
        attr_accessor :maxsamplevalue
      
        # 
        # Corresponds to the JSON property `metadatadate`
        # @return [String]
        attr_accessor :metadatadate
      
        # 
        # Corresponds to the JSON property `meteringmode`
        # @return [Fixnum]
        attr_accessor :meteringmode
      
        # This is similar to gcameramicrovideooffset, except it stores the unverified
        # value that was provided in the motion photo file. This field is not part of
        # the XMP or spec. It is used to ensure we preserve data from the original file
        # when offset is modified.
        # Corresponds to the JSON property `microvideooriginaloffset`
        # @return [Fixnum]
        attr_accessor :microvideooriginaloffset
      
        # Mime type of image
        # Corresponds to the JSON property `mimeType`
        # @return [Fixnum]
        attr_accessor :mime_type
      
        # 
        # Corresponds to the JSON property `minormodelagedisclosure`
        # @return [String]
        attr_accessor :minormodelagedisclosure
      
        # 
        # Corresponds to the JSON property `minsamplevalue`
        # @return [Fixnum]
        attr_accessor :minsamplevalue
      
        # 
        # Corresponds to the JSON property `mode`
        # @return [Fixnum]
        attr_accessor :mode
      
        # 
        # Corresponds to the JSON property `modelage`
        # @return [Array<Fixnum>]
        attr_accessor :modelage
      
        # 
        # Corresponds to the JSON property `modelreleaseid`
        # @return [Array<String>]
        attr_accessor :modelreleaseid
      
        # 
        # Corresponds to the JSON property `modelreleasestatus`
        # @return [String]
        attr_accessor :modelreleasestatus
      
        # 
        # Corresponds to the JSON property `modifydate`
        # @return [String]
        attr_accessor :modifydate
      
        # The Motion Photo Video Data (MPVD) box header of a HEIF motion photo. It is
        # used for reconstructing the original moton photo bytes. See go/photos-be-heic-
        # motion-photos for more details.
        # Corresponds to the JSON property `motionphotovideodataboxheader`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :motionphotovideodataboxheader
      
        # 
        # Corresponds to the JSON property `nickname`
        # @return [String]
        attr_accessor :nickname
      
        # 
        # Corresponds to the JSON property `objectattributereference`
        # @return [Array<String>]
        attr_accessor :objectattributereference
      
        # 
        # Corresponds to the JSON property `objectcycle`
        # @return [String]
        attr_accessor :objectcycle
      
        # 
        # Corresponds to the JSON property `objecttypereference`
        # @return [String]
        attr_accessor :objecttypereference
      
        # 
        # Corresponds to the JSON property `offsettime`
        # @return [String]
        attr_accessor :offsettime
      
        # 
        # Corresponds to the JSON property `offsettimedigitized`
        # @return [String]
        attr_accessor :offsettimedigitized
      
        # 
        # Corresponds to the JSON property `offsettimeoriginal`
        # @return [String]
        attr_accessor :offsettimeoriginal
      
        # 
        # Corresponds to the JSON property `organisationinimagecode`
        # @return [Array<String>]
        attr_accessor :organisationinimagecode
      
        # 
        # Corresponds to the JSON property `organisationinimagename`
        # @return [Array<String>]
        attr_accessor :organisationinimagename
      
        # Exif camera orientation. "1" means "no rotation".
        # Corresponds to the JSON property `orientation`
        # @return [Fixnum]
        attr_accessor :orientation
      
        # 
        # Corresponds to the JSON property `originatingprogram`
        # @return [String]
        attr_accessor :originatingprogram
      
        # 
        # Corresponds to the JSON property `owner`
        # @return [Array<String>]
        attr_accessor :owner
      
        # 
        # Corresponds to the JSON property `ownername`
        # @return [String]
        attr_accessor :ownername
      
        # 
        # Corresponds to the JSON property `panoramaMetadata`
        # @return [Google::Apis::ContentwarehouseV1::PhotosPanoramaMetadata]
        attr_accessor :panorama_metadata
      
        # 
        # Corresponds to the JSON property `personinimage`
        # @return [Array<String>]
        attr_accessor :personinimage
      
        # 
        # Corresponds to the JSON property `photometricinterpretation`
        # @return [Fixnum]
        attr_accessor :photometricinterpretation
      
        # 
        # Corresponds to the JSON property `planarconfiguration`
        # @return [Fixnum]
        attr_accessor :planarconfiguration
      
        # 
        # Corresponds to the JSON property `poseheadingdegrees`
        # @return [Float]
        attr_accessor :poseheadingdegrees
      
        # 
        # Corresponds to the JSON property `posepitchdegrees`
        # @return [Float]
        attr_accessor :posepitchdegrees
      
        # 
        # Corresponds to the JSON property `poserolldegrees`
        # @return [Float]
        attr_accessor :poserolldegrees
      
        # 
        # Corresponds to the JSON property `primarychromaticities`
        # @return [Float]
        attr_accessor :primarychromaticities
      
        # 
        # Corresponds to the JSON property `productid`
        # @return [Array<String>]
        attr_accessor :productid
      
        # 
        # Corresponds to the JSON property `programversion`
        # @return [String]
        attr_accessor :programversion
      
        # 
        # Corresponds to the JSON property `projectiontype`
        # @return [String]
        attr_accessor :projectiontype
      
        # 
        # Corresponds to the JSON property `propertyreleaseid`
        # @return [Array<String>]
        attr_accessor :propertyreleaseid
      
        # 
        # Corresponds to the JSON property `propertyreleasestatus`
        # @return [String]
        attr_accessor :propertyreleasestatus
      
        # 
        # Corresponds to the JSON property `publisher`
        # @return [Array<String>]
        attr_accessor :publisher
      
        # 
        # Corresponds to the JSON property `rating`
        # @return [Float]
        attr_accessor :rating
      
        # 
        # Corresponds to the JSON property `redeyemode`
        # @return [Boolean]
        attr_accessor :redeyemode
        alias_method :redeyemode?, :redeyemode
      
        # 
        # Corresponds to the JSON property `referenceblackwhite`
        # @return [Float]
        attr_accessor :referenceblackwhite
      
        # 
        # Corresponds to the JSON property `referencedate`
        # @return [Array<String>]
        attr_accessor :referencedate
      
        # 
        # Corresponds to the JSON property `referencenumber`
        # @return [Array<String>]
        attr_accessor :referencenumber
      
        # 
        # Corresponds to the JSON property `referenceservice`
        # @return [Array<String>]
        attr_accessor :referenceservice
      
        # 
        # Corresponds to the JSON property `relatedimagefileformat`
        # @return [String]
        attr_accessor :relatedimagefileformat
      
        # 
        # Corresponds to the JSON property `relatedimageheight`
        # @return [Fixnum]
        attr_accessor :relatedimageheight
      
        # 
        # Corresponds to the JSON property `relatedimagewidth`
        # @return [Fixnum]
        attr_accessor :relatedimagewidth
      
        # 
        # Corresponds to the JSON property `relatedsoundfile`
        # @return [String]
        attr_accessor :relatedsoundfile
      
        # 
        # Corresponds to the JSON property `relation`
        # @return [Array<String>]
        attr_accessor :relation
      
        # 
        # Corresponds to the JSON property `releasedate`
        # @return [String]
        attr_accessor :releasedate
      
        # 
        # Corresponds to the JSON property `releasetime`
        # @return [String]
        attr_accessor :releasetime
      
        # 
        # Corresponds to the JSON property `resolutionunit`
        # @return [Fixnum]
        attr_accessor :resolutionunit
      
        # being returned to caller Use values defined in "MIME_TYPE" This field is
        # deprecated. Rotation is now accomplished via ImageInfo.exif_orientation and
        # ImageInfo.edit_list. Number of degrees (0, 90, 180,
        # Corresponds to the JSON property `rotate`
        # @return [Fixnum]
        attr_accessor :rotate
      
        # 
        # Corresponds to the JSON property `rowsperstrip`
        # @return [Fixnum]
        attr_accessor :rowsperstrip
      
        # 
        # Corresponds to the JSON property `samplesperpixel`
        # @return [Fixnum]
        attr_accessor :samplesperpixel
      
        # 
        # Corresponds to the JSON property `saturation`
        # @return [Fixnum]
        attr_accessor :saturation
      
        # 
        # Corresponds to the JSON property `scene`
        # @return [Array<String>]
        attr_accessor :scene
      
        # 
        # Corresponds to the JSON property `scenecapturetype`
        # @return [Fixnum]
        attr_accessor :scenecapturetype
      
        # 
        # Corresponds to the JSON property `sensingmethod`
        # @return [Fixnum]
        attr_accessor :sensingmethod
      
        # 
        # Corresponds to the JSON property `sensorheight`
        # @return [Float]
        attr_accessor :sensorheight
      
        # 
        # Corresponds to the JSON property `sensorwidth`
        # @return [Float]
        attr_accessor :sensorwidth
      
        # 
        # Corresponds to the JSON property `serialnumber`
        # @return [String]
        attr_accessor :serialnumber
      
        # 
        # Corresponds to the JSON property `serviceidentifier`
        # @return [String]
        attr_accessor :serviceidentifier
      
        # 
        # Corresponds to the JSON property `sharpness`
        # @return [Fixnum]
        attr_accessor :sharpness
      
        # 
        # Corresponds to the JSON property `shutterspeedvalue`
        # @return [Float]
        attr_accessor :shutterspeedvalue
      
        # 
        # Corresponds to the JSON property `software`
        # @return [String]
        attr_accessor :software
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `sourcephotoscount`
        # @return [Fixnum]
        attr_accessor :sourcephotoscount
      
        # 
        # Corresponds to the JSON property `spectralsensitivity`
        # @return [String]
        attr_accessor :spectralsensitivity
      
        # 
        # Corresponds to the JSON property `state`
        # @return [String]
        attr_accessor :state
      
        # 
        # Corresponds to the JSON property `stitchingsoftware`
        # @return [String]
        attr_accessor :stitchingsoftware
      
        # 
        # Corresponds to the JSON property `stripbytecounts`
        # @return [Fixnum]
        attr_accessor :stripbytecounts
      
        # 
        # Corresponds to the JSON property `stripoffsets`
        # @return [Fixnum]
        attr_accessor :stripoffsets
      
        # 
        # Corresponds to the JSON property `subjectarea`
        # @return [Fixnum]
        attr_accessor :subjectarea
      
        # 
        # Corresponds to the JSON property `subjectcode`
        # @return [Array<String>]
        attr_accessor :subjectcode
      
        # 
        # Corresponds to the JSON property `subjectdistancerange`
        # @return [Fixnum]
        attr_accessor :subjectdistancerange
      
        # 
        # Corresponds to the JSON property `subjectlocation`
        # @return [Fixnum]
        attr_accessor :subjectlocation
      
        # 
        # Corresponds to the JSON property `subjectreference`
        # @return [Array<String>]
        attr_accessor :subjectreference
      
        # 
        # Corresponds to the JSON property `sublocation`
        # @return [String]
        attr_accessor :sublocation
      
        # 
        # Corresponds to the JSON property `subsectime`
        # @return [String]
        attr_accessor :subsectime
      
        # 
        # Corresponds to the JSON property `subsectimedigitized`
        # @return [String]
        attr_accessor :subsectimedigitized
      
        # 
        # Corresponds to the JSON property `subsectimeoriginal`
        # @return [String]
        attr_accessor :subsectimeoriginal
      
        # 
        # Corresponds to the JSON property `supplementalcategory`
        # @return [Array<String>]
        attr_accessor :supplementalcategory
      
        # 
        # Corresponds to the JSON property `thresholding`
        # @return [Fixnum]
        attr_accessor :thresholding
      
        # The build CL for the version of thumbnailer that built this image.
        # Corresponds to the JSON property `thumbnailerBuildCl`
        # @return [Fixnum]
        attr_accessor :thumbnailer_build_cl
      
        # 
        # Corresponds to the JSON property `timesent`
        # @return [String]
        attr_accessor :timesent
      
        # Remaining minutes of offset.
        # Corresponds to the JSON property `timezoneminutes`
        # @return [Array<Fixnum>]
        attr_accessor :timezoneminutes
      
        # The elements in the timezone and daylight savings field arrays correspond to
        # the following date/time fields: 0) datecreated (ie. DateTimeOriginal) 1)
        # datetime (ie. DateTime or last modified date) 2) datetimedigitized (ie.
        # DateTimeDigitized) If the field does not exist, then there is no valid time
        # zone information for that date/time field. Offset in hours.
        # Corresponds to the JSON property `timezoneoffset`
        # @return [Array<Fixnum>]
        attr_accessor :timezoneoffset
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `transmissionreference`
        # @return [String]
        attr_accessor :transmissionreference
      
        # 
        # Corresponds to the JSON property `type`
        # @return [Array<String>]
        attr_accessor :type
      
        # For unique hash:
        # Corresponds to the JSON property `uniqueid`
        # @return [String]
        attr_accessor :uniqueid
      
        # 
        # Corresponds to the JSON property `uno`
        # @return [String]
        attr_accessor :uno
      
        # 
        # Corresponds to the JSON property `urgency`
        # @return [String]
        attr_accessor :urgency
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `usageterms`
        # @return [String]
        attr_accessor :usageterms
      
        # GPano-related fields. A handful of these have been deprecated due to a change
        # in the spec since its initial design.
        # Corresponds to the JSON property `usepanoramaviewer`
        # @return [Boolean]
        attr_accessor :usepanoramaviewer
        alias_method :usepanoramaviewer?, :usepanoramaviewer
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        # 
        # Corresponds to the JSON property `webstatement`
        # @return [String]
        attr_accessor :webstatement
      
        # 
        # Corresponds to the JSON property `whitebalance`
        # @return [Fixnum]
        attr_accessor :whitebalance
      
        # 
        # Corresponds to the JSON property `whitepoint`
        # @return [Float]
        attr_accessor :whitepoint
      
        # width and height are before any rotation (including EXIF orientation).
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        # 
        # Corresponds to the JSON property `xmp4c`
        # @return [Google::Apis::ContentwarehouseV1::PhotosFourCMetadata]
        attr_accessor :xmp4c
      
        # 
        # Corresponds to the JSON property `xresolution`
        # @return [Float]
        attr_accessor :xresolution
      
        # 
        # Corresponds to the JSON property `ycbcrcoefficients`
        # @return [Float]
        attr_accessor :ycbcrcoefficients
      
        # 
        # Corresponds to the JSON property `ycbcrpositioning`
        # @return [Fixnum]
        attr_accessor :ycbcrpositioning
      
        # 
        # Corresponds to the JSON property `ycbcrsubsampling`
        # @return [Fixnum]
        attr_accessor :ycbcrsubsampling
      
        # 
        # Corresponds to the JSON property `yresolution`
        # @return [Float]
        attr_accessor :yresolution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_blendingtype = args[:deprecated_blendingtype] if args.key?(:deprecated_blendingtype)
          @deprecated_gpstimestamp = args[:deprecated_gpstimestamp] if args.key?(:deprecated_gpstimestamp)
          @deprecated_iscolor = args[:deprecated_iscolor] if args.key?(:deprecated_iscolor)
          @deprecated_largestvalidinteriorrectheight = args[:deprecated_largestvalidinteriorrectheight] if args.key?(:deprecated_largestvalidinteriorrectheight)
          @deprecated_largestvalidinteriorrectleft = args[:deprecated_largestvalidinteriorrectleft] if args.key?(:deprecated_largestvalidinteriorrectleft)
          @deprecated_largestvalidinteriorrecttop = args[:deprecated_largestvalidinteriorrecttop] if args.key?(:deprecated_largestvalidinteriorrecttop)
          @deprecated_largestvalidinteriorrectwidth = args[:deprecated_largestvalidinteriorrectwidth] if args.key?(:deprecated_largestvalidinteriorrectwidth)
          @deprecated_process = args[:deprecated_process] if args.key?(:deprecated_process)
          @actionadvised = args[:actionadvised] if args.key?(:actionadvised)
          @addlmodelinfo = args[:addlmodelinfo] if args.key?(:addlmodelinfo)
          @advisory = args[:advisory] if args.key?(:advisory)
          @altitude = args[:altitude] if args.key?(:altitude)
          @animation_metadata = args[:animation_metadata] if args.key?(:animation_metadata)
          @aperturefnumber = args[:aperturefnumber] if args.key?(:aperturefnumber)
          @aperturevalue = args[:aperturevalue] if args.key?(:aperturevalue)
          @artworkorobject = args[:artworkorobject] if args.key?(:artworkorobject)
          @audioduration = args[:audioduration] if args.key?(:audioduration)
          @audiooutcue = args[:audiooutcue] if args.key?(:audiooutcue)
          @audiosamplingrate = args[:audiosamplingrate] if args.key?(:audiosamplingrate)
          @audiosamplingresolution = args[:audiosamplingresolution] if args.key?(:audiosamplingresolution)
          @audiotype = args[:audiotype] if args.key?(:audiotype)
          @author = args[:author] if args.key?(:author)
          @authorposition = args[:authorposition] if args.key?(:authorposition)
          @autoenhance = args[:autoenhance] if args.key?(:autoenhance)
          @baseurl = args[:baseurl] if args.key?(:baseurl)
          @bit_depth = args[:bit_depth] if args.key?(:bit_depth)
          @bitspersample = args[:bitspersample] if args.key?(:bitspersample)
          @brightnessvalue = args[:brightnessvalue] if args.key?(:brightnessvalue)
          @burstuuid = args[:burstuuid] if args.key?(:burstuuid)
          @cameraid = args[:cameraid] if args.key?(:cameraid)
          @cameramake = args[:cameramake] if args.key?(:cameramake)
          @cameramodel = args[:cameramodel] if args.key?(:cameramodel)
          @caption = args[:caption] if args.key?(:caption)
          @captionwriter = args[:captionwriter] if args.key?(:captionwriter)
          @capturesoftware = args[:capturesoftware] if args.key?(:capturesoftware)
          @category = args[:category] if args.key?(:category)
          @ccdwidth = args[:ccdwidth] if args.key?(:ccdwidth)
          @celllength = args[:celllength] if args.key?(:celllength)
          @cellwidth = args[:cellwidth] if args.key?(:cellwidth)
          @certificate = args[:certificate] if args.key?(:certificate)
          @chromasubsampling = args[:chromasubsampling] if args.key?(:chromasubsampling)
          @ciadrcity = args[:ciadrcity] if args.key?(:ciadrcity)
          @ciadrctry = args[:ciadrctry] if args.key?(:ciadrctry)
          @ciadrextadr = args[:ciadrextadr] if args.key?(:ciadrextadr)
          @ciadrpcode = args[:ciadrpcode] if args.key?(:ciadrpcode)
          @ciadrregion = args[:ciadrregion] if args.key?(:ciadrregion)
          @ciemailwork = args[:ciemailwork] if args.key?(:ciemailwork)
          @citelwork = args[:citelwork] if args.key?(:citelwork)
          @city = args[:city] if args.key?(:city)
          @ciurlwork = args[:ciurlwork] if args.key?(:ciurlwork)
          @colormap = args[:colormap] if args.key?(:colormap)
          @colorprofile = args[:colorprofile] if args.key?(:colorprofile)
          @colorspace = args[:colorspace] if args.key?(:colorspace)
          @compressedbitsperpixel = args[:compressedbitsperpixel] if args.key?(:compressedbitsperpixel)
          @compressionlevel = args[:compressionlevel] if args.key?(:compressionlevel)
          @contact = args[:contact] if args.key?(:contact)
          @contentlocationcode = args[:contentlocationcode] if args.key?(:contentlocationcode)
          @contentlocationname = args[:contentlocationname] if args.key?(:contentlocationname)
          @contrast = args[:contrast] if args.key?(:contrast)
          @contributor = args[:contributor] if args.key?(:contributor)
          @copyrightnotice = args[:copyrightnotice] if args.key?(:copyrightnotice)
          @country = args[:country] if args.key?(:country)
          @countrycode = args[:countrycode] if args.key?(:countrycode)
          @coverage = args[:coverage] if args.key?(:coverage)
          @createdate = args[:createdate] if args.key?(:createdate)
          @credits = args[:credits] if args.key?(:credits)
          @croppedareaimageheightpixels = args[:croppedareaimageheightpixels] if args.key?(:croppedareaimageheightpixels)
          @croppedareaimagewidthpixels = args[:croppedareaimagewidthpixels] if args.key?(:croppedareaimagewidthpixels)
          @croppedarealeftpixels = args[:croppedarealeftpixels] if args.key?(:croppedarealeftpixels)
          @croppedareatoppixels = args[:croppedareatoppixels] if args.key?(:croppedareatoppixels)
          @customrendered = args[:customrendered] if args.key?(:customrendered)
          @cvterm = args[:cvterm] if args.key?(:cvterm)
          @date = args[:date] if args.key?(:date)
          @datecreated = args[:datecreated] if args.key?(:datecreated)
          @datesent = args[:datesent] if args.key?(:datesent)
          @datetime = args[:datetime] if args.key?(:datetime)
          @datetimedigitized = args[:datetimedigitized] if args.key?(:datetimedigitized)
          @daylightsavings = args[:daylightsavings] if args.key?(:daylightsavings)
          @destination = args[:destination] if args.key?(:destination)
          @destination_latitude = args[:destination_latitude] if args.key?(:destination_latitude)
          @destination_longitude = args[:destination_longitude] if args.key?(:destination_longitude)
          @digimageguid = args[:digimageguid] if args.key?(:digimageguid)
          @digitalsourcefiletype = args[:digitalsourcefiletype] if args.key?(:digitalsourcefiletype)
          @digitalsourcetype = args[:digitalsourcetype] if args.key?(:digitalsourcetype)
          @digitalzoomratio = args[:digitalzoomratio] if args.key?(:digitalzoomratio)
          @distance = args[:distance] if args.key?(:distance)
          @dynamic_depth_metadata = args[:dynamic_depth_metadata] if args.key?(:dynamic_depth_metadata)
          @editorialupdate = args[:editorialupdate] if args.key?(:editorialupdate)
          @editstatus = args[:editstatus] if args.key?(:editstatus)
          @envelopenumber = args[:envelopenumber] if args.key?(:envelopenumber)
          @envelopepriority = args[:envelopepriority] if args.key?(:envelopepriority)
          @event = args[:event] if args.key?(:event)
          @exif4c = args[:exif4c] if args.key?(:exif4c)
          @exif_time = args[:exif_time] if args.key?(:exif_time)
          @exif_time_utc = args[:exif_time_utc] if args.key?(:exif_time_utc)
          @exif_time_utc_source = args[:exif_time_utc_source] if args.key?(:exif_time_utc_source)
          @expirationdate = args[:expirationdate] if args.key?(:expirationdate)
          @expirationtime = args[:expirationtime] if args.key?(:expirationtime)
          @exposurebias = args[:exposurebias] if args.key?(:exposurebias)
          @exposureindex = args[:exposureindex] if args.key?(:exposureindex)
          @exposurelockused = args[:exposurelockused] if args.key?(:exposurelockused)
          @exposuremode = args[:exposuremode] if args.key?(:exposuremode)
          @exposureprogram = args[:exposureprogram] if args.key?(:exposureprogram)
          @exposuretime = args[:exposuretime] if args.key?(:exposuretime)
          @extrasamples = args[:extrasamples] if args.key?(:extrasamples)
          @fillorder = args[:fillorder] if args.key?(:fillorder)
          @firmware = args[:firmware] if args.key?(:firmware)
          @firstphotodate = args[:firstphotodate] if args.key?(:firstphotodate)
          @fixtureidentifier = args[:fixtureidentifier] if args.key?(:fixtureidentifier)
          @flashcompensation = args[:flashcompensation] if args.key?(:flashcompensation)
          @flashenergy = args[:flashenergy] if args.key?(:flashenergy)
          @flashreturn = args[:flashreturn] if args.key?(:flashreturn)
          @flashused = args[:flashused] if args.key?(:flashused)
          @focallength = args[:focallength] if args.key?(:focallength)
          @focallengthin35mmfilm = args[:focallengthin35mmfilm] if args.key?(:focallengthin35mmfilm)
          @focalplaneunits = args[:focalplaneunits] if args.key?(:focalplaneunits)
          @focalplanexres = args[:focalplanexres] if args.key?(:focalplanexres)
          @format = args[:format] if args.key?(:format)
          @freebytecounts = args[:freebytecounts] if args.key?(:freebytecounts)
          @freeoffsets = args[:freeoffsets] if args.key?(:freeoffsets)
          @fullpanoheightpixels = args[:fullpanoheightpixels] if args.key?(:fullpanoheightpixels)
          @fullpanowidthpixels = args[:fullpanowidthpixels] if args.key?(:fullpanowidthpixels)
          @function = args[:function] if args.key?(:function)
          @gaincontrol = args[:gaincontrol] if args.key?(:gaincontrol)
          @gaudiomime = args[:gaudiomime] if args.key?(:gaudiomime)
          @gcameraburstid = args[:gcameraburstid] if args.key?(:gcameraburstid)
          @gcameraburstprimary = args[:gcameraburstprimary] if args.key?(:gcameraburstprimary)
          @gcameradisableautocreation = args[:gcameradisableautocreation] if args.key?(:gcameradisableautocreation)
          @gcameramicrovideo = args[:gcameramicrovideo] if args.key?(:gcameramicrovideo)
          @gcameramicrovideooffset = args[:gcameramicrovideooffset] if args.key?(:gcameramicrovideooffset)
          @gcameramicrovideopresentationtimestampus = args[:gcameramicrovideopresentationtimestampus] if args.key?(:gcameramicrovideopresentationtimestampus)
          @gcameramicrovideoversion = args[:gcameramicrovideoversion] if args.key?(:gcameramicrovideoversion)
          @gcameramotionphoto = args[:gcameramotionphoto] if args.key?(:gcameramotionphoto)
          @gcameramotionphotopresentationtimestampus = args[:gcameramotionphotopresentationtimestampus] if args.key?(:gcameramotionphotopresentationtimestampus)
          @gcameramotionphotoversion = args[:gcameramotionphotoversion] if args.key?(:gcameramotionphotoversion)
          @gcameraspecialtypeid = args[:gcameraspecialtypeid] if args.key?(:gcameraspecialtypeid)
          @gcreationscameraburstid = args[:gcreationscameraburstid] if args.key?(:gcreationscameraburstid)
          @gcreationstype = args[:gcreationstype] if args.key?(:gcreationstype)
          @gdepth_metadata = args[:gdepth_metadata] if args.key?(:gdepth_metadata)
          @gimagemime = args[:gimagemime] if args.key?(:gimagemime)
          @gpsdatestamp = args[:gpsdatestamp] if args.key?(:gpsdatestamp)
          @gpsdestbearing = args[:gpsdestbearing] if args.key?(:gpsdestbearing)
          @gpsdestbearingref = args[:gpsdestbearingref] if args.key?(:gpsdestbearingref)
          @gpsdestdistance = args[:gpsdestdistance] if args.key?(:gpsdestdistance)
          @gpsdestdistanceref = args[:gpsdestdistanceref] if args.key?(:gpsdestdistanceref)
          @gpsdestlatitude = args[:gpsdestlatitude] if args.key?(:gpsdestlatitude)
          @gpsdestlatituderef = args[:gpsdestlatituderef] if args.key?(:gpsdestlatituderef)
          @gpsdestlongitude = args[:gpsdestlongitude] if args.key?(:gpsdestlongitude)
          @gpsdestlongituderef = args[:gpsdestlongituderef] if args.key?(:gpsdestlongituderef)
          @gpsdifferential = args[:gpsdifferential] if args.key?(:gpsdifferential)
          @gpsdop = args[:gpsdop] if args.key?(:gpsdop)
          @gpsimgdirection = args[:gpsimgdirection] if args.key?(:gpsimgdirection)
          @gpsimgdirectionref = args[:gpsimgdirectionref] if args.key?(:gpsimgdirectionref)
          @gpsmapdatum = args[:gpsmapdatum] if args.key?(:gpsmapdatum)
          @gpsmeasuremode = args[:gpsmeasuremode] if args.key?(:gpsmeasuremode)
          @gpssatellites = args[:gpssatellites] if args.key?(:gpssatellites)
          @gpsspeed = args[:gpsspeed] if args.key?(:gpsspeed)
          @gpsspeedref = args[:gpsspeedref] if args.key?(:gpsspeedref)
          @gpsstatus = args[:gpsstatus] if args.key?(:gpsstatus)
          @gpstime = args[:gpstime] if args.key?(:gpstime)
          @gpstrack = args[:gpstrack] if args.key?(:gpstrack)
          @gpstrackref = args[:gpstrackref] if args.key?(:gpstrackref)
          @grayresponsecurve = args[:grayresponsecurve] if args.key?(:grayresponsecurve)
          @grayresponseunit = args[:grayresponseunit] if args.key?(:grayresponseunit)
          @has_alpha = args[:has_alpha] if args.key?(:has_alpha)
          @headline = args[:headline] if args.key?(:headline)
          @height = args[:height] if args.key?(:height)
          @hostcomputer = args[:hostcomputer] if args.key?(:hostcomputer)
          @identifier = args[:identifier] if args.key?(:identifier)
          @imagenumber = args[:imagenumber] if args.key?(:imagenumber)
          @imageorientation = args[:imageorientation] if args.key?(:imageorientation)
          @imagetype = args[:imagetype] if args.key?(:imagetype)
          @initialhorizontalfovdegrees = args[:initialhorizontalfovdegrees] if args.key?(:initialhorizontalfovdegrees)
          @initialverticalfovdegrees = args[:initialverticalfovdegrees] if args.key?(:initialverticalfovdegrees)
          @initialviewheadingdegrees = args[:initialviewheadingdegrees] if args.key?(:initialviewheadingdegrees)
          @initialviewpitchdegrees = args[:initialviewpitchdegrees] if args.key?(:initialviewpitchdegrees)
          @initialviewrolldegrees = args[:initialviewrolldegrees] if args.key?(:initialviewrolldegrees)
          @instructions = args[:instructions] if args.key?(:instructions)
          @intellectualgenre = args[:intellectualgenre] if args.key?(:intellectualgenre)
          @interoperabilityindex = args[:interoperabilityindex] if args.key?(:interoperabilityindex)
          @iptc4c = args[:iptc4c] if args.key?(:iptc4c)
          @iptclastedited = args[:iptclastedited] if args.key?(:iptclastedited)
          @ismpformat = args[:ismpformat] if args.key?(:ismpformat)
          @isoequivalent = args[:isoequivalent] if args.key?(:isoequivalent)
          @keyword = args[:keyword] if args.key?(:keyword)
          @label = args[:label] if args.key?(:label)
          @language = args[:language] if args.key?(:language)
          @languageidentifier = args[:languageidentifier] if args.key?(:languageidentifier)
          @lastphotodate = args[:lastphotodate] if args.key?(:lastphotodate)
          @latitude = args[:latitude] if args.key?(:latitude)
          @lens = args[:lens] if args.key?(:lens)
          @lensid = args[:lensid] if args.key?(:lensid)
          @lensinfo = args[:lensinfo] if args.key?(:lensinfo)
          @lightsource = args[:lightsource] if args.key?(:lightsource)
          @location = args[:location] if args.key?(:location)
          @locationshown = args[:locationshown] if args.key?(:locationshown)
          @longitude = args[:longitude] if args.key?(:longitude)
          @marked = args[:marked] if args.key?(:marked)
          @maxaperturevalue = args[:maxaperturevalue] if args.key?(:maxaperturevalue)
          @maxavailheight = args[:maxavailheight] if args.key?(:maxavailheight)
          @maxavailwidth = args[:maxavailwidth] if args.key?(:maxavailwidth)
          @maxsamplevalue = args[:maxsamplevalue] if args.key?(:maxsamplevalue)
          @metadatadate = args[:metadatadate] if args.key?(:metadatadate)
          @meteringmode = args[:meteringmode] if args.key?(:meteringmode)
          @microvideooriginaloffset = args[:microvideooriginaloffset] if args.key?(:microvideooriginaloffset)
          @mime_type = args[:mime_type] if args.key?(:mime_type)
          @minormodelagedisclosure = args[:minormodelagedisclosure] if args.key?(:minormodelagedisclosure)
          @minsamplevalue = args[:minsamplevalue] if args.key?(:minsamplevalue)
          @mode = args[:mode] if args.key?(:mode)
          @modelage = args[:modelage] if args.key?(:modelage)
          @modelreleaseid = args[:modelreleaseid] if args.key?(:modelreleaseid)
          @modelreleasestatus = args[:modelreleasestatus] if args.key?(:modelreleasestatus)
          @modifydate = args[:modifydate] if args.key?(:modifydate)
          @motionphotovideodataboxheader = args[:motionphotovideodataboxheader] if args.key?(:motionphotovideodataboxheader)
          @nickname = args[:nickname] if args.key?(:nickname)
          @objectattributereference = args[:objectattributereference] if args.key?(:objectattributereference)
          @objectcycle = args[:objectcycle] if args.key?(:objectcycle)
          @objecttypereference = args[:objecttypereference] if args.key?(:objecttypereference)
          @offsettime = args[:offsettime] if args.key?(:offsettime)
          @offsettimedigitized = args[:offsettimedigitized] if args.key?(:offsettimedigitized)
          @offsettimeoriginal = args[:offsettimeoriginal] if args.key?(:offsettimeoriginal)
          @organisationinimagecode = args[:organisationinimagecode] if args.key?(:organisationinimagecode)
          @organisationinimagename = args[:organisationinimagename] if args.key?(:organisationinimagename)
          @orientation = args[:orientation] if args.key?(:orientation)
          @originatingprogram = args[:originatingprogram] if args.key?(:originatingprogram)
          @owner = args[:owner] if args.key?(:owner)
          @ownername = args[:ownername] if args.key?(:ownername)
          @panorama_metadata = args[:panorama_metadata] if args.key?(:panorama_metadata)
          @personinimage = args[:personinimage] if args.key?(:personinimage)
          @photometricinterpretation = args[:photometricinterpretation] if args.key?(:photometricinterpretation)
          @planarconfiguration = args[:planarconfiguration] if args.key?(:planarconfiguration)
          @poseheadingdegrees = args[:poseheadingdegrees] if args.key?(:poseheadingdegrees)
          @posepitchdegrees = args[:posepitchdegrees] if args.key?(:posepitchdegrees)
          @poserolldegrees = args[:poserolldegrees] if args.key?(:poserolldegrees)
          @primarychromaticities = args[:primarychromaticities] if args.key?(:primarychromaticities)
          @productid = args[:productid] if args.key?(:productid)
          @programversion = args[:programversion] if args.key?(:programversion)
          @projectiontype = args[:projectiontype] if args.key?(:projectiontype)
          @propertyreleaseid = args[:propertyreleaseid] if args.key?(:propertyreleaseid)
          @propertyreleasestatus = args[:propertyreleasestatus] if args.key?(:propertyreleasestatus)
          @publisher = args[:publisher] if args.key?(:publisher)
          @rating = args[:rating] if args.key?(:rating)
          @redeyemode = args[:redeyemode] if args.key?(:redeyemode)
          @referenceblackwhite = args[:referenceblackwhite] if args.key?(:referenceblackwhite)
          @referencedate = args[:referencedate] if args.key?(:referencedate)
          @referencenumber = args[:referencenumber] if args.key?(:referencenumber)
          @referenceservice = args[:referenceservice] if args.key?(:referenceservice)
          @relatedimagefileformat = args[:relatedimagefileformat] if args.key?(:relatedimagefileformat)
          @relatedimageheight = args[:relatedimageheight] if args.key?(:relatedimageheight)
          @relatedimagewidth = args[:relatedimagewidth] if args.key?(:relatedimagewidth)
          @relatedsoundfile = args[:relatedsoundfile] if args.key?(:relatedsoundfile)
          @relation = args[:relation] if args.key?(:relation)
          @releasedate = args[:releasedate] if args.key?(:releasedate)
          @releasetime = args[:releasetime] if args.key?(:releasetime)
          @resolutionunit = args[:resolutionunit] if args.key?(:resolutionunit)
          @rotate = args[:rotate] if args.key?(:rotate)
          @rowsperstrip = args[:rowsperstrip] if args.key?(:rowsperstrip)
          @samplesperpixel = args[:samplesperpixel] if args.key?(:samplesperpixel)
          @saturation = args[:saturation] if args.key?(:saturation)
          @scene = args[:scene] if args.key?(:scene)
          @scenecapturetype = args[:scenecapturetype] if args.key?(:scenecapturetype)
          @sensingmethod = args[:sensingmethod] if args.key?(:sensingmethod)
          @sensorheight = args[:sensorheight] if args.key?(:sensorheight)
          @sensorwidth = args[:sensorwidth] if args.key?(:sensorwidth)
          @serialnumber = args[:serialnumber] if args.key?(:serialnumber)
          @serviceidentifier = args[:serviceidentifier] if args.key?(:serviceidentifier)
          @sharpness = args[:sharpness] if args.key?(:sharpness)
          @shutterspeedvalue = args[:shutterspeedvalue] if args.key?(:shutterspeedvalue)
          @software = args[:software] if args.key?(:software)
          @source = args[:source] if args.key?(:source)
          @sourcephotoscount = args[:sourcephotoscount] if args.key?(:sourcephotoscount)
          @spectralsensitivity = args[:spectralsensitivity] if args.key?(:spectralsensitivity)
          @state = args[:state] if args.key?(:state)
          @stitchingsoftware = args[:stitchingsoftware] if args.key?(:stitchingsoftware)
          @stripbytecounts = args[:stripbytecounts] if args.key?(:stripbytecounts)
          @stripoffsets = args[:stripoffsets] if args.key?(:stripoffsets)
          @subjectarea = args[:subjectarea] if args.key?(:subjectarea)
          @subjectcode = args[:subjectcode] if args.key?(:subjectcode)
          @subjectdistancerange = args[:subjectdistancerange] if args.key?(:subjectdistancerange)
          @subjectlocation = args[:subjectlocation] if args.key?(:subjectlocation)
          @subjectreference = args[:subjectreference] if args.key?(:subjectreference)
          @sublocation = args[:sublocation] if args.key?(:sublocation)
          @subsectime = args[:subsectime] if args.key?(:subsectime)
          @subsectimedigitized = args[:subsectimedigitized] if args.key?(:subsectimedigitized)
          @subsectimeoriginal = args[:subsectimeoriginal] if args.key?(:subsectimeoriginal)
          @supplementalcategory = args[:supplementalcategory] if args.key?(:supplementalcategory)
          @thresholding = args[:thresholding] if args.key?(:thresholding)
          @thumbnailer_build_cl = args[:thumbnailer_build_cl] if args.key?(:thumbnailer_build_cl)
          @timesent = args[:timesent] if args.key?(:timesent)
          @timezoneminutes = args[:timezoneminutes] if args.key?(:timezoneminutes)
          @timezoneoffset = args[:timezoneoffset] if args.key?(:timezoneoffset)
          @title = args[:title] if args.key?(:title)
          @transmissionreference = args[:transmissionreference] if args.key?(:transmissionreference)
          @type = args[:type] if args.key?(:type)
          @uniqueid = args[:uniqueid] if args.key?(:uniqueid)
          @uno = args[:uno] if args.key?(:uno)
          @urgency = args[:urgency] if args.key?(:urgency)
          @url = args[:url] if args.key?(:url)
          @usageterms = args[:usageterms] if args.key?(:usageterms)
          @usepanoramaviewer = args[:usepanoramaviewer] if args.key?(:usepanoramaviewer)
          @version = args[:version] if args.key?(:version)
          @webstatement = args[:webstatement] if args.key?(:webstatement)
          @whitebalance = args[:whitebalance] if args.key?(:whitebalance)
          @whitepoint = args[:whitepoint] if args.key?(:whitepoint)
          @width = args[:width] if args.key?(:width)
          @xmp4c = args[:xmp4c] if args.key?(:xmp4c)
          @xresolution = args[:xresolution] if args.key?(:xresolution)
          @ycbcrcoefficients = args[:ycbcrcoefficients] if args.key?(:ycbcrcoefficients)
          @ycbcrpositioning = args[:ycbcrpositioning] if args.key?(:ycbcrpositioning)
          @ycbcrsubsampling = args[:ycbcrsubsampling] if args.key?(:ycbcrsubsampling)
          @yresolution = args[:yresolution] if args.key?(:yresolution)
        end
      end
      
      # 
      class PhotosPanoramaMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `sphericalPanorama`
        # @return [Boolean]
        attr_accessor :spherical_panorama
        alias_method :spherical_panorama?, :spherical_panorama
      
        # True if the image is a VR180 image. See go/3d180 for details.
        # Corresponds to the JSON property `vr180Panorama`
        # @return [Boolean]
        attr_accessor :vr180_panorama
        alias_method :vr180_panorama?, :vr180_panorama
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @spherical_panorama = args[:spherical_panorama] if args.key?(:spherical_panorama)
          @vr180_panorama = args[:vr180_panorama] if args.key?(:vr180_panorama)
        end
      end
      
      # Bounding box coordinates are relative to the width and height of the image.
      # For example, if image is 100x200 and NormalizedBoundingBox is , the bounding
      # box coordinates will be (10, 40) to (50, 180). Note parts of the bounding box
      # may fall outside the image.
      class PhotosVisionGroundtruthdbNormalizedBoundingBox
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `xmax`
        # @return [Float]
        attr_accessor :xmax
      
        # 
        # Corresponds to the JSON property `xmin`
        # @return [Float]
        attr_accessor :xmin
      
        # 
        # Corresponds to the JSON property `ymax`
        # @return [Float]
        attr_accessor :ymax
      
        # 
        # Corresponds to the JSON property `ymin`
        # @return [Float]
        attr_accessor :ymin
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @xmax = args[:xmax] if args.key?(:xmax)
          @xmin = args[:xmin] if args.key?(:xmin)
          @ymax = args[:ymax] if args.key?(:ymax)
          @ymin = args[:ymin] if args.key?(:ymin)
        end
      end
      
      # 
      class PhotosVisionObjectrecFeatureVector
        include Google::Apis::Core::Hashable
      
        # For single precision floating point data
        # Corresponds to the JSON property `floatData`
        # @return [Array<Float>]
        attr_accessor :float_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @float_data = args[:float_data] if args.key?(:float_data)
        end
      end
      
      # The geo-location of a single point, or of the "center" of a group of points.
      class PhotosVisionObjectrecGeoLocation
        include Google::Apis::Core::Hashable
      
        # Altitude of the point above the earth's surface, in meters.
        # Corresponds to the JSON property `altitudeMeters`
        # @return [Float]
        attr_accessor :altitude_meters
      
        # Country code string.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # Indicates if the lat/lon above is assumed to come from a GPS device.
        # Corresponds to the JSON property `fromGps`
        # @return [Boolean]
        attr_accessor :from_gps
        alias_method :from_gps?, :from_gps
      
        # Latitude in degrees north. Values south of the equator are negative.
        # Corresponds to the JSON property `lat`
        # @return [Float]
        attr_accessor :lat
      
        # When applied to a single point, represents the estimated error bounds of
        # manual geotagging. The estimate is based on size of the bounding box of the
        # map used for manual geotagging. When applied to a group of points, the error
        # bounds represent the dispersion around the group center (lat/lon above). The
        # dispersion in this case is computed as half the interquartile range. Reference:
        # http://en.wikipedia.org/wiki/Interquartile_range (lat +/- lat_error_bound,
        # lng +/- lng_error_bound).
        # Corresponds to the JSON property `latErrorBound`
        # @return [Float]
        attr_accessor :lat_error_bound
      
        # Longitude in degrees east. Values west of 0 deg are negative.
        # Corresponds to the JSON property `lon`
        # @return [Float]
        attr_accessor :lon
      
        # 
        # Corresponds to the JSON property `lonErrorBound`
        # @return [Float]
        attr_accessor :lon_error_bound
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @altitude_meters = args[:altitude_meters] if args.key?(:altitude_meters)
          @country_code = args[:country_code] if args.key?(:country_code)
          @from_gps = args[:from_gps] if args.key?(:from_gps)
          @lat = args[:lat] if args.key?(:lat)
          @lat_error_bound = args[:lat_error_bound] if args.key?(:lat_error_bound)
          @lon = args[:lon] if args.key?(:lon)
          @lon_error_bound = args[:lon_error_bound] if args.key?(:lon_error_bound)
        end
      end
      
      # Global feature for the image.
      class PhotosVisionObjectrecGlobalFeature
        include Google::Apis::Core::Hashable
      
        # Optional info provided by the feature extractor.
        # Corresponds to the JSON property `additionalInfo`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :additional_info
      
        # 
        # Corresponds to the JSON property `featureVector`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecFeatureVector]
        attr_accessor :feature_vector
      
        # Quantized/compressed feature vector (8 bit per value). Can be decoded by
        # multiplying data_factor to each data byte.
        # Corresponds to the JSON property `quantizedFeatureVector`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecQuantizedFeatureVector]
        attr_accessor :quantized_feature_vector
      
        # Tag for this global feature. E.g., "DELG", "SBv4" or "DELG_region1".
        # Corresponds to the JSON property `tag`
        # @return [String]
        attr_accessor :tag
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_info = args[:additional_info] if args.key?(:additional_info)
          @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
          @quantized_feature_vector = args[:quantized_feature_vector] if args.key?(:quantized_feature_vector)
          @tag = args[:tag] if args.key?(:tag)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # ImageTemplate contains local and/or global features generated from one image.
      # User-defined members can be set to any value within the constraints outlined
      # below. Algorithms usually pass these through without evaluation, unless
      # documented otherwise. Next id: 29
      class PhotosVisionObjectrecImageTemplate
        include Google::Apis::Core::Hashable
      
        # Name of the author or image source. User-defined. Must be NULL-terminated.
        # Corresponds to the JSON property `authorName`
        # @return [String]
        attr_accessor :author_name
      
        # Identifier for which corpus the image belongs to. Currently Cyclone uses this
        # field in: - photos_vision_objectrec.SpatialMatcherRequest.residual_template to
        # select which spatial matcher should be applied to the candidate matches -
        # photos_vision_objectrec.CustomCorpusQuantizer to map a custom corpus to one or
        # more posting lists
        # Corresponds to the JSON property `corpus`
        # @return [String]
        attr_accessor :corpus
      
        # The geo-location of a single point, or of the "center" of a group of points.
        # Corresponds to the JSON property `geoLocation`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecGeoLocation]
        attr_accessor :geo_location
      
        # 
        # Corresponds to the JSON property `globalFeature`
        # @return [Array<Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecGlobalFeature>]
        attr_accessor :global_feature
      
        # 
        # Corresponds to the JSON property `imageHeight`
        # @return [Fixnum]
        attr_accessor :image_height
      
        # Unique identifier for the image used to compute this template.
        # Corresponds to the JSON property `imageId`
        # @return [Fixnum]
        attr_accessor :image_id
      
        # URL or filename of the image used to compute this template. User-defined. Must
        # contain only ASCII characters and be NULL-terminated.
        # Corresponds to the JSON property `imageUrl`
        # @return [String]
        attr_accessor :image_url
      
        # Dimension of the image used to compute this template.
        # Corresponds to the JSON property `imageWidth`
        # @return [Fixnum]
        attr_accessor :image_width
      
        # 
        # Corresponds to the JSON property `info`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :info
      
        # Tags pertaining to this image. User-defined. Must be NULL-terminated.
        # Corresponds to the JSON property `objectInfo`
        # @return [Array<String>]
        attr_accessor :object_info
      
        # Name of the object/scene depicted. User-defined. Must contain only ASCII
        # characters and be NULL-terminated.
        # Corresponds to the JSON property `objectName`
        # @return [String]
        attr_accessor :object_name
      
        # Opaque template data. May be used to pass through additional data from
        # template sources to processing modules, that is not already covered by other
        # members of this PB. It is the responsibility of processing modules to verify
        # that the data is in a compatible format.
        # Corresponds to the JSON property `opaqueData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :opaque_data
      
        # A region of interest in the image.
        # Corresponds to the JSON property `roi`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecRoi]
        attr_accessor :roi
      
        # 
        # Corresponds to the JSON property `subset`
        # @return [Array<Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecImageTemplateSubSet>]
        attr_accessor :subset
      
        # Feature version.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @author_name = args[:author_name] if args.key?(:author_name)
          @corpus = args[:corpus] if args.key?(:corpus)
          @geo_location = args[:geo_location] if args.key?(:geo_location)
          @global_feature = args[:global_feature] if args.key?(:global_feature)
          @image_height = args[:image_height] if args.key?(:image_height)
          @image_id = args[:image_id] if args.key?(:image_id)
          @image_url = args[:image_url] if args.key?(:image_url)
          @image_width = args[:image_width] if args.key?(:image_width)
          @info = args[:info] if args.key?(:info)
          @object_info = args[:object_info] if args.key?(:object_info)
          @object_name = args[:object_name] if args.key?(:object_name)
          @opaque_data = args[:opaque_data] if args.key?(:opaque_data)
          @roi = args[:roi] if args.key?(:roi)
          @subset = args[:subset] if args.key?(:subset)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Each SubSet contains LocalDescriptors of a specific type. The type indicates
      # which algorithm has been used to generate the descriptors. No enum is defined
      # for the descriptor_type. For most applications it is sufficient to know if two
      # descriptors are of the same or a different type, while ignoring the details of
      # their generation. The descriptor type '0' is reserved and must not be used.
      class PhotosVisionObjectrecImageTemplateSubSet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `descriptor`
        # @return [Array<Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecLocalDescriptor>]
        attr_accessor :descriptor
      
        # 
        # Corresponds to the JSON property `descriptorType`
        # @return [Fixnum]
        attr_accessor :descriptor_type
      
        # Used to indicate if the descriptor is binary or not. When decompressing
        # feature this is useful to decide calling different decompression functions.
        # Corresponds to the JSON property `isBinaryDescriptor`
        # @return [Boolean]
        attr_accessor :is_binary_descriptor
        alias_method :is_binary_descriptor?, :is_binary_descriptor
      
        # Used to store the number of descriptors for statistical purposes, if the
        # descriptors themselves are not stored.
        # Corresponds to the JSON property `numDescriptors`
        # @return [Fixnum]
        attr_accessor :num_descriptors
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @descriptor = args[:descriptor] if args.key?(:descriptor)
          @descriptor_type = args[:descriptor_type] if args.key?(:descriptor_type)
          @is_binary_descriptor = args[:is_binary_descriptor] if args.key?(:is_binary_descriptor)
          @num_descriptors = args[:num_descriptors] if args.key?(:num_descriptors)
        end
      end
      
      # LocalDescriptor holds interest point data and an optional local descriptor
      # vector.
      class PhotosVisionObjectrecLocalDescriptor
        include Google::Apis::Core::Hashable
      
        # A 2x2 float matrix.
        # Corresponds to the JSON property `affineMatrix`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecMatrix2D]
        attr_accessor :affine_matrix
      
        # 
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # data_factor and data represent the local descriptor vector in a compressed
        # format, using only 8 bit per value. Each byte of the data string yields one
        # component of the local descriptor by bit-casting it to an int8 and multiplying
        # it by data_factor. Protocol buffers do not support int8 directly.
        # Corresponds to the JSON property `dataFactor`
        # @return [Float]
        attr_accessor :data_factor
      
        # Unquantized feature vector (float).
        # Corresponds to the JSON property `featureVector`
        # @return [Google::Apis::ContentwarehouseV1::PhotosVisionObjectrecFeatureVector]
        attr_accessor :feature_vector
      
        # Opaque descriptor data. May be used to pass through descriptor data from
        # descriptor sources to processing modules, that is not already covered by data/
        # data_factor and/or cannot be expressed as a vector of numbers. It is the
        # responsibility of processing modules to verify that the data is in a
        # compatible format.
        # Corresponds to the JSON property `opaqueData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :opaque_data
      
        # Orientation is optional, as some interest point detectors don't compute it.
        # The range of orientation is [-pi,pi).
        # Corresponds to the JSON property `orientation`
        # @return [Float]
        attr_accessor :orientation
      
        # Each interest point must have a characteristic scale > 0.
        # Corresponds to the JSON property `scale`
        # @return [Float]
        attr_accessor :scale
      
        # The strength or weight, indicating the relative significance of this point.
        # Corresponds to the JSON property `strength`
        # @return [Float]
        attr_accessor :strength
      
        # The position in the image with sub-pixel accuracy. The center of the upper
        # left pixel has coordinates (0.0, 0.0). Thus the range for x and y is (-0.5,
        # width - 0.5) x (-0.5, height - 0.5).
        # Corresponds to the JSON property `x`
        # @return [Float]
        attr_accessor :x
      
        # 
        # Corresponds to the JSON property `y`
        # @return [Float]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @affine_matrix = args[:affine_matrix] if args.key?(:affine_matrix)
          @data = args[:data] if args.key?(:data)
          @data_factor = args[:data_factor] if args.key?(:data_factor)
          @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
          @opaque_data = args[:opaque_data] if args.key?(:opaque_data)
          @orientation = args[:orientation] if args.key?(:orientation)
          @scale = args[:scale] if args.key?(:scale)
          @strength = args[:strength] if args.key?(:strength)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # A 2x2 float matrix.
      class PhotosVisionObjectrecMatrix2D
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `xx`
        # @return [Float]
        attr_accessor :xx
      
        # 
        # Corresponds to the JSON property `xy`
        # @return [Float]
        attr_accessor :xy
      
        # 
        # Corresponds to the JSON property `yx`
        # @return [Float]
        attr_accessor :yx
      
        # 
        # Corresponds to the JSON property `yy`
        # @return [Float]
        attr_accessor :yy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @xx = args[:xx] if args.key?(:xx)
          @xy = args[:xy] if args.key?(:xy)
          @yx = args[:yx] if args.key?(:yx)
          @yy = args[:yy] if args.key?(:yy)
        end
      end
      
      # Quantized/compressed feature vector (8 bit per value). Can be decoded by
      # multiplying data_factor to each data byte.
      class PhotosVisionObjectrecQuantizedFeatureVector
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # 
        # Corresponds to the JSON property `dataFactor`
        # @return [Float]
        attr_accessor :data_factor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @data_factor = args[:data_factor] if args.key?(:data_factor)
        end
      end
      
      # A region of interest in the image.
      class PhotosVisionObjectrecRoi
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `xMax`
        # @return [Fixnum]
        attr_accessor :x_max
      
        # 
        # Corresponds to the JSON property `xMin`
        # @return [Fixnum]
        attr_accessor :x_min
      
        # 
        # Corresponds to the JSON property `yMax`
        # @return [Fixnum]
        attr_accessor :y_max
      
        # 
        # Corresponds to the JSON property `yMin`
        # @return [Fixnum]
        attr_accessor :y_min
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x_max = args[:x_max] if args.key?(:x_max)
          @x_min = args[:x_min] if args.key?(:x_min)
          @y_max = args[:y_max] if args.key?(:y_max)
          @y_min = args[:y_min] if args.key?(:y_min)
        end
      end
      
      # A protocol buffer to store the url, referer and porn flag for a url. and an
      # optional image score. Next available tag id: 50.
      class PornFlagData
        include Google::Apis::Core::Hashable
      
        # Content score - computed on the image pixel data only. Additionally, we store
        # a version and minor version number of the model which was used to compute this
        # score. Note: these fields are copies of adaboost_image_feature_porn* in
        # ImageData.
        # Corresponds to the JSON property `adaboostContentScore`
        # @return [Float]
        attr_accessor :adaboost_content_score
      
        # 
        # Corresponds to the JSON property `adaboostContentScoreMinorVersion`
        # @return [Fixnum]
        attr_accessor :adaboost_content_score_minor_version
      
        # 
        # Corresponds to the JSON property `adaboostContentScoreVersion`
        # @return [Fixnum]
        attr_accessor :adaboost_content_score_version
      
        # Don't change the field names. The names are used as sparse feature labels in
        # client projects.
        # Corresponds to the JSON property `coclickBrainScores`
        # @return [Google::Apis::ContentwarehouseV1::ImageSafesearchContentBrainPornAnnotation]
        attr_accessor :coclick_brain_scores
      
        # Score predicting how likely an image is offensive or suggestive about CSAI (
        # child sexual abuse imagery).
        # Corresponds to the JSON property `csaiScore`
        # @return [Float]
        attr_accessor :csai_score
      
        # DebugInfo stores debug information from the overall classifier. This allows
        # for instance to update counters related to blacklisting without running the
        # full classifier again.
        # Corresponds to the JSON property `debugInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImagePornDebugInfo>]
        attr_accessor :debug_info
      
        # Final offensive score based on image salient terms and image OCR vulgar and
        # offensive scores.
        # Corresponds to the JSON property `finalOffensiveScore`
        # @return [Float]
        attr_accessor :final_offensive_score
      
        # Final violence score based on some image signals (brain pixel score, co-
        # clicked images violence score, navboost queries score, etc.).
        # Corresponds to the JSON property `finalViolenceScore`
        # @return [Float]
        attr_accessor :final_violence_score
      
        # A string that indicates the version of SafeSearch classifier used to compute
        # final_violence_score.
        # Corresponds to the JSON property `finalViolenceScoreVersion`
        # @return [String]
        attr_accessor :final_violence_score_version
      
        # 
        # Corresponds to the JSON property `imageEntitiesViolenceScore`
        # @return [Float]
        attr_accessor :image_entities_violence_score
      
        # PornStatsImage is repeated even though we use only a single version, to help
        # with rolling out new versions with miminum risk. Multiple versions should
        # exist only for a short window of time. Once the new version is rolled out, the
        # data for older versions should no longer be generated.
        # Corresponds to the JSON property `imageStats`
        # @return [Array<Google::Apis::ContentwarehouseV1::PornStatsImage>]
        attr_accessor :image_stats
      
        # largest face, scaled by 1000 This field is same as ImageData.largest_face_frac.
        # Corresponds to the JSON property `largestFaceFrac`
        # @return [Float]
        attr_accessor :largest_face_frac
      
        # 
        # Corresponds to the JSON property `largestFaceFraction`
        # @return [Fixnum]
        attr_accessor :largest_face_fraction
      
        # number of faces
        # Corresponds to the JSON property `numberFaces`
        # @return [Fixnum]
        attr_accessor :number_faces
      
        # Information about image OCR text. For details see image/safesearch/content/
        # public/ocr_annotation.proto.
        # Corresponds to the JSON property `ocrAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::ImageSafesearchContentOcrAnnotation]
        attr_accessor :ocr_annotation
      
        # Vulgar score of the text found by OCR in the image.
        # Corresponds to the JSON property `ocrVulgarScore`
        # @return [Float]
        attr_accessor :ocr_vulgar_score
      
        # QuimbyCongas-based detection of offensive symbols in the image (currently
        # swastika and Nazi yellow badge).
        # Corresponds to the JSON property `offensiveSymbolDetection`
        # @return [Google::Apis::ContentwarehouseV1::ImageSafesearchContentOffensiveSymbolDetection]
        attr_accessor :offensive_symbol_detection
      
        # Overall porn score that determines the porn restricts used during image search
        # retrieval.
        # Corresponds to the JSON property `overallPornScore`
        # @return [Float]
        attr_accessor :overall_porn_score
      
        # Binary version of the PhotoDNA hash (144 bytes long). If not set (
        # has_photodna_hash() == false) it means that it was not computed, if empty (
        # has_photodna_hash() == true && photodna_hash() == "") it means that the
        # computation failed (cannot be computed for images smaller than 50 x 50).
        # Corresponds to the JSON property `photodnaHash`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :photodna_hash
      
        # This field is set to true when we are pretty confident that the image is porn (
        # with higher precision than the img_porn_moderate restrict). In particular, it
        # means that the image might be demoted for non-porn queries when SafeSearch is
        # Off.
        # Corresponds to the JSON property `pornWithHighConfidence`
        # @return [Boolean]
        attr_accessor :porn_with_high_confidence
        alias_method :porn_with_high_confidence?, :porn_with_high_confidence
      
        # OR of the prop_porn_flag and prop_softporn_flag.
        # Corresponds to the JSON property `propAnyPornFlag`
        # @return [Boolean]
        attr_accessor :prop_any_porn_flag
        alias_method :prop_any_porn_flag?, :prop_any_porn_flag
      
        # Text classifier properties for the referrer page.
        # Corresponds to the JSON property `propPornFlag`
        # @return [Boolean]
        attr_accessor :prop_porn_flag
        alias_method :prop_porn_flag?, :prop_porn_flag
      
        # 
        # Corresponds to the JSON property `propSoftpornFlag`
        # @return [Boolean]
        attr_accessor :prop_softporn_flag
        alias_method :prop_softporn_flag?, :prop_softporn_flag
      
        # QBST-based image offensive score, Navboost based
        # Corresponds to the JSON property `qbstOffensiveScore`
        # @return [Float]
        attr_accessor :qbst_offensive_score
      
        # QBST-based image spoof score, Navboost based, unrelated to the pixel-based
        # score in PornAnnotation.
        # Corresponds to the JSON property `qbstSpoofScore`
        # @return [Float]
        attr_accessor :qbst_spoof_score
      
        # QuerySats contains the information about the queries that users typed to
        # search for this image.
        # Corresponds to the JSON property `queryStats`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryStats]
        attr_accessor :query_stats
      
        # Aggregated navboost query violence score.
        # Corresponds to the JSON property `queryTextViolenceScore`
        # @return [Float]
        attr_accessor :query_text_violence_score
      
        # url of the referer page
        # Corresponds to the JSON property `referer`
        # @return [String]
        attr_accessor :referer
      
        # ReferrerCounts stores how many referrers an images has and how many of them
        # were classified as porn and as adult/softporn respectively. Note that a
        # referrer is usually a landing page, but as of March 2011 this also includes
        # referrers which an image can 'inherit' by propagating counts from near
        # duplicate images.
        # Corresponds to the JSON property `referrerCounts`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornReferrerCounts]
        attr_accessor :referrer_counts
      
        # Starburst-based score predicting sexualization level of the image.
        # Corresponds to the JSON property `semanticSexualizationScore`
        # @return [Float]
        attr_accessor :semantic_sexualization_score
      
        # Additional SafeSearch signals that are used to compute final scores.
        # Corresponds to the JSON property `starburstPornScore`
        # @return [Float]
        attr_accessor :starburst_porn_score
      
        # 
        # Corresponds to the JSON property `starburstViolenceScore`
        # @return [Float]
        attr_accessor :starburst_violence_score
      
        # PornStatsText is repeated even though we use only a single version, to help
        # with rolling out new versions with miminum risk. Multiple versions should
        # exist only for a short window of time. Once the new version is rolled out, the
        # data for older versions should no longer be generated.
        # Corresponds to the JSON property `textStats`
        # @return [Array<Google::Apis::ContentwarehouseV1::PornStatsText>]
        attr_accessor :text_stats
      
        # url of the image
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Per-URL porn scores for the URLs associated with the corresponding image.
        # Corresponds to the JSON property `urlPornScores`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornAggregatedUrlPornScores]
        attr_accessor :url_porn_scores
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @adaboost_content_score = args[:adaboost_content_score] if args.key?(:adaboost_content_score)
          @adaboost_content_score_minor_version = args[:adaboost_content_score_minor_version] if args.key?(:adaboost_content_score_minor_version)
          @adaboost_content_score_version = args[:adaboost_content_score_version] if args.key?(:adaboost_content_score_version)
          @coclick_brain_scores = args[:coclick_brain_scores] if args.key?(:coclick_brain_scores)
          @csai_score = args[:csai_score] if args.key?(:csai_score)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @final_offensive_score = args[:final_offensive_score] if args.key?(:final_offensive_score)
          @final_violence_score = args[:final_violence_score] if args.key?(:final_violence_score)
          @final_violence_score_version = args[:final_violence_score_version] if args.key?(:final_violence_score_version)
          @image_entities_violence_score = args[:image_entities_violence_score] if args.key?(:image_entities_violence_score)
          @image_stats = args[:image_stats] if args.key?(:image_stats)
          @largest_face_frac = args[:largest_face_frac] if args.key?(:largest_face_frac)
          @largest_face_fraction = args[:largest_face_fraction] if args.key?(:largest_face_fraction)
          @number_faces = args[:number_faces] if args.key?(:number_faces)
          @ocr_annotation = args[:ocr_annotation] if args.key?(:ocr_annotation)
          @ocr_vulgar_score = args[:ocr_vulgar_score] if args.key?(:ocr_vulgar_score)
          @offensive_symbol_detection = args[:offensive_symbol_detection] if args.key?(:offensive_symbol_detection)
          @overall_porn_score = args[:overall_porn_score] if args.key?(:overall_porn_score)
          @photodna_hash = args[:photodna_hash] if args.key?(:photodna_hash)
          @porn_with_high_confidence = args[:porn_with_high_confidence] if args.key?(:porn_with_high_confidence)
          @prop_any_porn_flag = args[:prop_any_porn_flag] if args.key?(:prop_any_porn_flag)
          @prop_porn_flag = args[:prop_porn_flag] if args.key?(:prop_porn_flag)
          @prop_softporn_flag = args[:prop_softporn_flag] if args.key?(:prop_softporn_flag)
          @qbst_offensive_score = args[:qbst_offensive_score] if args.key?(:qbst_offensive_score)
          @qbst_spoof_score = args[:qbst_spoof_score] if args.key?(:qbst_spoof_score)
          @query_stats = args[:query_stats] if args.key?(:query_stats)
          @query_text_violence_score = args[:query_text_violence_score] if args.key?(:query_text_violence_score)
          @referer = args[:referer] if args.key?(:referer)
          @referrer_counts = args[:referrer_counts] if args.key?(:referrer_counts)
          @semantic_sexualization_score = args[:semantic_sexualization_score] if args.key?(:semantic_sexualization_score)
          @starburst_porn_score = args[:starburst_porn_score] if args.key?(:starburst_porn_score)
          @starburst_violence_score = args[:starburst_violence_score] if args.key?(:starburst_violence_score)
          @text_stats = args[:text_stats] if args.key?(:text_stats)
          @url = args[:url] if args.key?(:url)
          @url_porn_scores = args[:url_porn_scores] if args.key?(:url_porn_scores)
        end
      end
      
      # Site aggregated image content signals are captured in this protocol buffer.
      # This is versioned. Not all fields are present in each version. It is important
      # to document all the fields that are used in each version here.
      class PornStatsImage
        include Google::Apis::Core::Hashable
      
        # image content score data
        # Corresponds to the JSON property `imageCount`
        # @return [Fixnum]
        attr_accessor :image_count
      
        # 
        # Corresponds to the JSON property `siteKey`
        # @return [String]
        attr_accessor :site_key
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_count = args[:image_count] if args.key?(:image_count)
          @site_key = args[:site_key] if args.key?(:site_key)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Site aggregated text signals are captured in this protocol buffer. This is
      # versioned. Not all fields are present in each version. It is important to
      # document all the fields that are used in each version here.
      class PornStatsText
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anyPornPageCount`
        # @return [Fixnum]
        attr_accessor :any_porn_page_count
      
        # 
        # Corresponds to the JSON property `pageCount`
        # @return [Fixnum]
        attr_accessor :page_count
      
        # 
        # Corresponds to the JSON property `siteKey`
        # @return [String]
        attr_accessor :site_key
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @any_porn_page_count = args[:any_porn_page_count] if args.key?(:any_porn_page_count)
          @page_count = args[:page_count] if args.key?(:page_count)
          @site_key = args[:site_key] if args.key?(:site_key)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Next free ID: 32
      class PostalAddress
        include Google::Apis::Core::Hashable
      
        # These correspond to the "AddressLine" elements in xAL, which are used to hold
        # unstructured text. This is an addendum to the structured values; when the
        # address is formatted, the provided lines are prepended to the formatted
        # version of the street component fields for Western countries, and appended for
        # CJK countries. These lines are in display order. Formerly users of
        # PostalAddress were discouraged from mixing address_line with structured
        # address elements. Mixing is now encouraged if address_line has to be used at
        # all.
        # Corresponds to the JSON property `addressLine`
        # @return [Array<String>]
        attr_accessor :address_line
      
        # Top-level administrative subdivision of this country. Examples: US state, IT
        # region, UK constituent nation, JP prefecture.
        # Corresponds to the JSON property `administrativeAreaName`
        # @return [String]
        attr_accessor :administrative_area_name
      
        # Name corresponding to country code. Optional. This can usually be inferred
        # from country_name_code.
        # Corresponds to the JSON property `countryName`
        # @return [String]
        attr_accessor :country_name
      
        # xAL does not specify a scheme for country codes. We strongly recommend ISO
        # 3166-1-alpha-2 (two letter codes, as used in DNS) if you use this field. (Use "
        # GB", not "UK".)
        # Corresponds to the JSON property `countryNameCode`
        # @return [String]
        attr_accessor :country_name_code
      
        # Dependent locality or sublocality. Used for UK dependent localities, or
        # neighborhoods or boroughs in other locations. If trying to represent a UK
        # double-dependent locality, include both the double-dependent locality and the
        # dependent locality in this field, e.g. "Whaley, Langwith".
        # Corresponds to the JSON property `dependentLocalityName`
        # @return [String]
        attr_accessor :dependent_locality_name
      
        # Dependent thoroughfares are used to define UK-style dependent thoroughfares,
        # and secondary streets in addresses in other locales, including intersections.
        # Formatting is locale-dependent.
        # Corresponds to the JSON property `dependentThoroughfareName`
        # @return [String]
        attr_accessor :dependent_thoroughfare_name
      
        # NEW: The firm or organization. This goes at a finer granularity than
        # address_lines in the address. Omit if not needed.
        # Corresponds to the JSON property `firmName`
        # @return [String]
        attr_accessor :firm_name
      
        # Required to support the suppression of country names from formatted results
        # for addresses within geo-politically disputed areas. Note that we cannot
        # achieve this by not setting the country, as this would prevent us from
        # selecting a suitable formatting template. Addresses converted from Oyster, by
        # the standard conversion libraries, will have this field set if the address
        # lies within a geo-politically disputed area (ie, contained within features of
        # type TYPE_DISPUTED_AREA) even if the disputed area itself is not a visible
        # part of the formatted address. An example of a disputed area is "No Man's Land"
        # near Jerusalem which has the flag FLAG_NEVER_DISPLAY set for all its names.
        # See: go/disputed-areas-2014 for more information.
        # Corresponds to the JSON property `isDisputed`
        # @return [Boolean]
        attr_accessor :is_disputed
        alias_method :is_disputed?, :is_disputed
      
        # Language of the address. May affect address formatting for multi- lingual
        # countries. Also allows storing multilingual location names as repeated
        # PostalAddress. Not in xAL. Use language codes which are accepted by
        # i18n_identifiers::LanguageCodeCoverter::FromOther(). Examples include "en" and
        # "de-CH".
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # Locality. This is something of a fuzzy term, but it generally refers to the
        # city/town portion of an address. In regions of the world where localities are
        # not well defined or do not fit into this structure well (for example, Japan),
        # leave locality_name empty and use address_line. Examples: US city, IT comune,
        # UK post town.
        # Corresponds to the JSON property `localityName`
        # @return [String]
        attr_accessor :locality_name
      
        # This corresponds to PostBoxNumber in xAL format. In xAL format, it's nested
        # inside PostBox, which also contains a "Type" field to distinguish between PO
        # Box, Private Bag etc. Current support in this proto is for PO Box only. Note
        # that although this is modelled as a string, it should have the number only,
        # with any necessary punctuation (such as "-"). For example, for "P.O. Box 123",
        # this field would hold "123" - the template displaying this would prepend P.O.
        # Box when formatting if necessary.
        # Corresponds to the JSON property `postBoxNumber`
        # @return [String]
        attr_accessor :post_box_number
      
        # Despite the name, postal_code_number values are frequently alphanumeric.
        # Examples: "94043", "SW1W", "SW1W 9TQ".
        # Corresponds to the JSON property `postalCodeNumber`
        # @return [String]
        attr_accessor :postal_code_number
      
        # Used for postal-code suffixes, such as the 4-digit extension of a US ZIP+4
        # code.
        # Corresponds to the JSON property `postalCodeNumberExtension`
        # @return [String]
        attr_accessor :postal_code_number_extension
      
        # The "premise" is something like a house or building.
        # Corresponds to the JSON property `premiseName`
        # @return [String]
        attr_accessor :premise_name
      
        # NEW: The recipient. This goes at a finer granularity than address_lines in the
        # address. Not present in xAL. Omit if not needed.
        # Corresponds to the JSON property `recipientName`
        # @return [String]
        attr_accessor :recipient_name
      
        # This corresponds to the SortingCode sub-element of the xAL
        # PostalServiceElements element. Use is very country-specific. Where it is used,
        # the value is either a string like "CEDEX", optionally followed by a number (e.
        # g. "CEDEX 7"), or just a number alone, representing the "sector code" (Jamaica)
        # , "delivery area indicator" (Malawi) or "post office indicator" (e.g. Côte d'
        # Ivoire).
        # Corresponds to the JSON property `sortingCode`
        # @return [String]
        attr_accessor :sorting_code
      
        # Second-level administrative subdivision of this country. Examples: US county,
        # IT province, UK county.
        # Corresponds to the JSON property `subAdministrativeAreaName`
        # @return [String]
        attr_accessor :sub_administrative_area_name
      
        # The "subpremise" is something like an apartment or suite. xAL offers more
        # structured premise and subpremise values, but we don't.
        # Corresponds to the JSON property `subPremiseName`
        # @return [String]
        attr_accessor :sub_premise_name
      
        # Name of thoroughfare. Intersections should be represented with this field or
        # address_line. Examples: "Amphitheatre Parkway", "N Shoreline Blvd & Charleston
        # Rd"
        # Corresponds to the JSON property `thoroughfareName`
        # @return [String]
        attr_accessor :thoroughfare_name
      
        # Thoroughfare numbers (street numbers) can be very complex indeed. xAL defines
        # fancy structures like "ThoroughfareNumberRange" to represent the details, but
        # we haven't included that yet. It is worth noting that this needs to be a
        # string, not a number. Example: "1600"
        # Corresponds to the JSON property `thoroughfareNumber`
        # @return [String]
        attr_accessor :thoroughfare_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address_line = args[:address_line] if args.key?(:address_line)
          @administrative_area_name = args[:administrative_area_name] if args.key?(:administrative_area_name)
          @country_name = args[:country_name] if args.key?(:country_name)
          @country_name_code = args[:country_name_code] if args.key?(:country_name_code)
          @dependent_locality_name = args[:dependent_locality_name] if args.key?(:dependent_locality_name)
          @dependent_thoroughfare_name = args[:dependent_thoroughfare_name] if args.key?(:dependent_thoroughfare_name)
          @firm_name = args[:firm_name] if args.key?(:firm_name)
          @is_disputed = args[:is_disputed] if args.key?(:is_disputed)
          @language_code = args[:language_code] if args.key?(:language_code)
          @locality_name = args[:locality_name] if args.key?(:locality_name)
          @post_box_number = args[:post_box_number] if args.key?(:post_box_number)
          @postal_code_number = args[:postal_code_number] if args.key?(:postal_code_number)
          @postal_code_number_extension = args[:postal_code_number_extension] if args.key?(:postal_code_number_extension)
          @premise_name = args[:premise_name] if args.key?(:premise_name)
          @recipient_name = args[:recipient_name] if args.key?(:recipient_name)
          @sorting_code = args[:sorting_code] if args.key?(:sorting_code)
          @sub_administrative_area_name = args[:sub_administrative_area_name] if args.key?(:sub_administrative_area_name)
          @sub_premise_name = args[:sub_premise_name] if args.key?(:sub_premise_name)
          @thoroughfare_name = args[:thoroughfare_name] if args.key?(:thoroughfare_name)
          @thoroughfare_number = args[:thoroughfare_number] if args.key?(:thoroughfare_number)
        end
      end
      
      # The restricts that are computed before building a Mustang index.
      class PrecomputedRestricts
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `restricts`
        # @return [Array<String>]
        attr_accessor :restricts
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @restricts = args[:restricts] if args.key?(:restricts)
        end
      end
      
      # Per-doc data for premium documents in the Google index.
      class PremiumPerDocData
        include Google::Apis::Core::Hashable
      
        # type froogle/currency/currency.h
        # Corresponds to the JSON property `Currency`
        # @return [Fixnum]
        attr_accessor :currency
      
        # publishing date (seconds since 1970,
        # Corresponds to the JSON property `Date`
        # @return [Fixnum]
        attr_accessor :date
      
        # entitlement data
        # Corresponds to the JSON property `Entitlement`
        # @return [Array<Fixnum>]
        attr_accessor :entitlement
      
        # True if a free document is archival in nature.
        # Corresponds to the JSON property `IsArchival`
        # @return [Boolean]
        attr_accessor :is_archival
        alias_method :is_archival?, :is_archival
      
        # User is entitled to see the premium content for free.
        # Corresponds to the JSON property `IsEntitled`
        # @return [Boolean]
        attr_accessor :is_entitled
        alias_method :is_entitled?, :is_entitled
      
        # price * 100 if available
        # Corresponds to the JSON property `Price`
        # @return [Fixnum]
        attr_accessor :price
      
        # negative values for prior dates) FP of the Premium publication name
        # Corresponds to the JSON property `Publication`
        # @return [Fixnum]
        attr_accessor :publication
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @currency = args[:currency] if args.key?(:currency)
          @date = args[:date] if args.key?(:date)
          @entitlement = args[:entitlement] if args.key?(:entitlement)
          @is_archival = args[:is_archival] if args.key?(:is_archival)
          @is_entitled = args[:is_entitled] if args.key?(:is_entitled)
          @price = args[:price] if args.key?(:price)
          @publication = args[:publication] if args.key?(:publication)
        end
      end
      
      # This is proto2's version of MessageSet.
      class Proto2BridgeMessageSet
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Available tags: 14+
      class PseudoVideoData
        include Google::Apis::Core::Hashable
      
        # ASR model MPM version.
        # Corresponds to the JSON property `AsrModel`
        # @return [String]
        attr_accessor :asr_model
      
        # This should be the MustangDocId, we need to figure out how to generate a
        # uint64 given the int64 we have in data_set
        # Corresponds to the JSON property `DocKey`
        # @return [Fixnum]
        attr_accessor :doc_key
      
        # Language of the recognizer used to generate transcript.
        # Corresponds to the JSON property `Lang`
        # @return [String]
        attr_accessor :lang
      
        # This is the videodocid associate to the http://video.google.com/videoplay?
        # docid= NUMBER
        # Corresponds to the JSON property `MustangDocId`
        # @return [String]
        attr_accessor :mustang_doc_id
      
        # URL for document.
        # Corresponds to the JSON property `Url`
        # @return [String]
        attr_accessor :url
      
        # 
        # Corresponds to the JSON property `s3Mode`
        # @return [String]
        attr_accessor :s3_mode
      
        # S3 ASR model info.
        # Corresponds to the JSON property `s3ModelInfoLabel`
        # @return [String]
        attr_accessor :s3_model_info_label
      
        # A time-coded transcription of the document's audio track.
        # Corresponds to the JSON property `transcript`
        # @return [Google::Apis::ContentwarehouseV1::PseudoVideoDataTranscript]
        attr_accessor :transcript
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_model = args[:asr_model] if args.key?(:asr_model)
          @doc_key = args[:doc_key] if args.key?(:doc_key)
          @lang = args[:lang] if args.key?(:lang)
          @mustang_doc_id = args[:mustang_doc_id] if args.key?(:mustang_doc_id)
          @url = args[:url] if args.key?(:url)
          @s3_mode = args[:s3_mode] if args.key?(:s3_mode)
          @s3_model_info_label = args[:s3_model_info_label] if args.key?(:s3_model_info_label)
          @transcript = args[:transcript] if args.key?(:transcript)
        end
      end
      
      # A time-coded transcription of the document's audio track.
      class PseudoVideoDataTranscript
        include Google::Apis::Core::Hashable
      
        # The complete transcription text.
        # Corresponds to the JSON property `Text`
        # @return [String]
        attr_accessor :text
      
        # 
        # Corresponds to the JSON property `timestamp`
        # @return [Array<Google::Apis::ContentwarehouseV1::PseudoVideoDataTranscriptTimestamp>]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text = args[:text] if args.key?(:text)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # Mapping of time/character correspondences. Used to map found snippets to the
      # time and thumbnail nearest that snippet.
      class PseudoVideoDataTranscriptTimestamp
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `CharOffset`
        # @return [Fixnum]
        attr_accessor :char_offset
      
        # quantized to values in range 0-127
        # Corresponds to the JSON property `Confidence`
        # @return [Fixnum]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `TimeOffset`
        # @return [Fixnum]
        attr_accessor :time_offset
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @char_offset = args[:char_offset] if args.key?(:char_offset)
          @confidence = args[:confidence] if args.key?(:confidence)
          @time_offset = args[:time_offset] if args.key?(:time_offset)
        end
      end
      
      # PToken expresses policy-relevant properties of the data objects being
      # processed and stored in Google's production systems. See go/ptoken to learn
      # more. Next ID: 8
      class PtokenPToken
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `compoundPtokenData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :compound_ptoken_data
      
        # 
        # Corresponds to the JSON property `ptokenData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ptoken_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compound_ptoken_data = args[:compound_ptoken_data] if args.key?(:compound_ptoken_data)
          @ptoken_data = args[:ptoken_data] if args.key?(:ptoken_data)
        end
      end
      
      # Information of the app to be annotated for the query. It contains the name of
      # the app, the package name associated with it. It also contains the confidence
      # associated with `app, package` pair. This confidence is calculated from
      # different signals like navboost, ranking etc. which later is used for ranking
      # the apps for a particular query. The source of this app information is also
      # indicated. This app info can either be from installed app (collected from
      # device content) or from the fastmap. LINT.IfChange
      class QualityActionsAppInfo
        include Google::Apis::Core::Hashable
      
        # The list of android intents that the app is capable of executing.
        # Corresponds to the JSON property `androidIntent`
        # @return [Array<String>]
        attr_accessor :android_intent
      
        # This is the string matched from the query.
        # Corresponds to the JSON property `appName`
        # @return [String]
        attr_accessor :app_name
      
        # Category that this app falls into.
        # Corresponds to the JSON property `category`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsAppUnderstandingCategory]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # This is the display name of the app as shown below the app icon.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # URL for the website associated with this app.
        # Corresponds to the JSON property `fallbackUrl`
        # @return [String]
        attr_accessor :fallback_url
      
        # Note that the package_name could be empty for two reasons: - The AppInfo is
        # annotated by device content. - The ngram exists in app name fastmap, but there
        # are a lot of packages associated with it. e.g., there could be a lot of apps
        # for app name "recipes app".
        # Corresponds to the JSON property `packageName`
        # @return [String]
        attr_accessor :package_name
      
        # For the future source, use the field in source_data.source().
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `sourceData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityActionsAppInfoSourceData>]
        attr_accessor :source_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_intent = args[:android_intent] if args.key?(:android_intent)
          @app_name = args[:app_name] if args.key?(:app_name)
          @category = args[:category] if args.key?(:category)
          @confidence = args[:confidence] if args.key?(:confidence)
          @display_name = args[:display_name] if args.key?(:display_name)
          @fallback_url = args[:fallback_url] if args.key?(:fallback_url)
          @package_name = args[:package_name] if args.key?(:package_name)
          @source = args[:source] if args.key?(:source)
          @source_data = args[:source_data] if args.key?(:source_data)
        end
      end
      
      # This deprecates the above: * confidence=3 * source=4 This allows us to merge
      # AppInfo data per package_name.
      class QualityActionsAppInfoSourceData
        include Google::Apis::Core::Hashable
      
        # Additional signals when the source is ATV's allow list.
        # Corresponds to the JSON property `allowListSourceData`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsAppInfoSourceDataAllowListSourceData]
        attr_accessor :allow_list_source_data
      
        # Confidence from navboost.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Number of installs from marmot.
        # Corresponds to the JSON property `install`
        # @return [Fixnum]
        attr_accessor :install
      
        # 
        # Corresponds to the JSON property `isCategorical`
        # @return [Boolean]
        attr_accessor :is_categorical
        alias_method :is_categorical?, :is_categorical
      
        # The MEDIA_PROVIDER source can further specify information about the content
        # served by the app.
        # Corresponds to the JSON property `mediaProviderSourceData`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsAppInfoSourceDataMediaProviderSourceData]
        attr_accessor :media_provider_source_data
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # Signals present when the source is TELEPORT.
        # Corresponds to the JSON property `teleportSourceData`
        # @return [Google::Apis::ContentwarehouseV1::AssistantTeleportTeleportNicknameSignals]
        attr_accessor :teleport_source_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_list_source_data = args[:allow_list_source_data] if args.key?(:allow_list_source_data)
          @confidence = args[:confidence] if args.key?(:confidence)
          @install = args[:install] if args.key?(:install)
          @is_categorical = args[:is_categorical] if args.key?(:is_categorical)
          @media_provider_source_data = args[:media_provider_source_data] if args.key?(:media_provider_source_data)
          @source = args[:source] if args.key?(:source)
          @teleport_source_data = args[:teleport_source_data] if args.key?(:teleport_source_data)
        end
      end
      
      # Additional signals when the source is ATV's allow list.
      class QualityActionsAppInfoSourceDataAllowListSourceData
        include Google::Apis::Core::Hashable
      
        # Whether the app is in the pre-release stage and only available for testing.
        # Corresponds to the JSON property `preReleaseMode`
        # @return [Boolean]
        attr_accessor :pre_release_mode
        alias_method :pre_release_mode?, :pre_release_mode
      
        # Whether app compatibility is unknown. This field is needed for apps like apple
        # tv that have different package names on different devices. Play Gateway
        # Service (PGS) lookup is needed to validate that the app is available on the
        # user's device. go/app-fulfillment-quality
        # Corresponds to the JSON property `unknownAppDeviceCompatibility`
        # @return [Boolean]
        attr_accessor :unknown_app_device_compatibility
        alias_method :unknown_app_device_compatibility?, :unknown_app_device_compatibility
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pre_release_mode = args[:pre_release_mode] if args.key?(:pre_release_mode)
          @unknown_app_device_compatibility = args[:unknown_app_device_compatibility] if args.key?(:unknown_app_device_compatibility)
        end
      end
      
      # The MEDIA_PROVIDER source can further specify information about the content
      # served by the app.
      class QualityActionsAppInfoSourceDataMediaProviderSourceData
        include Google::Apis::Core::Hashable
      
        # The unique provider key/enumeration string as used in KG. See also /base/
        # mediaasset/provider/provider_enumerator.
        # Corresponds to the JSON property `providerKey`
        # @return [String]
        attr_accessor :provider_key
      
        # The type of content served by the App. See also chrome.dongle.pints.
        # ProviderType.
        # Corresponds to the JSON property `providerType`
        # @return [String]
        attr_accessor :provider_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provider_key = args[:provider_key] if args.key?(:provider_key)
          @provider_type = args[:provider_type] if args.key?(:provider_type)
        end
      end
      
      # Category that this app falls into.
      class QualityActionsAppUnderstandingCategory
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @confidence = args[:confidence] if args.key?(:confidence)
        end
      end
      
      # 
      class QualityActionsCustomizedNotification
        include Google::Apis::Core::Hashable
      
        # Buttons on the notification
        # Corresponds to the JSON property `buttons`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityActionsCustomizedNotificationButton>]
        attr_accessor :buttons
      
        # Surface type for the notification
        # Corresponds to the JSON property `surfaceType`
        # @return [String]
        attr_accessor :surface_type
      
        # Tap action on the notification body. This overwrites the default tap action on
        # reminder trigger notification (which on mobile, is the reminders hub page).
        # Corresponds to the JSON property `tapAction`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsCustomizedNotificationPayload]
        attr_accessor :tap_action
      
        # Notification text
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @buttons = args[:buttons] if args.key?(:buttons)
          @surface_type = args[:surface_type] if args.key?(:surface_type)
          @tap_action = args[:tap_action] if args.key?(:tap_action)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # 
      class QualityActionsCustomizedNotificationButton
        include Google::Apis::Core::Hashable
      
        # REQUIRED. text for the button label
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # REQUIRED. tap action for the button
        # Corresponds to the JSON property `tapAction`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsCustomizedNotificationPayload]
        attr_accessor :tap_action
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
          @tap_action = args[:tap_action] if args.key?(:tap_action)
        end
      end
      
      # 
      class QualityActionsCustomizedNotificationPayload
        include Google::Apis::Core::Hashable
      
        # Currently for payload we only support raw string url. More structured options
        # may be added in the future
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Aqua annotation data for news provider. This proto is added as an extension to
      # NimbleAnnotationData.semantics_proto for nimble annotation.
      class QualityActionsNewsProviderAnnotationData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `providers`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityActionsNewsProviderAnnotationDataProvider>]
        attr_accessor :providers
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @providers = args[:providers] if args.key?(:providers)
        end
      end
      
      # NextId: 6
      class QualityActionsNewsProviderAnnotationDataProvider
        include Google::Apis::Core::Hashable
      
        # List of supported locales for this provider. Must follow the format from go/
        # iii, e.g.: 'en', 'en-US', 'en-GB', etc. Short forms without regions codes,
        # such as, 'en' match all possible regions: en-US, en-GB, en-IN, etc.
        # Corresponds to the JSON property `locales`
        # @return [Array<String>]
        attr_accessor :locales
      
        # The official name of the provider. Used in TTS and should be localized.
        # Corresponds to the JSON property `officialName`
        # @return [String]
        attr_accessor :official_name
      
        # TTS hint for the pronunciation of the name. Should be left blank unless TTS
        # performs poorly on official_name. Example: Without hinting, TTS mispronounces "
        # The Daily 202" as "the daily two hundred and two". Feeding tts the string "the
        # daily two oh two" produces correct TTS.
        # Corresponds to the JSON property `officialNamePronunciation`
        # @return [String]
        attr_accessor :official_name_pronunciation
      
        # The provider id used for news source URL lookup in Kansas. See b/27250779 for
        # details.
        # Corresponds to the JSON property `providerId`
        # @return [Fixnum]
        attr_accessor :provider_id
      
        # A score of how confident the annotated span is a news provider. For example, a
        # high score is assigned for span "bbc news", but a low score for span "bbc",
        # which only triggers narrative news aqua parse for a query with explicit news
        # intent, e.g [play news from bbc].
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locales = args[:locales] if args.key?(:locales)
          @official_name = args[:official_name] if args.key?(:official_name)
          @official_name_pronunciation = args[:official_name_pronunciation] if args.key?(:official_name_pronunciation)
          @provider_id = args[:provider_id] if args.key?(:provider_id)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Next id: 30
      class QualityActionsReminder
        include Google::Apis::Core::Hashable
      
        # OPTIONAL. True if the reminder is archived. Not present implies false.
        # Corresponds to the JSON property `archived`
        # @return [Boolean]
        attr_accessor :archived
        alias_method :archived?, :archived
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `archivedTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :archived_time
      
        # OPTIONAL. When the reminder was completed (only present when archived == true).
        # Maps to apps_intelligence.dialog.Task's complete_time field.
        # Corresponds to the JSON property `archivedTimestamp`
        # @return [String]
        attr_accessor :archived_timestamp
      
        # REQUIRED. async_interaction_type of the reminder trigger notification
        # Corresponds to the JSON property `asyncInteractionType`
        # @return [String]
        attr_accessor :async_interaction_type
      
        # OPTIONAL. Attachments associated with this Reminder. If the attachment has
        # different behavior on different surfaces (e.g., deeplinks), specify multiple
        # attachments here, and specify the surface types and links in the inner fields.
        # There should be at most one attachment for each surface.
        # Corresponds to the JSON property `attachment`
        # @return [Array<Google::Apis::ContentwarehouseV1::AssistantRemindersAttachment>]
        attr_accessor :attachment
      
        # OPTIONAL. Populated only for assignable reminders (E.g. "buy milk"). It will
        # be used in the post-execution card-rendering. If not poulated, i.e. in non-
        # assignable mode, caller should fallback to use $title.
        # Corresponds to the JSON property `bareTitle`
        # @return [String]
        attr_accessor :bare_title
      
        # OPTIONAL. The reminders "client" id. This ID uniquely identifies a reminder
        # instance and may be generated by any client that writes to our Reminder
        # backend.
        # Corresponds to the JSON property `clientId`
        # @return [String]
        attr_accessor :client_id
      
        # Define Reminder Client Type. This field is for the purposes of 1) UX
        # Customization: Reminder frontends can be configured to have a slightly
        # different UX (e.g., A customized button on Hubpage. A customized notification
        # layout.) 2) Metrics: Client can count how many Reminders with a certain client
        # type are retrieved/mutated. (e.g., VEIDs in go/oparaw.) 3) Index: ListReminder
        # can list all Reminders with a certain client type. 4) Visibility control: some
        # frontends (identified by provenance type, shortn/_xVC9nY2Eb8) only have access
        # to a subset of client types.
        # Corresponds to the JSON property `clientType`
        # @return [Google::Apis::ContentwarehouseV1::QualityDialogManagerReminderClientType]
        attr_accessor :client_type
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `createTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :create_time
      
        # OPTIONAL. The create time of this reminder. This field is propagated only only
        # for the reminders fetched from backend.
        # Corresponds to the JSON property `createTimestamp`
        # @return [String]
        attr_accessor :create_timestamp
      
        # A representation of a person other than the current user, who may have created
        # the reminder for the current user, or will receive it from them.
        # Corresponds to the JSON property `creator`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderPerson]
        attr_accessor :creator
      
        # OPTIONAL. Contains fields needed to build the customized notification card
        # Corresponds to the JSON property `customizedNotificationCard`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityActionsCustomizedNotification>]
        attr_accessor :customized_notification_card
      
        # A date-time specification, combining a date and civil time (relative to a
        # given timezone). IMPORTANT: The definition of DateTime proto is being moved to
        # //assistant/api/core_types/governed/datetime_type.proto. All existing
        # references will be updated to point to the new location. If you are adding a
        # reference, use the new one instead.
        # Corresponds to the JSON property `datetime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDateTime]
        attr_accessor :datetime
      
        # OPTIONAL. Full-length description of the reminder.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # DEPRECATED. Use `client_id` or `server_id` instead.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # A representation of reminder-triggering locations. They may be specific,
        # resolved locations, non-specific location groups, or personal aliases. Next id:
        # 12
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderLocation]
        attr_accessor :location
      
        # Annotate a single reminder instance.
        # Corresponds to the JSON property `log`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsReminderLog]
        attr_accessor :log
      
        # Since this is stored in BE, any update on this proto needs LGTM by ARIS
        # storage owner
        # Corresponds to the JSON property `memoryPayload`
        # @return [Google::Apis::ContentwarehouseV1::AssistantRemindersMemoryPayload]
        attr_accessor :memory_payload
      
        # OPTIONAL. True if the reminder is notifying on the device that is making the
        # request to the server.
        # Corresponds to the JSON property `notifying`
        # @return [Boolean]
        attr_accessor :notifying
        alias_method :notifying?, :notifying
      
        # OPTIONAL. Populated if the reminder is based off of a personal reference, e.g.
        # [my hotel] when the user has a hotel reservation. Contains the information
        # needed for suggestion chip attribution, e.g. a link back to the email
        # reservation.
        # Corresponds to the JSON property `personalReferenceMetadata`
        # @return [Google::Apis::ContentwarehouseV1::CopleySourceTypeList]
        attr_accessor :personal_reference_metadata
      
        # A representation of a person other than the current user, who may have created
        # the reminder for the current user, or will receive it from them.
        # Corresponds to the JSON property `recipient`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderPerson]
        attr_accessor :recipient
      
        # Recurrence rule for specifying time-based repeating reminders.
        # Corresponds to the JSON property `recurrence`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderRecurrenceInfo]
        attr_accessor :recurrence
      
        # OPTIONAL. The reminders backend "server" id. Only filled in some scenarios, e.
        # g. to generate the reminders hubpage detailed-reminder view.
        # Corresponds to the JSON property `serverId`
        # @return [String]
        attr_accessor :server_id
      
        # 
        # Corresponds to the JSON property `symbolicTime`
        # @return [String]
        attr_accessor :symbolic_time
      
        # REQUIRED. The main textual representation of the reminder with the final title.
        # For assignable reminders, this would be e.g. "From John: buy milk".
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # OPTIONAL. The last updated time of this reminder. This field is propagated
        # only for the reminders fetched from ARIS (go/aris-dd).
        # Corresponds to the JSON property `updateTimestamp`
        # @return [String]
        attr_accessor :update_timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @archived = args[:archived] if args.key?(:archived)
          @archived_time = args[:archived_time] if args.key?(:archived_time)
          @archived_timestamp = args[:archived_timestamp] if args.key?(:archived_timestamp)
          @async_interaction_type = args[:async_interaction_type] if args.key?(:async_interaction_type)
          @attachment = args[:attachment] if args.key?(:attachment)
          @bare_title = args[:bare_title] if args.key?(:bare_title)
          @client_id = args[:client_id] if args.key?(:client_id)
          @client_type = args[:client_type] if args.key?(:client_type)
          @create_time = args[:create_time] if args.key?(:create_time)
          @create_timestamp = args[:create_timestamp] if args.key?(:create_timestamp)
          @creator = args[:creator] if args.key?(:creator)
          @customized_notification_card = args[:customized_notification_card] if args.key?(:customized_notification_card)
          @datetime = args[:datetime] if args.key?(:datetime)
          @description = args[:description] if args.key?(:description)
          @id = args[:id] if args.key?(:id)
          @location = args[:location] if args.key?(:location)
          @log = args[:log] if args.key?(:log)
          @memory_payload = args[:memory_payload] if args.key?(:memory_payload)
          @notifying = args[:notifying] if args.key?(:notifying)
          @personal_reference_metadata = args[:personal_reference_metadata] if args.key?(:personal_reference_metadata)
          @recipient = args[:recipient] if args.key?(:recipient)
          @recurrence = args[:recurrence] if args.key?(:recurrence)
          @server_id = args[:server_id] if args.key?(:server_id)
          @symbolic_time = args[:symbolic_time] if args.key?(:symbolic_time)
          @title = args[:title] if args.key?(:title)
          @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp)
        end
      end
      
      # A representation of reminder-triggering locations. They may be specific,
      # resolved locations, non-specific location groups, or personal aliases. Next id:
      # 12
      class QualityActionsReminderLocation
        include Google::Apis::Core::Hashable
      
        # If LocationType is CATEGORICAL, this is info about the category. For example,
        # the category "Grocery Stores" includes chains such as Safeway and Whole Foods.
        # Corresponds to the JSON property `categoryInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderLocationCategoryInfo]
        attr_accessor :category_info
      
        # If LocationType is CHAIN, this is info about the chain.
        # Corresponds to the JSON property `chainInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsReminderLocationChainInfo]
        attr_accessor :chain_info
      
        # Optional additional information about the types of the custom location. This
        # field is not stored in backend, and is only used to plumb NLP information to
        # fulfillment UI.
        # Corresponds to the JSON property `customLocationType`
        # @return [String]
        attr_accessor :custom_location_type
      
        # An address string that is suitable for displaying to the user in an
        # application interface. It can be detailed, or brief. e.g. "80 Absolute Ave,
        # Unit 1708, Mississauga, ON" e.g. "151 Charles Street West"
        # Corresponds to the JSON property `displayAddress`
        # @return [String]
        attr_accessor :display_address
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `geoFeatureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :geo_feature_id
      
        # 
        # Corresponds to the JSON property `lat`
        # @return [Float]
        attr_accessor :lat
      
        # 
        # Corresponds to the JSON property `lng`
        # @return [Float]
        attr_accessor :lng
      
        # 
        # Corresponds to the JSON property `locationType`
        # @return [String]
        attr_accessor :location_type
      
        # Descriptive name, e.g. "43rd st new york", a user-edited place name (e.g. "Gym"
        # ), or a reverse geocoded business name. This can be any string.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Deprecated in favor of Reminder.personal_reference_metadata.
        # Corresponds to the JSON property `personalLocationMetadata`
        # @return [Google::Apis::ContentwarehouseV1::CopleySourceTypeList]
        attr_accessor :personal_location_metadata
      
        # A localized, shortened version of the address, suitable for TTS. This
        # originates in the LocationFrame.
        # Corresponds to the JSON property `ttsAddress`
        # @return [String]
        attr_accessor :tts_address
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_info = args[:category_info] if args.key?(:category_info)
          @chain_info = args[:chain_info] if args.key?(:chain_info)
          @custom_location_type = args[:custom_location_type] if args.key?(:custom_location_type)
          @display_address = args[:display_address] if args.key?(:display_address)
          @geo_feature_id = args[:geo_feature_id] if args.key?(:geo_feature_id)
          @lat = args[:lat] if args.key?(:lat)
          @lng = args[:lng] if args.key?(:lng)
          @location_type = args[:location_type] if args.key?(:location_type)
          @name = args[:name] if args.key?(:name)
          @personal_location_metadata = args[:personal_location_metadata] if args.key?(:personal_location_metadata)
          @tts_address = args[:tts_address] if args.key?(:tts_address)
        end
      end
      
      # If LocationType is CATEGORICAL, this is info about the category. For example,
      # the category "Grocery Stores" includes chains such as Safeway and Whole Foods.
      class QualityActionsReminderLocationCategoryInfo
        include Google::Apis::Core::Hashable
      
        # A (localized) display string describing the category. This is s generic string
        # describing the category, and may be different than the term the user actually
        # said, e.g. name: "supermarket", display_name: "Grocery Stores"
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # 
        # Corresponds to the JSON property `locationCategory`
        # @return [String]
        attr_accessor :location_category
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @location_category = args[:location_category] if args.key?(:location_category)
        end
      end
      
      # If LocationType is CHAIN, this is info about the chain.
      class QualityActionsReminderLocationChainInfo
        include Google::Apis::Core::Hashable
      
        # The freebase mid of the chain entity.
        # Corresponds to the JSON property `chainMid`
        # @return [String]
        attr_accessor :chain_mid
      
        # The geostore.NameProto.text (corresponding to the user's language) at the time
        # of reminder creation. In most cases, this is the same as name, but there may
        # be corner cases where they differ, e.g. name: "bestbuy", chain_name: "Best Buy"
        # .
        # Corresponds to the JSON property `chainName`
        # @return [String]
        attr_accessor :chain_name
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `featureId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :feature_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chain_mid = args[:chain_mid] if args.key?(:chain_mid)
          @chain_name = args[:chain_name] if args.key?(:chain_name)
          @feature_id = args[:feature_id] if args.key?(:feature_id)
        end
      end
      
      # A representation of a person other than the current user, who may have created
      # the reminder for the current user, or will receive it from them.
      class QualityActionsReminderPerson
        include Google::Apis::Core::Hashable
      
        # REQUIRED. Their full name, which will be shown/spoken when referring to this
        # person informally, e.g. "You have 2 reminders from Dave Smith."
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # OPTIONAL. Their email address.
        # Corresponds to the JSON property `emailAddress`
        # @return [String]
        attr_accessor :email_address
      
        # REQUIRED. Their gaia id (used by the backend for CRUD operations).
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # REQUIRED. Their given name, which will be shown/spoken when referring to this
        # person informally, e.g. "You have 2 reminders from Dave."
        # Corresponds to the JSON property `givenName`
        # @return [String]
        attr_accessor :given_name
      
        # OPTIONAL. The URL of the photo. This field is read from photo field from go/
        # people-api. Also see go/khdgk for URL formats. This field might be missing if
        # user does not have photo URL available.
        # Corresponds to the JSON property `photoUrl`
        # @return [String]
        attr_accessor :photo_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
          @email_address = args[:email_address] if args.key?(:email_address)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @given_name = args[:given_name] if args.key?(:given_name)
          @photo_url = args[:photo_url] if args.key?(:photo_url)
        end
      end
      
      # Recurrence rule for specifying time-based repeating reminders.
      class QualityActionsReminderRecurrenceInfo
        include Google::Apis::Core::Hashable
      
        # OPTIONAL. Client-assigned-id for the recurring reminder
        # Corresponds to the JSON property `clientId`
        # @return [String]
        attr_accessor :client_id
      
        # Date-based recurrences specify repeating events. Conceptually, a recurrence is
        # a (possibly unbounded) sequence of dates on which an event falls, described by
        # a list of constraints. A date is in a recurrence if and only if it satisfies
        # all of the constraints. Note that devices may support some constraints, but
        # not all. IMPORTANT: The definition of Recurrence proto is being moved to //
        # assistant/api/core_types/governed/datetime_type.proto. All existing references
        # will be updated to point to the new location. If you are adding a reference,
        # use the new one instead.
        # Corresponds to the JSON property `recurrence`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiRecurrence]
        attr_accessor :recurrence
      
        # An id which uniquely identifies a recurrence series.
        # Corresponds to the JSON property `recurrenceId`
        # @return [String]
        attr_accessor :recurrence_id
      
        # REQUIRED. Server-assigned-id for the recurring reminder
        # Corresponds to the JSON property `serverId`
        # @return [String]
        attr_accessor :server_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_id = args[:client_id] if args.key?(:client_id)
          @recurrence = args[:recurrence] if args.key?(:recurrence)
          @recurrence_id = args[:recurrence_id] if args.key?(:recurrence_id)
          @server_id = args[:server_id] if args.key?(:server_id)
        end
      end
      
      # Ringtone information used for the notification of timer and alarm.
      class QualityActionsRingtone
        include Google::Apis::Core::Hashable
      
        # A Duration represents a signed, fixed-length span of time represented as a
        # count of seconds and fractions of seconds at nanosecond resolution. It is
        # independent of any calendar and concepts like "day" or "month". It is related
        # to Timestamp in that the difference between two Timestamp values is a Duration
        # and it can be added or subtracted from a Timestamp. Range is approximately +-
        # 10,000 years.
        # Corresponds to the JSON property `pauseDuration`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiDuration]
        attr_accessor :pause_duration
      
        # The sound urls will be used to play.
        # Corresponds to the JSON property `soundUrl`
        # @return [Array<String>]
        attr_accessor :sound_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pause_duration = args[:pause_duration] if args.key?(:pause_duration)
          @sound_url = args[:sound_url] if args.key?(:sound_url)
        end
      end
      
      # The room in which an alarm or timer resides
      class QualityActionsRoom
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `homegraphId`
        # @return [String]
        attr_accessor :homegraph_id
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @homegraph_id = args[:homegraph_id] if args.key?(:homegraph_id)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Conceptually, timers are clocks that count down from an initial duration and
      # notify when they reach 0. In practice, as a timer is running, it holds a
      # stable expiration time and computes the remaining duration using the current
      # time. When a timer is paused, it holds a stable remaining duration.
      class QualityActionsTimer
        include Google::Apis::Core::Hashable
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `creationTime`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :creation_time
      
        # Next ID: 73
        # Corresponds to the JSON property `device`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiSettingsDeviceSettings]
        attr_accessor :device
      
        # When not paused: the time the timer is (or was) scheduled to expire, in
        # milliseconds since the Unix epoch. This should be deprecated and replaced by
        # the expire_timer_time with DateTime type once DateTime proto includes unix
        # timestamp (b/63636831).
        # Corresponds to the JSON property `expireTime`
        # @return [Fixnum]
        attr_accessor :expire_time
      
        # The top-level DATE/TIME representation. It can represent either (1) one or
        # multiple Date/Time ranges, or (2) one or multiple of Date/Time points, or (3)
        # a recurrent date/time expression. Next available ID: 12. Only one of |range|, |
        # point| and |recurrent| will be set: |range| contains a list of resolved Date/
        # Time ranges. |point| contains a list of resolved Date/Time points. |recurrent|
        # contains the representation for periodical dates/times. |range| and |point|
        # are repeated to accommodate the need when the date/time expression under one
        # non-terminal is resolved to a list of correct values. For example, "Mondays in
        # April, 2014" may have 4 correct dates.
        # Corresponds to the JSON property `expireTimerTime`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDateTime]
        attr_accessor :expire_timer_time
      
        # A string key used as an identifier to this timer, unique for a given Provider.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The label, provided by a user, associated with this timer.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # An absolute point in time independent of timezone or calendar, based on the
        # proto3 Timestamp (//google/protobuf/timestamp.proto). IMPORTANT: The
        # definition of Timestamp proto is being moved to //assistant/api/core_types/
        # governed/datetime_type.proto. All existing references will be updated to point
        # to the new location. If you are adding a reference, use the new one instead.
        # NOTE: THIS IS NO LONGER RECOMMENDED TO BE USED. It was originally defined
        # separately from google.protobuf.Timestamp due to incompatibility with proto2
        # syntax. The incompatibility issues have since been resolved and so the Google-
        # wide standard representation of google.protobuf.Timestamp should be preferred.
        # In fact, google.protobuf.* protos in general are now recommended to be used in
        # new APIs.
        # Corresponds to the JSON property `lastUpdated`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiTimestamp]
        attr_accessor :last_updated
      
        # The duration of the timer when it was started, in milliseconds.
        # Corresponds to the JSON property `originalDuration`
        # @return [Fixnum]
        attr_accessor :original_duration
      
        # To represent unanchored durations - the length of a date/time expression not
        # related to calendar in local context. E.g., "play first (DURATION: 5 minutes)
        # of Yellow Submarine", "it takes (DURATION: more than 3 days) to finish." In
        # contrast, queries like: "wake me up in 5 minutes" will be resolved to a
        # AbsoluteDateTime since the query indicates that the reference is now. A
        # duration can be turned into a range if either end is anchored.
        # Corresponds to the JSON property `originalTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDuration]
        attr_accessor :original_timer_duration
      
        # Provider. Like, Spotify or iHeartRadio. Next ID: 13
        # Corresponds to the JSON property `provider`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesProvider]
        attr_accessor :provider
      
        # When PAUSED: the remaining duration in milliseconds.
        # Corresponds to the JSON property `remainingDuration`
        # @return [Fixnum]
        attr_accessor :remaining_duration
      
        # To represent unanchored durations - the length of a date/time expression not
        # related to calendar in local context. E.g., "play first (DURATION: 5 minutes)
        # of Yellow Submarine", "it takes (DURATION: more than 3 days) to finish." In
        # contrast, queries like: "wake me up in 5 minutes" will be resolved to a
        # AbsoluteDateTime since the query indicates that the reference is now. A
        # duration can be turned into a range if either end is anchored.
        # Corresponds to the JSON property `remainingTimerDuration`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingDatetimeDuration]
        attr_accessor :remaining_timer_duration
      
        # Ringtone information used for the notification of timer and alarm.
        # Corresponds to the JSON property `ringtone`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsRingtone]
        attr_accessor :ringtone
      
        # Task metadata information describing the ringtone. Next id: 11
        # Corresponds to the JSON property `ringtoneTaskMetadata`
        # @return [Google::Apis::ContentwarehouseV1::AssistantApiCoreTypesGovernedRingtoneTaskMetadata]
        attr_accessor :ringtone_task_metadata
      
        # The room in which an alarm or timer resides
        # Corresponds to the JSON property `room`
        # @return [Google::Apis::ContentwarehouseV1::QualityActionsRoom]
        attr_accessor :room
      
        # The current status of the timer.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # Whether or not the device will vibrate when the timer fires.
        # Corresponds to the JSON property `vibrate`
        # @return [Boolean]
        attr_accessor :vibrate
        alias_method :vibrate?, :vibrate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @creation_time = args[:creation_time] if args.key?(:creation_time)
          @device = args[:device] if args.key?(:device)
          @expire_time = args[:expire_time] if args.key?(:expire_time)
          @expire_timer_time = args[:expire_timer_time] if args.key?(:expire_timer_time)
          @id = args[:id] if args.key?(:id)
          @label = args[:label] if args.key?(:label)
          @last_updated = args[:last_updated] if args.key?(:last_updated)
          @original_duration = args[:original_duration] if args.key?(:original_duration)
          @original_timer_duration = args[:original_timer_duration] if args.key?(:original_timer_duration)
          @provider = args[:provider] if args.key?(:provider)
          @remaining_duration = args[:remaining_duration] if args.key?(:remaining_duration)
          @remaining_timer_duration = args[:remaining_timer_duration] if args.key?(:remaining_timer_duration)
          @ringtone = args[:ringtone] if args.key?(:ringtone)
          @ringtone_task_metadata = args[:ringtone_task_metadata] if args.key?(:ringtone_task_metadata)
          @room = args[:room] if args.key?(:room)
          @status = args[:status] if args.key?(:status)
          @vibrate = args[:vibrate] if args.key?(:vibrate)
        end
      end
      
      # Proto populated into shards and copied to superroot. Message storing a
      # versioned TopicEmbeddings scores. This is copied from TopicEmbeddings in
      # docjoins.
      class QualityAuthorityTopicEmbeddingsVersionedItem
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `pageEmbedding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :page_embedding
      
        # Compressed site/page embeddings.
        # Corresponds to the JSON property `siteEmbedding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :site_embedding
      
        # Number denoting how much a site is focused on one topic.
        # Corresponds to the JSON property `siteFocusScore`
        # @return [Float]
        attr_accessor :site_focus_score
      
        # The measure of how far page_embeddings deviate from the site_embedding.
        # Corresponds to the JSON property `siteRadius`
        # @return [Float]
        attr_accessor :site_radius
      
        # 
        # Corresponds to the JSON property `versionId`
        # @return [Fixnum]
        attr_accessor :version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @page_embedding = args[:page_embedding] if args.key?(:page_embedding)
          @site_embedding = args[:site_embedding] if args.key?(:site_embedding)
          @site_focus_score = args[:site_focus_score] if args.key?(:site_focus_score)
          @site_radius = args[:site_radius] if args.key?(:site_radius)
          @version_id = args[:version_id] if args.key?(:version_id)
        end
      end
      
      # 
      class QualityCalypsoAppsLink
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `applicationId`
        # @return [Array<String>]
        attr_accessor :application_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_id = args[:application_id] if args.key?(:application_id)
        end
      end
      
      # Proto message containing site-level signal for search stack. Because
      # firefly_stats.proto depends on "//segindexer:compositedoc_proto", we cannot
      # make perdocdata contain it.
      class QualityCopiaFireflySiteSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dailyClicks`
        # @return [Fixnum]
        attr_accessor :daily_clicks
      
        # 
        # Corresponds to the JSON property `dailyGoodClicks`
        # @return [Fixnum]
        attr_accessor :daily_good_clicks
      
        # 
        # Corresponds to the JSON property `dataTimeSec`
        # @return [Fixnum]
        attr_accessor :data_time_sec
      
        # 
        # Corresponds to the JSON property `firstBoostedTimeSec`
        # @return [Fixnum]
        attr_accessor :first_boosted_time_sec
      
        # 
        # Corresponds to the JSON property `impressionsInBoostedPeriod`
        # @return [Fixnum]
        attr_accessor :impressions_in_boosted_period
      
        # 
        # Corresponds to the JSON property `latestBylineDateSec`
        # @return [Fixnum]
        attr_accessor :latest_byline_date_sec
      
        # 
        # Corresponds to the JSON property `latestFirstseenSec`
        # @return [Fixnum]
        attr_accessor :latest_firstseen_sec
      
        # 
        # Corresponds to the JSON property `numOfArticles8`
        # @return [Fixnum]
        attr_accessor :num_of_articles8
      
        # number of articles (lattice article score is 0.8 or more) sliced by 30 days (
        # num_of_articles_by_periods[0] is the newest).
        # Corresponds to the JSON property `numOfArticlesByPeriods`
        # @return [Array<Fixnum>]
        attr_accessor :num_of_articles_by_periods
      
        # 
        # Corresponds to the JSON property `numOfGamblingPages`
        # @return [Fixnum]
        attr_accessor :num_of_gambling_pages
      
        # 
        # Corresponds to the JSON property `numOfUrls`
        # @return [Fixnum]
        attr_accessor :num_of_urls
      
        # number of urls sliced by 30 days (num_of_urls_by_periods[0] is the newest).
        # Corresponds to the JSON property `numOfUrlsByPeriods`
        # @return [Array<Fixnum>]
        attr_accessor :num_of_urls_by_periods
      
        # 
        # Corresponds to the JSON property `recentImpForQuotaSystem`
        # @return [Fixnum]
        attr_accessor :recent_imp_for_quota_system
      
        # Hash value of the site. This will be used by our experiment and analysis.
        # Corresponds to the JSON property `siteFp`
        # @return [Fixnum]
        attr_accessor :site_fp
      
        # 
        # Corresponds to the JSON property `totalImpressions`
        # @return [Fixnum]
        attr_accessor :total_impressions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @daily_clicks = args[:daily_clicks] if args.key?(:daily_clicks)
          @daily_good_clicks = args[:daily_good_clicks] if args.key?(:daily_good_clicks)
          @data_time_sec = args[:data_time_sec] if args.key?(:data_time_sec)
          @first_boosted_time_sec = args[:first_boosted_time_sec] if args.key?(:first_boosted_time_sec)
          @impressions_in_boosted_period = args[:impressions_in_boosted_period] if args.key?(:impressions_in_boosted_period)
          @latest_byline_date_sec = args[:latest_byline_date_sec] if args.key?(:latest_byline_date_sec)
          @latest_firstseen_sec = args[:latest_firstseen_sec] if args.key?(:latest_firstseen_sec)
          @num_of_articles8 = args[:num_of_articles8] if args.key?(:num_of_articles8)
          @num_of_articles_by_periods = args[:num_of_articles_by_periods] if args.key?(:num_of_articles_by_periods)
          @num_of_gambling_pages = args[:num_of_gambling_pages] if args.key?(:num_of_gambling_pages)
          @num_of_urls = args[:num_of_urls] if args.key?(:num_of_urls)
          @num_of_urls_by_periods = args[:num_of_urls_by_periods] if args.key?(:num_of_urls_by_periods)
          @recent_imp_for_quota_system = args[:recent_imp_for_quota_system] if args.key?(:recent_imp_for_quota_system)
          @site_fp = args[:site_fp] if args.key?(:site_fp)
          @total_impressions = args[:total_impressions] if args.key?(:total_impressions)
        end
      end
      
      # Various external IDs that we may have for a given LocalResult. These IDs can
      # map to the corresponding result in other Google systems (KnowledgeGraph) or in
      # third-party systems (OpenTable).
      class QualityDialogManagerExternalIds
        include Google::Apis::Core::Hashable
      
        # Information to indicate BG availability for businesses. This message is filled
        # from Topic Server and stored in the GSR in Superroot.
        # Corresponds to the JSON property `blueGingerSupportedServices`
        # @return [Google::Apis::ContentwarehouseV1::BlueGingerClientVisibleProtoBlueGingerSupportedServices]
        attr_accessor :blue_ginger_supported_services
      
        # 
        # Corresponds to the JSON property `knowledgeGraphMid`
        # @return [String]
        attr_accessor :knowledge_graph_mid
      
        # Actions supported by Madden for a local entity.
        # Corresponds to the JSON property `maddenSupportedActions`
        # @return [Google::Apis::ContentwarehouseV1::GeoOndemandAssistantSupportedActions]
        attr_accessor :madden_supported_actions
      
        # 
        # Corresponds to the JSON property `openTableRestaurantId`
        # @return [String]
        attr_accessor :open_table_restaurant_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blue_ginger_supported_services = args[:blue_ginger_supported_services] if args.key?(:blue_ginger_supported_services)
          @knowledge_graph_mid = args[:knowledge_graph_mid] if args.key?(:knowledge_graph_mid)
          @madden_supported_actions = args[:madden_supported_actions] if args.key?(:madden_supported_actions)
          @open_table_restaurant_id = args[:open_table_restaurant_id] if args.key?(:open_table_restaurant_id)
        end
      end
      
      # 
      class QualityDialogManagerLocalIntentOptions
        include Google::Apis::Core::Hashable
      
        # LINT.ThenChange( //depot/google3/googledata/nlp/generation/messages/assistant/\
        # dialog_LOCAL_LocalAssistantSchema/\ dialog.LOCAL.LocalAssistantSchema_zxx.
        # genx.textpb, //depot/google3/quality/dialog_manager/verticals/local/assistant/\
        # suggestion_chip_util.cc)
        # Corresponds to the JSON property `intent`
        # @return [Array<String>]
        attr_accessor :intent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent = args[:intent] if args.key?(:intent)
        end
      end
      
      # A generic representation of a local result returned by a local backend. Next
      # ID: 33
      class QualityDialogManagerLocalResult
        include Google::Apis::Core::Hashable
      
        # This field can represent different areas depending on the country. For example
        # in the US it is state but in Canada it would be a province.
        # Corresponds to the JSON property `adminArea1`
        # @return [String]
        attr_accessor :admin_area1
      
        # The set of available intents changes with result. An intersection of
        # available_intents and allowed_intents (See: local_config.proto), is shown to
        # the user.
        # Corresponds to the JSON property `availableIntents`
        # @return [Google::Apis::ContentwarehouseV1::QualityDialogManagerLocalIntentOptions]
        attr_accessor :available_intents
      
        # A high-level categorization of business types. Used for location elements that
        # are either BUSINESS_NAME or BUSINESS_CATEGORY. The business types roughly
        # correspond to QRef collections and should be interpreted broadly. E.g., hotel
        # also include motels, youth hostels, and guest houses; restaurants includes
        # bars and cafes, etc. Business types can be populated by QRef collections;
        # other population is done by grammar categories from local_categories.grammar.
        # It is expected that some business organizations will match more than one
        # business type. E.g., Safeway is both a grocery store and a pharmacy. Next ID:
        # 43 NOTE(oksana): LocalCategoryReliable grammar over-rides a few business type
        # queries to include hyper_reliable location element. If you change this, please
        # make sure that LocalCategoryReliable grammar reflects this too. LINT.IfChange
        # Corresponds to the JSON property `businessType`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalBusinessType]
        attr_accessor :business_type
      
        # 
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # The two-letter ISO 3166-1 country code of this result. Generated by
        # FindFeatureCountryCode http://google3/geostore/base/public/country.h?l=39&rcl=
        # 154898119 so it should always be populated, but technically there is no
        # guarantee.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # For a directions result, this field will be the distance from the origin to
        # this result using the best measure we have available - the distance along a
        # route, if we have one, or just the crow's flight distance. For a local result,
        # this field will be the crow's flight distance from the user to the result.
        # Corresponds to the JSON property `distanceMeters`
        # @return [Fixnum]
        attr_accessor :distance_meters
      
        # The standard units of the location where the user is based (not their current
        # location). For example, miles for a user from the US, kilometers for the UK. A
        # US user currently in the UK should have units read in miles.
        # Corresponds to the JSON property `distanceUnits`
        # @return [String]
        attr_accessor :distance_units
      
        # Various external IDs that we may have for a given LocalResult. These IDs can
        # map to the corresponding result in other Google systems (KnowledgeGraph) or in
        # third-party systems (OpenTable).
        # Corresponds to the JSON property `externalIds`
        # @return [Google::Apis::ContentwarehouseV1::QualityDialogManagerExternalIds]
        attr_accessor :external_ids
      
        # 
        # Corresponds to the JSON property `featureType`
        # @return [String]
        attr_accessor :feature_type
      
        # If true, this LocalResult is located in the same state as the user's location.
        # Corresponds to the JSON property `inUserAdminArea1`
        # @return [Boolean]
        attr_accessor :in_user_admin_area1
        alias_method :in_user_admin_area1?, :in_user_admin_area1
      
        # If true, this LocalResult is located in the same country as the user's
        # location.
        # Corresponds to the JSON property `inUserCountry`
        # @return [Boolean]
        attr_accessor :in_user_country
        alias_method :in_user_country?, :in_user_country
      
        # Whether this result is in the same city or town that the user is in.
        # Corresponds to the JSON property `inUserLocality`
        # @return [Boolean]
        attr_accessor :in_user_locality
        alias_method :in_user_locality?, :in_user_locality
      
        # * Proto representing the metadata associated with food ordering internal
        # action. Next ID: 13
        # Corresponds to the JSON property `internalFoodOrderingMetadata`
        # @return [Google::Apis::ContentwarehouseV1::LocalsearchProtoInternalFoodOrderingActionMetadata]
        attr_accessor :internal_food_ordering_metadata
      
        # If the original query had a chain intent, and this result is for a business
        # chain.
        # Corresponds to the JSON property `isBusinessChain`
        # @return [Boolean]
        attr_accessor :is_business_chain
        alias_method :is_business_chain?, :is_business_chain
      
        # City/Town.
        # Corresponds to the JSON property `locality`
        # @return [String]
        attr_accessor :locality
      
        # The name of the result, extracted from its FeatureProto's name field.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Neighborhood within a city. This field is not likely to be set for towns or
        # smaller cities.
        # Corresponds to the JSON property `neighborhood`
        # @return [String]
        attr_accessor :neighborhood
      
        # This message holds all info the local assistant team will need to lookup a
        # LocalResult in search.
        # Corresponds to the JSON property `resultId`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingLocalLocalResultId]
        attr_accessor :result_id
      
        # 
        # Corresponds to the JSON property `streetName`
        # @return [String]
        attr_accessor :street_name
      
        # 
        # Corresponds to the JSON property `streetNumber`
        # @return [String]
        attr_accessor :street_number
      
        # A list of text synonyms the user could use to refer to the result.
        # Corresponds to the JSON property `synonym`
        # @return [Array<String>]
        attr_accessor :synonym
      
        # The address of this result formatted for TTS output. This formatting removes
        # acronyms like 2-letter state codes as they cannot be spoken well.
        # Corresponds to the JSON property `ttsAddress`
        # @return [String]
        attr_accessor :tts_address
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @admin_area1 = args[:admin_area1] if args.key?(:admin_area1)
          @available_intents = args[:available_intents] if args.key?(:available_intents)
          @business_type = args[:business_type] if args.key?(:business_type)
          @country = args[:country] if args.key?(:country)
          @country_code = args[:country_code] if args.key?(:country_code)
          @distance_meters = args[:distance_meters] if args.key?(:distance_meters)
          @distance_units = args[:distance_units] if args.key?(:distance_units)
          @external_ids = args[:external_ids] if args.key?(:external_ids)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @in_user_admin_area1 = args[:in_user_admin_area1] if args.key?(:in_user_admin_area1)
          @in_user_country = args[:in_user_country] if args.key?(:in_user_country)
          @in_user_locality = args[:in_user_locality] if args.key?(:in_user_locality)
          @internal_food_ordering_metadata = args[:internal_food_ordering_metadata] if args.key?(:internal_food_ordering_metadata)
          @is_business_chain = args[:is_business_chain] if args.key?(:is_business_chain)
          @locality = args[:locality] if args.key?(:locality)
          @name = args[:name] if args.key?(:name)
          @neighborhood = args[:neighborhood] if args.key?(:neighborhood)
          @result_id = args[:result_id] if args.key?(:result_id)
          @street_name = args[:street_name] if args.key?(:street_name)
          @street_number = args[:street_number] if args.key?(:street_number)
          @synonym = args[:synonym] if args.key?(:synonym)
          @tts_address = args[:tts_address] if args.key?(:tts_address)
        end
      end
      
      # Define Reminder Client Type. This field is for the purposes of 1) UX
      # Customization: Reminder frontends can be configured to have a slightly
      # different UX (e.g., A customized button on Hubpage. A customized notification
      # layout.) 2) Metrics: Client can count how many Reminders with a certain client
      # type are retrieved/mutated. (e.g., VEIDs in go/oparaw.) 3) Index: ListReminder
      # can list all Reminders with a certain client type. 4) Visibility control: some
      # frontends (identified by provenance type, shortn/_xVC9nY2Eb8) only have access
      # to a subset of client types.
      class QualityDialogManagerReminderClientType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Set of per-document markup restrictions based on go/eucd-indexing-design. Used
      # for EUCD and global preview compliance. Next ID: 17
      class QualityDniDocPreviewRestrictions
        include Google::Apis::Core::Hashable
      
        # Publish date set by webmaster. See detailed description here: http://shortn/
        # _1eC0zzjR7k. Note that this will currently only be set for canonical documents
        # where byline date could be extracted.
        # Corresponds to the JSON property `bylineDateSecs`
        # @return [Fixnum]
        attr_accessor :byline_date_secs
      
        # The time that the info in this attachment was computed during crawl, in
        # microseconds.
        # Corresponds to the JSON property `crawlTsUsec`
        # @return [Fixnum]
        attr_accessor :crawl_ts_usec
      
        # When making changes to this proto, make sure to run: blaze test commerce/
        # datastore/tools/codegen:code_generator_test blaze run commerce/datastore/tools/
        # codegen:code_generator See http://go/cds-schema-council for details. LINT.
        # IfChange
        # Corresponds to the JSON property `extendedNewsPreviewsDomain`
        # @return [Google::Apis::ContentwarehouseV1::QualityDniExtendedNewsPreviews]
        attr_accessor :extended_news_previews_domain
      
        # Whether the favicon for a given domain should be displayed.
        # FAVICON_DISPLAY_UNSPECIFIED - Display the favicon DISABLE_FAVICON - the
        # favicon should not be rendered by the feature
        # Corresponds to the JSON property `faviconDisplay`
        # @return [String]
        attr_accessor :favicon_display
      
        # Firstseen date populated by indexing. It works as fallback to byline_date if
        # it doesn't exist. Note that this will currently only be set for canonical
        # documents where firstseen date could be populated.
        # Corresponds to the JSON property `firstseenDateSecs`
        # @return [Fixnum]
        attr_accessor :firstseen_date_secs
      
        # Only be true when the page itself is an AMP page. For paired AMP, the
        # canonical page will have this bit as false.
        # Corresponds to the JSON property `isAmp`
        # @return [Boolean]
        attr_accessor :is_amp
        alias_method :is_amp?, :is_amp
      
        # 
        # Corresponds to the JSON property `isEucdDomain`
        # @return [Boolean]
        attr_accessor :is_eucd_domain
        alias_method :is_eucd_domain?, :is_eucd_domain
      
        # The max number of snippet characters allowed. Based on document markup. No
        # limit if value is less than 0, Google could use any length of snippets.
        # Default value 0 is the strictest restriction, to avoid violating mistakenly If
        # not set, there is no snippet length policy to enforce. Features must first
        # check has_max_snippet_length to avoid applying an overly strict policy.
        # Corresponds to the JSON property `maxSnippetLength`
        # @return [Fixnum]
        attr_accessor :max_snippet_length
      
        # Same as the max_snippet_length, max_thumbnail_size, max_video_preview_secs
        # listed above. But values are based on publisher's preferences from Search
        # Console's robots meta tag tool.
        # Corresponds to the JSON property `maxSnippetLengthFromPublisher`
        # @return [Fixnum]
        attr_accessor :max_snippet_length_from_publisher
      
        # 
        # Corresponds to the JSON property `maxSnippetLengthPublisherDefault`
        # @return [Fixnum]
        attr_accessor :max_snippet_length_publisher_default
      
        # The max thumbnail size allowed. Based on document markup Default value NONE is
        # the strictest restriction, to avoid violating mistakenly. If not set, there is
        # no thumbnail policy to enforce.
        # Corresponds to the JSON property `maxThumbnailSize`
        # @return [String]
        attr_accessor :max_thumbnail_size
      
        # 
        # Corresponds to the JSON property `maxThumbnailSizeFromPublisher`
        # @return [String]
        attr_accessor :max_thumbnail_size_from_publisher
      
        # 
        # Corresponds to the JSON property `maxThumbnailSizePublisherDefault`
        # @return [Fixnum]
        attr_accessor :max_thumbnail_size_publisher_default
      
        # The max seconds of video preview allowed. Based on document markup. No limit
        # if value is less than 0, Google could show any seconds of video. Default value
        # 0 is the strictest restriction, to avoid violating mistakenly If not set,
        # there is no preview length policy to enforce. Features must first check
        # has_max_video_preview_secs to avoid applying an overly strict policy.
        # Corresponds to the JSON property `maxVideoPreviewSecs`
        # @return [Fixnum]
        attr_accessor :max_video_preview_secs
      
        # 
        # Corresponds to the JSON property `maxVideoPreviewSecsFromPublisher`
        # @return [Fixnum]
        attr_accessor :max_video_preview_secs_from_publisher
      
        # 
        # Corresponds to the JSON property `maxVideoPreviewSecsPublisherDefault`
        # @return [Fixnum]
        attr_accessor :max_video_preview_secs_publisher_default
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byline_date_secs = args[:byline_date_secs] if args.key?(:byline_date_secs)
          @crawl_ts_usec = args[:crawl_ts_usec] if args.key?(:crawl_ts_usec)
          @extended_news_previews_domain = args[:extended_news_previews_domain] if args.key?(:extended_news_previews_domain)
          @favicon_display = args[:favicon_display] if args.key?(:favicon_display)
          @firstseen_date_secs = args[:firstseen_date_secs] if args.key?(:firstseen_date_secs)
          @is_amp = args[:is_amp] if args.key?(:is_amp)
          @is_eucd_domain = args[:is_eucd_domain] if args.key?(:is_eucd_domain)
          @max_snippet_length = args[:max_snippet_length] if args.key?(:max_snippet_length)
          @max_snippet_length_from_publisher = args[:max_snippet_length_from_publisher] if args.key?(:max_snippet_length_from_publisher)
          @max_snippet_length_publisher_default = args[:max_snippet_length_publisher_default] if args.key?(:max_snippet_length_publisher_default)
          @max_thumbnail_size = args[:max_thumbnail_size] if args.key?(:max_thumbnail_size)
          @max_thumbnail_size_from_publisher = args[:max_thumbnail_size_from_publisher] if args.key?(:max_thumbnail_size_from_publisher)
          @max_thumbnail_size_publisher_default = args[:max_thumbnail_size_publisher_default] if args.key?(:max_thumbnail_size_publisher_default)
          @max_video_preview_secs = args[:max_video_preview_secs] if args.key?(:max_video_preview_secs)
          @max_video_preview_secs_from_publisher = args[:max_video_preview_secs_from_publisher] if args.key?(:max_video_preview_secs_from_publisher)
          @max_video_preview_secs_publisher_default = args[:max_video_preview_secs_publisher_default] if args.key?(:max_video_preview_secs_publisher_default)
        end
      end
      
      # When making changes to this proto, make sure to run: blaze test commerce/
      # datastore/tools/codegen:code_generator_test blaze run commerce/datastore/tools/
      # codegen:code_generator See http://go/cds-schema-council for details. LINT.
      # IfChange
      class QualityDniExtendedNewsPreviews
        include Google::Apis::Core::Hashable
      
        # Publisher's country code (ISO-3166) Used in V0.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # List of countries that desnippet the publisher. ISO 3166-1-alpha-2 country
        # code (such as FR). See go/iiuse#region-identifiers. Used in V1.
        # Corresponds to the JSON property `desnippetedCountryCode`
        # @return [Array<String>]
        attr_accessor :desnippeted_country_code
      
        # Search Console Signals that modifies how policy are calculated. Didn't add `
        # wmconsole.EnpDesnippetingOverrideRules` direcly to avoid cicular dependency
        # issue: go/enp-v2#bookmark=id.dvb1qcltabv9 ENPv2 proto (
        # EnpDesnippetingOverrideRules): google3/crawler/wmconsole/proto/
        # config_enp_desnippeting_override_rules.proto
        # Corresponds to the JSON property `policyCriteriaBase64`
        # @return [String]
        attr_accessor :policy_criteria_base64
      
        # ENP status.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        # The default version is V0 (for backward compatibility).
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @desnippeted_country_code = args[:desnippeted_country_code] if args.key?(:desnippeted_country_code)
          @policy_criteria_base64 = args[:policy_criteria_base64] if args.key?(:policy_criteria_base64)
          @status = args[:status] if args.key?(:status)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # PerDocData for fringe-query-prior (built into the shards for eventual
      # consumption at Fringe classification time). Not stored in DocJoins. NEXT ID:
      # 11
      class QualityFringeFringeQueryPriorPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `encodedCalibratedFringeSitePriorScore`
        # @return [Fixnum]
        attr_accessor :encoded_calibrated_fringe_site_prior_score
      
        # An encoding of the Chard XLQ-hoax prediction in [0,1].
        # Corresponds to the JSON property `encodedChardXlqHoaxPrediction`
        # @return [Fixnum]
        attr_accessor :encoded_chard_xlq_hoax_prediction
      
        # An encoding of the Chard XLQ-YMYL prediction in [0,1].
        # Corresponds to the JSON property `encodedChardXlqYmylPrediction`
        # @return [Fixnum]
        attr_accessor :encoded_chard_xlq_ymyl_prediction
      
        # An estimate of the vulnerability of this doc to show fringe content, based on
        # the context around the document. Can be interpreted as a 'safe' QScore
        # threshold to use (see go/doc-fringe-vulnerability for more info). Encoded for
        # compactness and to restrict visibility. Please contact fringe-ranking@ to get
        # access to quality_fringe::DocumentFringeVulnerabilityEncoding to decode this
        # field.
        # Corresponds to the JSON property `encodedDocumentFringeVulnerability`
        # @return [Fixnum]
        attr_accessor :encoded_document_fringe_vulnerability
      
        # Highest entity prior seen for document's Headline and SingleTopic entities (
        # see go/topicality-score for definitions of entity topicalities). Represents
        # probability that a query is fringe, given that the entity is in the result set
        # with topicality >= Headline. Scores scaled to integers between 0 and 1000 for
        # compactness. Scores must be interpreted through FringeQueryPriorEncoding::
        # Decode API.
        # Corresponds to the JSON property `encodedEntityPriorScore`
        # @return [Fixnum]
        attr_accessor :encoded_entity_prior_score
      
        # Probability that a query is fringe, given this document is in the result set.
        # Scores scaled to integers between 0 and 1000 for compactness. Scores must be
        # interpreted through FringeQueryPriorEncoding::Decode API.
        # Corresponds to the JSON property `encodedFringePriorScore`
        # @return [Fixnum]
        attr_accessor :encoded_fringe_prior_score
      
        # Probability that a query is fringe, given this document's site is in the
        # result set. Scores scaled to integers between 0 and 1000 for compactness.
        # Scores must be interpreted through FringeQueryPriorEncoding::Decode API.
        # Corresponds to the JSON property `encodedFringeSitePriorScore`
        # @return [Fixnum]
        attr_accessor :encoded_fringe_site_prior_score
      
        # Probability that a query is fringe, given this document's site is in the
        # result set. Does not use signals with a dependency on the QueryFringeScore of
        # a document. Scores scaled to integers between 0 and 1000 for compactness.
        # Scores must be interpreted through FringeQueryPriorEncoding::Decode API. Will
        # NOT be present if the fringe_site_prior_score_for_qfs_training is not
        # significantly different from the site_prior_score.
        # Corresponds to the JSON property `encodedFringeSitePriorScoreForQfsTraining`
        # @return [Fixnum]
        attr_accessor :encoded_fringe_site_prior_score_for_qfs_training
      
        # A combined encoding of the pXLQ score in [0,1] and the confidence with which
        # that score should be interpreted in [0,1].
        # Corresponds to the JSON property `encodedPredictedXlqScoreAndConfidence`
        # @return [Fixnum]
        attr_accessor :encoded_predicted_xlq_score_and_confidence
      
        # A score in [0, 1] representing the similarity of this doc to known fringe-
        # vulnerable 'seeds'. See go/fringe-proximity for more information. Encoded for
        # compactness and to restrict visibility.
        # Corresponds to the JSON property `encodedProximityScore`
        # @return [Fixnum]
        attr_accessor :encoded_proximity_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encoded_calibrated_fringe_site_prior_score = args[:encoded_calibrated_fringe_site_prior_score] if args.key?(:encoded_calibrated_fringe_site_prior_score)
          @encoded_chard_xlq_hoax_prediction = args[:encoded_chard_xlq_hoax_prediction] if args.key?(:encoded_chard_xlq_hoax_prediction)
          @encoded_chard_xlq_ymyl_prediction = args[:encoded_chard_xlq_ymyl_prediction] if args.key?(:encoded_chard_xlq_ymyl_prediction)
          @encoded_document_fringe_vulnerability = args[:encoded_document_fringe_vulnerability] if args.key?(:encoded_document_fringe_vulnerability)
          @encoded_entity_prior_score = args[:encoded_entity_prior_score] if args.key?(:encoded_entity_prior_score)
          @encoded_fringe_prior_score = args[:encoded_fringe_prior_score] if args.key?(:encoded_fringe_prior_score)
          @encoded_fringe_site_prior_score = args[:encoded_fringe_site_prior_score] if args.key?(:encoded_fringe_site_prior_score)
          @encoded_fringe_site_prior_score_for_qfs_training = args[:encoded_fringe_site_prior_score_for_qfs_training] if args.key?(:encoded_fringe_site_prior_score_for_qfs_training)
          @encoded_predicted_xlq_score_and_confidence = args[:encoded_predicted_xlq_score_and_confidence] if args.key?(:encoded_predicted_xlq_score_and_confidence)
          @encoded_proximity_score = args[:encoded_proximity_score] if args.key?(:encoded_proximity_score)
        end
      end
      
      # 
      class QualityGenieComplexQueriesComplexQueriesOutputRewrite
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entities`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityGenieComplexQueriesComplexQueriesOutputRewriteEntity>]
        attr_accessor :entities
      
        # 
        # Corresponds to the JSON property `rewriteType`
        # @return [String]
        attr_accessor :rewrite_type
      
        # 
        # Corresponds to the JSON property `textualRewrite`
        # @return [String]
        attr_accessor :textual_rewrite
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entities = args[:entities] if args.key?(:entities)
          @rewrite_type = args[:rewrite_type] if args.key?(:rewrite_type)
          @textual_rewrite = args[:textual_rewrite] if args.key?(:textual_rewrite)
        end
      end
      
      # 
      class QualityGenieComplexQueriesComplexQueriesOutputRewriteEntity
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Compressed version of quality_geo_brainloc.goldmine.BrainlocAnnotation for
      # indexing. (See BrainlocAnnotation for detailed documentation.) Next ID: 10
      class QualityGeoBrainlocBrainlocAttachment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `brainlocVersion`
        # @return [Fixnum]
        attr_accessor :brainloc_version
      
        # 
        # Corresponds to the JSON property `topCitiesRawScores`
        # @return [Array<Fixnum>]
        attr_accessor :top_cities_raw_scores
      
        # Compressed top locations and their scores. *Locations are stored using their
        # model vocab IDs. *Location scores are stored using 14 bits of precision (2
        # bytes).
        # Corresponds to the JSON property `topCitiesVocabIds`
        # @return [Array<Fixnum>]
        attr_accessor :top_cities_vocab_ids
      
        # 
        # Corresponds to the JSON property `topCountiesRawScores`
        # @return [Array<Fixnum>]
        attr_accessor :top_counties_raw_scores
      
        # 
        # Corresponds to the JSON property `topCountiesVocabIds`
        # @return [Array<Fixnum>]
        attr_accessor :top_counties_vocab_ids
      
        # 
        # Corresponds to the JSON property `topCountriesRawScores`
        # @return [Array<Fixnum>]
        attr_accessor :top_countries_raw_scores
      
        # 
        # Corresponds to the JSON property `topCountriesVocabIds`
        # @return [Array<Fixnum>]
        attr_accessor :top_countries_vocab_ids
      
        # 
        # Corresponds to the JSON property `topStatesRawScores`
        # @return [Array<Fixnum>]
        attr_accessor :top_states_raw_scores
      
        # 
        # Corresponds to the JSON property `topStatesVocabIds`
        # @return [Array<Fixnum>]
        attr_accessor :top_states_vocab_ids
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @brainloc_version = args[:brainloc_version] if args.key?(:brainloc_version)
          @top_cities_raw_scores = args[:top_cities_raw_scores] if args.key?(:top_cities_raw_scores)
          @top_cities_vocab_ids = args[:top_cities_vocab_ids] if args.key?(:top_cities_vocab_ids)
          @top_counties_raw_scores = args[:top_counties_raw_scores] if args.key?(:top_counties_raw_scores)
          @top_counties_vocab_ids = args[:top_counties_vocab_ids] if args.key?(:top_counties_vocab_ids)
          @top_countries_raw_scores = args[:top_countries_raw_scores] if args.key?(:top_countries_raw_scores)
          @top_countries_vocab_ids = args[:top_countries_vocab_ids] if args.key?(:top_countries_vocab_ids)
          @top_states_raw_scores = args[:top_states_raw_scores] if args.key?(:top_states_raw_scores)
          @top_states_vocab_ids = args[:top_states_vocab_ids] if args.key?(:top_states_vocab_ids)
        end
      end
      
      # 
      class QualityLabelsGoogleLabelData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `label`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityLabelsGoogleLabelDataLabel>]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # 
      class QualityLabelsGoogleLabelDataLabel
        include Google::Apis::Core::Hashable
      
        # If global_label_value is present, confidence is ignored. confidence is
        # DEPRECATED.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # A byte-size value representing 64 * (1 + global_label_value). Use this instead
        # of global_label_value to save on label storage. See quality_prose::
        # LabelValueToBucket() for more info.
        # Corresponds to the JSON property `globalLabelBucket`
        # @return [Fixnum]
        attr_accessor :global_label_bucket
      
        # 
        # Corresponds to the JSON property `globalLabelValue`
        # @return [Float]
        attr_accessor :global_label_value
      
        # At least one of label_id and label_name must be filled in
        # Corresponds to the JSON property `labelId`
        # @return [Fixnum]
        attr_accessor :label_id
      
        # 
        # Corresponds to the JSON property `labelName`
        # @return [String]
        attr_accessor :label_name
      
        # 
        # Corresponds to the JSON property `provider`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityLabelsGoogleLabelDataLabelProvider>]
        attr_accessor :provider
      
        # 
        # Corresponds to the JSON property `providerId`
        # @return [Array<Fixnum>]
        attr_accessor :provider_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @global_label_bucket = args[:global_label_bucket] if args.key?(:global_label_bucket)
          @global_label_value = args[:global_label_value] if args.key?(:global_label_value)
          @label_id = args[:label_id] if args.key?(:label_id)
          @label_name = args[:label_name] if args.key?(:label_name)
          @provider = args[:provider] if args.key?(:provider)
          @provider_id = args[:provider_id] if args.key?(:provider_id)
        end
      end
      
      # If Provider group is not present the provider is the legacy classifiers (with
      # id 0) and the label_value provided by Google is the global_label_value.
      class QualityLabelsGoogleLabelDataLabelProvider
        include Google::Apis::Core::Hashable
      
        # This field is intended to be deprecated. If id == 0 and feed is true it means
        # this label is from a feed. If id == 0 and feed is false, this label is from "
        # Google" If id != 0, feed is meaningless.
        # Corresponds to the JSON property `feed`
        # @return [Boolean]
        attr_accessor :feed
        alias_method :feed?, :feed
      
        # We are currently using this field to indicate an id of the set of classifiers
        # that produced this label. This deviates from the original intention. Also see
        # ClassifierDescription and refer to http://go/genre-labels-provider-id for
        # further info.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # A byte-size value representing 64 * (1 + global_label_value). Use it instead
        # of global_label_value to save on label storage.
        # Corresponds to the JSON property `labelBucket`
        # @return [Fixnum]
        attr_accessor :label_bucket
      
        # 
        # Corresponds to the JSON property `labelValue`
        # @return [Float]
        attr_accessor :label_value
      
        # This name will only sometimes be filled in! Frontends can in general expect
        # this to be filled in, but it will not usually be stored in backends.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feed = args[:feed] if args.key?(:feed)
          @id = args[:id] if args.key?(:id)
          @label_bucket = args[:label_bucket] if args.key?(:label_bucket)
          @label_value = args[:label_value] if args.key?(:label_value)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class QualityNavboostCrapsAgingData
        include Google::Apis::Core::Hashable
      
        # Documents with byline date younger than month at the event time.
        # Corresponds to the JSON property `lastMonthBucket`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsAgingDataAgingAgeBucket]
        attr_accessor :last_month_bucket
      
        # Documents with byline date younger than week at the event time.
        # Corresponds to the JSON property `lastWeekBucket`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsAgingDataAgingAgeBucket]
        attr_accessor :last_week_bucket
      
        # Documents with byline date younger than year at the event time.
        # Corresponds to the JSON property `lastYearBucket`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsAgingDataAgingAgeBucket]
        attr_accessor :last_year_bucket
      
        # Documents with byline date older than year at the event time.
        # Corresponds to the JSON property `yearPlusBucket`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsAgingDataAgingAgeBucket]
        attr_accessor :year_plus_bucket
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_month_bucket = args[:last_month_bucket] if args.key?(:last_month_bucket)
          @last_week_bucket = args[:last_week_bucket] if args.key?(:last_week_bucket)
          @last_year_bucket = args[:last_year_bucket] if args.key?(:last_year_bucket)
          @year_plus_bucket = args[:year_plus_bucket] if args.key?(:year_plus_bucket)
        end
      end
      
      # 
      class QualityNavboostCrapsAgingDataAgingAgeBucket
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `goodClicks`
        # @return [Float]
        attr_accessor :good_clicks
      
        # 
        # Corresponds to the JSON property `impressions`
        # @return [Float]
        attr_accessor :impressions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @good_clicks = args[:good_clicks] if args.key?(:good_clicks)
          @impressions = args[:impressions] if args.key?(:impressions)
        end
      end
      
      # Click / impression signals for craps. The tag numbers are the same as they
      # were in the original CrapsData (below). This is deliberate.
      class QualityNavboostCrapsCrapsClickSignals
        include Google::Apis::Core::Hashable
      
        # Thus far this field is only used for host level unsquashed impressions. When
        # compressed (e.g., in perdocdata.proto, CompressedQualitySignals), this value
        # is represented individually and thus is generally incompatible with the other
        # values which are compressed as click-ratios.
        # Corresponds to the JSON property `absoluteImpressions`
        # @return [Float]
        attr_accessor :absolute_impressions
      
        # 
        # Corresponds to the JSON property `badClicks`
        # @return [Float]
        attr_accessor :bad_clicks
      
        # 
        # Corresponds to the JSON property `clicks`
        # @return [Float]
        attr_accessor :clicks
      
        # 
        # Corresponds to the JSON property `goodClicks`
        # @return [Float]
        attr_accessor :good_clicks
      
        # 
        # Corresponds to the JSON property `impressions`
        # @return [Float]
        attr_accessor :impressions
      
        # 
        # Corresponds to the JSON property `lastLongestClicks`
        # @return [Float]
        attr_accessor :last_longest_clicks
      
        # This is not being populated for the current format - instead two instances of
        # CrapsClickSignals (squashed/unsquashed) are used. We are migrating to the new
        # format where this field will be populated.
        # Corresponds to the JSON property `unsquashedClicks`
        # @return [Float]
        attr_accessor :unsquashed_clicks
      
        # This is not being populated for the current format - instead two instances of
        # CrapsClickSignals (squashed/unsquashed) are used. We are migrating to the new
        # format where this field will be populated.
        # Corresponds to the JSON property `unsquashedImpressions`
        # @return [Float]
        attr_accessor :unsquashed_impressions
      
        # 
        # Corresponds to the JSON property `unsquashedLastLongestClicks`
        # @return [Float]
        attr_accessor :unsquashed_last_longest_clicks
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @absolute_impressions = args[:absolute_impressions] if args.key?(:absolute_impressions)
          @bad_clicks = args[:bad_clicks] if args.key?(:bad_clicks)
          @clicks = args[:clicks] if args.key?(:clicks)
          @good_clicks = args[:good_clicks] if args.key?(:good_clicks)
          @impressions = args[:impressions] if args.key?(:impressions)
          @last_longest_clicks = args[:last_longest_clicks] if args.key?(:last_longest_clicks)
          @unsquashed_clicks = args[:unsquashed_clicks] if args.key?(:unsquashed_clicks)
          @unsquashed_impressions = args[:unsquashed_impressions] if args.key?(:unsquashed_impressions)
          @unsquashed_last_longest_clicks = args[:unsquashed_last_longest_clicks] if args.key?(:unsquashed_last_longest_clicks)
        end
      end
      
      # NEXT TAG: 27
      class QualityNavboostCrapsCrapsData
        include Google::Apis::Core::Hashable
      
        # Contains counter for Aging signal (go/freshness-aging). It's used internally
        # by Craps/Aging pipeline.
        # Corresponds to the JSON property `agingCounts`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsAgingData]
        attr_accessor :aging_counts
      
        # 
        # Corresponds to the JSON property `badClicks`
        # @return [Float]
        attr_accessor :bad_clicks
      
        # 
        # Corresponds to the JSON property `clicks`
        # @return [Float]
        attr_accessor :clicks
      
        # The two-letter uppercase country slice of the CrapsData. Examples: "US", "FR",
        # "BR"
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # CrapsDevice has the gws interface, gws tier and operating system for events
        # from QSessions.
        # Corresponds to the JSON property `device`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsDevice]
        attr_accessor :device
      
        # Contains CrapsClickSignals for specific features. (i.e. for mobile, US, metro
        # id - 123")
        # Corresponds to the JSON property `features`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityNavboostCrapsFeatureCrapsData>]
        attr_accessor :features
      
        # 
        # Corresponds to the JSON property `goodClicks`
        # @return [Float]
        attr_accessor :good_clicks
      
        # These fields may become legacy fields; we may retire them and use the squashed
        # field (below) instead, to allow for some nesting.
        # Corresponds to the JSON property `impressions`
        # @return [Float]
        attr_accessor :impressions
      
        # The language slice of the CrapsData. Examples: "en", "fr", "pt-BR",
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # The number of clicks that were last and longest in related user queries.
        # Corresponds to the JSON property `lastLongestClicks`
        # @return [Float]
        attr_accessor :last_longest_clicks
      
        # NEXT TAG: 27
        # Corresponds to the JSON property `mobileData`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsData]
        attr_accessor :mobile_data
      
        # Click / impression signals for craps. The tag numbers are the same as they
        # were in the original CrapsData (below). This is deliberate.
        # Corresponds to the JSON property `mobileSignals`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsClickSignals]
        attr_accessor :mobile_signals
      
        # Contains a packed string in network byte order, as expected by CrapsIpPrior.
        # Only populated if we looked up the ip_prior_bad_fraction at retrieval time.
        # Corresponds to the JSON property `packedIpAddress`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :packed_ip_address
      
        # Level of pattern. More general patterns get higher values. For URL patterns
        # this field = 0. For example, if we have "http://abc.def.ghi/xyz.html" level 0
        # pattern will be "http://abc.def.ghi/xyz.html" level 1 pattern will be "p://abc.
        # def.ghi" level 2 pattern will be "p://def.ghi"
        # Corresponds to the JSON property `patternLevel`
        # @return [Fixnum]
        attr_accessor :pattern_level
      
        # For pattern data, this will contain stats of the SCC's of the individual urls
        # contributing to the pattern.
        # Corresponds to the JSON property `patternSccStats`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsStatsWithWeightsProto]
        attr_accessor :pattern_scc_stats
      
        # 
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        # This field can be used by the craps pipeline to slice up signals by various
        # attributes such as device type, country, locale etc. The slice_tag can be an
        # arbitrary string, and the CrapsData values for each slice_tag are aggregated
        # separately, together with the default empty slice_tag.
        # Corresponds to the JSON property `sliceTag`
        # @return [String]
        attr_accessor :slice_tag
      
        # Click / impression signals for craps. The tag numbers are the same as they
        # were in the original CrapsData (below). This is deliberate.
        # Corresponds to the JSON property `squashed`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsClickSignals]
        attr_accessor :squashed
      
        # Used to assign a prior based on IP address. See quality/navboost/craps/craps-
        # ip-prior.h. This value is prior to the linear transformation (scaling / offset
        # / min / max) that's applied in craps-penalty.cc.
        # Corresponds to the JSON property `unscaledIpPriorBadFraction`
        # @return [Float]
        attr_accessor :unscaled_ip_prior_bad_fraction
      
        # Click / impression signals for craps. The tag numbers are the same as they
        # were in the original CrapsData (below). This is deliberate.
        # Corresponds to the JSON property `unsquashed`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsClickSignals]
        attr_accessor :unsquashed
      
        # Click / impression signals for craps. The tag numbers are the same as they
        # were in the original CrapsData (below). This is deliberate.
        # Corresponds to the JSON property `unsquashedMobileSignals`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsClickSignals]
        attr_accessor :unsquashed_mobile_signals
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aging_counts = args[:aging_counts] if args.key?(:aging_counts)
          @bad_clicks = args[:bad_clicks] if args.key?(:bad_clicks)
          @clicks = args[:clicks] if args.key?(:clicks)
          @country = args[:country] if args.key?(:country)
          @device = args[:device] if args.key?(:device)
          @features = args[:features] if args.key?(:features)
          @good_clicks = args[:good_clicks] if args.key?(:good_clicks)
          @impressions = args[:impressions] if args.key?(:impressions)
          @language = args[:language] if args.key?(:language)
          @last_longest_clicks = args[:last_longest_clicks] if args.key?(:last_longest_clicks)
          @mobile_data = args[:mobile_data] if args.key?(:mobile_data)
          @mobile_signals = args[:mobile_signals] if args.key?(:mobile_signals)
          @packed_ip_address = args[:packed_ip_address] if args.key?(:packed_ip_address)
          @pattern_level = args[:pattern_level] if args.key?(:pattern_level)
          @pattern_scc_stats = args[:pattern_scc_stats] if args.key?(:pattern_scc_stats)
          @query = args[:query] if args.key?(:query)
          @slice_tag = args[:slice_tag] if args.key?(:slice_tag)
          @squashed = args[:squashed] if args.key?(:squashed)
          @unscaled_ip_prior_bad_fraction = args[:unscaled_ip_prior_bad_fraction] if args.key?(:unscaled_ip_prior_bad_fraction)
          @unsquashed = args[:unsquashed] if args.key?(:unsquashed)
          @unsquashed_mobile_signals = args[:unsquashed_mobile_signals] if args.key?(:unsquashed_mobile_signals)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # CrapsDevice has the gws interface, gws tier and operating system for events
      # from QSessions.
      class QualityNavboostCrapsCrapsDevice
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `os`
        # @return [String]
        attr_accessor :os
      
        # An enum taken from GWSLogEntryProto that indicates what type of device a
        # request came from. This includes an entry for DESKTOP(1), MOBILE(2), and
        # TABLET(3) devices. Reference: - gwslog(608): GWSLogEntryProto.ux_interface
        # Corresponds to the JSON property `uxInterface`
        # @return [Fixnum]
        attr_accessor :ux_interface
      
        # Indicates the device browser tier for the given request. 1 means modern
        # browsers, 3 means very old browsers, and 2 is everything in the middle. See
        # Reference: - gwslog(609): GWSLogEntryProto.ux_tier
        # Corresponds to the JSON property `uxTier`
        # @return [Fixnum]
        attr_accessor :ux_tier
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @os = args[:os] if args.key?(:os)
          @ux_interface = args[:ux_interface] if args.key?(:ux_interface)
          @ux_tier = args[:ux_tier] if args.key?(:ux_tier)
        end
      end
      
      # 
      class QualityNavboostCrapsFeatureCrapsData
        include Google::Apis::Core::Hashable
      
        # Country, like "us". If not present, it's an aggregation for all countries.
        # This is the same format as one used in Glue.
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # Device, like "m". If not present, it's an aggregation for all devices. "m" -
        # mobile devices. "d" - destop devices.
        # Corresponds to the JSON property `device`
        # @return [String]
        attr_accessor :device
      
        # Language, like "en". If not present, it's an aggregation for all languages.
        # This is the same format as one used in Glue.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Location id for metro and city. If not present, it's an aggregation for all
        # locations within current country.
        # Corresponds to the JSON property `locationId`
        # @return [Fixnum]
        attr_accessor :location_id
      
        # Click / impression signals for craps. The tag numbers are the same as they
        # were in the original CrapsData (below). This is deliberate.
        # Corresponds to the JSON property `signals`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsClickSignals]
        attr_accessor :signals
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country = args[:country] if args.key?(:country)
          @device = args[:device] if args.key?(:device)
          @language = args[:language] if args.key?(:language)
          @location_id = args[:location_id] if args.key?(:location_id)
          @signals = args[:signals] if args.key?(:signals)
        end
      end
      
      # 
      class QualityNavboostCrapsStatsWithWeightsProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hi`
        # @return [Float]
        attr_accessor :hi
      
        # 
        # Corresponds to the JSON property `kind`
        # @return [Fixnum]
        attr_accessor :kind
      
        # 
        # Corresponds to the JSON property `lo`
        # @return [Float]
        attr_accessor :lo
      
        # 
        # Corresponds to the JSON property `mean`
        # @return [Float]
        attr_accessor :mean
      
        # 
        # Corresponds to the JSON property `median`
        # @return [Float]
        attr_accessor :median
      
        # 
        # Corresponds to the JSON property `n`
        # @return [Fixnum]
        attr_accessor :n
      
        # 
        # Corresponds to the JSON property `pc10`
        # @return [Float]
        attr_accessor :pc10
      
        # 
        # Corresponds to the JSON property `pc25`
        # @return [Float]
        attr_accessor :pc25
      
        # 
        # Corresponds to the JSON property `pc75`
        # @return [Float]
        attr_accessor :pc75
      
        # 
        # Corresponds to the JSON property `pc90`
        # @return [Float]
        attr_accessor :pc90
      
        # 
        # Corresponds to the JSON property `stdError`
        # @return [Float]
        attr_accessor :std_error
      
        # 
        # Corresponds to the JSON property `stddev`
        # @return [Float]
        attr_accessor :stddev
      
        # 
        # Corresponds to the JSON property `varOfMean`
        # @return [Float]
        attr_accessor :var_of_mean
      
        # 
        # Corresponds to the JSON property `variance`
        # @return [Float]
        attr_accessor :variance
      
        # 
        # Corresponds to the JSON property `weightedN`
        # @return [Float]
        attr_accessor :weighted_n
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hi = args[:hi] if args.key?(:hi)
          @kind = args[:kind] if args.key?(:kind)
          @lo = args[:lo] if args.key?(:lo)
          @mean = args[:mean] if args.key?(:mean)
          @median = args[:median] if args.key?(:median)
          @n = args[:n] if args.key?(:n)
          @pc10 = args[:pc10] if args.key?(:pc10)
          @pc25 = args[:pc25] if args.key?(:pc25)
          @pc75 = args[:pc75] if args.key?(:pc75)
          @pc90 = args[:pc90] if args.key?(:pc90)
          @std_error = args[:std_error] if args.key?(:std_error)
          @stddev = args[:stddev] if args.key?(:stddev)
          @var_of_mean = args[:var_of_mean] if args.key?(:var_of_mean)
          @variance = args[:variance] if args.key?(:variance)
          @weighted_n = args[:weighted_n] if args.key?(:weighted_n)
        end
      end
      
      # Experimental NsrTeam data. This is a proto containing versioned signals which
      # can be used to run live experiments. This proto will not be propagated to MDU
      # shards, but it will be populated at query time by go/web-signal-joins inside
      # the CompressedQualitySignals subproto of PerDocData proto. See go/0DayLEs for
      # the design doc. Note how this is only meant to be used during LEs, it should *
      # not* be used for launches.
      class QualityNsrExperimentalNsrTeamData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `versionedSignals`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityNsrExperimentalNsrTeamScoringSignal>]
        attr_accessor :versioned_signals
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @versioned_signals = args[:versioned_signals] if args.key?(:versioned_signals)
        end
      end
      
      # The versioned signals used by the ExperimentalNsrTeamData proto.
      class QualityNsrExperimentalNsrTeamScoringSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `valueBool`
        # @return [Boolean]
        attr_accessor :value_bool
        alias_method :value_bool?, :value_bool
      
        # 
        # Corresponds to the JSON property `valueDouble`
        # @return [Float]
        attr_accessor :value_double
      
        # 
        # Corresponds to the JSON property `valueFloat`
        # @return [Float]
        attr_accessor :value_float
      
        # 
        # Corresponds to the JSON property `valueInt32`
        # @return [Fixnum]
        attr_accessor :value_int32
      
        # 
        # Corresponds to the JSON property `valueUint32`
        # @return [Fixnum]
        attr_accessor :value_uint32
      
        # 
        # Corresponds to the JSON property `versionId`
        # @return [Fixnum]
        attr_accessor :version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @value_bool = args[:value_bool] if args.key?(:value_bool)
          @value_double = args[:value_double] if args.key?(:value_double)
          @value_float = args[:value_float] if args.key?(:value_float)
          @value_int32 = args[:value_int32] if args.key?(:value_int32)
          @value_uint32 = args[:value_uint32] if args.key?(:value_uint32)
          @version_id = args[:version_id] if args.key?(:version_id)
        end
      end
      
      # This is a wrapper needed for the WSJ corpus. We want the WSJ RPCs to inject
      # both the experimental_data and the keys, and as of June 2022 these need to be
      # first level members of the proto.
      class QualityNsrExperimentalNsrTeamWsjData
        include Google::Apis::Core::Hashable
      
        # Experimental NsrTeam data. This is a proto containing versioned signals which
        # can be used to run live experiments. This proto will not be propagated to MDU
        # shards, but it will be populated at query time by go/web-signal-joins inside
        # the CompressedQualitySignals subproto of PerDocData proto. See go/0DayLEs for
        # the design doc. Note how this is only meant to be used during LEs, it should *
        # not* be used for launches.
        # Corresponds to the JSON property `experimentalNsrTeamData`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrExperimentalNsrTeamData]
        attr_accessor :experimental_nsr_team_data
      
        # The key used to lookup this data in the WSJ corpus. The WSJ data is sitechunk-
        # level, however the documents in the MDU shards are simply urls. WSJ does a
        # mapping from url -> `primary_chunk, secondary, fallbacks, etc.` and retrieves
        # all the keys from the corpus. This lookup key field will keep track of which
        # key was used for this particular lookup.
        # Corresponds to the JSON property `lookupKey`
        # @return [String]
        attr_accessor :lookup_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experimental_nsr_team_data = args[:experimental_nsr_team_data] if args.key?(:experimental_nsr_team_data)
          @lookup_key = args[:lookup_key] if args.key?(:lookup_key)
        end
      end
      
      # Versioned NSR score data.
      class QualityNsrNsrVersionedData
        include Google::Apis::Core::Hashable
      
        # The corresponding NSR value.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        # The unique id of the version, preferably just scaled: 19.1 x 10 = 191.
        # Corresponds to the JSON property `versionId`
        # @return [Fixnum]
        attr_accessor :version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @value = args[:value] if args.key?(:value)
          @version_id = args[:version_id] if args.key?(:version_id)
        end
      end
      
      # NOTE: When adding a new field to be propagated to Raffia check if
      # NsrPatternSignalSpec needs to be updated. Next ID: 31
      class QualityNsrNsrData
        include Google::Apis::Core::Hashable
      
        # Score from article classification of the site.
        # Corresponds to the JSON property `articleScore`
        # @return [Float]
        attr_accessor :article_score
      
        # 
        # Corresponds to the JSON property `articleScoreV2`
        # @return [Float]
        attr_accessor :article_score_v2
      
        # An id for defining clusters of sites. Used in ecosystem experiments (project
        # Tundra).
        # Corresponds to the JSON property `clusterId`
        # @return [Fixnum]
        attr_accessor :cluster_id
      
        # The uplift-per-cluster values used in Tundra's uplift arm.
        # Corresponds to the JSON property `clusterUplift`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrNsrDataClusterUplift]
        attr_accessor :cluster_uplift
      
        # Delta site-level signal in Q* penalizing sites with a large number of
        # distracting/annoying resources loaded by the site (see go/clutter-v0).
        # Corresponds to the JSON property `clutterScore`
        # @return [Float]
        attr_accessor :clutter_score
      
        # 
        # Corresponds to the JSON property `host`
        # @return [String]
        attr_accessor :host
      
        # Bit to determine whether the site has the local authority covid signal, as
        # computed by go/covid-local-authority
        # Corresponds to the JSON property `isCovidLocalAuthority`
        # @return [Boolean]
        attr_accessor :is_covid_local_authority
        alias_method :is_covid_local_authority?, :is_covid_local_authority
      
        # Bit to determine whether the site has the election authority signal, as
        # computed by go/election-authority
        # Corresponds to the JSON property `isElectionAuthority`
        # @return [Boolean]
        attr_accessor :is_election_authority
        alias_method :is_election_authority?, :is_election_authority
      
        # Bit to determine whether the site has mostly video content, but is not hosted
        # on any known video-hosting domains. Site is considered to be video-focused, if
        # it has > 50% of the URLs with watch pages (with smoothing prior). ariane/
        # 4045246
        # Corresponds to the JSON property `isVideoFocusedSite`
        # @return [Boolean]
        attr_accessor :is_video_focused_site
        alias_method :is_video_focused_site?, :is_video_focused_site
      
        # Locality score of the site, i.e. the locality component of the LocalAuthority
        # signal (see go/pq-localauthority).
        # Corresponds to the JSON property `localityScore`
        # @return [Float]
        attr_accessor :locality_score
      
        # Contains meta information about this data.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::QualityNsrNsrDataMetadata]
        attr_accessor :metadata
      
        # This field used as a temporary field for clean transitions when we need to
        # roll out Q* and NSR changes simultaneously.
        # Corresponds to the JSON property `newNsr`
        # @return [Float]
        attr_accessor :new_nsr
      
        # 
        # Corresponds to the JSON property `nsr`
        # @return [Float]
        attr_accessor :nsr
      
        # This signal is used to unconditionally override NSR as a bid in Q*. Should
        # only be used in case of emergency (see go/nsr-override-bid). To have any
        # effect, the value should be present and greater than 0.001.
        # Corresponds to the JSON property `nsrOverrideBid`
        # @return [Float]
        attr_accessor :nsr_override_bid
      
        # NSR variance logodds [0, infinity).
        # Corresponds to the JSON property `nsrVariance`
        # @return [Float]
        attr_accessor :nsr_variance
      
        # If true indicates that we do not have NSR data computed for the chunk, and
        # instead the data is coming from an average of other host chunks.
        # Corresponds to the JSON property `nsrdataFromFallbackPatternKey`
        # @return [Boolean]
        attr_accessor :nsrdata_from_fallback_pattern_key
        alias_method :nsrdata_from_fallback_pattern_key?, :nsrdata_from_fallback_pattern_key
      
        # Secondary NSR sitechunk. When present, it provides more granular chunking than
        # primary sitechunks (see quality/nsr/util/sitechunker.h for details).
        # Corresponds to the JSON property `secondarySiteChunk`
        # @return [String]
        attr_accessor :secondary_site_chunk
      
        # Aggregated value of url autopilot scores for this sitechunk.
        # Corresponds to the JSON property `siteAutopilotScore`
        # @return [Float]
        attr_accessor :site_autopilot_score
      
        # Primary NSR sitechunk. In most of the cases it's same as HOST_LEVEL_V3
        # sitechunked canonical url of the document. In rare, but important cases it's
        # based on page markup (see quality/nsr/util/sitechunker.h for details).
        # Corresponds to the JSON property `siteChunk`
        # @return [String]
        attr_accessor :site_chunk
      
        # These are only annotated in the Goldmine NSR annotator.
        # Corresponds to the JSON property `siteChunkSource`
        # @return [String]
        attr_accessor :site_chunk_source
      
        # Average value of the site_link_in for pages in the sitechunk.
        # Corresponds to the JSON property `siteLinkIn`
        # @return [Float]
        attr_accessor :site_link_in
      
        # Aggregated value of url link out scores for this sitechunk.
        # Corresponds to the JSON property `siteLinkOut`
        # @return [Float]
        attr_accessor :site_link_out
      
        # 
        # Corresponds to the JSON property `sitePr`
        # @return [Float]
        attr_accessor :site_pr
      
        # Estimate of site's PQ rating stddev--spread of the page-level PQ ratings of a
        # site. Note this is different from nsr_variance which predicts error of NSR
        # itself from the aggregated site-level rating.
        # Corresponds to the JSON property `siteQualityStddev`
        # @return [Float]
        attr_accessor :site_quality_stddev
      
        # The SpamBrain LAVC score, as of July 2022. See more information at go/
        # cloverfield-lavc-deck.
        # Corresponds to the JSON property `spambrainLavcScore`
        # @return [Float]
        attr_accessor :spambrain_lavc_score
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Versioned map of NSR values for experimenting with the next release.
        # Corresponds to the JSON property `versionedData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityNsrNsrVersionedData>]
        attr_accessor :versioned_data
      
        # NSR from a headroom model targeting low-quality video sites.
        # Corresponds to the JSON property `vlqNsr`
        # @return [Float]
        attr_accessor :vlq_nsr
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @article_score = args[:article_score] if args.key?(:article_score)
          @article_score_v2 = args[:article_score_v2] if args.key?(:article_score_v2)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_uplift = args[:cluster_uplift] if args.key?(:cluster_uplift)
          @clutter_score = args[:clutter_score] if args.key?(:clutter_score)
          @host = args[:host] if args.key?(:host)
          @is_covid_local_authority = args[:is_covid_local_authority] if args.key?(:is_covid_local_authority)
          @is_election_authority = args[:is_election_authority] if args.key?(:is_election_authority)
          @is_video_focused_site = args[:is_video_focused_site] if args.key?(:is_video_focused_site)
          @locality_score = args[:locality_score] if args.key?(:locality_score)
          @metadata = args[:metadata] if args.key?(:metadata)
          @new_nsr = args[:new_nsr] if args.key?(:new_nsr)
          @nsr = args[:nsr] if args.key?(:nsr)
          @nsr_override_bid = args[:nsr_override_bid] if args.key?(:nsr_override_bid)
          @nsr_variance = args[:nsr_variance] if args.key?(:nsr_variance)
          @nsrdata_from_fallback_pattern_key = args[:nsrdata_from_fallback_pattern_key] if args.key?(:nsrdata_from_fallback_pattern_key)
          @secondary_site_chunk = args[:secondary_site_chunk] if args.key?(:secondary_site_chunk)
          @site_autopilot_score = args[:site_autopilot_score] if args.key?(:site_autopilot_score)
          @site_chunk = args[:site_chunk] if args.key?(:site_chunk)
          @site_chunk_source = args[:site_chunk_source] if args.key?(:site_chunk_source)
          @site_link_in = args[:site_link_in] if args.key?(:site_link_in)
          @site_link_out = args[:site_link_out] if args.key?(:site_link_out)
          @site_pr = args[:site_pr] if args.key?(:site_pr)
          @site_quality_stddev = args[:site_quality_stddev] if args.key?(:site_quality_stddev)
          @spambrain_lavc_score = args[:spambrain_lavc_score] if args.key?(:spambrain_lavc_score)
          @url = args[:url] if args.key?(:url)
          @versioned_data = args[:versioned_data] if args.key?(:versioned_data)
          @vlq_nsr = args[:vlq_nsr] if args.key?(:vlq_nsr)
        end
      end
      
      # The uplift-per-cluster values used in Tundra's uplift arm.
      class QualityNsrNsrDataClusterUplift
        include Google::Apis::Core::Hashable
      
        # Score for the local sites arm.
        # Corresponds to the JSON property `local`
        # @return [Float]
        attr_accessor :local
      
        # Score for the small sites arm.
        # Corresponds to the JSON property `small`
        # @return [Float]
        attr_accessor :small
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @local = args[:local] if args.key?(:local)
          @small = args[:small] if args.key?(:small)
        end
      end
      
      # Contains meta information about this data.
      class QualityNsrNsrDataMetadata
        include Google::Apis::Core::Hashable
      
        # This is an internal field set by Raffia, to indicate which lookup key this
        # record belonged to. This is helpful in determining where the final data is
        # coming from, as we don't populate `site_chunk` fields offline (at all), so we
        # cannot distinguish if data is coming from host fallback, secondary chunks or
        # something else.
        # Corresponds to the JSON property `raffiaLookupKey`
        # @return [String]
        attr_accessor :raffia_lookup_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raffia_lookup_key = args[:raffia_lookup_key] if args.key?(:raffia_lookup_key)
        end
      end
      
      # 
      class QualityNsrPqData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `deltaAutopilotScore`
        # @return [Float]
        attr_accessor :delta_autopilot_score
      
        # 
        # Corresponds to the JSON property `deltaLinkIncoming`
        # @return [Float]
        attr_accessor :delta_link_incoming
      
        # 
        # Corresponds to the JSON property `deltaLinkOutgoing`
        # @return [Float]
        attr_accessor :delta_link_outgoing
      
        # Total deltaNSR adjustment based on subchunks. This is a page-level adjustment (
        # subchunks are retrieved based on the page classification).
        # Corresponds to the JSON property `deltaSubchunkAdjustment`
        # @return [Float]
        attr_accessor :delta_subchunk_adjustment
      
        # 
        # Corresponds to the JSON property `linkIncoming`
        # @return [Float]
        attr_accessor :link_incoming
      
        # 
        # Corresponds to the JSON property `linkOutgoing`
        # @return [Float]
        attr_accessor :link_outgoing
      
        # 
        # Corresponds to the JSON property `page2vecLq`
        # @return [Float]
        attr_accessor :page2vec_lq
      
        # 
        # Corresponds to the JSON property `subchunkData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityNsrPqDataSubchunkData>]
        attr_accessor :subchunk_data
      
        # 
        # Corresponds to the JSON property `urlAutopilotScore`
        # @return [Float]
        attr_accessor :url_autopilot_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @delta_autopilot_score = args[:delta_autopilot_score] if args.key?(:delta_autopilot_score)
          @delta_link_incoming = args[:delta_link_incoming] if args.key?(:delta_link_incoming)
          @delta_link_outgoing = args[:delta_link_outgoing] if args.key?(:delta_link_outgoing)
          @delta_subchunk_adjustment = args[:delta_subchunk_adjustment] if args.key?(:delta_subchunk_adjustment)
          @link_incoming = args[:link_incoming] if args.key?(:link_incoming)
          @link_outgoing = args[:link_outgoing] if args.key?(:link_outgoing)
          @page2vec_lq = args[:page2vec_lq] if args.key?(:page2vec_lq)
          @subchunk_data = args[:subchunk_data] if args.key?(:subchunk_data)
          @url_autopilot_score = args[:url_autopilot_score] if args.key?(:url_autopilot_score)
        end
      end
      
      # Data used to compute delta_subchunk_adjustment. (I.e, the subchunks looked up,
      # with their confidences and weights). This data is not propagated to ascorer.
      class QualityNsrPqDataSubchunkData
        include Google::Apis::Core::Hashable
      
        # Confidence associated with the chunk.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Subchunk delta in nsr.
        # Corresponds to the JSON property `deltaNsr`
        # @return [Float]
        attr_accessor :delta_nsr
      
        # Weight with which this document belong to this subchunk (greater than 0).
        # Corresponds to the JSON property `pageWeight`
        # @return [Float]
        attr_accessor :page_weight
      
        # Type of this chunk. Eg, ymyl_health, d2v, etc.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @delta_nsr = args[:delta_nsr] if args.key?(:delta_nsr)
          @page_weight = args[:page_weight] if args.key?(:page_weight)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class QualityOrbitAsteroidBeltDocumentIntentScores
        include Google::Apis::Core::Hashable
      
        # Map of imageid key to ImageIntentScores, for images on cdoc.doc_images
        # Corresponds to the JSON property `imageIntentScores`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::QualityOrbitAsteroidBeltImageIntentScores>]
        attr_accessor :image_intent_scores
      
        # The 'intents' and 'scores' fields are stored as parallel lists for compactness.
        # The 'scores' field should not be accessed directly, but instead through the
        # functions in document_intent_scores_utils.
        # Corresponds to the JSON property `intents`
        # @return [Array<String>]
        attr_accessor :intents
      
        # The intent scores, scaled to integers between 0 and 100 for compactness.
        # Corresponds to the JSON property `scores`
        # @return [Array<Fixnum>]
        attr_accessor :scores
      
        # Version 0: Presence of an intent label in the 'intents' field represents our
        # best-effort classification. The 'scores' field is not meaningful. Version 1:
        # Values in the 'scores' field represent the estimated precision of the
        # classifier for a threshold at that score.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_intent_scores = args[:image_intent_scores] if args.key?(:image_intent_scores)
          @intents = args[:intents] if args.key?(:intents)
          @scores = args[:scores] if args.key?(:scores)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class QualityOrbitAsteroidBeltImageIntentScores
        include Google::Apis::Core::Hashable
      
        # The unique identifier for an Asteroid Belt document intent is being reused
        # here
        # Corresponds to the JSON property `intents`
        # @return [Array<String>]
        attr_accessor :intents
      
        # The intent scores, scaled to integers between 0 and 100 for compactness.
        # Corresponds to the JSON property `scores`
        # @return [Array<Fixnum>]
        attr_accessor :scores
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intents = args[:intents] if args.key?(:intents)
          @scores = args[:scores] if args.key?(:scores)
        end
      end
      
      # Information for chosen snippet. Next ID: 7
      class QualityPreviewChosenSnippetInfo
        include Google::Apis::Core::Hashable
      
        # Whether this snippet is a vulgar candidate.
        # Corresponds to the JSON property `isVulgar`
        # @return [Boolean]
        attr_accessor :is_vulgar
        alias_method :is_vulgar?, :is_vulgar
      
        # 
        # Corresponds to the JSON property `leadingTextType`
        # @return [String]
        attr_accessor :leading_text_type
      
        # 
        # Corresponds to the JSON property `snippetType`
        # @return [String]
        attr_accessor :snippet_type
      
        # Source of the chosen snippet, decided in PORC. String value of quality.porc.
        # TextSnippetCandidate.TextSnippetSource defined at google3/quality/porc/proto/
        # text_snippet.proto Note: This field is only populated and used in offline
        # pipeline.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `tidbits`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityPreviewChosenSnippetInfoTidbitInfo>]
        attr_accessor :tidbits
      
        # Whether this snippet has trailing ellipsis.
        # Corresponds to the JSON property `trailingEllipsis`
        # @return [Boolean]
        attr_accessor :trailing_ellipsis
        alias_method :trailing_ellipsis?, :trailing_ellipsis
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_vulgar = args[:is_vulgar] if args.key?(:is_vulgar)
          @leading_text_type = args[:leading_text_type] if args.key?(:leading_text_type)
          @snippet_type = args[:snippet_type] if args.key?(:snippet_type)
          @source = args[:source] if args.key?(:source)
          @tidbits = args[:tidbits] if args.key?(:tidbits)
          @trailing_ellipsis = args[:trailing_ellipsis] if args.key?(:trailing_ellipsis)
        end
      end
      
      # Information to identify tidbits.
      class QualityPreviewChosenSnippetInfoTidbitInfo
        include Google::Apis::Core::Hashable
      
        # Section name of current snippet.
        # Corresponds to the JSON property `sectionName`
        # @return [String]
        attr_accessor :section_name
      
        # Separator to put before this tidbit.
        # Corresponds to the JSON property `separator`
        # @return [String]
        attr_accessor :separator
      
        # Tidbit text for validation.
        # Corresponds to the JSON property `tidbitText`
        # @return [String]
        attr_accessor :tidbit_text
      
        # Tidbit token range in the section.
        # Corresponds to the JSON property `tokenBegin`
        # @return [Fixnum]
        attr_accessor :token_begin
      
        # 
        # Corresponds to the JSON property `tokenEnd`
        # @return [Fixnum]
        attr_accessor :token_end
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @section_name = args[:section_name] if args.key?(:section_name)
          @separator = args[:separator] if args.key?(:separator)
          @tidbit_text = args[:tidbit_text] if args.key?(:tidbit_text)
          @token_begin = args[:token_begin] if args.key?(:token_begin)
          @token_end = args[:token_end] if args.key?(:token_end)
        end
      end
      
      # Snippet candidate related information and signal scores.
      class QualityPreviewRanklabSnippet
        include Google::Apis::Core::Hashable
      
        # Snippet brain scores.
        # Corresponds to the JSON property `brainFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetBrainFeatures]
        attr_accessor :brain_features
      
        # Document related features used in snippets scoring. Next ID: 10
        # Corresponds to the JSON property `documentFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetDocumentFeatures]
        attr_accessor :document_features
      
        # 
        # Corresponds to the JSON property `experimentalFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetExperimentalFeatures]
        attr_accessor :experimental_features
      
        # Quality related features used in snippets scoring. Next ID: 10
        # Corresponds to the JSON property `qualityFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetQualityFeatures]
        attr_accessor :quality_features
      
        # Query related features used in snippets scoring. Next ID: 7
        # Corresponds to the JSON property `queryFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetQueryFeatures]
        attr_accessor :query_features
      
        # Snippet query term coverage features.
        # Corresponds to the JSON property `queryTermCoverageFeatures`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetQueryTermCoverageFeatures]
        attr_accessor :query_term_coverage_features
      
        # Information for chosen snippet. Next ID: 7
        # Corresponds to the JSON property `snippetInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewChosenSnippetInfo]
        attr_accessor :snippet_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @brain_features = args[:brain_features] if args.key?(:brain_features)
          @document_features = args[:document_features] if args.key?(:document_features)
          @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
          @quality_features = args[:quality_features] if args.key?(:quality_features)
          @query_features = args[:query_features] if args.key?(:query_features)
          @query_term_coverage_features = args[:query_term_coverage_features] if args.key?(:query_term_coverage_features)
          @snippet_info = args[:snippet_info] if args.key?(:snippet_info)
        end
      end
      
      # A collection of data corresponding to a single title candidate. This will be
      # used as: - a collection of signals to score and select titles in production -
      # an input for training title models NOTE: When adding a floating point value
      # for Ranklab purposes, use float32 instead of float64, because some of the
      # Ranklab library still does not fully support float64. Next ID: 67
      class QualityPreviewRanklabTitle
        include Google::Apis::Core::Hashable
      
        # `goldmine_final_score` value in base.
        # Corresponds to the JSON property `baseGoldmineFinalScore`
        # @return [Float]
        attr_accessor :base_goldmine_final_score
      
        # The ranking index of this candidate (starting from 0) in base.
        # Corresponds to the JSON property `baseRank`
        # @return [Fixnum]
        attr_accessor :base_rank
      
        # Title source type.
        # Corresponds to the JSON property `dataSourceType`
        # @return [String]
        attr_accessor :data_source_type
      
        # Document language for this title. It is used for model inference and hence
        # flattened into RanklabTitle instead of RanklabDoc.
        # Corresponds to the JSON property `docLang`
        # @return [String]
        attr_accessor :doc_lang
      
        # Represents how relavant this title candidate is to the document. Ranged in [0,
        # 1], and this signal is basically calculated as Cosine-similarity between
        # salient term vector and pQ2T model of title candidate sentence.
        # Corresponds to the JSON property `docRelevance`
        # @return [Float]
        attr_accessor :doc_relevance
      
        # Numbers of duplicated tokens. For example, duplicated tokens for a title "dog
        # cat cat cat" is 2 (for 2 extra "cat").
        # Corresponds to the JSON property `dupTokens`
        # @return [Fixnum]
        attr_accessor :dup_tokens
      
        # A score assigned for candidates forced by experiments.
        # Corresponds to the JSON property `forcedExperimentScore`
        # @return [Fixnum]
        attr_accessor :forced_experiment_score
      
        # The score for `text` computed in Goldmine (AlternativeTitlesAnnotator) with
        # additional scoring adjustments applied. Currently includes Blockbert scoring.
        # Corresponds to the JSON property `goldmineAdjustedScore`
        # @return [Float]
        attr_accessor :goldmine_adjusted_score
      
        # =============================================================== Internal boost
        # feature signals used to compute `goldmine_page_score`. They are exposed only
        # for debugging purpose.
        # Corresponds to the JSON property `goldmineAnchorFactor`
        # @return [Float]
        attr_accessor :goldmine_anchor_factor
      
        # 
        # Corresponds to the JSON property `goldmineAnchorSupportOnly`
        # @return [Float]
        attr_accessor :goldmine_anchor_support_only
      
        # 
        # Corresponds to the JSON property `goldmineBlockbertFactor`
        # @return [Float]
        attr_accessor :goldmine_blockbert_factor
      
        # 
        # Corresponds to the JSON property `goldmineBodyFactor`
        # @return [Float]
        attr_accessor :goldmine_body_factor
      
        # Deprecated: use `goldmine_page_score` instead.
        # Corresponds to the JSON property `goldmineFinalScore`
        # @return [Float]
        attr_accessor :goldmine_final_score
      
        # 
        # Corresponds to the JSON property `goldmineForeign`
        # @return [Float]
        attr_accessor :goldmine_foreign
      
        # 
        # Corresponds to the JSON property `goldmineGeometryFactor`
        # @return [Float]
        attr_accessor :goldmine_geometry_factor
      
        # 
        # Corresponds to the JSON property `goldmineHasBoilerplateInTitle`
        # @return [Float]
        attr_accessor :goldmine_has_boilerplate_in_title
      
        # 
        # Corresponds to the JSON property `goldmineHasTitleNgram`
        # @return [Float]
        attr_accessor :goldmine_has_title_ngram
      
        # 
        # Corresponds to the JSON property `goldmineHeaderIsH1`
        # @return [Float]
        attr_accessor :goldmine_header_is_h1
      
        # 
        # Corresponds to the JSON property `goldmineHeadingFactor`
        # @return [Float]
        attr_accessor :goldmine_heading_factor
      
        # 
        # Corresponds to the JSON property `goldmineIsBadTitle`
        # @return [Float]
        attr_accessor :goldmine_is_bad_title
      
        # 
        # Corresponds to the JSON property `goldmineIsHeadingTag`
        # @return [Float]
        attr_accessor :goldmine_is_heading_tag
      
        # 
        # Corresponds to the JSON property `goldmineIsTitleTag`
        # @return [Float]
        attr_accessor :goldmine_is_title_tag
      
        # 
        # Corresponds to the JSON property `goldmineIsTruncated`
        # @return [Float]
        attr_accessor :goldmine_is_truncated
      
        # 
        # Corresponds to the JSON property `goldmineLocalTitleFactor`
        # @return [Float]
        attr_accessor :goldmine_local_title_factor
      
        # 
        # Corresponds to the JSON property `goldmineLocationFactor`
        # @return [Float]
        attr_accessor :goldmine_location_factor
      
        # 
        # Corresponds to the JSON property `goldmineNavboostFactor`
        # @return [Float]
        attr_accessor :goldmine_navboost_factor
      
        # 
        # Corresponds to the JSON property `goldmineOgTitleFactor`
        # @return [Float]
        attr_accessor :goldmine_og_title_factor
      
        # 
        # Corresponds to the JSON property `goldmineOnPageDemotionFactor`
        # @return [Float]
        attr_accessor :goldmine_on_page_demotion_factor
      
        # The number of BoostFeatures present in AlternativeTitlesGeneator but not
        # populated above.
        # Corresponds to the JSON property `goldmineOtherBoostFeatureCount`
        # @return [Fixnum]
        attr_accessor :goldmine_other_boost_feature_count
      
        # The score for the `text` computed in Goldmine (AlternativeTitlesAnnotator).
        # Corresponds to the JSON property `goldminePageScore`
        # @return [Float]
        attr_accessor :goldmine_page_score
      
        # 
        # Corresponds to the JSON property `goldmineReadabilityScore`
        # @return [Float]
        attr_accessor :goldmine_readability_score
      
        # 
        # Corresponds to the JSON property `goldmineSalientTermFactor`
        # @return [Float]
        attr_accessor :goldmine_salient_term_factor
      
        # 
        # Corresponds to the JSON property `goldmineSitenameFactor`
        # @return [Float]
        attr_accessor :goldmine_sitename_factor
      
        # 
        # Corresponds to the JSON property `goldmineSubHeading`
        # @return [Float]
        attr_accessor :goldmine_sub_heading
      
        # 
        # Corresponds to the JSON property `goldmineTitleTagFactor`
        # @return [Float]
        attr_accessor :goldmine_title_tag_factor
      
        # 
        # Corresponds to the JSON property `goldmineTrustFactor`
        # @return [Float]
        attr_accessor :goldmine_trust_factor
      
        # 
        # Corresponds to the JSON property `goldmineUrlMatchFactor`
        # @return [Float]
        attr_accessor :goldmine_url_match_factor
      
        # Whether a title contains site information.
        # Corresponds to the JSON property `hasSiteInfo`
        # @return [Boolean]
        attr_accessor :has_site_info
        alias_method :has_site_info?, :has_site_info
      
        # Whether this title candidate is truncated or not.
        # Corresponds to the JSON property `isTruncated`
        # @return [Boolean]
        attr_accessor :is_truncated
        alias_method :is_truncated?, :is_truncated
      
        # Whether a title is valid (i.e., not empty).
        # Corresponds to the JSON property `isValid`
        # @return [Boolean]
        attr_accessor :is_valid
        alias_method :is_valid?, :is_valid
      
        # How good or bad this title is as a `data_source_type` title type.
        # Corresponds to the JSON property `perTypeQuality`
        # @return [String]
        attr_accessor :per_type_quality
      
        # Rank of this title among titles of the same `data_source_type`.
        # Corresponds to the JSON property `perTypeRank`
        # @return [Fixnum]
        attr_accessor :per_type_rank
      
        # Numbers of body title tokens covered by this title, in range of [0, 1]. Not
        # set if body title is considered "bad".
        # Corresponds to the JSON property `percentBodyTitleTokensCovered`
        # @return [Float]
        attr_accessor :percent_body_title_tokens_covered
      
        # Numbers of tokens covered by body title, in range of [0, 1]. Not set if body
        # title is considered "bad".
        # Corresponds to the JSON property `percentTokensCoveredByBodyTitle`
        # @return [Float]
        attr_accessor :percent_tokens_covered_by_body_title
      
        # The number of (different) terms with a query match. It may include the match
        # with any SQuery node (e.g., synonyms).
        # Corresponds to the JSON property `queryMatch`
        # @return [Fixnum]
        attr_accessor :query_match
      
        # A number of matched query terms divided by the number of all terms in query.
        # Synonyms or other terms that appear in squery but not in the raw query are
        # excluded. Takes values in [0, 1].
        # Corresponds to the JSON property `queryMatchFraction`
        # @return [Float]
        attr_accessor :query_match_fraction
      
        # Represents how relavant this title candidate is to the query. Ranged in [0, 1],
        # and this signal is basically calculated as Cosine-similarity between QBST
        # term vector and pQ2T model of title candidate sentence.
        # Corresponds to the JSON property `queryRelevance`
        # @return [Float]
        attr_accessor :query_relevance
      
        # 
        # Corresponds to the JSON property `sourceGeometry`
        # @return [Boolean]
        attr_accessor :source_geometry
        alias_method :source_geometry?, :source_geometry
      
        # 
        # Corresponds to the JSON property `sourceHeadingTag`
        # @return [Boolean]
        attr_accessor :source_heading_tag
        alias_method :source_heading_tag?, :source_heading_tag
      
        # 
        # Corresponds to the JSON property `sourceLocalTitle`
        # @return [Boolean]
        attr_accessor :source_local_title
        alias_method :source_local_title?, :source_local_title
      
        # 
        # Corresponds to the JSON property `sourceOffdomainAnchor`
        # @return [Boolean]
        attr_accessor :source_offdomain_anchor
        alias_method :source_offdomain_anchor?, :source_offdomain_anchor
      
        # 
        # Corresponds to the JSON property `sourceOndomainAnchor`
        # @return [Boolean]
        attr_accessor :source_ondomain_anchor
        alias_method :source_ondomain_anchor?, :source_ondomain_anchor
      
        # 
        # Corresponds to the JSON property `sourceOnsiteAnchor`
        # @return [Boolean]
        attr_accessor :source_onsite_anchor
        alias_method :source_onsite_anchor?, :source_onsite_anchor
      
        # =============================================================== Title
        # candidate's original source information. They are populated only for non-
        # production environment for debugging purposes.
        # Corresponds to the JSON property `sourceTitleTag`
        # @return [Boolean]
        attr_accessor :source_title_tag
        alias_method :source_title_tag?, :source_title_tag
      
        # 
        # Corresponds to the JSON property `sourceTransliteratedTitle`
        # @return [Boolean]
        attr_accessor :source_transliterated_title
        alias_method :source_transliterated_title?, :source_transliterated_title
      
        # `goldmine_final_score` value in test.
        # Corresponds to the JSON property `testGoldmineFinalScore`
        # @return [Float]
        attr_accessor :test_goldmine_final_score
      
        # The ranking index of this candidate (starting from 0) in test.
        # Corresponds to the JSON property `testRank`
        # @return [Fixnum]
        attr_accessor :test_rank
      
        # Title text to display. Populated for debugging purpose only, and won't be used
        # for model inferences. This represetns the exact display text in SERP, with
        # modifications like truncations or site-title appending involved.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # A rendered width of this title divided by the max allowed width for title.
        # Takes values in [0, 1].
        # Corresponds to the JSON property `widthFraction`
        # @return [Float]
        attr_accessor :width_fraction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @base_goldmine_final_score = args[:base_goldmine_final_score] if args.key?(:base_goldmine_final_score)
          @base_rank = args[:base_rank] if args.key?(:base_rank)
          @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
          @doc_lang = args[:doc_lang] if args.key?(:doc_lang)
          @doc_relevance = args[:doc_relevance] if args.key?(:doc_relevance)
          @dup_tokens = args[:dup_tokens] if args.key?(:dup_tokens)
          @forced_experiment_score = args[:forced_experiment_score] if args.key?(:forced_experiment_score)
          @goldmine_adjusted_score = args[:goldmine_adjusted_score] if args.key?(:goldmine_adjusted_score)
          @goldmine_anchor_factor = args[:goldmine_anchor_factor] if args.key?(:goldmine_anchor_factor)
          @goldmine_anchor_support_only = args[:goldmine_anchor_support_only] if args.key?(:goldmine_anchor_support_only)
          @goldmine_blockbert_factor = args[:goldmine_blockbert_factor] if args.key?(:goldmine_blockbert_factor)
          @goldmine_body_factor = args[:goldmine_body_factor] if args.key?(:goldmine_body_factor)
          @goldmine_final_score = args[:goldmine_final_score] if args.key?(:goldmine_final_score)
          @goldmine_foreign = args[:goldmine_foreign] if args.key?(:goldmine_foreign)
          @goldmine_geometry_factor = args[:goldmine_geometry_factor] if args.key?(:goldmine_geometry_factor)
          @goldmine_has_boilerplate_in_title = args[:goldmine_has_boilerplate_in_title] if args.key?(:goldmine_has_boilerplate_in_title)
          @goldmine_has_title_ngram = args[:goldmine_has_title_ngram] if args.key?(:goldmine_has_title_ngram)
          @goldmine_header_is_h1 = args[:goldmine_header_is_h1] if args.key?(:goldmine_header_is_h1)
          @goldmine_heading_factor = args[:goldmine_heading_factor] if args.key?(:goldmine_heading_factor)
          @goldmine_is_bad_title = args[:goldmine_is_bad_title] if args.key?(:goldmine_is_bad_title)
          @goldmine_is_heading_tag = args[:goldmine_is_heading_tag] if args.key?(:goldmine_is_heading_tag)
          @goldmine_is_title_tag = args[:goldmine_is_title_tag] if args.key?(:goldmine_is_title_tag)
          @goldmine_is_truncated = args[:goldmine_is_truncated] if args.key?(:goldmine_is_truncated)
          @goldmine_local_title_factor = args[:goldmine_local_title_factor] if args.key?(:goldmine_local_title_factor)
          @goldmine_location_factor = args[:goldmine_location_factor] if args.key?(:goldmine_location_factor)
          @goldmine_navboost_factor = args[:goldmine_navboost_factor] if args.key?(:goldmine_navboost_factor)
          @goldmine_og_title_factor = args[:goldmine_og_title_factor] if args.key?(:goldmine_og_title_factor)
          @goldmine_on_page_demotion_factor = args[:goldmine_on_page_demotion_factor] if args.key?(:goldmine_on_page_demotion_factor)
          @goldmine_other_boost_feature_count = args[:goldmine_other_boost_feature_count] if args.key?(:goldmine_other_boost_feature_count)
          @goldmine_page_score = args[:goldmine_page_score] if args.key?(:goldmine_page_score)
          @goldmine_readability_score = args[:goldmine_readability_score] if args.key?(:goldmine_readability_score)
          @goldmine_salient_term_factor = args[:goldmine_salient_term_factor] if args.key?(:goldmine_salient_term_factor)
          @goldmine_sitename_factor = args[:goldmine_sitename_factor] if args.key?(:goldmine_sitename_factor)
          @goldmine_sub_heading = args[:goldmine_sub_heading] if args.key?(:goldmine_sub_heading)
          @goldmine_title_tag_factor = args[:goldmine_title_tag_factor] if args.key?(:goldmine_title_tag_factor)
          @goldmine_trust_factor = args[:goldmine_trust_factor] if args.key?(:goldmine_trust_factor)
          @goldmine_url_match_factor = args[:goldmine_url_match_factor] if args.key?(:goldmine_url_match_factor)
          @has_site_info = args[:has_site_info] if args.key?(:has_site_info)
          @is_truncated = args[:is_truncated] if args.key?(:is_truncated)
          @is_valid = args[:is_valid] if args.key?(:is_valid)
          @per_type_quality = args[:per_type_quality] if args.key?(:per_type_quality)
          @per_type_rank = args[:per_type_rank] if args.key?(:per_type_rank)
          @percent_body_title_tokens_covered = args[:percent_body_title_tokens_covered] if args.key?(:percent_body_title_tokens_covered)
          @percent_tokens_covered_by_body_title = args[:percent_tokens_covered_by_body_title] if args.key?(:percent_tokens_covered_by_body_title)
          @query_match = args[:query_match] if args.key?(:query_match)
          @query_match_fraction = args[:query_match_fraction] if args.key?(:query_match_fraction)
          @query_relevance = args[:query_relevance] if args.key?(:query_relevance)
          @source_geometry = args[:source_geometry] if args.key?(:source_geometry)
          @source_heading_tag = args[:source_heading_tag] if args.key?(:source_heading_tag)
          @source_local_title = args[:source_local_title] if args.key?(:source_local_title)
          @source_offdomain_anchor = args[:source_offdomain_anchor] if args.key?(:source_offdomain_anchor)
          @source_ondomain_anchor = args[:source_ondomain_anchor] if args.key?(:source_ondomain_anchor)
          @source_onsite_anchor = args[:source_onsite_anchor] if args.key?(:source_onsite_anchor)
          @source_title_tag = args[:source_title_tag] if args.key?(:source_title_tag)
          @source_transliterated_title = args[:source_transliterated_title] if args.key?(:source_transliterated_title)
          @test_goldmine_final_score = args[:test_goldmine_final_score] if args.key?(:test_goldmine_final_score)
          @test_rank = args[:test_rank] if args.key?(:test_rank)
          @text = args[:text] if args.key?(:text)
          @width_fraction = args[:width_fraction] if args.key?(:width_fraction)
        end
      end
      
      # Snippet brain scores.
      class QualityPreviewSnippetBrainFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `modelScore`
        # @return [Float]
        attr_accessor :model_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @model_score = args[:model_score] if args.key?(:model_score)
        end
      end
      
      # Document related features used in snippets scoring. Next ID: 10
      class QualityPreviewSnippetDocumentFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `experimentalTitleSalientTermsScore`
        # @return [Float]
        attr_accessor :experimental_title_salient_terms_score
      
        # 
        # Corresponds to the JSON property `leadingtextDistanceScore`
        # @return [Float]
        attr_accessor :leadingtext_distance_score
      
        # 
        # Corresponds to the JSON property `metaBoostScore`
        # @return [Float]
        attr_accessor :meta_boost_score
      
        # 
        # Corresponds to the JSON property `salientPositionBoostScore`
        # @return [Float]
        attr_accessor :salient_position_boost_score
      
        # 
        # Corresponds to the JSON property `salientTermsScore`
        # @return [Float]
        attr_accessor :salient_terms_score
      
        # 
        # Corresponds to the JSON property `schemaOrgDescriptionBoostScore`
        # @return [Float]
        attr_accessor :schema_org_description_boost_score
      
        # 
        # Corresponds to the JSON property `unstableTokensScore`
        # @return [Float]
        attr_accessor :unstable_tokens_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experimental_title_salient_terms_score = args[:experimental_title_salient_terms_score] if args.key?(:experimental_title_salient_terms_score)
          @leadingtext_distance_score = args[:leadingtext_distance_score] if args.key?(:leadingtext_distance_score)
          @meta_boost_score = args[:meta_boost_score] if args.key?(:meta_boost_score)
          @salient_position_boost_score = args[:salient_position_boost_score] if args.key?(:salient_position_boost_score)
          @salient_terms_score = args[:salient_terms_score] if args.key?(:salient_terms_score)
          @schema_org_description_boost_score = args[:schema_org_description_boost_score] if args.key?(:schema_org_description_boost_score)
          @unstable_tokens_score = args[:unstable_tokens_score] if args.key?(:unstable_tokens_score)
        end
      end
      
      # 
      class QualityPreviewSnippetExperimentalFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isLikelyHomepage`
        # @return [Boolean]
        attr_accessor :is_likely_homepage
        alias_method :is_likely_homepage?, :is_likely_homepage
      
        # 
        # Corresponds to the JSON property `numQueryItems`
        # @return [Fixnum]
        attr_accessor :num_query_items
      
        # 
        # Corresponds to the JSON property `numTidbits`
        # @return [Fixnum]
        attr_accessor :num_tidbits
      
        # 
        # Corresponds to the JSON property `numVisibleTokens`
        # @return [Fixnum]
        attr_accessor :num_visible_tokens
      
        # 
        # Corresponds to the JSON property `radish`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewSnippetRadishFeatures]
        attr_accessor :radish
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_likely_homepage = args[:is_likely_homepage] if args.key?(:is_likely_homepage)
          @num_query_items = args[:num_query_items] if args.key?(:num_query_items)
          @num_tidbits = args[:num_tidbits] if args.key?(:num_tidbits)
          @num_visible_tokens = args[:num_visible_tokens] if args.key?(:num_visible_tokens)
          @radish = args[:radish] if args.key?(:radish)
        end
      end
      
      # Quality related features used in snippets scoring. Next ID: 10
      class QualityPreviewSnippetQualityFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `foreignMetaScore`
        # @return [Float]
        attr_accessor :foreign_meta_score
      
        # 
        # Corresponds to the JSON property `hiddenRatioScore`
        # @return [Float]
        attr_accessor :hidden_ratio_score
      
        # 
        # Corresponds to the JSON property `numTidbitsScore`
        # @return [Float]
        attr_accessor :num_tidbits_score
      
        # 
        # Corresponds to the JSON property `numVisibleTokensScore`
        # @return [Float]
        attr_accessor :num_visible_tokens_score
      
        # 
        # Corresponds to the JSON property `outlinkScore`
        # @return [Float]
        attr_accessor :outlink_score
      
        # 
        # Corresponds to the JSON property `redundancyScore`
        # @return [Float]
        attr_accessor :redundancy_score
      
        # 
        # Corresponds to the JSON property `sentenceStartScore`
        # @return [Float]
        attr_accessor :sentence_start_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @foreign_meta_score = args[:foreign_meta_score] if args.key?(:foreign_meta_score)
          @hidden_ratio_score = args[:hidden_ratio_score] if args.key?(:hidden_ratio_score)
          @num_tidbits_score = args[:num_tidbits_score] if args.key?(:num_tidbits_score)
          @num_visible_tokens_score = args[:num_visible_tokens_score] if args.key?(:num_visible_tokens_score)
          @outlink_score = args[:outlink_score] if args.key?(:outlink_score)
          @redundancy_score = args[:redundancy_score] if args.key?(:redundancy_score)
          @sentence_start_score = args[:sentence_start_score] if args.key?(:sentence_start_score)
        end
      end
      
      # Query related features used in snippets scoring. Next ID: 7
      class QualityPreviewSnippetQueryFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `experimentalQueryTitleScore`
        # @return [Float]
        attr_accessor :experimental_query_title_score
      
        # 
        # Corresponds to the JSON property `passageembedScore`
        # @return [Float]
        attr_accessor :passageembed_score
      
        # 
        # Corresponds to the JSON property `queryHasPassageembedEmbeddings`
        # @return [Boolean]
        attr_accessor :query_has_passageembed_embeddings
        alias_method :query_has_passageembed_embeddings?, :query_has_passageembed_embeddings
      
        # 
        # Corresponds to the JSON property `queryScore`
        # @return [Float]
        attr_accessor :query_score
      
        # 
        # Corresponds to the JSON property `radishScore`
        # @return [Float]
        attr_accessor :radish_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experimental_query_title_score = args[:experimental_query_title_score] if args.key?(:experimental_query_title_score)
          @passageembed_score = args[:passageembed_score] if args.key?(:passageembed_score)
          @query_has_passageembed_embeddings = args[:query_has_passageembed_embeddings] if args.key?(:query_has_passageembed_embeddings)
          @query_score = args[:query_score] if args.key?(:query_score)
          @radish_score = args[:radish_score] if args.key?(:radish_score)
        end
      end
      
      # Snippet query term coverage features.
      class QualityPreviewSnippetQueryTermCoverageFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `snippetQueryTermCoverage`
        # @return [Float]
        attr_accessor :snippet_query_term_coverage
      
        # 
        # Corresponds to the JSON property `titleQueryTermCoverage`
        # @return [Float]
        attr_accessor :title_query_term_coverage
      
        # 
        # Corresponds to the JSON property `titleSnippetQueryTermCoverage`
        # @return [Float]
        attr_accessor :title_snippet_query_term_coverage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @snippet_query_term_coverage = args[:snippet_query_term_coverage] if args.key?(:snippet_query_term_coverage)
          @title_query_term_coverage = args[:title_query_term_coverage] if args.key?(:title_query_term_coverage)
          @title_snippet_query_term_coverage = args[:title_snippet_query_term_coverage] if args.key?(:title_snippet_query_term_coverage)
        end
      end
      
      # 
      class QualityPreviewSnippetRadishFeatures
        include Google::Apis::Core::Hashable
      
        # Answer score of the passage for this `navboost_query`.
        # Corresponds to the JSON property `answerScore`
        # @return [Float]
        attr_accessor :answer_score
      
        # Navboost query for this radish signal.
        # Corresponds to the JSON property `navboostQuery`
        # @return [String]
        attr_accessor :navboost_query
      
        # The ratio of overlapping tokens between the radish passage and snippet
        # candidate.
        # Corresponds to the JSON property `passageCoverage`
        # @return [Float]
        attr_accessor :passage_coverage
      
        # Integer value of indexing::annotations::wa_passages::Passage::Type.
        # Corresponds to the JSON property `passageType`
        # @return [Fixnum]
        attr_accessor :passage_type
      
        # The index of this passage under `navboost_query`.
        # Corresponds to the JSON property `queryPassageIdx`
        # @return [Fixnum]
        attr_accessor :query_passage_idx
      
        # How the similarity score is computed. Integer value of
        # mustang_repos_www_snippets::RadishSignalScoringInfo::SimilarityMethod.
        # Corresponds to the JSON property `similarityMethod`
        # @return [Fixnum]
        attr_accessor :similarity_method
      
        # Similarity score between this `navboost_query` and the incoming query.
        # Corresponds to the JSON property `similarityScore`
        # @return [Float]
        attr_accessor :similarity_score
      
        # 
        # Corresponds to the JSON property `snippetCoverage`
        # @return [Float]
        attr_accessor :snippet_coverage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @answer_score = args[:answer_score] if args.key?(:answer_score)
          @navboost_query = args[:navboost_query] if args.key?(:navboost_query)
          @passage_coverage = args[:passage_coverage] if args.key?(:passage_coverage)
          @passage_type = args[:passage_type] if args.key?(:passage_type)
          @query_passage_idx = args[:query_passage_idx] if args.key?(:query_passage_idx)
          @similarity_method = args[:similarity_method] if args.key?(:similarity_method)
          @similarity_score = args[:similarity_score] if args.key?(:similarity_score)
          @snippet_coverage = args[:snippet_coverage] if args.key?(:snippet_coverage)
        end
      end
      
      # Protocol message for data related to product sites. This data is stored as
      # signals data in docjoins.
      class QualityProductProductSiteData
        include Google::Apis::Core::Hashable
      
        # Data for each locale.
        # Corresponds to the JSON property `locale`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityProductProductSiteDataLocaleData>]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # Data for one locale.
      class QualityProductProductSiteDataLocaleData
        include Google::Apis::Core::Hashable
      
        # Site boosting multiplier.
        # Corresponds to the JSON property `boostFactor`
        # @return [Float]
        attr_accessor :boost_factor
      
        # Whether this is a gobi site, ie, a site from a gobi domain that should be
        # boosted for a category query with this gobi domain. For example, amazon.com is
        # a gobi store domain for category query [hdtv] but some sites (like askville.
        # amazon.com) from amazon.com should not be boosted.
        # Corresponds to the JSON property `gobiSite`
        # @return [Boolean]
        attr_accessor :gobi_site
        alias_method :gobi_site?, :gobi_site
      
        # Locale for this data.
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boost_factor = args[:boost_factor] if args.key?(:boost_factor)
          @gobi_site = args[:gobi_site] if args.key?(:gobi_site)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # 
      class QualityProseCseUrlInfo
        include Google::Apis::Core::Hashable
      
        # There were defined back in 2007, but were never used. optional string label =
        # 2; optional uint64 user = 3; optional float score = 4;
        # Corresponds to the JSON property `cseId`
        # @return [String]
        attr_accessor :cse_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cse_id = args[:cse_id] if args.key?(:cse_id)
        end
      end
      
      # Used to annotate the source of cross-account personal data. See go/cross-
      # account-understanding.
      class QualityQrewriteAccountProvenance
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dataSources`
        # @return [Array<String>]
        attr_accessor :data_sources
      
        # The Google account the annotated personal data belongs to.
        # Corresponds to the JSON property `googleAccount`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteAccountProvenanceGoogleAccount]
        attr_accessor :google_account
      
        # The 3P account the annotated personal data belongs to.
        # Corresponds to the JSON property `thirdPartyAccount`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteAccountProvenanceThirdPartyAccount]
        attr_accessor :third_party_account
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_sources = args[:data_sources] if args.key?(:data_sources)
          @google_account = args[:google_account] if args.key?(:google_account)
          @third_party_account = args[:third_party_account] if args.key?(:third_party_account)
        end
      end
      
      # The Google account the annotated personal data belongs to.
      class QualityQrewriteAccountProvenanceGoogleAccount
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # 
        # Corresponds to the JSON property `isDasherAccount`
        # @return [Boolean]
        attr_accessor :is_dasher_account
        alias_method :is_dasher_account?, :is_dasher_account
      
        # 
        # Corresponds to the JSON property `isSecondaryAccount`
        # @return [Boolean]
        attr_accessor :is_secondary_account
        alias_method :is_secondary_account?, :is_secondary_account
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @is_dasher_account = args[:is_dasher_account] if args.key?(:is_dasher_account)
          @is_secondary_account = args[:is_secondary_account] if args.key?(:is_secondary_account)
        end
      end
      
      # The 3P account the annotated personal data belongs to.
      class QualityQrewriteAccountProvenanceThirdPartyAccount
        include Google::Apis::Core::Hashable
      
        # Email address of the linked account (eg foo@outlook.com).
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # Unique identifier for the third party provider. Defined by Google via AoG.
        # Corresponds to the JSON property `thirdPartyProviderId`
        # @return [Fixnum]
        attr_accessor :third_party_provider_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @third_party_provider_id = args[:third_party_provider_id] if args.key?(:third_party_provider_id)
        end
      end
      
      # Alternative names with info like RecognitionAlternateSource indicating where
      # is it from.
      class QualityQrewriteAlternativeNameInfo
        include Google::Apis::Core::Hashable
      
        # Neural contact match signals.
        # Corresponds to the JSON property `matchSignal`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsCommonContactMatchSignal]
        attr_accessor :match_signal
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @match_signal = args[:match_signal] if args.key?(:match_signal)
          @name = args[:name] if args.key?(:name)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class QualityQrewriteCalendarReference
        include Google::Apis::Core::Hashable
      
        # A calendar alias wrapper used for query annotation. Aliases values are defined
        # in the extension with build visibility restrictions as they may contain data
        # from an account other than the user's primary account. This proto is used as
        # an metadata output from the QRewrite annotation. It can be used for calendar
        # aliases from different sources i.e. aliases based on the domain of the account
        # associated with the calendar (go/calendar-aliases-annotation).
        # Corresponds to the JSON property `calendarAlias`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteQRewriteAccountAwareCalendarAliasWrapper]
        attr_accessor :calendar_alias
      
        # 
        # Corresponds to the JSON property `contactCalendarName`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteContactCalendarName]
        attr_accessor :contact_calendar_name
      
        # 
        # Corresponds to the JSON property `familyCalendarAlias`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteFamilyCalendarAlias]
        attr_accessor :family_calendar_alias
      
        # 
        # Corresponds to the JSON property `primaryCalendarAlias`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewritePrimaryCalendarAlias]
        attr_accessor :primary_calendar_alias
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calendar_alias = args[:calendar_alias] if args.key?(:calendar_alias)
          @contact_calendar_name = args[:contact_calendar_name] if args.key?(:contact_calendar_name)
          @family_calendar_alias = args[:family_calendar_alias] if args.key?(:family_calendar_alias)
          @primary_calendar_alias = args[:primary_calendar_alias] if args.key?(:primary_calendar_alias)
        end
      end
      
      # A complete query candidate Id includes a list of Id fields. The Id field order
      # is maintained as the order by which each field is appended to the list.
      class QualityQrewriteCandidateId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `field`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewriteCandidateIdField>]
        attr_accessor :field
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field = args[:field] if args.key?(:field)
        end
      end
      
      # The message represents a field in the query candidate Id.
      class QualityQrewriteCandidateIdField
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class QualityQrewriteContactCalendarName
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contact`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingModelsPersonPerson]
        attr_accessor :contact
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact = args[:contact] if args.key?(:contact)
        end
      end
      
      # 
      class QualityQrewriteFamilyCalendarAlias
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `familyCalendarId`
        # @return [String]
        attr_accessor :family_calendar_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @family_calendar_id = args[:family_calendar_id] if args.key?(:family_calendar_id)
        end
      end
      
      # Contact metadata Next Id: 35
      class QualityQrewritePersonalContactData
        include Google::Apis::Core::Hashable
      
        # Used to annotate the source of cross-account personal data. See go/cross-
        # account-understanding.
        # Corresponds to the JSON property `accountProvenance`
        # @return [Google::Apis::ContentwarehouseV1::QualityQrewriteAccountProvenance]
        attr_accessor :account_provenance
      
        # Other metadata relating with the contact. This field is added so that the
        # value can be copied to the corresponding field |additional_contact_metadata|
        # in person.proto, that later will be logged to Assistant Interaction Event
        # footprint from client side.
        # Corresponds to the JSON property `additionalContactMetadata`
        # @return [Array<Hash<String,Object>>]
        attr_accessor :additional_contact_metadata
      
        # Populated only if matched_name_type is GIVEN_NAME_ALIAS or FULL_NAME_ALIAS.
        # Corresponds to the JSON property `commonNameAliasConfidence`
        # @return [Float]
        attr_accessor :common_name_alias_confidence
      
        # Concept id for relationships in query language, e.g. "Mother" in English, "Mè
        # re" in French. It's only populated for source = RELATIONSHIP.
        # Corresponds to the JSON property `conceptId`
        # @return [String]
        attr_accessor :concept_id
      
        # Concept id for relationships in English, e.g. "Mother" for all non-English
        # locales. It's only populated for source = RELATIONSHIP. It is used as the key
        # to store relationship in memory (see http://go/assistant-relationship). For
        # English, this field is not filled, and we will use concept_id field as the
        # relationship key in memory.
        # Corresponds to the JSON property `conceptIdEn`
        # @return [String]
        attr_accessor :concept_id_en
      
        # TODO(shuaiwang) these are kept here temporarily because aqua regression tests
        # are still referring to them, migrating aqua regression tests to use the new
        # person_data field depends on binary change (i.e. this proto change) so there's
        # a period we need to keep both.
        # Corresponds to the JSON property `displayName`
        # @return [String]
        attr_accessor :display_name
      
        # 
        # Corresponds to the JSON property `familyName`
        # @return [String]
        attr_accessor :family_name
      
        # The ffrac score of the suggested contact from Starlight.
        # Corresponds to the JSON property `ffracScore`
        # @return [Float]
        attr_accessor :ffrac_score
      
        # 
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # 
        # Corresponds to the JSON property `givenName`
        # @return [String]
        attr_accessor :given_name
      
        # Whether we have address info for this contact. IMPORTANT, READ BEFORE USING
        # THIS FIELD: - This is a temporary solution to export this info for device
        # contacts. - This could only be set for device contacts, contacts from other
        # sources won't have this bit set even if there's address available inside
        # person_data. - This will go away once Starlight supports device contacts,
        # addresses will be available inside person_data the same way as Focus contacts.
        # TODO(shuaiwang) remove after b/20412551
        # Corresponds to the JSON property `hasAddressForDeviceContacts`
        # @return [Boolean]
        attr_accessor :has_address_for_device_contacts
        alias_method :has_address_for_device_contacts?, :has_address_for_device_contacts
      
        # 
        # Corresponds to the JSON property `hasGplusProfile`
        # @return [Boolean]
        attr_accessor :has_gplus_profile
        alias_method :has_gplus_profile?, :has_gplus_profile
      
        # If the contact data is from on device lookup.
        # Corresponds to the JSON property `isFromOnDeviceLookup`
        # @return [Boolean]
        attr_accessor :is_from_on_device_lookup
        alias_method :is_from_on_device_lookup?, :is_from_on_device_lookup
      
        # Indicate the contact matches the transliterated query.
        # Corresponds to the JSON property `isTransliteratedMatch`
        # @return [Boolean]
        attr_accessor :is_transliterated_match
        alias_method :is_transliterated_match?, :is_transliterated_match
      
        # If the lookup was done using relationship which is visible to guests. This
        # value will only be set if lookup was done using relationship. E.g. user has a
        # guest relationship (doctor) -> (John) And user says "call doctor", then this
        # value will be true.
        # Corresponds to the JSON property `isVisibleToGuestsRelationship`
        # @return [Boolean]
        attr_accessor :is_visible_to_guests_relationship
        alias_method :is_visible_to_guests_relationship?, :is_visible_to_guests_relationship
      
        # Neural contact match signals.
        # Corresponds to the JSON property `matchSignal`
        # @return [Google::Apis::ContentwarehouseV1::AssistantVerticalsCommonContactMatchSignal]
        attr_accessor :match_signal
      
        # LINT.ThenChange(//depot/google3/assistant/verticals/communication/\
        # fulfillment/proto/contact_logging_enums.proto, //depot/google3/assistant/api/
        # dialog_state/values/person.proto, //depot/google3/assistant/context/proto/
        # person.proto)
        # Corresponds to the JSON property `matchedNameType`
        # @return [String]
        attr_accessor :matched_name_type
      
        # Alternate name from recognition that has contact matched. Need this to make
        # name correction history log consistent.
        # Corresponds to the JSON property `matchedRecognitionAlternateName`
        # @return [String]
        attr_accessor :matched_recognition_alternate_name
      
        # Merged-person combines multiple sources of data like contacts and profiles.
        # See go/people-api and go/understanding-merged-person NOTE: Why are all the
        # fields repeated? See go/people-api-concepts#repeated
        # Corresponds to the JSON property `personData`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleOzExternalMergedpeopleapiPerson]
        attr_accessor :person_data
      
        # Contact meta data. Next ID: 30
        # Corresponds to the JSON property `personalContactDataLog`
        # @return [Google::Apis::ContentwarehouseV1::AssistantLogsCommunicationPersonalContactDataLog]
        attr_accessor :personal_contact_data_log
      
        # The QRefAnnotator annotates spans of input with freebase-ids and collection-
        # information. NEXT ID TO USE: 41
        # Corresponds to the JSON property `pkgPerson`
        # @return [Google::Apis::ContentwarehouseV1::NlpSemanticParsingQRefAnnotation]
        attr_accessor :pkg_person
      
        # 
        # Corresponds to the JSON property `pkgReferenceType`
        # @return [String]
        attr_accessor :pkg_reference_type
      
        # Populate only if AlternateSource is not NONE.
        # Corresponds to the JSON property `recognitionAlternateScore`
        # @return [Float]
        attr_accessor :recognition_alternate_score
      
        # If not none, then it indicates the personal contact data is alternate and how
        # the alternate is fulfilled.
        # Corresponds to the JSON property `recognitionAlternateSource`
        # @return [String]
        attr_accessor :recognition_alternate_source
      
        # Contains lexical metadata for a given reference. For example, this proto will
        # be used to store locale-specific Lexical mids for contact relationships (e.g. /
        # g/11gv0vypg4 is the mid for mother in english and /g/11gmy_gv87 is for mother
        # in french) as an extension to QRefAnnotation::other_metadata, when available.
        # Corresponds to the JSON property `relationshipLexicalInfo`
        # @return [Google::Apis::ContentwarehouseV1::CopleyLexicalMetadata]
        attr_accessor :relationship_lexical_info
      
        # Resolved relationship names and contact pointers from Assistant Memory. This
        # field is populated into both relationship annotation (source = RELATIONSHIP)
        # and Focus/device contacts retrieved by that contact name. The data from
        # Assistant Memory comes from two different columns: ASSISTANT_SETTINGS and
        # PWS_CONTACT_ANNOTATION. We support multiple people with same relationship (e.g.
        # multiple brothers) by using a repeated relationship_memory field. Examples
        # are at go/person-subgrammar-relationship.
        # Corresponds to the JSON property `relationshipMemory`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewriteRelationshipMemoryData>]
        attr_accessor :relationship_memory
      
        # Gaia ID of the user this contact belongs to. Only populates if contact is
        # shared from another user. See go/shared-contacts-assistant. E.g. user A
        # triggers the request and uses user B's contact data (which is marked as
        # visible to user A). This field will be populated with user B's gaia id.
        # Corresponds to the JSON property `sharedContactOwnerGaiaId`
        # @return [Fixnum]
        attr_accessor :shared_contact_owner_gaia_id
      
        # LINT.ThenChange(//depot/google3/assistant/verticals/communication/\
        # fulfillment/proto/contact_logging_enums.proto, //depot/google3/assistant/api/
        # dialog_state/values/person.proto) Data source of the contact data.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_provenance = args[:account_provenance] if args.key?(:account_provenance)
          @additional_contact_metadata = args[:additional_contact_metadata] if args.key?(:additional_contact_metadata)
          @common_name_alias_confidence = args[:common_name_alias_confidence] if args.key?(:common_name_alias_confidence)
          @concept_id = args[:concept_id] if args.key?(:concept_id)
          @concept_id_en = args[:concept_id_en] if args.key?(:concept_id_en)
          @display_name = args[:display_name] if args.key?(:display_name)
          @family_name = args[:family_name] if args.key?(:family_name)
          @ffrac_score = args[:ffrac_score] if args.key?(:ffrac_score)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @given_name = args[:given_name] if args.key?(:given_name)
          @has_address_for_device_contacts = args[:has_address_for_device_contacts] if args.key?(:has_address_for_device_contacts)
          @has_gplus_profile = args[:has_gplus_profile] if args.key?(:has_gplus_profile)
          @is_from_on_device_lookup = args[:is_from_on_device_lookup] if args.key?(:is_from_on_device_lookup)
          @is_transliterated_match = args[:is_transliterated_match] if args.key?(:is_transliterated_match)
          @is_visible_to_guests_relationship = args[:is_visible_to_guests_relationship] if args.key?(:is_visible_to_guests_relationship)
          @match_signal = args[:match_signal] if args.key?(:match_signal)
          @matched_name_type = args[:matched_name_type] if args.key?(:matched_name_type)
          @matched_recognition_alternate_name = args[:matched_recognition_alternate_name] if args.key?(:matched_recognition_alternate_name)
          @person_data = args[:person_data] if args.key?(:person_data)
          @personal_contact_data_log = args[:personal_contact_data_log] if args.key?(:personal_contact_data_log)
          @pkg_person = args[:pkg_person] if args.key?(:pkg_person)
          @pkg_reference_type = args[:pkg_reference_type] if args.key?(:pkg_reference_type)
          @recognition_alternate_score = args[:recognition_alternate_score] if args.key?(:recognition_alternate_score)
          @recognition_alternate_source = args[:recognition_alternate_source] if args.key?(:recognition_alternate_source)
          @relationship_lexical_info = args[:relationship_lexical_info] if args.key?(:relationship_lexical_info)
          @relationship_memory = args[:relationship_memory] if args.key?(:relationship_memory)
          @shared_contact_owner_gaia_id = args[:shared_contact_owner_gaia_id] if args.key?(:shared_contact_owner_gaia_id)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class QualityQrewritePrimaryCalendarAlias
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # A calendar alias wrapper used for query annotation. Aliases values are defined
      # in the extension with build visibility restrictions as they may contain data
      # from an account other than the user's primary account. This proto is used as
      # an metadata output from the QRewrite annotation. It can be used for calendar
      # aliases from different sources i.e. aliases based on the domain of the account
      # associated with the calendar (go/calendar-aliases-annotation).
      class QualityQrewriteQRewriteAccountAwareCalendarAliasWrapper
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Relationship->contact data provided by Assistant Memory.
      class QualityQrewriteRelationshipMemoryData
        include Google::Apis::Core::Hashable
      
        # A contact pointer that represents a contact (http://go/assistant-contact-id).
        # Corresponds to the JSON property `contactPointer`
        # @return [Google::Apis::ContentwarehouseV1::FocusBackendContactPointer]
        attr_accessor :contact_pointer
      
        # The contact name copied from UserAttribute.value.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_pointer = args[:contact_pointer] if args.key?(:contact_pointer)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Used as Mustang attachment DO NOT: - ACCESS THE PROTO FIELDS DIRECTLY - USE
      # THE DECODING LIBRARY IN quality/rankembed/mustang/fixed_point_decoding_helpers.
      # h INSTEAD. - USE HARDCODED MustangRankEmbedInfo TEXT PROTOS IN TESTS! USE
      # quality/rankembed/test_utils/mustang_rankembed_info_utils.h INSTEAD.
      class QualityRankembedMustangMustangRankEmbedInfo
        include Google::Apis::Core::Hashable
      
        # Each uint64 encodes 8 8-bit values for the quantized document embedding
        # Corresponds to the JSON property `compressedDocumentEmbedding`
        # @return [Google::Apis::ContentwarehouseV1::QualityRankembedMustangMustangRankEmbedInfoCompressedEmbedding]
        attr_accessor :compressed_document_embedding
      
        # This field replaces the above 3 "per-encoding-type-fields", where the encoding
        # type (and the embedding type) are part of the encoding, and is stored in the
        # first byte. The remaining bytes are the same as the previous 3 fields, but
        # shifted by 1 byte. - byte[0]: encoding type & embedding type - byte[1....]:
        # similar to the above depending on the encoding type.
        # Corresponds to the JSON property `fixedPointEncoding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :fixed_point_encoding
      
        # - byte[0]: version - bytes[1...4]: scalar - bytes[5,...]: the values, one byte
        # per 2 values
        # Corresponds to the JSON property `scaledFixedPoint4Encoding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :scaled_fixed_point4_encoding
      
        # - byte[0]: version - bytes[1...4]: scalar - bytes[5,...]: the values, one byte
        # per value
        # Corresponds to the JSON property `scaledFixedPoint8Encoding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :scaled_fixed_point8_encoding
      
        # - byte[0]: version - bytes[1...4]: scalar - bytes[5...8]: shift - bytes[9,...]:
        # the values, one byte per 2 values
        # Corresponds to the JSON property `scaledShiftedFixedPoint4Encoding`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :scaled_shifted_fixed_point4_encoding
      
        # First 7 bits encode the version, then each chunck of 5 bits encode the index
        # of a potential improv query (lsb to msb) -------|-----|-----|-----|-----|-----
        # version| id1 | id2 | id3 | id4 | id5 where id1 is the index of the first
        # improv query in the improv debug table. As of cl/270008220, this field only
        # contains the version info. For backward compatibility, version still only uses
        # the first 7 bits, and is still prepended by 5 1 bits.
        # Corresponds to the JSON property `versionAndImprovInfo`
        # @return [Fixnum]
        attr_accessor :version_and_improv_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compressed_document_embedding = args[:compressed_document_embedding] if args.key?(:compressed_document_embedding)
          @fixed_point_encoding = args[:fixed_point_encoding] if args.key?(:fixed_point_encoding)
          @scaled_fixed_point4_encoding = args[:scaled_fixed_point4_encoding] if args.key?(:scaled_fixed_point4_encoding)
          @scaled_fixed_point8_encoding = args[:scaled_fixed_point8_encoding] if args.key?(:scaled_fixed_point8_encoding)
          @scaled_shifted_fixed_point4_encoding = args[:scaled_shifted_fixed_point4_encoding] if args.key?(:scaled_shifted_fixed_point4_encoding)
          @version_and_improv_info = args[:version_and_improv_info] if args.key?(:version_and_improv_info)
        end
      end
      
      # 
      class QualityRankembedMustangMustangRankEmbedInfoCompressedEmbedding
        include Google::Apis::Core::Hashable
      
        # using fixed64 instead of uint64 saves ~14% is storage
        # Corresponds to the JSON property `packedValue`
        # @return [Array<Fixnum>]
        attr_accessor :packed_value
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<Fixnum>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @packed_value = args[:packed_value] if args.key?(:packed_value)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class QualityRichsnippetsAppsProtosLaunchAppInfoPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `app`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityRichsnippetsAppsProtosLaunchableAppPerDocData>]
        attr_accessor :app
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @app = args[:app] if args.key?(:app)
        end
      end
      
      # A subset of LaunchableApplication, which is stored in the PerDocData proto (
      # indexer/perdocdata/perdocdata.proto) and thus stored in the Search Mustang
      # index. It is used to identify documents containing app links at serving time
      # by SuperRoot. A subset of LaunchableApplication is used to save on storage
      # requirements.
      class QualityRichsnippetsAppsProtosLaunchableAppPerDocData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `indexStatus`
        # @return [String]
        attr_accessor :index_status
      
        # Android package id of the application associated with this document (example: '
        # com.imdb.mobile'), encoded with the Fingerprint2011() function.
        # Corresponds to the JSON property `packageIdFingerprint`
        # @return [Fixnum]
        attr_accessor :package_id_fingerprint
      
        # A subset of the data in the PerAppInfo message, encoded to save on space. See
        # quality/calypso/utils/app_info_utils.h for encoding/decoding.
        # Corresponds to the JSON property `perAppInfoEncoded`
        # @return [Fixnum]
        attr_accessor :per_app_info_encoded
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index_status = args[:index_status] if args.key?(:index_status)
          @package_id_fingerprint = args[:package_id_fingerprint] if args.key?(:package_id_fingerprint)
          @per_app_info_encoded = args[:per_app_info_encoded] if args.key?(:per_app_info_encoded)
        end
      end
      
      # This is a measure of how salient this country is for the document.
      class QualitySalientCountriesSalientCountry
        include Google::Apis::Core::Hashable
      
        # 2-letter country format.
        # Corresponds to the JSON property `country`
        # @return [String]
        attr_accessor :country
      
        # How salient this country is for the document. [0,1] range.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country = args[:country] if args.key?(:country)
          @salience = args[:salience] if args.key?(:salience)
        end
      end
      
      # Set of SalientCountry for a document.
      class QualitySalientCountriesSalientCountrySet
        include Google::Apis::Core::Hashable
      
        # Packed Country and salience optimized for index storage
        # Corresponds to the JSON property `packedCountry`
        # @return [Array<Fixnum>]
        attr_accessor :packed_country
      
        # 
        # Corresponds to the JSON property `packedSalience`
        # @return [Array<Fixnum>]
        attr_accessor :packed_salience
      
        # 
        # Corresponds to the JSON property `salientCountry`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientCountriesSalientCountry>]
        attr_accessor :salient_country
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @packed_country = args[:packed_country] if args.key?(:packed_country)
          @packed_salience = args[:packed_salience] if args.key?(:packed_salience)
          @salient_country = args[:salient_country] if args.key?(:salient_country)
        end
      end
      
      # DocData contains additional salient-term-set-level information that
      # complements a SalientTermSet.
      class QualitySalientTermsDocData
        include Google::Apis::Core::Hashable
      
        # confidence is a measurement of how much data we had to compute the
        # SalientTermSet. Range: [0.0, 1.0]
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # head_volume_ratio is the ratio of the sum of term frequency of the top K terms
        # over the volume of all terms. Range: [0.0, 1.0]. K is defined by
        # Accumulator2Params::head_size.
        # Corresponds to the JSON property `headVolumeRatio`
        # @return [Float]
        attr_accessor :head_volume_ratio
      
        # language is the main language of this SalientTermSet.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # signal_data contains signal-specific (e.g., body, anchors, clicks) data for
        # this SalientTermSet.
        # Corresponds to the JSON property `signalData`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientTermsSignalData>]
        attr_accessor :signal_data
      
        # virtual_volume is a measurement of how much data we had to compute the
        # SalientTermSet. Range: [0.0, +infinity)].
        # Corresponds to the JSON property `virtualVolume`
        # @return [Float]
        attr_accessor :virtual_volume
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @head_volume_ratio = args[:head_volume_ratio] if args.key?(:head_volume_ratio)
          @language = args[:language] if args.key?(:language)
          @signal_data = args[:signal_data] if args.key?(:signal_data)
          @virtual_volume = args[:virtual_volume] if args.key?(:virtual_volume)
        end
      end
      
      # SalientTerm can be two things depending on where this message is. When right
      # under a SalientTermSet, it is a normalized term and weight pair, along with
      # other term-level data. When under another SalientTerm message, it is a non-
      # normalized original term (see original_term field).
      class QualitySalientTermsSalientTerm
        include Google::Apis::Core::Hashable
      
        # idf of the original_term. Used by Accumulator2. This field is only available
        # in debug mode.
        # Corresponds to the JSON property `idf`
        # @return [Float]
        attr_accessor :idf
      
        # label can be two things depending on where this message is. When right under a
        # SalientTermSet, it is the normalized term returned by quality_salient_terms::
        # utils::NormalizeTerm() from salient_terms_utils.h. When under another
        # SalientTerm message, it is the original term as found in a signal (see
        # original_term field).
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # original_term are the different ways we found this normalized term in the
        # signals. They are in increasing idf order (the most common version first). An
        # empty string means that this original term is the same as the label field in
        # the parent SalientTerm message. NOTE: Please do not access this field directly.
        # Use quality_salient_terms::utils::OriginalTermsIterator from
        # salient_terms_utils.h instead.
        # Corresponds to the JSON property `originalTerm`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTerm>]
        attr_accessor :original_term
      
        # salience is the importance of the term as a descriptor in [0, 1] (the higher
        # the more important). This field takes precedence over weight field below. NOTE:
        # Please do not access this field directly. Use quality_salient_terms::utils::
        # GetSalience() from salient_terms_utils.h instead.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        # signal_term contains extra signal-specific (e.g., body, anchors, clicks) data
        # for this term.
        # Corresponds to the JSON property `signalTerm`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientTermsSignalTermData>]
        attr_accessor :signal_term
      
        # virtual_tf is the accumulated corrected term frequency from all the signals.
        # This field is only available in debug mode.
        # Corresponds to the JSON property `virtualTf`
        # @return [Float]
        attr_accessor :virtual_tf
      
        # weight is the importance of the term as a descriptor in [0, 100] (the higher
        # the more important). NOTE: Please do not access this field directly. Use
        # quality_salient_terms::utils::GetSalience() from salient_terms_utils.h instead.
        # DEPRECATED: prefer salience field above.
        # Corresponds to the JSON property `weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @idf = args[:idf] if args.key?(:idf)
          @label = args[:label] if args.key?(:label)
          @original_term = args[:original_term] if args.key?(:original_term)
          @salience = args[:salience] if args.key?(:salience)
          @signal_term = args[:signal_term] if args.key?(:signal_term)
          @virtual_tf = args[:virtual_tf] if args.key?(:virtual_tf)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # SalientTermSet is a collection of terms (unigrams and bigrams) with associated
      # weights that can describe something. The "salient terms".
      class QualitySalientTermsSalientTermSet
        include Google::Apis::Core::Hashable
      
        # DocData contains additional salient-term-set-level information that
        # complements a SalientTermSet.
        # Corresponds to the JSON property `docData`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientTermsDocData]
        attr_accessor :doc_data
      
        # salient_term is the list of terms that are good descriptors, sorted in
        # decreasing order of weight.
        # Corresponds to the JSON property `salientTerm`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTerm>]
        attr_accessor :salient_term
      
        # version is the Salient Terms version used to create the SalientTermSet. This
        # is specific to web documents salient terms.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_data = args[:doc_data] if args.key?(:doc_data)
          @salient_term = args[:salient_term] if args.key?(:salient_term)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # SignalData stores signal-specific salient-term-set-level information. Stores
      # mostly internal data as it is one of the primary data structures used in the
      # populators.
      class QualitySalientTermsSignalData
        include Google::Apis::Core::Hashable
      
        # A fixed bias for this signal, the higher the stronger. This can be used to
        # balance the weight of signals independently of the confidence we give it. This
        # field is only available in debug mode.
        # Corresponds to the JSON property `bias`
        # @return [Float]
        attr_accessor :bias
      
        # The measurement of how much we trust this signal. Range: [0.0, 1.0] This field
        # is available is both debug and non-debug mode.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Raw saliences equal to half_salience will be equal to 0.5 normalized. Range: [
        # 0, volume]. This field is only available in debug mode.
        # Corresponds to the JSON property `halfSalience`
        # @return [Float]
        attr_accessor :half_salience
      
        # The minimum TF for a term not to be considered noise. While the possible range
        # of values for this field is [0, observed_volume], it is expected to be a
        # somewhat small percentage of observed_volume (e.g. 5%). This field is only
        # available in debug mode.
        # Corresponds to the JSON property `noiseCorrection`
        # @return [Float]
        attr_accessor :noise_correction
      
        # The measurement of how much we trust this signal, calculated using the
        # observed volume. Range: [0.0, 1.0] This field is only available in debug mode.
        # Corresponds to the JSON property `observedConfidence`
        # @return [Float]
        attr_accessor :observed_confidence
      
        # The amount of signal we observed for a document. Range: [0.0, +infinity) This
        # field is only available in debug mode.
        # Corresponds to the JSON property `observedVolume`
        # @return [Float]
        attr_accessor :observed_volume
      
        # The amount of raw signal we observed for a document. Range: [0.0, +infinity)
        # This field is only available in debug mode.
        # Corresponds to the JSON property `rawVolume`
        # @return [Float]
        attr_accessor :raw_volume
      
        # source is the type of the signal of this SignalData.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The amount of signal left after applying all corrections. Range: [0.0, +
        # infinity) This field is only available in debug mode.
        # Corresponds to the JSON property `volume`
        # @return [Float]
        attr_accessor :volume
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bias = args[:bias] if args.key?(:bias)
          @confidence = args[:confidence] if args.key?(:confidence)
          @half_salience = args[:half_salience] if args.key?(:half_salience)
          @noise_correction = args[:noise_correction] if args.key?(:noise_correction)
          @observed_confidence = args[:observed_confidence] if args.key?(:observed_confidence)
          @observed_volume = args[:observed_volume] if args.key?(:observed_volume)
          @raw_volume = args[:raw_volume] if args.key?(:raw_volume)
          @source = args[:source] if args.key?(:source)
          @volume = args[:volume] if args.key?(:volume)
        end
      end
      
      # SignalTermData is signal-specific term-level information. Stores mostly
      # internal data as it is one of the primary data structures used in the
      # populators.
      class QualitySalientTermsSignalTermData
        include Google::Apis::Core::Hashable
      
        # The deduction of bigram counts from its unigram children. This field is only
        # available in debug mode.
        # Corresponds to the JSON property `bigramDiscountTf`
        # @return [Float]
        attr_accessor :bigram_discount_tf
      
        # How much we trust this bigram. For bigrams only. Range: [0.0, 1.0] This field
        # is only available in debug mode.
        # Corresponds to the JSON property `bigramness`
        # @return [Float]
        attr_accessor :bigramness
      
        # Measures how topical this term is to a particular signal. A term like "lincoln"
        # in the Abraham Lincoln's Wikipedia page should have a centrality close to 1.0
        # while non-central terms like "florida" should have a centrality close to 0.0.
        # Range: [0.0, 1.0] This field is only available in debug mode.
        # Corresponds to the JSON property `centrality`
        # @return [Float]
        attr_accessor :centrality
      
        # The final term frequency for a particular term. This field is only available
        # in debug mode.
        # Corresponds to the JSON property `correctedTf`
        # @return [Float]
        attr_accessor :corrected_tf
      
        # The term frequency we were expecting for a term given its IDF. Range: [0,
        # observed_volume] This field is only available in debug mode.
        # Corresponds to the JSON property `expectedTf`
        # @return [Float]
        attr_accessor :expected_tf
      
        # Global NPMI. For bigrams only. This is a measure of the quality of bigrams
        # calculated using IDF. Range: [-1.0, 1.0] This field is only available in debug
        # mode.
        # Corresponds to the JSON property `globalNpmi`
        # @return [Float]
        attr_accessor :global_npmi
      
        # The IDF of the label of a particular term. For a canonical term, this is the
        # mean IDF of its originals, weighted by their observed TF. This field is only
        # available in debug mode.
        # Corresponds to the JSON property `idf`
        # @return [Float]
        attr_accessor :idf
      
        # Whether or not this term is a bigram. This field is only available in debug
        # mode.
        # Corresponds to the JSON property `isBigram`
        # @return [Boolean]
        attr_accessor :is_bigram
        alias_method :is_bigram?, :is_bigram
      
        # Raw string that identifies a particular term. This field is only available in
        # debug mode.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # Local NPMI (normalized pointwise mutual information). For bigrams only. This
        # is a measure of the quality of bigrams calculated using observed TF. Range: [-
        # 1.0, 1.0] This field is only available in debug mode.
        # Corresponds to the JSON property `localNpmi`
        # @return [Float]
        attr_accessor :local_npmi
      
        # The observed term frequency in a particular signal. This field is only
        # available in debug mode.
        # Corresponds to the JSON property `observedTf`
        # @return [Float]
        attr_accessor :observed_tf
      
        # The list of the original terms for a canonical. This is used in the pipeline
        # and it is not present in the final output. This field is only available in
        # debug mode.
        # Corresponds to the JSON property `originalTerm`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySalientTermsSignalTermData>]
        attr_accessor :original_term
      
        # The raw term frequency in a particular signal. This field is only available in
        # debug mode.
        # Corresponds to the JSON property `rawTf`
        # @return [Float]
        attr_accessor :raw_tf
      
        # The measure of how important this term is in this signal. Range: [0.0, 1.0]
        # This field is only available in debug mode.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        # source is the type of the signal of this SignalTermData.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bigram_discount_tf = args[:bigram_discount_tf] if args.key?(:bigram_discount_tf)
          @bigramness = args[:bigramness] if args.key?(:bigramness)
          @centrality = args[:centrality] if args.key?(:centrality)
          @corrected_tf = args[:corrected_tf] if args.key?(:corrected_tf)
          @expected_tf = args[:expected_tf] if args.key?(:expected_tf)
          @global_npmi = args[:global_npmi] if args.key?(:global_npmi)
          @idf = args[:idf] if args.key?(:idf)
          @is_bigram = args[:is_bigram] if args.key?(:is_bigram)
          @label = args[:label] if args.key?(:label)
          @local_npmi = args[:local_npmi] if args.key?(:local_npmi)
          @observed_tf = args[:observed_tf] if args.key?(:observed_tf)
          @original_term = args[:original_term] if args.key?(:original_term)
          @raw_tf = args[:raw_tf] if args.key?(:raw_tf)
          @salience = args[:salience] if args.key?(:salience)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class QualitySherlockKnexAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `item`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySherlockKnexAnnotationItem>]
        attr_accessor :item
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @item = args[:item] if args.key?(:item)
        end
      end
      
      # 
      class QualitySherlockKnexAnnotationItem
        include Google::Apis::Core::Hashable
      
        # in [0, 1].
        # Corresponds to the JSON property `calibratedScore`
        # @return [Float]
        attr_accessor :calibrated_score
      
        # 
        # Corresponds to the JSON property `debugName`
        # @return [String]
        attr_accessor :debug_name
      
        # in /m/ or /g/.
        # Corresponds to the JSON property `equivalentMid`
        # @return [String]
        attr_accessor :equivalent_mid
      
        # in [0, 1].
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @calibrated_score = args[:calibrated_score] if args.key?(:calibrated_score)
          @debug_name = args[:debug_name] if args.key?(:debug_name)
          @equivalent_mid = args[:equivalent_mid] if args.key?(:equivalent_mid)
          @score = args[:score] if args.key?(:score)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # This proto is a lightweight version of ShoppingAnnotation in docjoin
      # attachment. We're doing a deep copy of protos defined in ShoppingAnnotation so
      # that we can control individual fields that will sit in Muppet. Data here will
      # be used for scoring organic shopping web results and previews. Many shopping
      # related signals, e.g., product review score, are also served from this
      # attachment. Next ID: 20
      class QualityShoppingShoppingAttachment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `datasetModelBuyingGuideScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_buying_guide_score
      
        # From forum and qna confidence score * 100, http://go/sdu-ugc-page-intro
        # Corresponds to the JSON property `datasetModelForumListScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_forum_list_score
      
        # 
        # Corresponds to the JSON property `datasetModelForumSingleScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_forum_single_score
      
        # 
        # Corresponds to the JSON property `datasetModelInStoreOnlyScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_in_store_only_score
      
        # 
        # Corresponds to the JSON property `datasetModelIndirectAvailabilityScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_indirect_availability_score
      
        # From indexing.ml.PageType.confidence * 100 (DatasetModelAnnotation in cdoc) go/
        # sdu-shopping-page-intro
        # Corresponds to the JSON property `datasetModelMultiProductScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_multi_product_score
      
        # 
        # Corresponds to the JSON property `datasetModelProductComparisonScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_product_comparison_score
      
        # 
        # Corresponds to the JSON property `datasetModelProductReviewScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_product_review_score
      
        # 
        # Corresponds to the JSON property `datasetModelProductTopnScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_product_topn_score
      
        # 
        # Corresponds to the JSON property `datasetModelQnaListScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_qna_list_score
      
        # 
        # Corresponds to the JSON property `datasetModelQnaSingleScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_qna_single_score
      
        # 
        # Corresponds to the JSON property `datasetModelSingleProductScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_single_product_score
      
        # 
        # Corresponds to the JSON property `datasetModelSoldOutScore`
        # @return [Fixnum]
        attr_accessor :dataset_model_sold_out_score
      
        # From indexing.badpages.CollapserInfo.expired_shopping_page_score * 100
        # Corresponds to the JSON property `expiredShoppingPageScore`
        # @return [Fixnum]
        attr_accessor :expired_shopping_page_score
      
        # From MagicPageTypeAnnotation.multiplicity.confidence_score * 100 Deprecated as
        # of July 2020 when dataset_model_multi_product_score and
        # dataset_model_single_product_score were added.
        # Corresponds to the JSON property `multiProductScore`
        # @return [Fixnum]
        attr_accessor :multi_product_score
      
        # 
        # Corresponds to the JSON property `product`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentProduct>]
        attr_accessor :product
      
        # From ShoppingSiteClassifier.score * 100
        # Corresponds to the JSON property `shoppingSiteScore`
        # @return [Fixnum]
        attr_accessor :shopping_site_score
      
        # From ShoppingSiteClassifierShopfab.score * 100
        # Corresponds to the JSON property `shoppingSiteScoreShopfab`
        # @return [Fixnum]
        attr_accessor :shopping_site_score_shopfab
      
        # 
        # Corresponds to the JSON property `singleProductScore`
        # @return [Fixnum]
        attr_accessor :single_product_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dataset_model_buying_guide_score = args[:dataset_model_buying_guide_score] if args.key?(:dataset_model_buying_guide_score)
          @dataset_model_forum_list_score = args[:dataset_model_forum_list_score] if args.key?(:dataset_model_forum_list_score)
          @dataset_model_forum_single_score = args[:dataset_model_forum_single_score] if args.key?(:dataset_model_forum_single_score)
          @dataset_model_in_store_only_score = args[:dataset_model_in_store_only_score] if args.key?(:dataset_model_in_store_only_score)
          @dataset_model_indirect_availability_score = args[:dataset_model_indirect_availability_score] if args.key?(:dataset_model_indirect_availability_score)
          @dataset_model_multi_product_score = args[:dataset_model_multi_product_score] if args.key?(:dataset_model_multi_product_score)
          @dataset_model_product_comparison_score = args[:dataset_model_product_comparison_score] if args.key?(:dataset_model_product_comparison_score)
          @dataset_model_product_review_score = args[:dataset_model_product_review_score] if args.key?(:dataset_model_product_review_score)
          @dataset_model_product_topn_score = args[:dataset_model_product_topn_score] if args.key?(:dataset_model_product_topn_score)
          @dataset_model_qna_list_score = args[:dataset_model_qna_list_score] if args.key?(:dataset_model_qna_list_score)
          @dataset_model_qna_single_score = args[:dataset_model_qna_single_score] if args.key?(:dataset_model_qna_single_score)
          @dataset_model_single_product_score = args[:dataset_model_single_product_score] if args.key?(:dataset_model_single_product_score)
          @dataset_model_sold_out_score = args[:dataset_model_sold_out_score] if args.key?(:dataset_model_sold_out_score)
          @expired_shopping_page_score = args[:expired_shopping_page_score] if args.key?(:expired_shopping_page_score)
          @multi_product_score = args[:multi_product_score] if args.key?(:multi_product_score)
          @product = args[:product] if args.key?(:product)
          @shopping_site_score = args[:shopping_site_score] if args.key?(:shopping_site_score)
          @shopping_site_score_shopfab = args[:shopping_site_score_shopfab] if args.key?(:shopping_site_score_shopfab)
          @single_product_score = args[:single_product_score] if args.key?(:single_product_score)
        end
      end
      
      # 
      class QualityShoppingShoppingAttachmentLocale
        include Google::Apis::Core::Hashable
      
        # Use integers for fast scoring. Note: 26 is UNKNOWN_LANGUAGE_ID, 0 is UNKNOWN
        # region, see i18n::languages::Language and StableInternalRegionconverter Use -1
        # as default for both.
        # Corresponds to the JSON property `languageId`
        # @return [Fixnum]
        attr_accessor :language_id
      
        # 
        # Corresponds to the JSON property `regionId`
        # @return [Fixnum]
        attr_accessor :region_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language_id = args[:language_id] if args.key?(:language_id)
          @region_id = args[:region_id] if args.key?(:region_id)
        end
      end
      
      # Moka product attribute facet (go/gx).
      class QualityShoppingShoppingAttachmentMokaFacetValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `facetId`
        # @return [Fixnum]
        attr_accessor :facet_id
      
        # 
        # Corresponds to the JSON property `measureValue`
        # @return [Float]
        attr_accessor :measure_value
      
        # 
        # Corresponds to the JSON property `tagId`
        # @return [Fixnum]
        attr_accessor :tag_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @facet_id = args[:facet_id] if args.key?(:facet_id)
          @measure_value = args[:measure_value] if args.key?(:measure_value)
          @tag_id = args[:tag_id] if args.key?(:tag_id)
        end
      end
      
      # 
      class QualityShoppingShoppingAttachmentOffer
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `condition`
        # @return [String]
        attr_accessor :condition
      
        # 
        # Corresponds to the JSON property `controlType`
        # @return [String]
        attr_accessor :control_type
      
        # fingerprint of original offer item_urland mobile_offer_url (if present) to be
        # able to understand if offer data came from different url.
        # Corresponds to the JSON property `fingerprintOfOfferUrls`
        # @return [Array<Fixnum>]
        attr_accessor :fingerprint_of_offer_urls
      
        # image_id is sorted and distinct for efficient search during serving.
        # Corresponds to the JSON property `imageId`
        # @return [Array<Fixnum>]
        attr_accessor :image_id
      
        # inferred_images are sorted by inferred_image_id for efficient search during
        # serving.
        # Corresponds to the JSON property `inferredImages`
        # @return [Array<Google::Apis::ContentwarehouseV1::ShoppingWebentityShoppingAnnotationInferredImage>]
        attr_accessor :inferred_images
      
        # information about methods used to match offer with indexed url. See
        # shopping_annotation.proto
        # Corresponds to the JSON property `matchingType`
        # @return [Fixnum]
        attr_accessor :matching_type
      
        # account_id of the merchant in shopping systems.
        # Corresponds to the JSON property `merchantAccountId`
        # @return [Fixnum]
        attr_accessor :merchant_account_id
      
        # merchant_item_id is meaningless without the merchant_account_id.
        # Corresponds to the JSON property `merchantItemId`
        # @return [String]
        attr_accessor :merchant_item_id
      
        # direct to consumer brand merchant relationship
        # Corresponds to the JSON property `nonDisplayableBrandMerchantRelationship`
        # @return [String]
        attr_accessor :non_displayable_brand_merchant_relationship
      
        # 
        # Corresponds to the JSON property `nonDisplayableCurrency`
        # @return [String]
        attr_accessor :non_displayable_currency
      
        # non_displayable_organic_mscore is a organic confidence score that a merchant
        # will not cause financial or consumer trust damage. In range [0, 1]. See go/
        # merchant-quality-score .
        # Corresponds to the JSON property `nonDisplayableOrganicMscore`
        # @return [Float]
        attr_accessor :non_displayable_organic_mscore
      
        # 
        # Corresponds to the JSON property `offerDocid`
        # @return [Fixnum]
        attr_accessor :offer_docid
      
        # 
        # Corresponds to the JSON property `refType`
        # @return [String]
        attr_accessor :ref_type
      
        # Versioning Information used for Logging Purposes. See go/sori-logjoining.
        # Corresponds to the JSON property `soriVersionId`
        # @return [Google::Apis::ContentwarehouseV1::ShoppingWebentityShoppingAnnotationSoriVersionId]
        attr_accessor :sori_version_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @condition = args[:condition] if args.key?(:condition)
          @control_type = args[:control_type] if args.key?(:control_type)
          @fingerprint_of_offer_urls = args[:fingerprint_of_offer_urls] if args.key?(:fingerprint_of_offer_urls)
          @image_id = args[:image_id] if args.key?(:image_id)
          @inferred_images = args[:inferred_images] if args.key?(:inferred_images)
          @matching_type = args[:matching_type] if args.key?(:matching_type)
          @merchant_account_id = args[:merchant_account_id] if args.key?(:merchant_account_id)
          @merchant_item_id = args[:merchant_item_id] if args.key?(:merchant_item_id)
          @non_displayable_brand_merchant_relationship = args[:non_displayable_brand_merchant_relationship] if args.key?(:non_displayable_brand_merchant_relationship)
          @non_displayable_currency = args[:non_displayable_currency] if args.key?(:non_displayable_currency)
          @non_displayable_organic_mscore = args[:non_displayable_organic_mscore] if args.key?(:non_displayable_organic_mscore)
          @offer_docid = args[:offer_docid] if args.key?(:offer_docid)
          @ref_type = args[:ref_type] if args.key?(:ref_type)
          @sori_version_id = args[:sori_version_id] if args.key?(:sori_version_id)
        end
      end
      
      # Next ID: 15
      class QualityShoppingShoppingAttachmentPBlock
        include Google::Apis::Core::Hashable
      
        # Field full_title may contain duplicate info from title and list_title.
        # Corresponds to the JSON property `fullTitle`
        # @return [String]
        attr_accessor :full_title
      
        # Ordering for `image_docid`, and `image_info` are the same.
        # Corresponds to the JSON property `imageDocid`
        # @return [Array<Fixnum>]
        attr_accessor :image_docid
      
        # 
        # Corresponds to the JSON property `imageInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentPBlockImageInfo>]
        attr_accessor :image_info
      
        # 
        # Corresponds to the JSON property `isFreeDelivery`
        # @return [Boolean]
        attr_accessor :is_free_delivery
        alias_method :is_free_delivery?, :is_free_delivery
      
        # 
        # Corresponds to the JSON property `isFreeReturn`
        # @return [Boolean]
        attr_accessor :is_free_return
        alias_method :is_free_return?, :is_free_return
      
        # 
        # Corresponds to the JSON property `listTitle`
        # @return [String]
        attr_accessor :list_title
      
        # 
        # Corresponds to the JSON property `maxPriceValue`
        # @return [Float]
        attr_accessor :max_price_value
      
        # 
        # Corresponds to the JSON property `minPriceValue`
        # @return [Float]
        attr_accessor :min_price_value
      
        # 
        # Corresponds to the JSON property `price`
        # @return [String]
        attr_accessor :price
      
        # 
        # Corresponds to the JSON property `priceCurrency`
        # @return [String]
        attr_accessor :price_currency
      
        # 
        # Corresponds to the JSON property `priceValue`
        # @return [Float]
        attr_accessor :price_value
      
        # Product info extracted by Product Blocks go/sdu-shopping-page-intro and go/
        # product-block-extraction. Here is an example of a page with a ## list_title (
        # Shoes) and 3 blocks with their own titles: | Shoes | | ---------------------| |
        # * For Running | | ---------------------| | * Men's Hiking | | ----------------
        # -----| ## | * Dress Shoes | The field full_title is what we constructed to
        # best describe the product in the block. For example, for the above 3 blocks,
        # their full_titles will contain info from list_title: "Shoes For Running", "
        # Shoes Men's Hiking", "Dress Shoes". Note that the list_title is not repeated
        # for the 3rd block Real sample pages: http://screen/6UaoBtwWsLfbSKg http://
        # screen/BDHRgDonKG3KcXu, http://screen/53tLwNaX8mmYzDz
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @full_title = args[:full_title] if args.key?(:full_title)
          @image_docid = args[:image_docid] if args.key?(:image_docid)
          @image_info = args[:image_info] if args.key?(:image_info)
          @is_free_delivery = args[:is_free_delivery] if args.key?(:is_free_delivery)
          @is_free_return = args[:is_free_return] if args.key?(:is_free_return)
          @list_title = args[:list_title] if args.key?(:list_title)
          @max_price_value = args[:max_price_value] if args.key?(:max_price_value)
          @min_price_value = args[:min_price_value] if args.key?(:min_price_value)
          @price = args[:price] if args.key?(:price)
          @price_currency = args[:price_currency] if args.key?(:price_currency)
          @price_value = args[:price_value] if args.key?(:price_value)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class QualityShoppingShoppingAttachmentPBlockImageInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class QualityShoppingShoppingAttachmentProduct
        include Google::Apis::Core::Hashable
      
        # Information about a rating provided for a product. This can represent an
        # aggregated rating if count is set. Next Id: 4
        # Corresponds to the JSON property `aggregateRating`
        # @return [Google::Apis::ContentwarehouseV1::ShoppingWebentityShoppingAnnotationProductRating]
        attr_accessor :aggregate_rating
      
        # 
        # Corresponds to the JSON property `brandEntityId`
        # @return [Fixnum]
        attr_accessor :brand_entity_id
      
        # 
        # Corresponds to the JSON property `catalogId`
        # @return [Fixnum]
        attr_accessor :catalog_id
      
        # 
        # Corresponds to the JSON property `encodedProductSalientTerms`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded_product_salient_terms
      
        # 
        # Corresponds to the JSON property `globalProductClusterId`
        # @return [Fixnum]
        attr_accessor :global_product_cluster_id
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentLocale]
        attr_accessor :locale
      
        # 
        # Corresponds to the JSON property `mokaFacet`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentMokaFacetValue>]
        attr_accessor :moka_facet
      
        # 
        # Corresponds to the JSON property `nonDisplayableDescription`
        # @return [String]
        attr_accessor :non_displayable_description
      
        # 
        # Corresponds to the JSON property `nonDisplayableTitle`
        # @return [String]
        attr_accessor :non_displayable_title
      
        # 
        # Corresponds to the JSON property `offer`
        # @return [Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentOffer]
        attr_accessor :offer
      
        # Whether an outlink points to the same domain or off-domain. Only added if the
        # relationship is known, and the Offer has ref_type of OUTLINK.
        # Corresponds to the JSON property `outlinkDomainRelationship`
        # @return [String]
        attr_accessor :outlink_domain_relationship
      
        # Next ID: 15
        # Corresponds to the JSON property `pblock`
        # @return [Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachmentPBlock]
        attr_accessor :pblock
      
        # 
        # Corresponds to the JSON property `productClusterMid`
        # @return [Fixnum]
        attr_accessor :product_cluster_mid
      
        # Organic product popularity.
        # Corresponds to the JSON property `productPopularity`
        # @return [Float]
        attr_accessor :product_popularity
      
        # Relevance embedding from ShoppingAnnotation.Product
        # Corresponds to the JSON property `relevanceEmbedding`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityRankembedMustangMustangRankEmbedInfo>]
        attr_accessor :relevance_embedding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregate_rating = args[:aggregate_rating] if args.key?(:aggregate_rating)
          @brand_entity_id = args[:brand_entity_id] if args.key?(:brand_entity_id)
          @catalog_id = args[:catalog_id] if args.key?(:catalog_id)
          @encoded_product_salient_terms = args[:encoded_product_salient_terms] if args.key?(:encoded_product_salient_terms)
          @global_product_cluster_id = args[:global_product_cluster_id] if args.key?(:global_product_cluster_id)
          @locale = args[:locale] if args.key?(:locale)
          @moka_facet = args[:moka_facet] if args.key?(:moka_facet)
          @non_displayable_description = args[:non_displayable_description] if args.key?(:non_displayable_description)
          @non_displayable_title = args[:non_displayable_title] if args.key?(:non_displayable_title)
          @offer = args[:offer] if args.key?(:offer)
          @outlink_domain_relationship = args[:outlink_domain_relationship] if args.key?(:outlink_domain_relationship)
          @pblock = args[:pblock] if args.key?(:pblock)
          @product_cluster_mid = args[:product_cluster_mid] if args.key?(:product_cluster_mid)
          @product_popularity = args[:product_popularity] if args.key?(:product_popularity)
          @relevance_embedding = args[:relevance_embedding] if args.key?(:relevance_embedding)
        end
      end
      
      # Sitelink candidates that is generated from breadcrumbs.
      class QualitySitemapBreadcrumbTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `docs`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapBreadcrumbTargetDoc>]
        attr_accessor :docs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docs = args[:docs] if args.key?(:docs)
        end
      end
      
      # 
      class QualitySitemapBreadcrumbTargetDoc
        include Google::Apis::Core::Hashable
      
        # The number of web pages that contains the url in their breadcrumbs.
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class QualitySitemapCoClickTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `docs`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapCoClickTargetDoc>]
        attr_accessor :docs
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docs = args[:docs] if args.key?(:docs)
          @language = args[:language] if args.key?(:language)
        end
      end
      
      # 
      class QualitySitemapCoClickTargetDoc
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `coClickByLocale`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapCoClickTargetDocCoClickByLocale>]
        attr_accessor :co_click_by_locale
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @co_click_by_locale = args[:co_click_by_locale] if args.key?(:co_click_by_locale)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class QualitySitemapCoClickTargetDocCoClickByLocale
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `coClicks`
        # @return [Float]
        attr_accessor :co_clicks
      
        # 
        # Corresponds to the JSON property `coClicksCapped`
        # @return [Float]
        attr_accessor :co_clicks_capped
      
        # 
        # Corresponds to the JSON property `coClicksParent`
        # @return [Float]
        attr_accessor :co_clicks_parent
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @co_clicks = args[:co_clicks] if args.key?(:co_clicks)
          @co_clicks_capped = args[:co_clicks_capped] if args.key?(:co_clicks_capped)
          @co_clicks_parent = args[:co_clicks_parent] if args.key?(:co_clicks_parent)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # Scoring signals for computing the sitelink score. This message is currently
      # intended only for debugging. Accordingly, this is populated in CDoc but not in
      # MDU. It is enforced by the [(exclude_from_mdu) = true] annotation of the
      # corresponding fields in Target and TargetGroup.
      class QualitySitemapScoringSignals
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotations`
        # @return [Array<String>]
        attr_accessor :annotations
      
        # 
        # Corresponds to the JSON property `chromeTransCount`
        # @return [Fixnum]
        attr_accessor :chrome_trans_count
      
        # 
        # Corresponds to the JSON property `chromeTransProb`
        # @return [Float]
        attr_accessor :chrome_trans_prob
      
        # 
        # Corresponds to the JSON property `chromeWeight`
        # @return [Float]
        attr_accessor :chrome_weight
      
        # 
        # Corresponds to the JSON property `country`
        # @return [Array<String>]
        attr_accessor :country
      
        # 
        # Corresponds to the JSON property `countryConfidence`
        # @return [Array<Float>]
        attr_accessor :country_confidence
      
        # 
        # Corresponds to the JSON property `impressions`
        # @return [Fixnum]
        attr_accessor :impressions
      
        # 
        # Corresponds to the JSON property `langConfidence`
        # @return [Array<Float>]
        attr_accessor :lang_confidence
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Array<String>]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `localCountryIdentifier`
        # @return [Array<String>]
        attr_accessor :local_country_identifier
      
        # 
        # Corresponds to the JSON property `longClicks`
        # @return [Fixnum]
        attr_accessor :long_clicks
      
        # 
        # Corresponds to the JSON property `longCtr`
        # @return [Float]
        attr_accessor :long_ctr
      
        # 
        # Corresponds to the JSON property `navboostScore`
        # @return [Float]
        attr_accessor :navboost_score
      
        # 
        # Corresponds to the JSON property `navmenuScore`
        # @return [Float]
        attr_accessor :navmenu_score
      
        # 
        # Corresponds to the JSON property `pagerank`
        # @return [Fixnum]
        attr_accessor :pagerank
      
        # 
        # Corresponds to the JSON property `recentLongCtr`
        # @return [Float]
        attr_accessor :recent_long_ctr
      
        # 
        # Corresponds to the JSON property `targetCdocLanguages`
        # @return [Array<Fixnum>]
        attr_accessor :target_cdoc_languages
      
        # 
        # Corresponds to the JSON property `titleScore`
        # @return [Float]
        attr_accessor :title_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotations = args[:annotations] if args.key?(:annotations)
          @chrome_trans_count = args[:chrome_trans_count] if args.key?(:chrome_trans_count)
          @chrome_trans_prob = args[:chrome_trans_prob] if args.key?(:chrome_trans_prob)
          @chrome_weight = args[:chrome_weight] if args.key?(:chrome_weight)
          @country = args[:country] if args.key?(:country)
          @country_confidence = args[:country_confidence] if args.key?(:country_confidence)
          @impressions = args[:impressions] if args.key?(:impressions)
          @lang_confidence = args[:lang_confidence] if args.key?(:lang_confidence)
          @language = args[:language] if args.key?(:language)
          @local_country_identifier = args[:local_country_identifier] if args.key?(:local_country_identifier)
          @long_clicks = args[:long_clicks] if args.key?(:long_clicks)
          @long_ctr = args[:long_ctr] if args.key?(:long_ctr)
          @navboost_score = args[:navboost_score] if args.key?(:navboost_score)
          @navmenu_score = args[:navmenu_score] if args.key?(:navmenu_score)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @recent_long_ctr = args[:recent_long_ctr] if args.key?(:recent_long_ctr)
          @target_cdoc_languages = args[:target_cdoc_languages] if args.key?(:target_cdoc_languages)
          @title_score = args[:title_score] if args.key?(:title_score)
        end
      end
      
      # Information about a single sub-result.
      class QualitySitemapSubresult
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # A set of metadata about a list item that is passed on to Muppet from indexing.
        # Corresponds to the JSON property `itemMetadata`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapThirdPartyCarouselsListItemMuppetMetadata]
        attr_accessor :item_metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @item_metadata = args[:item_metadata] if args.key?(:item_metadata)
        end
      end
      
      # A container for encapsulating a list of sub-results.
      class QualitySitemapSubresultList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `subresult`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapSubresult>]
        attr_accessor :subresult
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @subresult = args[:subresult] if args.key?(:subresult)
        end
      end
      
      # Represents a single sitelink target, contains basic information used to
      # display the target (such as url and title) and to, maybe, dynamically change
      # the way targets are selected and/or ranked (such as score and is_mobile).
      # Please update the TargetInternal message if you make a change to this proto.
      # See "Note on adding new fields".
      class QualitySitemapTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDSnippet`
        # @return [Array<String>]
        attr_accessor :deprecated_snippet
      
        # 
        # Corresponds to the JSON property `isGoodForMobile`
        # @return [Boolean]
        attr_accessor :is_good_for_mobile
        alias_method :is_good_for_mobile?, :is_good_for_mobile
      
        # 
        # Corresponds to the JSON property `isMobileN1dup`
        # @return [Boolean]
        attr_accessor :is_mobile_n1dup
        alias_method :is_mobile_n1dup?, :is_mobile_n1dup
      
        # The languages of the document, taken from its cdoc.properties().languages()
        # Corresponds to the JSON property `languages`
        # @return [Array<Fixnum>]
        attr_accessor :languages
      
        # The following message contains info of sub image docs, it is populated in
        # query_state and consumed in web image boost twiddler: (go/
        # WebImageBoostTwiddler).
        # Corresponds to the JSON property `salientImage`
        # @return [Google::Apis::ContentwarehouseV1::WwwResultInfoSubImageDocInfo]
        attr_accessor :salient_image
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Scoring signals for computing the sitelink score. This message is currently
        # intended only for debugging. Accordingly, this is populated in CDoc but not in
        # MDU. It is enforced by the [(exclude_from_mdu) = true] annotation of the
        # corresponding fields in Target and TargetGroup.
        # Corresponds to the JSON property `scoringSignals`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapScoringSignals]
        attr_accessor :scoring_signals
      
        # Section texts used for Page Anchors Preview (go/page-anchor-preview-dd).
        # Corresponds to the JSON property `sectionTexts`
        # @return [Array<String>]
        attr_accessor :section_texts
      
        # The generic version of a snippet response
        # Corresponds to the JSON property `snippetResponse`
        # @return [Google::Apis::ContentwarehouseV1::GenericSnippetResponse]
        attr_accessor :snippet_response
      
        # 
        # Corresponds to the JSON property `sourceAnchor`
        # @return [Boolean]
        attr_accessor :source_anchor
        alias_method :source_anchor?, :source_anchor
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `twoLevelScore`
        # @return [Float]
        attr_accessor :two_level_score
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_snippet = args[:deprecated_snippet] if args.key?(:deprecated_snippet)
          @is_good_for_mobile = args[:is_good_for_mobile] if args.key?(:is_good_for_mobile)
          @is_mobile_n1dup = args[:is_mobile_n1dup] if args.key?(:is_mobile_n1dup)
          @languages = args[:languages] if args.key?(:languages)
          @salient_image = args[:salient_image] if args.key?(:salient_image)
          @score = args[:score] if args.key?(:score)
          @scoring_signals = args[:scoring_signals] if args.key?(:scoring_signals)
          @section_texts = args[:section_texts] if args.key?(:section_texts)
          @snippet_response = args[:snippet_response] if args.key?(:snippet_response)
          @source_anchor = args[:source_anchor] if args.key?(:source_anchor)
          @title = args[:title] if args.key?(:title)
          @two_level_score = args[:two_level_score] if args.key?(:two_level_score)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Represents a set of targets. The group may have a label field to uniquely
      # identify this target group among others - for instance, if these targets'
      # titles were generated using an alternative title algorithm, the label can be "
      # newtitles". See "Note on adding new fields".
      class QualitySitemapTargetGroup
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDCountry`
        # @return [Fixnum]
        attr_accessor :deprecated_country
      
        # 
        # Corresponds to the JSON property `Target`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapTarget>]
        attr_accessor :target
      
        # If all the targets in this group are named anchors on the source page.
        # Corresponds to the JSON property `allTargetsNamedAnchors`
        # @return [Boolean]
        attr_accessor :all_targets_named_anchors
        alias_method :all_targets_named_anchors?, :all_targets_named_anchors
      
        # If all the targets in this group are named topictags_scrollto on the source
        # page.
        # Corresponds to the JSON property `allTargetsNamedTopictagsScrollto`
        # @return [Boolean]
        attr_accessor :all_targets_named_topictags_scrollto
        alias_method :all_targets_named_topictags_scrollto?, :all_targets_named_topictags_scrollto
      
        # Sitelink candidates that is generated from breadcrumbs.
        # Corresponds to the JSON property `breadcrumbTarget`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapBreadcrumbTarget]
        attr_accessor :breadcrumb_target
      
        # 
        # Corresponds to the JSON property `coClickTarget`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapCoClickTarget>]
        attr_accessor :co_click_target
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `modifiedByHostcardHandler`
        # @return [Boolean]
        attr_accessor :modified_by_hostcard_handler
        alias_method :modified_by_hostcard_handler?, :modified_by_hostcard_handler
      
        # Scoring signals for computing the sitelink score. This message is currently
        # intended only for debugging. Accordingly, this is populated in CDoc but not in
        # MDU. It is enforced by the [(exclude_from_mdu) = true] annotation of the
        # corresponding fields in Target and TargetGroup.
        # Corresponds to the JSON property `scoringSignals`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapScoringSignals]
        attr_accessor :scoring_signals
      
        # A list of top urls with highest two_level_score, i.e., chrome_trans_clicks.
        # Corresponds to the JSON property `topUrl`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapTopUrl>]
        attr_accessor :top_url
      
        # 
        # Corresponds to the JSON property `twoLevelTarget`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapTwoLevelTarget>]
        attr_accessor :two_level_target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_country = args[:deprecated_country] if args.key?(:deprecated_country)
          @target = args[:target] if args.key?(:target)
          @all_targets_named_anchors = args[:all_targets_named_anchors] if args.key?(:all_targets_named_anchors)
          @all_targets_named_topictags_scrollto = args[:all_targets_named_topictags_scrollto] if args.key?(:all_targets_named_topictags_scrollto)
          @breadcrumb_target = args[:breadcrumb_target] if args.key?(:breadcrumb_target)
          @co_click_target = args[:co_click_target] if args.key?(:co_click_target)
          @country_code = args[:country_code] if args.key?(:country_code)
          @label = args[:label] if args.key?(:label)
          @language = args[:language] if args.key?(:language)
          @modified_by_hostcard_handler = args[:modified_by_hostcard_handler] if args.key?(:modified_by_hostcard_handler)
          @scoring_signals = args[:scoring_signals] if args.key?(:scoring_signals)
          @top_url = args[:top_url] if args.key?(:top_url)
          @two_level_target = args[:two_level_target] if args.key?(:two_level_target)
        end
      end
      
      # A set of metadata about a list item that is passed on to Muppet from indexing.
      class QualitySitemapThirdPartyCarouselsListItemMuppetMetadata
        include Google::Apis::Core::Hashable
      
        # DEPRECATED. No longer populated, and not used anywhere.
        # Corresponds to the JSON property `urlFoundOnPage`
        # @return [Boolean]
        attr_accessor :url_found_on_page
        alias_method :url_found_on_page?, :url_found_on_page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @url_found_on_page = args[:url_found_on_page] if args.key?(:url_found_on_page)
        end
      end
      
      # 
      class QualitySitemapTopUrl
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class QualitySitemapTwoLevelTarget
        include Google::Apis::Core::Hashable
      
        # Represents a single sitelink target, contains basic information used to
        # display the target (such as url and title) and to, maybe, dynamically change
        # the way targets are selected and/or ranked (such as score and is_mobile).
        # Please update the TargetInternal message if you make a change to this proto.
        # See "Note on adding new fields".
        # Corresponds to the JSON property `firstLevelTarget`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapTarget]
        attr_accessor :first_level_target
      
        # 
        # Corresponds to the JSON property `secondLevelTarget`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapTarget>]
        attr_accessor :second_level_target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @first_level_target = args[:first_level_target] if args.key?(:first_level_target)
          @second_level_target = args[:second_level_target] if args.key?(:second_level_target)
        end
      end
      
      # 
      class QualityTimebasedLastSignificantUpdate
        include Google::Apis::Core::Hashable
      
        # LastSignificantUpdate as UNIX timestamp in seconds. This is the new signal (go/
        # lsu-dd) from LSU Selector V2 (once that is enabled, see b/171879888 for status)
        # , falling back to the legacy V1 signal if the V2 signal does not exist. Please
        # use the 'source' field to determine where the value comes from.
        # Corresponds to the JSON property `date`
        # @return [Fixnum]
        attr_accessor :date
      
        # The source the signal comes from.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @date = args[:date] if args.key?(:date)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class QualityTimebasedOldnessInfo
        include Google::Apis::Core::Hashable
      
        # Set to true if this page is considered old.
        # Corresponds to the JSON property `isOldPage`
        # @return [Boolean]
        attr_accessor :is_old_page
        alias_method :is_old_page?, :is_old_page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_old_page = args[:is_old_page] if args.key?(:is_old_page)
        end
      end
      
      # 
      class QualityTimebasedPageType
        include Google::Apis::Core::Hashable
      
        # Set to true if this page is classified as a forum page.
        # Corresponds to the JSON property `isForumPage`
        # @return [Boolean]
        attr_accessor :is_forum_page
        alias_method :is_forum_page?, :is_forum_page
      
        # Set to true if this page has a fresh repeated date sequence.
        # Corresponds to the JSON property `isPageWithFreshRepeatedDates`
        # @return [Boolean]
        attr_accessor :is_page_with_fresh_repeated_dates
        alias_method :is_page_with_fresh_repeated_dates?, :is_page_with_fresh_repeated_dates
      
        # Set to true if this page is classified as a question answers page.
        # Corresponds to the JSON property `isQnaPage`
        # @return [Boolean]
        attr_accessor :is_qna_page
        alias_method :is_qna_page?, :is_qna_page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_forum_page = args[:is_forum_page] if args.key?(:is_forum_page)
          @is_page_with_fresh_repeated_dates = args[:is_page_with_fresh_repeated_dates] if args.key?(:is_page_with_fresh_repeated_dates)
          @is_qna_page = args[:is_qna_page] if args.key?(:is_qna_page)
        end
      end
      
      # Next ID: 21
      class QualityTimebasedSyntacticDate
        include Google::Apis::Core::Hashable
      
        # The following field is set only when the byline date is different from the "
        # date" field above. Currently this happens when the byline date is within the
        # 24 hours of the crawl time, or close but not exactly the same as blog post
        # date due to time zone. The syntactic date is never later than the crawl time.
        # NOTE: If this field is set, use_as_byline_date will be meaningless, and better
        # to be cleared.
        # Corresponds to the JSON property `bylineDate`
        # @return [Fixnum]
        attr_accessor :byline_date
      
        # The number of seconds since epoch (Jan 1, 1970). This can be negative to
        # indicate a publication date that is before 1970. For example, the ones from NY
        # Times archive: "http://select.nytimes.com/gst/abstract.html?res=
        # F10B13FB3D5A10728FDDAF089" "4DD405B8588F1D3&scp=91&sq=world+war+II&st=p"
        # Corresponds to the JSON property `date`
        # @return [Fixnum]
        attr_accessor :date
      
        # If the single date (plus the precision mark) is still not good enough, we will
        # use the following fields for a date range. In this case, the fields above may
        # all be empty.
        # Corresponds to the JSON property `daterange`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedSyntacticDateDateRange]
        attr_accessor :daterange
      
        # 
        # Corresponds to the JSON property `debugInfo`
        # @return [String]
        attr_accessor :debug_info
      
        # If set to true, the source of the date has explicit time zone specification.
        # Note: This is only used internally and should not be populated in docjoins.
        # Corresponds to the JSON property `fromExplicitTimeZone`
        # @return [Boolean]
        attr_accessor :from_explicit_time_zone
        alias_method :from_explicit_time_zone?, :from_explicit_time_zone
      
        # Used to store extra information about the syntactic date. For now only two
        # bits are set. Please refer to the encoding/decoding functions provided in:
        # quality/timebased/syntacticdate/util.h Bit 1 = High confidence byline. This
        # bit is set if the syntactic date has a byline date and this date is considered
        # to be high confidence. Bit 2 = High confidence byline without content age.
        # This bit is set if the syntactic date has a byline date and this date is
        # considered to be high confidence without support from content age.
        # Corresponds to the JSON property `info`
        # @return [Fixnum]
        attr_accessor :info
      
        # The following positions are the byte offset in doc body, which is consistent
        # with the date annotations. (See google3/repository/annotations/proto/
        # annotations.proto) These are given when we want to use the date as a byline
        # date, so the snippet generating code will know the positions.
        # Corresponds to the JSON property `position`
        # @return [Google::Apis::ContentwarehouseV1::QualityTimebasedSyntacticDatePosition]
        attr_accessor :position
      
        # The precision mark should be of type PRECISION_MARK.
        # Corresponds to the JSON property `precisionMark`
        # @return [Fixnum]
        attr_accessor :precision_mark
      
        # If this is true, do not use syntactic date in date restricts.
        # Corresponds to the JSON property `syntacticDateNotForRestrict`
        # @return [Boolean]
        attr_accessor :syntactic_date_not_for_restrict
        alias_method :syntactic_date_not_for_restrict?, :syntactic_date_not_for_restrict
      
        # Indicates the time zone offset in seconds applied to derive `date' in UTC.
        # Example: Annotation: "1pm PST" (UTC-8) => -8 * 3600 = -28800 Note: This is
        # only used internally and should not be populated in docjoins.
        # Corresponds to the JSON property `timeZoneOffsetSeconds`
        # @return [Fixnum]
        attr_accessor :time_zone_offset_seconds
      
        # This bit is set if we believe that the syntactic date is really high
        # confidence, but does not qualify as a byline date.
        # Corresponds to the JSON property `trustSyntacticDateInRanking`
        # @return [Boolean]
        attr_accessor :trust_syntactic_date_in_ranking
        alias_method :trust_syntactic_date_in_ranking?, :trust_syntactic_date_in_ranking
      
        # Whether this date is good for display as the snippet byline date.
        # Corresponds to the JSON property `useAsBylineDate`
        # @return [Boolean]
        attr_accessor :use_as_byline_date
        alias_method :use_as_byline_date?, :use_as_byline_date
      
        # This bit is set if the syntactic date is good to be used in site-level
        # timezone guessing statistics calculation. (The date should be absolute date
        # having a timestamp with hour and minute level information. It can come with or
        # without time zone information, which is indicated in from_explicit_time_zone
        # field defined below.)
        # Corresponds to the JSON property `useInTimeZoneGuessingMode`
        # @return [Boolean]
        attr_accessor :use_in_time_zone_guessing_mode
        alias_method :use_in_time_zone_guessing_mode?, :use_in_time_zone_guessing_mode
      
        # If true, the DateRange is used as date restrict, if false, the date is used as
        # date restrict. Has no effect if syntactic_date_not_for_restrict is true.
        # Corresponds to the JSON property `useRangeInsteadOfDateForRestrict`
        # @return [Boolean]
        attr_accessor :use_range_instead_of_date_for_restrict
        alias_method :use_range_instead_of_date_for_restrict?, :use_range_instead_of_date_for_restrict
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byline_date = args[:byline_date] if args.key?(:byline_date)
          @date = args[:date] if args.key?(:date)
          @daterange = args[:daterange] if args.key?(:daterange)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @from_explicit_time_zone = args[:from_explicit_time_zone] if args.key?(:from_explicit_time_zone)
          @info = args[:info] if args.key?(:info)
          @position = args[:position] if args.key?(:position)
          @precision_mark = args[:precision_mark] if args.key?(:precision_mark)
          @syntactic_date_not_for_restrict = args[:syntactic_date_not_for_restrict] if args.key?(:syntactic_date_not_for_restrict)
          @time_zone_offset_seconds = args[:time_zone_offset_seconds] if args.key?(:time_zone_offset_seconds)
          @trust_syntactic_date_in_ranking = args[:trust_syntactic_date_in_ranking] if args.key?(:trust_syntactic_date_in_ranking)
          @use_as_byline_date = args[:use_as_byline_date] if args.key?(:use_as_byline_date)
          @use_in_time_zone_guessing_mode = args[:use_in_time_zone_guessing_mode] if args.key?(:use_in_time_zone_guessing_mode)
          @use_range_instead_of_date_for_restrict = args[:use_range_instead_of_date_for_restrict] if args.key?(:use_range_instead_of_date_for_restrict)
        end
      end
      
      # If the single date (plus the precision mark) is still not good enough, we will
      # use the following fields for a date range. In this case, the fields above may
      # all be empty.
      class QualityTimebasedSyntacticDateDateRange
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end = args[:end] if args.key?(:end)
          @start = args[:start] if args.key?(:start)
        end
      end
      
      # The following positions are the byte offset in doc body, which is consistent
      # with the date annotations. (See google3/repository/annotations/proto/
      # annotations.proto) These are given when we want to use the date as a byline
      # date, so the snippet generating code will know the positions.
      class QualityTimebasedSyntacticDatePosition
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @end = args[:end] if args.key?(:end)
        end
      end
      
      # Protocol message for data related to good travel sites. This data is stored as
      # signals data in docjoins.
      class QualityTravelGoodSitesData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `i18n`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityTravelGoodSitesDataI18n>]
        attr_accessor :i18n
      
        # 
        # Corresponds to the JSON property `isAggr`
        # @return [Boolean]
        attr_accessor :is_aggr
        alias_method :is_aggr?, :is_aggr
      
        # 
        # Corresponds to the JSON property `isAttractionOfficial`
        # @return [Boolean]
        attr_accessor :is_attraction_official
        alias_method :is_attraction_official?, :is_attraction_official
      
        # 
        # Corresponds to the JSON property `isEntity`
        # @return [Boolean]
        attr_accessor :is_entity
        alias_method :is_entity?, :is_entity
      
        # 
        # Corresponds to the JSON property `isHotelOfficial`
        # @return [Boolean]
        attr_accessor :is_hotel_official
        alias_method :is_hotel_official?, :is_hotel_official
      
        # Factor that determines how local anchor credit is scaled before being added to
        # global anchors.
        # Corresponds to the JSON property `normalizationFactor`
        # @return [Float]
        attr_accessor :normalization_factor
      
        # 
        # Corresponds to the JSON property `signal`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityTravelGoodSitesDataSignal>]
        attr_accessor :signal
      
        # 
        # Corresponds to the JSON property `site`
        # @return [String]
        attr_accessor :site
      
        # Site quality score, which determines the site type.
        # Corresponds to the JSON property `totalScore`
        # @return [Float]
        attr_accessor :total_score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @i18n = args[:i18n] if args.key?(:i18n)
          @is_aggr = args[:is_aggr] if args.key?(:is_aggr)
          @is_attraction_official = args[:is_attraction_official] if args.key?(:is_attraction_official)
          @is_entity = args[:is_entity] if args.key?(:is_entity)
          @is_hotel_official = args[:is_hotel_official] if args.key?(:is_hotel_official)
          @normalization_factor = args[:normalization_factor] if args.key?(:normalization_factor)
          @signal = args[:signal] if args.key?(:signal)
          @site = args[:site] if args.key?(:site)
          @total_score = args[:total_score] if args.key?(:total_score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class QualityTravelGoodSitesDataI18n
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @locale = args[:locale] if args.key?(:locale)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Raw signals that determine the site quality score.
      class QualityTravelGoodSitesDataSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Audio-based language information about a Watch Page. For more information:
      # https://g3doc.corp.google.com/video/timedtext/g3doc/ali.md
      class QualityVidyaVideoLanguageVideoLanguage
        include Google::Apis::Core::Hashable
      
        # Audio language of video classified by Automatic Language Identification. It
        # corresponds to the first language (the highest confidence) in ALIResults.
        # lang_results.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Type of detected speech.
        # Corresponds to the JSON property `speechClass`
        # @return [String]
        attr_accessor :speech_class
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @speech_class = args[:speech_class] if args.key?(:speech_class)
        end
      end
      
      # Stores cluster scoring information for an entity Next Id: 6
      class QualityViewsExtractionClusterInfo
        include Google::Apis::Core::Hashable
      
        # The cluster_id represents the id of the set entity that WebRef provides.
        # Corresponds to the JSON property `clusterId`
        # @return [String]
        attr_accessor :cluster_id
      
        # Cluster set qref confidence score.
        # Corresponds to the JSON property `clusterSetScore`
        # @return [Float]
        attr_accessor :cluster_set_score
      
        # The mids of cluster members that are part of the same cluster. Note that
        # cluster members may end up having their own interpretation (EntityInfo which
        # includes a ClusterInfo) or not (eg because they do not explain the full query,
        # and so aqua does not output an interpretation for them). The latter case (a
        # cluster member is output only as part of this field), is equivalent to its
        # score being 0.
        # Corresponds to the JSON property `clusterSiblingMid`
        # @return [Array<String>]
        attr_accessor :cluster_sibling_mid
      
        # The score represents the score of the entity within the cluster.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `subCluster`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityViewsExtractionClusterInfo>]
        attr_accessor :sub_cluster
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
          @cluster_set_score = args[:cluster_set_score] if args.key?(:cluster_set_score)
          @cluster_sibling_mid = args[:cluster_sibling_mid] if args.key?(:cluster_sibling_mid)
          @score = args[:score] if args.key?(:score)
          @sub_cluster = args[:sub_cluster] if args.key?(:sub_cluster)
        end
      end
      
      # Wraps other annotations that are run over auto-generated video captions.
      class QualityWebanswersTranscriptAnnotations
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `videoTranscriptAnnotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityWebanswersVideoTranscriptAnnotations>]
        attr_accessor :video_transcript_annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @video_transcript_annotations = args[:video_transcript_annotations] if args.key?(:video_transcript_annotations)
        end
      end
      
      # 
      class QualityWebanswersVideoTranscriptAnnotations
        include Google::Apis::Core::Hashable
      
        # Should precisely match the amarna_docid in ContentBasedVideoMetadata.
        # Corresponds to the JSON property `amarnaDocid`
        # @return [String]
        attr_accessor :amarna_docid
      
        # The language of the transcript as recorded in Amarna.
        # Corresponds to the JSON property `lang`
        # @return [String]
        attr_accessor :lang
      
        # 
        # Corresponds to the JSON property `punctuatedTranscript`
        # @return [String]
        attr_accessor :punctuated_transcript
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `saftDocument`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :saft_document
      
        # Sentence boundaries.
        # Corresponds to the JSON property `saftSentenceBoundary`
        # @return [Google::Apis::ContentwarehouseV1::SentenceBoundaryAnnotations]
        attr_accessor :saft_sentence_boundary
      
        # YouTube caption timing information for http://go/video-answers.
        # Corresponds to the JSON property `timingInfo`
        # @return [Google::Apis::ContentwarehouseV1::QualityWebanswersVideoYouTubeCaptionTimingInfoAnnotations]
        attr_accessor :timing_info
      
        # Represents a collection of entities returned by the WebRef service. Next
        # available tag: 14.
        # Corresponds to the JSON property `webrefEntities`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntities]
        attr_accessor :webref_entities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amarna_docid = args[:amarna_docid] if args.key?(:amarna_docid)
          @lang = args[:lang] if args.key?(:lang)
          @punctuated_transcript = args[:punctuated_transcript] if args.key?(:punctuated_transcript)
          @saft_document = args[:saft_document] if args.key?(:saft_document)
          @saft_sentence_boundary = args[:saft_sentence_boundary] if args.key?(:saft_sentence_boundary)
          @timing_info = args[:timing_info] if args.key?(:timing_info)
          @webref_entities = args[:webref_entities] if args.key?(:webref_entities)
        end
      end
      
      # YouTube caption timing information for http://go/video-answers.
      class QualityWebanswersVideoYouTubeCaptionTimingInfoAnnotations
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        # 
        # Corresponds to the JSON property `instances`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityWebanswersVideoYouTubeCaptionTimingInfoAnnotationsInstance>]
        attr_accessor :instances
      
        # 
        # Corresponds to the JSON property `uploaderName`
        # @return [String]
        attr_accessor :uploader_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @instances = args[:instances] if args.key?(:instances)
          @uploader_name = args[:uploader_name] if args.key?(:uploader_name)
        end
      end
      
      # Byte-offset and timing information in videos. In CompositeDoc, we will store
      # the instance per sentence.
      class QualityWebanswersVideoYouTubeCaptionTimingInfoAnnotationsInstance
        include Google::Apis::Core::Hashable
      
        # Byte offsets in HTML. begin is inclusive and end is exclusive.
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `videoBeginMs`
        # @return [Fixnum]
        attr_accessor :video_begin_ms
      
        # 
        # Corresponds to the JSON property `videoEndMs`
        # @return [Fixnum]
        attr_accessor :video_end_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @end = args[:end] if args.key?(:end)
          @video_begin_ms = args[:video_begin_ms] if args.key?(:video_begin_ms)
          @video_end_ms = args[:video_end_ms] if args.key?(:video_end_ms)
        end
      end
      
      # Domain registration information for the document. NEXT ID TO USE: 3
      class RegistrationInfo
        include Google::Apis::Core::Hashable
      
        # This is the number of days since January 1st 1995 that this domain was last
        # created. This should always fit in 15 bits.
        # Corresponds to the JSON property `createdDate`
        # @return [Fixnum]
        attr_accessor :created_date
      
        # This is the number of days since January 1st 1995 that this domain last
        # expired. This should always fit in 15 bits. Jan 1st 1995 was chosen by the
        # history project as a special epoch date. Both the registrationinfo dates and
        # the linkage dates are measured in days since this epoch.
        # Corresponds to the JSON property `expiredDate`
        # @return [Fixnum]
        attr_accessor :expired_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @created_date = args[:created_date] if args.key?(:created_date)
          @expired_date = args[:expired_date] if args.key?(:expired_date)
        end
      end
      
      # GeoTopicality of a document is a set of GeoTopics ordered by their normalized
      # scores.
      class RepositoryAnnotationsGeoTopic
        include Google::Apis::Core::Hashable
      
        # This class represents an address, partial address, or address range. It is
        # intended to be attached to features to identify their address(es). Some
        # important points about addresses: - The addresses in the Geo Schema do *not*
        # include a component for the name of the feature, i.e. they are not self-
        # referential. For example, the name of a feature might be "Zack's Pizza" and
        # its address would be "123 Main Street". Similarly, streets, cities, and
        # counties do not include themselves as part of their address. The address of "
        # Seattle" is "King County, Washington, USA". If want to construct an address
        # that *does* include the feature name, you can simply prepend it to the other
        # address components. - Lakes, mountains, and other natural features do not
        # normally have addresses. Countries also do not have addresses because they are
        # at the top of the political hierarchy. - Address components in the Geo Schema
        # are listed in a particular order, independent of the conventions used by the
        # country in which they occur. The basic order is "smallest to largest" starting
        # with street numbers and routes, then political features, and ending with
        # postal features. The exact rules are defined by the implementation of the
        # AddressComponentOrdering::IsLessThan() function. - Some types of address
        # components may occur more than once in an address. For example, a UK address
        # with a "dependent thoroughfare" would have two components of TYPE_ROUTE (i.e.
        # street names). These are listed in the order they are normally written.
        # Corresponds to the JSON property `address`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAddressProto]
        attr_accessor :address
      
        # The raw scores used to calculate the normalized_score. Note that not all these
        # scores may be exposed to the users.
        # Corresponds to the JSON property `componentScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryAnnotationsGeoTopicalityScore>]
        attr_accessor :component_scores
      
        # A score [0, 1] indicating the confidence.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Is this a dense city (e.g., population > 100k)?
        # Corresponds to the JSON property `denseCity`
        # @return [Boolean]
        attr_accessor :dense_city
        alias_method :dense_city?, :dense_city
      
        # Sub type for POI types like ESTABLISHMENT_POI, ESTABLISHMENT_GROUNDS &
        # ESTABLISHMENT_BUILDING
        # Corresponds to the JSON property `establishmentType`
        # @return [Fixnum]
        attr_accessor :establishment_type
      
        # Latitude and Longitude of the location.
        # Corresponds to the JSON property `latE7`
        # @return [Fixnum]
        attr_accessor :lat_e7
      
        # 
        # Corresponds to the JSON property `lngE7`
        # @return [Fixnum]
        attr_accessor :lng_e7
      
        # Name of the Geographic location. This is the normalized name.
        # Corresponds to the JSON property `locationName`
        # @return [String]
        attr_accessor :location_name
      
        # A score [0, 1] indicating the likelihood of the location being the
        # GeoTopicality.
        # Corresponds to the JSON property `normalizedScore`
        # @return [Float]
        attr_accessor :normalized_score
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `oysterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :oyster_id
      
        # Oyster Feature Type
        # Corresponds to the JSON property `oysterType`
        # @return [Fixnum]
        attr_accessor :oyster_type
      
        # The sum of the normalized scores of POIs contained within a particular
        # locality.
        # Corresponds to the JSON property `sumContainedPoiNormalizedScores`
        # @return [Float]
        attr_accessor :sum_contained_poi_normalized_scores
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address = args[:address] if args.key?(:address)
          @component_scores = args[:component_scores] if args.key?(:component_scores)
          @confidence = args[:confidence] if args.key?(:confidence)
          @dense_city = args[:dense_city] if args.key?(:dense_city)
          @establishment_type = args[:establishment_type] if args.key?(:establishment_type)
          @lat_e7 = args[:lat_e7] if args.key?(:lat_e7)
          @lng_e7 = args[:lng_e7] if args.key?(:lng_e7)
          @location_name = args[:location_name] if args.key?(:location_name)
          @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
          @oyster_id = args[:oyster_id] if args.key?(:oyster_id)
          @oyster_type = args[:oyster_type] if args.key?(:oyster_type)
          @sum_contained_poi_normalized_scores = args[:sum_contained_poi_normalized_scores] if args.key?(:sum_contained_poi_normalized_scores)
        end
      end
      
      # 
      class RepositoryAnnotationsGeoTopicality
        include Google::Apis::Core::Hashable
      
        # The geotopics are ordered by normalized_score in descending order.
        # Corresponds to the JSON property `geotopics`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryAnnotationsGeoTopic>]
        attr_accessor :geotopics
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @geotopics = args[:geotopics] if args.key?(:geotopics)
        end
      end
      
      # 
      class RepositoryAnnotationsGeoTopicalityScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `rawScore`
        # @return [Float]
        attr_accessor :raw_score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @raw_score = args[:raw_score] if args.key?(:raw_score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # A conceptual structure for storing sentiment snippet information in mustang.
      # Essentially an adaptation of PhraseAnnotationProperties from //repository/
      # annotations/proto/annotations.proto.
      class RepositoryAnnotationsMustangSentimentSnippetAnnotations
        include Google::Apis::Core::Hashable
      
        # Deprecated: use snippet_score instead
        # Corresponds to the JSON property `deprecatedMagnitude`
        # @return [Float]
        attr_accessor :deprecated_magnitude
      
        # Deprecated: use snippet_score instead
        # Corresponds to the JSON property `deprecatedPolarity`
        # @return [Float]
        attr_accessor :deprecated_polarity
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `isTruncated`
        # @return [Boolean]
        attr_accessor :is_truncated
        alias_method :is_truncated?, :is_truncated
      
        # 
        # Corresponds to the JSON property `phraseType`
        # @return [String]
        attr_accessor :phrase_type
      
        # 
        # Corresponds to the JSON property `snippetScore`
        # @return [Fixnum]
        attr_accessor :snippet_score
      
        # This protobuffer is serving double duty as both a Mustang attachment and the
        # response proto that gets returned by Mustang in the WWWSnippetResponse's info
        # MessageSet. When stored as an attachment, this field will always be empty.
        # However, when returned with the WWWSnippetResponse, Mustang will print and
        # store the actual sentiment snippet's text here.
        # Corresponds to the JSON property `snippetText`
        # @return [String]
        attr_accessor :snippet_text
      
        # begin and end are token offsets.
        # Corresponds to the JSON property `start`
        # @return [Fixnum]
        attr_accessor :start
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_magnitude = args[:deprecated_magnitude] if args.key?(:deprecated_magnitude)
          @deprecated_polarity = args[:deprecated_polarity] if args.key?(:deprecated_polarity)
          @end = args[:end] if args.key?(:end)
          @is_truncated = args[:is_truncated] if args.key?(:is_truncated)
          @phrase_type = args[:phrase_type] if args.key?(:phrase_type)
          @snippet_score = args[:snippet_score] if args.key?(:snippet_score)
          @snippet_text = args[:snippet_text] if args.key?(:snippet_text)
          @start = args[:start] if args.key?(:start)
        end
      end
      
      # 
      class RepositoryAnnotationsRdfaBreadcrumbs
        include Google::Apis::Core::Hashable
      
        # Each crumb represents one link of the breadcrumb chain.
        # Corresponds to the JSON property `crumb`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryAnnotationsRdfaCrumb>]
        attr_accessor :crumb
      
        # The URL of the document from which this breadcrumb trail was extracted.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crumb = args[:crumb] if args.key?(:crumb)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # The information contained in a single crumb.
      class RepositoryAnnotationsRdfaCrumb
        include Google::Apis::Core::Hashable
      
        # The text that represented this crumb in the document.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # The URL linked from this crumb.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # This structure holds data for application information for rich snippets Next
      # ID: 48
      class RepositoryAnnotationsRdfaRdfaRichSnippetsApplication
        include Google::Apis::Core::Hashable
      
        # Fields for internal use
        # Corresponds to the JSON property `applicationUrl`
        # @return [String]
        attr_accessor :application_url
      
        # 
        # Corresponds to the JSON property `breadcrumbs`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryAnnotationsRdfaBreadcrumbs]
        attr_accessor :breadcrumbs
      
        # Application information.
        # Corresponds to the JSON property `category`
        # @return [Array<String>]
        attr_accessor :category
      
        # These are currently used only for Google Play.
        # Corresponds to the JSON property `countriesSupported`
        # @return [Array<String>]
        attr_accessor :countries_supported
      
        # 
        # Corresponds to the JSON property `countryPrices`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryAnnotationsRdfaRdfaRichSnippetsApplicationCountryPrice>]
        attr_accessor :country_prices
      
        # 
        # Corresponds to the JSON property `currency`
        # @return [String]
        attr_accessor :currency
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Developer console ID of the app if it exists. The ID is available for an app
        # registered to Google Developers Console, not Play Developer Console.
        # Corresponds to the JSON property `devConsoleId`
        # @return [String]
        attr_accessor :dev_console_id
      
        # Top 1 of extracted icon colors. We keep this field for backward compatibility.
        # Corresponds to the JSON property `extractedIconColor`
        # @return [Fixnum]
        attr_accessor :extracted_icon_color
      
        # Top 10 of extracted icon colors. r = (rgb >> 16) & 0xff; g = (rgb >> 8) & 0xff;
        # b = rgb & 0xff;
        # Corresponds to the JSON property `extractedIconColors`
        # @return [Array<Fixnum>]
        attr_accessor :extracted_icon_colors
      
        # Tags to be indexed for filtering, e.g. "ft_popular_score_gt_1m".
        # Corresponds to the JSON property `filteringTag`
        # @return [Array<String>]
        attr_accessor :filtering_tag
      
        # 
        # Corresponds to the JSON property `genre`
        # @return [Array<String>]
        attr_accessor :genre
      
        # Whether the app has editors choice tag
        # Corresponds to the JSON property `hasEditorsChoiceBadge`
        # @return [Boolean]
        attr_accessor :has_editors_choice_badge
        alias_method :has_editors_choice_badge?, :has_editors_choice_badge
      
        # Icon and Screenshots
        # Corresponds to the JSON property `iconUrlHref`
        # @return [String]
        attr_accessor :icon_url_href
      
        # 
        # Corresponds to the JSON property `iconUrlThumbnail`
        # @return [String]
        attr_accessor :icon_url_thumbnail
      
        # Whether the app offers in-app purchase.
        # Corresponds to the JSON property `inAppPurchase`
        # @return [Boolean]
        attr_accessor :in_app_purchase
        alias_method :in_app_purchase?, :in_app_purchase
      
        # Indicates if the localized data comes from default locale. This is needed
        # because the default localized data does not specify its locale. If this is
        # true, lang_locale may not be the correct locale and should be ignored.
        # Corresponds to the JSON property `isDefaultLangLocale`
        # @return [Boolean]
        attr_accessor :is_default_lang_locale
        alias_method :is_default_lang_locale?, :is_default_lang_locale
      
        # locale for the localized data, such as name, description and screenshots
        # Corresponds to the JSON property `langLocale`
        # @return [String]
        attr_accessor :lang_locale
      
        # 
        # Corresponds to the JSON property `lastUpdated`
        # @return [String]
        attr_accessor :last_updated
      
        # Market Android or itunes
        # Corresponds to the JSON property `marketplace`
        # @return [String]
        attr_accessor :marketplace
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `numDownloads`
        # @return [String]
        attr_accessor :num_downloads
      
        # See google3/quality/richsnippets/schema/data/operating_systems_rules.txt for
        # possible values.
        # Corresponds to the JSON property `operatingSystems`
        # @return [Array<String>]
        attr_accessor :operating_systems
      
        # Whether this App is optional result for Grid UI.
        # Corresponds to the JSON property `optionalResult`
        # @return [Boolean]
        attr_accessor :optional_result
        alias_method :optional_result?, :optional_result
      
        # 
        # Corresponds to the JSON property `originalRating`
        # @return [String]
        attr_accessor :original_rating
      
        # 
        # Corresponds to the JSON property `physicalDeviceTags`
        # @return [Array<String>]
        attr_accessor :physical_device_tags
      
        # 
        # Corresponds to the JSON property `platformTags`
        # @return [Array<String>]
        attr_accessor :platform_tags
      
        # 
        # Corresponds to the JSON property `popularScore`
        # @return [Float]
        attr_accessor :popular_score
      
        # Price
        # Corresponds to the JSON property `price`
        # @return [String]
        attr_accessor :price
      
        # Ratings and reviews Either for this version only or for all versions to be
        # displayed.
        # Corresponds to the JSON property `rating`
        # @return [String]
        attr_accessor :rating
      
        # 
        # Corresponds to the JSON property `ratingCount`
        # @return [String]
        attr_accessor :rating_count
      
        # 
        # Corresponds to the JSON property `releaseDate`
        # @return [String]
        attr_accessor :release_date
      
        # 
        # Corresponds to the JSON property `reviewAuthor`
        # @return [String]
        attr_accessor :review_author
      
        # 
        # Corresponds to the JSON property `reviewCount`
        # @return [String]
        attr_accessor :review_count
      
        # 
        # Corresponds to the JSON property `screenUrlHref`
        # @return [Array<String>]
        attr_accessor :screen_url_href
      
        # 
        # Corresponds to the JSON property `screenUrlThumbnail`
        # @return [Array<String>]
        attr_accessor :screen_url_thumbnail
      
        # bytes or numeric with MB or GB
        # Corresponds to the JSON property `size`
        # @return [String]
        attr_accessor :size
      
        # 
        # Corresponds to the JSON property `subcategory`
        # @return [Array<String>]
        attr_accessor :subcategory
      
        # Whether this App supports Android TV. Note that some App supports more than
        # one platforms. So we would use boolean for a platform.
        # Corresponds to the JSON property `supportsAndroidTv`
        # @return [Boolean]
        attr_accessor :supports_android_tv
        alias_method :supports_android_tv?, :supports_android_tv
      
        # Whether this App supports Google Cast.
        # Corresponds to the JSON property `supportsChromecast`
        # @return [Boolean]
        attr_accessor :supports_chromecast
        alias_method :supports_chromecast?, :supports_chromecast
      
        # 
        # Corresponds to the JSON property `totalRating`
        # @return [Float]
        attr_accessor :total_rating
      
        # Rating_count including all versions of this application.
        # Corresponds to the JSON property `totalRatingCount`
        # @return [Fixnum]
        attr_accessor :total_rating_count
      
        # Trusted Genome data with categorical app information key: locale (e.g. en,
        # en_US)
        # Corresponds to the JSON property `trustedGenomeData`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::VendingConsumerProtoTrustedGenomeAnnotation>]
        attr_accessor :trusted_genome_data
      
        # Vendor
        # Corresponds to the JSON property `vendor`
        # @return [String]
        attr_accessor :vendor
      
        # 
        # Corresponds to the JSON property `vendorCanonicalUrl`
        # @return [String]
        attr_accessor :vendor_canonical_url
      
        # 
        # Corresponds to the JSON property `vendorUrl`
        # @return [String]
        attr_accessor :vendor_url
      
        # 
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_url = args[:application_url] if args.key?(:application_url)
          @breadcrumbs = args[:breadcrumbs] if args.key?(:breadcrumbs)
          @category = args[:category] if args.key?(:category)
          @countries_supported = args[:countries_supported] if args.key?(:countries_supported)
          @country_prices = args[:country_prices] if args.key?(:country_prices)
          @currency = args[:currency] if args.key?(:currency)
          @description = args[:description] if args.key?(:description)
          @dev_console_id = args[:dev_console_id] if args.key?(:dev_console_id)
          @extracted_icon_color = args[:extracted_icon_color] if args.key?(:extracted_icon_color)
          @extracted_icon_colors = args[:extracted_icon_colors] if args.key?(:extracted_icon_colors)
          @filtering_tag = args[:filtering_tag] if args.key?(:filtering_tag)
          @genre = args[:genre] if args.key?(:genre)
          @has_editors_choice_badge = args[:has_editors_choice_badge] if args.key?(:has_editors_choice_badge)
          @icon_url_href = args[:icon_url_href] if args.key?(:icon_url_href)
          @icon_url_thumbnail = args[:icon_url_thumbnail] if args.key?(:icon_url_thumbnail)
          @in_app_purchase = args[:in_app_purchase] if args.key?(:in_app_purchase)
          @is_default_lang_locale = args[:is_default_lang_locale] if args.key?(:is_default_lang_locale)
          @lang_locale = args[:lang_locale] if args.key?(:lang_locale)
          @last_updated = args[:last_updated] if args.key?(:last_updated)
          @marketplace = args[:marketplace] if args.key?(:marketplace)
          @name = args[:name] if args.key?(:name)
          @num_downloads = args[:num_downloads] if args.key?(:num_downloads)
          @operating_systems = args[:operating_systems] if args.key?(:operating_systems)
          @optional_result = args[:optional_result] if args.key?(:optional_result)
          @original_rating = args[:original_rating] if args.key?(:original_rating)
          @physical_device_tags = args[:physical_device_tags] if args.key?(:physical_device_tags)
          @platform_tags = args[:platform_tags] if args.key?(:platform_tags)
          @popular_score = args[:popular_score] if args.key?(:popular_score)
          @price = args[:price] if args.key?(:price)
          @rating = args[:rating] if args.key?(:rating)
          @rating_count = args[:rating_count] if args.key?(:rating_count)
          @release_date = args[:release_date] if args.key?(:release_date)
          @review_author = args[:review_author] if args.key?(:review_author)
          @review_count = args[:review_count] if args.key?(:review_count)
          @screen_url_href = args[:screen_url_href] if args.key?(:screen_url_href)
          @screen_url_thumbnail = args[:screen_url_thumbnail] if args.key?(:screen_url_thumbnail)
          @size = args[:size] if args.key?(:size)
          @subcategory = args[:subcategory] if args.key?(:subcategory)
          @supports_android_tv = args[:supports_android_tv] if args.key?(:supports_android_tv)
          @supports_chromecast = args[:supports_chromecast] if args.key?(:supports_chromecast)
          @total_rating = args[:total_rating] if args.key?(:total_rating)
          @total_rating_count = args[:total_rating_count] if args.key?(:total_rating_count)
          @trusted_genome_data = args[:trusted_genome_data] if args.key?(:trusted_genome_data)
          @vendor = args[:vendor] if args.key?(:vendor)
          @vendor_canonical_url = args[:vendor_canonical_url] if args.key?(:vendor_canonical_url)
          @vendor_url = args[:vendor_url] if args.key?(:vendor_url)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # 
      class RepositoryAnnotationsRdfaRdfaRichSnippetsApplicationCountryPrice
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # ISO 4217 currency code.
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        # Price string converted from double value in a standard currency unit, like '
        # 199.35' or '1400'.
        # Corresponds to the JSON property `price`
        # @return [String]
        attr_accessor :price
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
          @price = args[:price] if args.key?(:price)
        end
      end
      
      # Represents a unique id for each entity. It contains the domain, entity type
      # and a legacy_id that is unique within that space. This protocol buffer stems
      # from a time when we were building our model based on entities from different
      # sources. Nowadays the domain_name and entity_type_name can be ignored and the
      # legacy_id is the Knowledge Graph mid except in some WebRef internal pipelines
      # such as reconciliation where it is still a vertical specific id. Current
      # usages (see GetKey and SetKey in entity-join-util.cc): domain_name = "
      # FreebaseDomain", entity_type_name = "Topic" domain_name = "GeoDomain",
      # entity_type_name = "Geo" domain_name = "ProductsDomain", entity_type_name = "
      # Product" domain_name = "ProductsDomain", entity_type_name = "ProductCluster"
      # domain_name = "UniversalDomain", entity_type_name = "Concept"
      class RepositoryWebrefAbsoluteLegacyId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `domainName`
        # @return [String]
        attr_accessor :domain_name
      
        # 
        # Corresponds to the JSON property `entityTypeName`
        # @return [String]
        attr_accessor :entity_type_name
      
        # 
        # Corresponds to the JSON property `legacyId`
        # @return [String]
        attr_accessor :legacy_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain_name = args[:domain_name] if args.key?(:domain_name)
          @entity_type_name = args[:entity_type_name] if args.key?(:entity_type_name)
          @legacy_id = args[:legacy_id] if args.key?(:legacy_id)
        end
      end
      
      # Represents the aggregated score of the entities for a given name, aggregated
      # over all sources. Next available tag: 3.
      class RepositoryWebrefAggregatedEntityNameScores
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entityScore`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityNameScore>]
        attr_accessor :entity_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_score = args[:entity_score] if args.key?(:entity_score)
        end
      end
      
      # Identifies a set of anchors in the CompositeDoc. Typically these anchors were
      # collapsed by WebRef into a single anchor and they were treated by the
      # annotator as equivalent. They all contain the same mentions (at the same
      # offsets).
      class RepositoryWebrefAnchorIndices
        include Google::Apis::Core::Hashable
      
        # The set of indices in the Anchors::anchor() array that belong to the collapsed
        # anchors.
        # Corresponds to the JSON property `index`
        # @return [Array<Fixnum>]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # Information about a category annotation on a name.
      class RepositoryWebrefAnnotatedCategoryInfo
        include Google::Apis::Core::Hashable
      
        # A debug string for the category.
        # Corresponds to the JSON property `debugString`
        # @return [String]
        attr_accessor :debug_string
      
        # Listiness score of the category.
        # Corresponds to the JSON property `listiness`
        # @return [Float]
        attr_accessor :listiness
      
        # The mid of the entity representing the category.
        # Corresponds to the JSON property `mid`
        # @return [Fixnum]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_string = args[:debug_string] if args.key?(:debug_string)
          @listiness = args[:listiness] if args.key?(:listiness)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # Debug info about the concept annotations. Note that it might not be present in
      # the output.
      class RepositoryWebrefAnnotationDebugInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `infoString`
        # @return [Array<String>]
        attr_accessor :info_string
      
        # Collection of input, extracted features and classification output.
        # Corresponds to the JSON property `rawClassification`
        # @return [Google::Apis::ContentwarehouseV1::EntitySignalsEntityClassification]
        attr_accessor :raw_classification
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @info_string = args[:info_string] if args.key?(:info_string)
          @raw_classification = args[:raw_classification] if args.key?(:raw_classification)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Human ratings of webref annotations (document-level ratings, mention-level
      # ratings, etc.).
      class RepositoryWebrefAnnotationRatings
        include Google::Apis::Core::Hashable
      
        # List of PerDocRelevanceRatings for Precision@5 evals done via ewok (template
        # 2282).
        # Corresponds to the JSON property `docLevelRelevanceRatings`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefDocLevelRelevanceRatings]
        attr_accessor :doc_level_relevance_ratings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_level_relevance_ratings = args[:doc_level_relevance_ratings] if args.key?(:doc_level_relevance_ratings)
        end
      end
      
      # Annotation statistics for each token type. Next available tag: 8.
      class RepositoryWebrefAnnotationStatsPerType
        include Google::Apis::Core::Hashable
      
        # The average score for the open world for: - all ranges of this segment_type; -
        # all capitalized ranges of this segment_type; - all uncapitalized ranges of
        # this segment_type.
        # Corresponds to the JSON property `avgOpenWorld`
        # @return [Float]
        attr_accessor :avg_open_world
      
        # 
        # Corresponds to the JSON property `avgOpenWorldCap`
        # @return [Float]
        attr_accessor :avg_open_world_cap
      
        # 
        # Corresponds to the JSON property `avgOpenWorldUncap`
        # @return [Float]
        attr_accessor :avg_open_world_uncap
      
        # The number of ranges with candidates that made it past primary pruning for: -
        # all ranges of this segment_type; - all capitalized ranges of this segment_type;
        # - all uncapitalized ranges of this segment_type.
        # Corresponds to the JSON property `numRangesWithCandidates`
        # @return [Fixnum]
        attr_accessor :num_ranges_with_candidates
      
        # 
        # Corresponds to the JSON property `numRangesWithCandidatesCap`
        # @return [Fixnum]
        attr_accessor :num_ranges_with_candidates_cap
      
        # 
        # Corresponds to the JSON property `numRangesWithCandidatesUncap`
        # @return [Fixnum]
        attr_accessor :num_ranges_with_candidates_uncap
      
        # The segment type.
        # Corresponds to the JSON property `tokenType`
        # @return [String]
        attr_accessor :token_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @avg_open_world = args[:avg_open_world] if args.key?(:avg_open_world)
          @avg_open_world_cap = args[:avg_open_world_cap] if args.key?(:avg_open_world_cap)
          @avg_open_world_uncap = args[:avg_open_world_uncap] if args.key?(:avg_open_world_uncap)
          @num_ranges_with_candidates = args[:num_ranges_with_candidates] if args.key?(:num_ranges_with_candidates)
          @num_ranges_with_candidates_cap = args[:num_ranges_with_candidates_cap] if args.key?(:num_ranges_with_candidates_cap)
          @num_ranges_with_candidates_uncap = args[:num_ranges_with_candidates_uncap] if args.key?(:num_ranges_with_candidates_uncap)
          @token_type = args[:token_type] if args.key?(:token_type)
        end
      end
      
      # Holds annotator checkpoints which record the state of the annotations. This is
      # useful for tracking down the source of diffs, in particular for non-
      # determinism.
      class RepositoryWebrefAnnotatorCheckpointFprint
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `fingerprint`
        # @return [Fixnum]
        attr_accessor :fingerprint
      
        # 
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # A message to collect annotator performance data.
      class RepositoryWebrefAnnotatorProfile
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `numCandidateMentions`
        # @return [Fixnum]
        attr_accessor :num_candidate_mentions
      
        # 
        # Corresponds to the JSON property `numEntities`
        # @return [Fixnum]
        attr_accessor :num_entities
      
        # 
        # Corresponds to the JSON property `numMentions`
        # @return [Fixnum]
        attr_accessor :num_mentions
      
        # 
        # Corresponds to the JSON property `numTokens`
        # @return [Fixnum]
        attr_accessor :num_tokens
      
        # Processor timings as produced by NestedPerfCounter, see google3/repository/
        # webref/base/nested-perf-counter.h.
        # Corresponds to the JSON property `processorTimingsRoot`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefProcessorTiming]
        attr_accessor :processor_timings_root
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_candidate_mentions = args[:num_candidate_mentions] if args.key?(:num_candidate_mentions)
          @num_entities = args[:num_entities] if args.key?(:num_entities)
          @num_mentions = args[:num_mentions] if args.key?(:num_mentions)
          @num_tokens = args[:num_tokens] if args.key?(:num_tokens)
          @processor_timings_root = args[:processor_timings_root] if args.key?(:processor_timings_root)
        end
      end
      
      # Book editions metadata for a book entity. This metadata is a pair of "/book/
      # book_edition" mid and its ISBN number.
      class RepositoryWebrefBookEditionMetadata
        include Google::Apis::Core::Hashable
      
        # Use varint encoding to save space.
        # Corresponds to the JSON property `bookEditionIsbn`
        # @return [Fixnum]
        attr_accessor :book_edition_isbn
      
        # 
        # Corresponds to the JSON property `bookEditionMid`
        # @return [Fixnum]
        attr_accessor :book_edition_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @book_edition_isbn = args[:book_edition_isbn] if args.key?(:book_edition_isbn)
          @book_edition_mid = args[:book_edition_mid] if args.key?(:book_edition_mid)
        end
      end
      
      # 
      class RepositoryWebrefBootstrappingScore
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `scoreRatio`
        # @return [Float]
        attr_accessor :score_ratio
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score_ratio = args[:score_ratio] if args.key?(:score_ratio)
        end
      end
      
      # High level category annotations for documents and queries.
      class RepositoryWebrefCategoryAnnotation
        include Google::Apis::Core::Hashable
      
        # Experimental scores for browsy topics, see * go/example-docs-with-implicit-
        # fashion-styles * go/browsy-entities
        # Corresponds to the JSON property `browsyTopic`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefCategoryAnnotationBrowsyTopic]
        attr_accessor :browsy_topic
      
        # Title of the category. Eg "Politics", "Technology".
        # Corresponds to the JSON property `debugString`
        # @return [String]
        attr_accessor :debug_string
      
        # The HitCat page classifier. See go/hitcat2 If you use any HitCat score, please:
        # 1. Add your use-case to go/hits-clients. 2. Subscribe to hits-users@ to
        # receive general updates.
        # Corresponds to the JSON property `hitcat`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefCategoryAnnotationHitCatSource]
        attr_accessor :hitcat
      
        # Mid representation of the category. Eg "/m/05qt0". WARNING: In UDR this field
        # is not populated, use document_entity.entity.mid instead of document_entity.
        # category.mid.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The QPrime query classifier signals.
        # Corresponds to the JSON property `shopping`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefCategoryAnnotationShoppingSignals]
        attr_accessor :shopping
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @browsy_topic = args[:browsy_topic] if args.key?(:browsy_topic)
          @debug_string = args[:debug_string] if args.key?(:debug_string)
          @hitcat = args[:hitcat] if args.key?(:hitcat)
          @mid = args[:mid] if args.key?(:mid)
          @shopping = args[:shopping] if args.key?(:shopping)
        end
      end
      
      # Experimental scores for browsy topics, see * go/example-docs-with-implicit-
      # fashion-styles * go/browsy-entities
      class RepositoryWebrefCategoryAnnotationBrowsyTopic
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
        end
      end
      
      # The HitCat page classifier. See go/hitcat2 If you use any HitCat score, please:
      # 1. Add your use-case to go/hits-clients. 2. Subscribe to hits-users@ to
      # receive general updates.
      class RepositoryWebrefCategoryAnnotationHitCatSource
        include Google::Apis::Core::Hashable
      
        # Confidence of the category in the range [0.0, 1.0). If a page has the category
        # "NBA" with high confidence we also expect it to have the "Basketball" with
        # high confidence. Categories with a confidence lower than 0.05 are omitted.
        # This can be interpreted as a confidence of 0, i.e. a strong signal that the
        # category is not relevant for the page. For some categories this score is
        # calibrated per-category to estimate the true precision. E.g., 70% of documents
        # retrieved within the confidence range [0.7 - eps, 0.7 + eps] will be relevant
        # when eps is close to 0.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Calibrated cumulative confidence guaranteeing maxmial recall for a precision
        # target. E.g., At least 90% of documents retrieved with cumulative_confidence >=
        # 0.9 will be relevant. This score is always calibrated per-category to
        # estimate the true cumulative precision and is not set for uncalibrated
        # categories.
        # Corresponds to the JSON property `cumulativeConfidence`
        # @return [Float]
        attr_accessor :cumulative_confidence
      
        # Note: For testing the next version. May change at any time. Experimental
        # confidence of the category in the range (0.0, 1.0).
        # Corresponds to the JSON property `experimentalConfidence`
        # @return [Float]
        attr_accessor :experimental_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @cumulative_confidence = args[:cumulative_confidence] if args.key?(:cumulative_confidence)
          @experimental_confidence = args[:experimental_confidence] if args.key?(:experimental_confidence)
        end
      end
      
      # The QPrime query classifier signals.
      class RepositoryWebrefCategoryAnnotationShoppingSignals
        include Google::Apis::Core::Hashable
      
        # Whether QPrime asserts that particular category.
        # Corresponds to the JSON property `isShoppingAnnotation`
        # @return [Boolean]
        attr_accessor :is_shopping_annotation
        alias_method :is_shopping_annotation?, :is_shopping_annotation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_shopping_annotation = args[:is_shopping_annotation] if args.key?(:is_shopping_annotation)
        end
      end
      
      # All informations about category types of the entity.
      class RepositoryWebrefCategoryInfo
        include Google::Apis::Core::Hashable
      
        # Contains all types relevant for this entity, along with their provenances and
        # confidences. This field basically replicates information above in a unified
        # way, so that Refcon scroing can make better use of it. If present, Refcon
        # scoring will use all_types, and ignore other fields like freebase_type. Note:
        # there is some basic conflict resolution applied when all_types are computed (
        # implemented in type-extractor.cc, IsLikelyConflictingFreebase).
        # Corresponds to the JSON property `allTypes`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFreebaseType>]
        attr_accessor :all_types
      
        # verticals4 categories that describe this entity.
        # Corresponds to the JSON property `fatcatCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFatcatCategory>]
        attr_accessor :fatcat_category
      
        # verticals4 categories that describe the context of the entity.
        # Corresponds to the JSON property `fatcatContext`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFatcatCategory>]
        attr_accessor :fatcat_context
      
        # 
        # Corresponds to the JSON property `freebaseType`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFreebaseType>]
        attr_accessor :freebase_type
      
        # 
        # Corresponds to the JSON property `kgCollection`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefKgCollection>]
        attr_accessor :kg_collection
      
        # Oyster type information.
        # Corresponds to the JSON property `oysterType`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefOysterType]
        attr_accessor :oyster_type
      
        # verticals4 categories that cooccur with this entity, aggregated over D2E. See
        # where we read from CompactDocClassification in http://google3/repository/
        # webref/preprocessing/fatcat-categories.cc.
        # Corresponds to the JSON property `salientCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFatcatCategory>]
        attr_accessor :salient_category
      
        # 
        # Corresponds to the JSON property `wikipediaCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWikipediaCategory>]
        attr_accessor :wikipedia_category
      
        # WPCat CategotyResult classification.
        # Corresponds to the JSON property `wpCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefFreebaseType>]
        attr_accessor :wp_category
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_types = args[:all_types] if args.key?(:all_types)
          @fatcat_category = args[:fatcat_category] if args.key?(:fatcat_category)
          @fatcat_context = args[:fatcat_context] if args.key?(:fatcat_context)
          @freebase_type = args[:freebase_type] if args.key?(:freebase_type)
          @kg_collection = args[:kg_collection] if args.key?(:kg_collection)
          @oyster_type = args[:oyster_type] if args.key?(:oyster_type)
          @salient_category = args[:salient_category] if args.key?(:salient_category)
          @wikipedia_category = args[:wikipedia_category] if args.key?(:wikipedia_category)
          @wp_category = args[:wp_category] if args.key?(:wp_category)
        end
      end
      
      # Metadata about clusters. See go/webref-variants for details. Next available
      # tag: 6.
      class RepositoryWebrefClusterMetadata
        include Google::Apis::Core::Hashable
      
        # If true, this entity is a synthetic entity created to represent a "set" in a
        # cluster, i.e. to represent a set of entities (its children in the cluster
        # graph) when we cannot disambiguate among them. This is similar to a KG
        # Collection, but this is not in KG.
        # Corresponds to the JSON property `isSet`
        # @return [Boolean]
        attr_accessor :is_set
        alias_method :is_set?, :is_set
      
        # When we apply a rule to define a particular cluster, we have a RuleInstance.
        # Some kinds of rules for clusters define more than one cluster. In those rules
        # we say things like "for each entity X with this property, we create a cluster
        # where..."; each particular cluster that we create is the result of an *
        # instance* of that rule, where the argument X has been bound to a particular
        # entity (note that this also applies to rules that define only one cluster; in
        # that case, there are no arguments). An entity that is part of a cluster plays
        # a "role" in such a cluster. This message describes such an instantiation of a
        # rule with a role and with concrete values for the arguments.
        # Corresponds to the JSON property `ruleInstance`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterProtoRuleInstance]
        attr_accessor :rule_instance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_set = args[:is_set] if args.key?(:is_set)
          @rule_instance = args[:rule_instance] if args.key?(:rule_instance)
        end
      end
      
      # A rule that defines a Cluster based on a list of mids. It creates a single Set,
      # and makes it the parent of each of the mids in the list.
      class RepositoryWebrefClusterProtoMidListRule
        include Google::Apis::Core::Hashable
      
        # Id of this rule; this is used to generate ids for the synthetic entities
        # created for a cluster. Required.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The mids of the entities that will be made into a cluster.
        # Corresponds to the JSON property `mid`
        # @return [Array<String>]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # An instance of a "mid list" rule. Each "mid list" rule defines exactly one
      # cluster.
      class RepositoryWebrefClusterProtoMidListRuleInstance
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # A rule that defines a Cluster based on a list of mids. It creates a single Set,
        # and makes it the parent of each of the mids in the list.
        # Corresponds to the JSON property `rule`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterProtoMidListRule]
        attr_accessor :rule
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @role = args[:role] if args.key?(:role)
          @rule = args[:rule] if args.key?(:rule)
        end
      end
      
      # A rule that defines a Cluster based on a relation. Given a relation (a link
      # type) R, then: For each entity B that has incoming links of type R This
      # defines an instance of this rule, with argument=B We create a Set S We make B
      # a child of S For each entity A that has a link R to B, we make A a child of S
      class RepositoryWebrefClusterProtoRelationRule
        include Google::Apis::Core::Hashable
      
        # If true, cluster global names and links will be extracted from the target of
        # the property. If false, all members of the cluster will be considered sources.
        # Corresponds to the JSON property `isCollapsible`
        # @return [Boolean]
        attr_accessor :is_collapsible
        alias_method :is_collapsible?, :is_collapsible
      
        # Whether the target of the relation is an intermediate (CVT) node in KG: - if
        # it is not: generate external_id for the cluster - if it is: - CVT should not
        # be /common/topic otherwise rule will not be created - cluster will reuse CVT
        # mid as its own
        # Corresponds to the JSON property `isCvtRule`
        # @return [Boolean]
        attr_accessor :is_cvt_rule
        alias_method :is_cvt_rule?, :is_cvt_rule
      
        # The topic_property_name for the link that defines the relation, e.g. "/tv/
        # tv_series_episode/series". Can start with a "!" to indicate that this link is
        # reversed during extraction and we want the reversed case. Required.
        # Corresponds to the JSON property `relation`
        # @return [String]
        attr_accessor :relation
      
        # Rule sequence id. The rule with the lowest sequence id in a cluster will
        # contribute its id to the id of the cluster.
        # Corresponds to the JSON property `sequenceId`
        # @return [Fixnum]
        attr_accessor :sequence_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_collapsible = args[:is_collapsible] if args.key?(:is_collapsible)
          @is_cvt_rule = args[:is_cvt_rule] if args.key?(:is_cvt_rule)
          @relation = args[:relation] if args.key?(:relation)
          @sequence_id = args[:sequence_id] if args.key?(:sequence_id)
        end
      end
      
      # An instance of a "relation" rule. Each "relation" rule defines a number of
      # clusters, one for each entity B that that has incoming links of a certain type
      # R; all entities with an outgoing link to B of type R are part of that cluster.
      class RepositoryWebrefClusterProtoRelationRuleInstance
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `role`
        # @return [String]
        attr_accessor :role
      
        # A rule that defines a Cluster based on a relation. Given a relation (a link
        # type) R, then: For each entity B that has incoming links of type R This
        # defines an instance of this rule, with argument=B We create a Set S We make B
        # a child of S For each entity A that has a link R to B, we make A a child of S
        # Corresponds to the JSON property `rule`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterProtoRelationRule]
        attr_accessor :rule
      
        # The identifier of a WebrefEntity (see webref-entities.proto). IMPORTANT:
        # Please consider reading this proto through GetWebrefEntityMid() in webref-
        # entities-util.h, because this proto may: a) contain both freebase_mid and
        # concept_id (this is frequently the case to avoid breaking downstream clients),
        # b) only contain freebase_mid or only contain concept_id (as the other one is
        # technically redundant), c) contain neither of them or be missing entirely (
        # potentially in future).
        # Corresponds to the JSON property `target`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityId]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @role = args[:role] if args.key?(:role)
          @rule = args[:rule] if args.key?(:rule)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # When we apply a rule to define a particular cluster, we have a RuleInstance.
      # Some kinds of rules for clusters define more than one cluster. In those rules
      # we say things like "for each entity X with this property, we create a cluster
      # where..."; each particular cluster that we create is the result of an *
      # instance* of that rule, where the argument X has been bound to a particular
      # entity (note that this also applies to rules that define only one cluster; in
      # that case, there are no arguments). An entity that is part of a cluster plays
      # a "role" in such a cluster. This message describes such an instantiation of a
      # rule with a role and with concrete values for the arguments.
      class RepositoryWebrefClusterProtoRuleInstance
        include Google::Apis::Core::Hashable
      
        # An instance of a "mid list" rule. Each "mid list" rule defines exactly one
        # cluster.
        # Corresponds to the JSON property `midList`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterProtoMidListRuleInstance]
        attr_accessor :mid_list
      
        # 
        # Corresponds to the JSON property `relation`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterProtoRelationRuleInstance>]
        attr_accessor :relation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid_list = args[:mid_list] if args.key?(:mid_list)
          @relation = args[:relation] if args.key?(:relation)
        end
      end
      
      # Flattened version of possibly nested compound values. This means that the `
      # value` in here is *never* a `compound_value` and all predicate MIDs on the
      # nested path are collapsed into the repeated `predicate_encoded_mid` field.
      # When `predicate_encoded_mid` contains only one predicate, this is equivalent
      # to a CompactKgPropertyValue.
      class RepositoryWebrefCompactFlatPropertyValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `predicateEncodedMid`
        # @return [Array<Fixnum>]
        attr_accessor :predicate_encoded_mid
      
        # The property corresponding to predicte_encoded_mid above. This is populated in
        # some non-serving tables.
        # Corresponds to the JSON property `propertyName`
        # @return [String]
        attr_accessor :property_name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefCompactKgValue>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @predicate_encoded_mid = args[:predicate_encoded_mid] if args.key?(:predicate_encoded_mid)
          @property_name = args[:property_name] if args.key?(:property_name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Analog to freebase::PropertyValue
      class RepositoryWebrefCompactKgPropertyValue
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `encodedMid`
        # @return [Fixnum]
        attr_accessor :encoded_mid
      
        # 
        # Corresponds to the JSON property `hrid`
        # @return [String]
        attr_accessor :hrid
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefCompactKgValue>]
        attr_accessor :value
      
        # 
        # Corresponds to the JSON property `valueStatus`
        # @return [String]
        attr_accessor :value_status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encoded_mid = args[:encoded_mid] if args.key?(:encoded_mid)
          @hrid = args[:hrid] if args.key?(:hrid)
          @value = args[:value] if args.key?(:value)
          @value_status = args[:value_status] if args.key?(:value_status)
        end
      end
      
      # Analog to freebase::Topic
      class RepositoryWebrefCompactKgTopic
        include Google::Apis::Core::Hashable
      
        # Mid of the topic; only filled in if no values.
        # Corresponds to the JSON property `mid`
        # @return [Fixnum]
        attr_accessor :mid
      
        # 
        # Corresponds to the JSON property `propertyValue`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefCompactKgPropertyValue>]
        attr_accessor :property_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @property_value = args[:property_value] if args.key?(:property_value)
        end
      end
      
      # Analog to freebase::Value TODO(b/144526840) This representation has several
      # quality and performance issues. Next available tag number: 12
      class RepositoryWebrefCompactKgValue
        include Google::Apis::Core::Hashable
      
        # Present when value is bool.
        # Corresponds to the JSON property `boolValue`
        # @return [Boolean]
        attr_accessor :bool_value
        alias_method :bool_value?, :bool_value
      
        # Analog to freebase::Topic
        # Corresponds to the JSON property `compoundValue`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefCompactKgTopic]
        attr_accessor :compound_value
      
        # Present when value is datetime.
        # Corresponds to the JSON property `datetimeValue`
        # @return [String]
        attr_accessor :datetime_value
      
        # Present when value is enum.
        # Corresponds to the JSON property `enumValue`
        # @return [String]
        attr_accessor :enum_value
      
        # Present when value is float.
        # Corresponds to the JSON property `floatValue`
        # @return [Float]
        attr_accessor :float_value
      
        # Present when value is an id.
        # Corresponds to the JSON property `idValue`
        # @return [Fixnum]
        attr_accessor :id_value
      
        # Present when value is int.
        # Corresponds to the JSON property `intValue`
        # @return [Fixnum]
        attr_accessor :int_value
      
        # Present when value is a serialized protocol buffer.
        # Corresponds to the JSON property `serializedProtoValue`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :serialized_proto_value
      
        # Present when value is text.
        # Corresponds to the JSON property `textValue`
        # @return [String]
        attr_accessor :text_value
      
        # Present when value is URI.
        # Corresponds to the JSON property `uriValue`
        # @return [String]
        attr_accessor :uri_value
      
        # 32-bit fprint of uri. Can be used instead of `uri_value` to save space. See `
        # GetNormalizedUriFprint32()`.
        # Corresponds to the JSON property `uriValueFprint32`
        # @return [Fixnum]
        attr_accessor :uri_value_fprint32
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bool_value = args[:bool_value] if args.key?(:bool_value)
          @compound_value = args[:compound_value] if args.key?(:compound_value)
          @datetime_value = args[:datetime_value] if args.key?(:datetime_value)
          @enum_value = args[:enum_value] if args.key?(:enum_value)
          @float_value = args[:float_value] if args.key?(:float_value)
          @id_value = args[:id_value] if args.key?(:id_value)
          @int_value = args[:int_value] if args.key?(:int_value)
          @serialized_proto_value = args[:serialized_proto_value] if args.key?(:serialized_proto_value)
          @text_value = args[:text_value] if args.key?(:text_value)
          @uri_value = args[:uri_value] if args.key?(:uri_value)
          @uri_value_fprint32 = args[:uri_value_fprint32] if args.key?(:uri_value_fprint32)
        end
      end
      
      # The ArgumentValue reference to Mention.CompoundMention.Component. Next
      # available tag number: 4
      class RepositoryWebrefComponentReference
        include Google::Apis::Core::Hashable
      
        # Optionally the freebase_mid of the WebrefEntity which the Component identifies
        # via entity_index. This is purely to help humans diagnose the WebrefEntities
        # structure, may not always be present and should not be used by production code.
        # Use QueryJoinToMeaningStructConverter to compose a proper value in place of
        # the component reference.
        # Corresponds to the JSON property `debugEntity`
        # @return [String]
        attr_accessor :debug_entity
      
        # The WebrefEntity referenced by `index` is equivalent to this function call in
        # this context, but not universally such that we don't want to recursively
        # expand its MRF. Use this for example if an entity corresponds to a category in
        # an Intersect: CellPhones() & RelatedTo(/m/foo), where /m/cell_phones is
        # equivalent to CellPhones() (and may or may not have an annotated span), but we
        # don't want to generally assert that /m/cell_phones == CellPhones(). This
        # cannot be an actual FunctionCall to avoid a circular dependency.
        # Corresponds to the JSON property `funcallName`
        # @return [String]
        attr_accessor :funcall_name
      
        # The index of the Component of the CompoundMention which has the mrf_index of
        # this MRF expression in WebrefEntity. Required.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_entity = args[:debug_entity] if args.key?(:debug_entity)
          @funcall_name = args[:funcall_name] if args.key?(:funcall_name)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # Metadata proto to be stored in concept tables. Note: Name table only stores
      # name_type_mask for better performance. Remember to change NameToConceptEntry
      # if you add a field to this proto.
      class RepositoryWebrefConceptNameMetadata
        include Google::Apis::Core::Hashable
      
        # Bitfield of ConceptNameMetadata::NameType bits.
        # Corresponds to the JSON property `nameTypeMask`
        # @return [Fixnum]
        attr_accessor :name_type_mask
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name_type_mask = args[:name_type_mask] if args.key?(:name_type_mask)
        end
      end
      
      # Detailed scores about the topicality of an entity. Next available tag: 16
      class RepositoryWebrefDetailedEntityScores
        include Google::Apis::Core::Hashable
      
        # Additional info regarding how the score of an annotation was obtained. These
        # will no longer be set once the feature `topic2_detailed_scores` is enabled (Q4
        # 2017).
        # Corresponds to the JSON property `anchorScore`
        # @return [Float]
        attr_accessor :anchor_score
      
        # 
        # Corresponds to the JSON property `bodyScore`
        # @return [Float]
        attr_accessor :body_score
      
        # Represents how much the entity is connected/related to the other entities in
        # the document. This signal partially influences the topicality score, but it is
        # not totally aligned with it: an entity can be very related to the rest of the
        # document, but not central for understanding it. Likewise, an entity can be
        # central to understand a document, but not very related to the rest of the
        # document. The value is in [0, 1].
        # Corresponds to the JSON property `connectedness`
        # @return [Float]
        attr_accessor :connectedness
      
        # How well the document scores for the entity. The score is unnormalized, and
        # serves as a relative ranking signal between different documents for an entity.
        # Corresponds to the JSON property `docScore`
        # @return [Float]
        attr_accessor :doc_score
      
        # If the annotation corresponds to a geo topic, this is populated with GeoTopic::
        # normalized_score.
        # Corresponds to the JSON property `geoTopicNormalizedScore`
        # @return [Float]
        attr_accessor :geo_topic_normalized_score
      
        # True if the entity is the author of the document. This was mainly developed
        # and tuned for news articles (e.g. /m/02x27qn on "www.vogue.com/article/flint-
        # town-netflix") but is also popluated for other content (e.g. scientific
        # articles). Important: the semantics of this field may change in the future or
        # it might be removed and replaced with a different API. If you want to use this
        # field, please reach out to ke-authors@ first.
        # Corresponds to the JSON property `isAuthor`
        # @return [Boolean]
        attr_accessor :is_author
        alias_method :is_author?, :is_author
      
        # True if the entity is the publisher of the page (e.g. CNN on "http://www.cnn.
        # com/foo/bar").
        # Corresponds to the JSON property `isPublisher`
        # @return [Boolean]
        attr_accessor :is_publisher
        alias_method :is_publisher?, :is_publisher
      
        # Set to true iff the entity matches the full URL of the document, meaning that
        # it is a reference page or related page of the entity.
        # Corresponds to the JSON property `isReferencePage`
        # @return [Boolean]
        attr_accessor :is_reference_page
        alias_method :is_reference_page?, :is_reference_page
      
        # If the annotation corresponds to a local entity, this is populated with
        # LocalEntityAnnotations::Instance::location_confidence.
        # Corresponds to the JSON property `localEntityLocationConfidence`
        # @return [Float]
        attr_accessor :local_entity_location_confidence
      
        # 
        # Corresponds to the JSON property `nbScore`
        # @return [Float]
        attr_accessor :nb_score
      
        # Experimental. This is used for doing experiments only. For example, new entity
        # confidence can be populated here to experiment with replacing the one re-
        # computed by NewAnnotationConfidence().
        # Corresponds to the JSON property `newConfidenceExperimentalDontUse`
        # @return [Float]
        attr_accessor :new_confidence_experimental_dont_use
      
        # DEPRECATED: this field is no longer set. As of early June 2018 it is
        # referenced in hundreds of test files and is difficult to remove from the code
        # base.
        # Corresponds to the JSON property `newsTopicalityScore`
        # @return [Float]
        attr_accessor :news_topicality_score
      
        # Representation of the topicality score that is normalized in [0, 1] and which
        # sum over all entities in the document is 1. It represents the "proportion" of
        # the document that talks about the entity. This score is less human
        # interpretable as the bucketized topicality score (EntityAnnotations.
        # topicality_score), but is more suited for some usages like aggregations.
        # Corresponds to the JSON property `normalizedTopicality`
        # @return [Float]
        attr_accessor :normalized_topicality
      
        # Signals used for mining new reference pages, set by the reference-page-scorer
        # processor.
        # Corresponds to the JSON property `referencePageScores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefReferencePageScores]
        attr_accessor :reference_page_scores
      
        # Relevance score generated by a Machine Learning entity classifier. This signal
        # is similar to topicality, but machine learning based and supported by
        # EntitySignals, not Webref. See http://go/entityclassifier for details on the
        # classifier.
        # Corresponds to the JSON property `relevanceScore`
        # @return [Float]
        attr_accessor :relevance_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_score = args[:anchor_score] if args.key?(:anchor_score)
          @body_score = args[:body_score] if args.key?(:body_score)
          @connectedness = args[:connectedness] if args.key?(:connectedness)
          @doc_score = args[:doc_score] if args.key?(:doc_score)
          @geo_topic_normalized_score = args[:geo_topic_normalized_score] if args.key?(:geo_topic_normalized_score)
          @is_author = args[:is_author] if args.key?(:is_author)
          @is_publisher = args[:is_publisher] if args.key?(:is_publisher)
          @is_reference_page = args[:is_reference_page] if args.key?(:is_reference_page)
          @local_entity_location_confidence = args[:local_entity_location_confidence] if args.key?(:local_entity_location_confidence)
          @nb_score = args[:nb_score] if args.key?(:nb_score)
          @new_confidence_experimental_dont_use = args[:new_confidence_experimental_dont_use] if args.key?(:new_confidence_experimental_dont_use)
          @news_topicality_score = args[:news_topicality_score] if args.key?(:news_topicality_score)
          @normalized_topicality = args[:normalized_topicality] if args.key?(:normalized_topicality)
          @reference_page_scores = args[:reference_page_scores] if args.key?(:reference_page_scores)
          @relevance_score = args[:relevance_score] if args.key?(:relevance_score)
        end
      end
      
      # 
      class RepositoryWebrefDetailedMentionScores
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `patternInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPatternInfo>]
        attr_accessor :pattern_info
      
        # How much confidence that a entity is annotated on a given name. NOTE: it's
        # slightly different with normal annotation confidence.
        # Corresponds to the JSON property `posteriorForLearning`
        # @return [Float]
        attr_accessor :posterior_for_learning
      
        # How much support this mention received from the results for PostRef. This is
        # populated only if explicitly requested and different from 0.
        # Corresponds to the JSON property `resultEntityScore`
        # @return [Float]
        attr_accessor :result_entity_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pattern_info = args[:pattern_info] if args.key?(:pattern_info)
          @posterior_for_learning = args[:posterior_for_learning] if args.key?(:posterior_for_learning)
          @result_entity_score = args[:result_entity_score] if args.key?(:result_entity_score)
        end
      end
      
      # Information that can be used to display the entity (e.g. title, image...).
      class RepositoryWebrefDisplayInfo
        include Google::Apis::Core::Hashable
      
        # Per language display name from reliable sources.
        # Corresponds to the JSON property `displayName`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefDisplayName>]
        attr_accessor :display_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @display_name = args[:display_name] if args.key?(:display_name)
        end
      end
      
      # Per language display name from reliable sources (e.g. Freebase, Wikipedia).
      # The name can be ambiguous (e.g. "Springfield" rather than "Springfield, Idaho")
      # , and is thus to be used in a context which provides sufficient disambiguation.
      # See: http://go/entity-names WARNING: This data is DEPRECATED and any user-
      # visible entity names need to be fetched from TopicServer. Note that any
      # display names included in this proto are merely a pass-through from KG and
      # have no freshness guarantees.
      class RepositoryWebrefDisplayName
        include Google::Apis::Core::Hashable
      
        # An encylopedia style topic name (e.g. "Dog", not "Dogs"). Corresponds to
        # Freebase /type/object/name and similar sources.
        # Corresponds to the JSON property `canonicalName`
        # @return [String]
        attr_accessor :canonical_name
      
        # The language of this name. See http://goto/iii for all the details on the
        # language identifiers.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # A name as it would be used for a news topic, an interest, the subject of a
        # story. E.g. in list of things ("Related topics: Smartphones, computers,
        # accidents". "Interests: Dogs"). *Fall back:* If the field is not populated,
        # fall back to the "canonical_name" field. This field is usually not populated
        # since (a) in most cases the subject form name is the same as the canonical
        # name, and (b) data coverage of subject-form names is currently much lower than
        # data coverage of canonical names. Note: In some languages (e.g. French) the
        # difference between canonical names and subject names is larger than in English
        # (not just plural vs. singular), but still strictly grammatical (including an
        # article, capitalization, plural vs. singular). Corresponds to Freebase /
        # freebase/linguistic_hint/subject_form.
        # Corresponds to the JSON property `subjectName`
        # @return [String]
        attr_accessor :subject_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
          @language = args[:language] if args.key?(:language)
          @subject_name = args[:subject_name] if args.key?(:subject_name)
        end
      end
      
      # List of PerDocRelevanceRatings for Precision@5 evals done via ewok (template
      # 2282).
      class RepositoryWebrefDocLevelRelevanceRatings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `perDocRelevanceRatings`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPerDocRelevanceRatings>]
        attr_accessor :per_doc_relevance_ratings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @per_doc_relevance_ratings = args[:per_doc_relevance_ratings] if args.key?(:per_doc_relevance_ratings)
        end
      end
      
      # Information about the document which is not produced by webref, typically
      # copied from the docjoin. Next available tag: 15
      class RepositoryWebrefDocumentMetadata
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `cdocAttachments`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :cdoc_attachments
      
        # The timestamp of when the document was crawled (if known). Copied from
        # CompositeDoc.Content.CrawlTime.
        # Corresponds to the JSON property `crawlTime`
        # @return [Fixnum]
        attr_accessor :crawl_time
      
        # Fingerprint of the document. We compute and set this fingerprint when creating
        # the pagesets that we use for evals. Otherwise, this field is not normally set.
        # We use the field to make sure that the human ratings that we have are
        # generated for the same version of the document, otherwise they might be
        # invalid. We do not compute the fingerprint on the fly (e.g. as a fingerprint
        # of the proto buffer serialization of the cdoc) because protocol buffer
        # serialization is not stable.
        # Corresponds to the JSON property `docFp`
        # @return [Fixnum]
        attr_accessor :doc_fp
      
        # DocId of the annotated document as read from cdoc.doc().docid().
        # Corresponds to the JSON property `docId`
        # @return [Fixnum]
        attr_accessor :doc_id
      
        # Submessage for forwarding urls in DocumentMetadata.
        # Corresponds to the JSON property `forwardingUrls`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefForwardingUrls]
        attr_accessor :forwarding_urls
      
        # Set to true if the document is a known disambiguation page, e.g. https://en.
        # wikipedia.org/wiki/Orange.
        # Corresponds to the JSON property `isDisambiguationPage`
        # @return [Boolean]
        attr_accessor :is_disambiguation_page
        alias_method :is_disambiguation_page?, :is_disambiguation_page
      
        # The document language, as read from doc().content().language(). This is go/
        # language-enum value.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # The (weighted) number of incoming anchors (links from other documents).
        # Corresponds to the JSON property `numIncomingAnchors`
        # @return [Float]
        attr_accessor :num_incoming_anchors
      
        # Copies of selected repeated extensions from cdoc, controlled by: --
        # webref_doc_metadata_copy_images (copies the repeated doc_images field (TypeId
        # 8798074), defined in image/search/imagedoc.proto).
        # Corresponds to the JSON property `repeatedCdocAttachments`
        # @return [Array<Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet>]
        attr_accessor :repeated_cdoc_attachments
      
        # SalientTermSet is a collection of terms (unigrams and bigrams) with associated
        # weights that can describe something. The "salient terms".
        # Corresponds to the JSON property `salientTerms`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTermSet]
        attr_accessor :salient_terms
      
        # The title of the document. Only set if --webref_doc_metadata_set_title is true.
        # The idea is that we can use this to more easily learn things like: title
        # contains "restaurants" -> more likely to be a list page.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # The total clicks on this document, taken from navboost data.
        # Corresponds to the JSON property `totalClicks`
        # @return [Float]
        attr_accessor :total_clicks
      
        # The url of the document.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cdoc_attachments = args[:cdoc_attachments] if args.key?(:cdoc_attachments)
          @crawl_time = args[:crawl_time] if args.key?(:crawl_time)
          @doc_fp = args[:doc_fp] if args.key?(:doc_fp)
          @doc_id = args[:doc_id] if args.key?(:doc_id)
          @forwarding_urls = args[:forwarding_urls] if args.key?(:forwarding_urls)
          @is_disambiguation_page = args[:is_disambiguation_page] if args.key?(:is_disambiguation_page)
          @language = args[:language] if args.key?(:language)
          @num_incoming_anchors = args[:num_incoming_anchors] if args.key?(:num_incoming_anchors)
          @repeated_cdoc_attachments = args[:repeated_cdoc_attachments] if args.key?(:repeated_cdoc_attachments)
          @salient_terms = args[:salient_terms] if args.key?(:salient_terms)
          @title = args[:title] if args.key?(:title)
          @total_clicks = args[:total_clicks] if args.key?(:total_clicks)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Represents a domain specific entity data.
      class RepositoryWebrefDomainSpecificRepresentation
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `entityData`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :entity_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_data = args[:entity_data] if args.key?(:entity_data)
        end
      end
      
      # Top level proto for enricher specific debug data that is only displayed in the
      # Webref demo and should not be used for anything production-related. Next id: 4.
      class RepositoryWebrefEnricherDebugData
        include Google::Apis::Core::Hashable
      
        # Contains selected properties (from KG) whose values are not other entities (in
        # which case they would be represented in link_info) but scalar values, possibly
        # reachable through (multiple) CVTs.
        # Corresponds to the JSON property `nonMidProperties`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefCompactFlatPropertyValue>]
        attr_accessor :non_mid_properties
      
        # This field contains reference pages for this entity. A reference page is a
        # page that is highly topical for this entity, which can be used to mine
        # additional information about this entity. Example reference pages for Apple
        # Inc. would be the composite docs for "http://en.wikipedia.org/wiki/Apple_Inc."
        # and http://www.apple.com. For actors or movies, you can also have the imdb
        # page. Also see: http://go/refx-pages.
        # Corresponds to the JSON property `referencePage`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedCompositeDoc>]
        attr_accessor :reference_page
      
        # This field contains mined related pages for the entity. A related page is a
        # page that is moderately topical for this entity (More details: http://shortn/
        # _KCE0GfQlpJ). This is mainly used to mine additional information for entities
        # which do not have reference pages Unlike reference pages, a single doc can be
        # a related page for multiple mids.
        # Corresponds to the JSON property `relatedPage`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedCompositeDoc>]
        attr_accessor :related_page
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @non_mid_properties = args[:non_mid_properties] if args.key?(:non_mid_properties)
          @reference_page = args[:reference_page] if args.key?(:reference_page)
          @related_page = args[:related_page] if args.key?(:related_page)
        end
      end
      
      # All annotations for a given concept (in one document collection). Available
      # tags: [10-15], [19-]
      class RepositoryWebrefEntityAnnotations
        include Google::Apis::Core::Hashable
      
        # The overall confidence that the entity is annotated somewhere in the document
        # or query. For WebRef it is computed as a function of the mention confidences
        # weighted by the importance of each mention, where for documents a mention is
        # of greater importance if it occurs in the title, h1 or anchors. For QRef it is
        # just the maximum of the confidence over all mentions. NOTE: You probably want
        # to use the mention-level segment_mentions.mention.confidence_score field
        # instead of this one.
        # Corresponds to the JSON property `confidenceScore`
        # @return [Float]
        attr_accessor :confidence_score
      
        # Debug info about the concept annotations. Note that it might not be present in
        # the output.
        # Corresponds to the JSON property `debugInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotationDebugInfo]
        attr_accessor :debug_info
      
        # Detailed scores about the topicality of an entity. Next available tag: 16
        # Corresponds to the JSON property `detailedEntityScores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefDetailedEntityScores]
        attr_accessor :detailed_entity_scores
      
        # Information about all ranges explained by the entity or any other entity it
        # implies. For example, the Zurich entity may explain both tokens "Zurich" and "
        # Switzerland" in [FIFA Zurich Switzerland], the first directly, the other via
        # implication. Only used in the context of query annotation.
        # Corresponds to the JSON property `explainedRangeInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefExplainedRangeInfo]
        attr_accessor :explained_range_info
      
        # An entity is marked as implicit if there is no explicit mention of the entity
        # in the content of the page. For instance, all mentions of the entity are in
        # query, url and/or anchors; or the entity has only implicit content mentions.
        # Corresponds to the JSON property `isImplicit`
        # @return [Boolean]
        attr_accessor :is_implicit
        alias_method :is_implicit?, :is_implicit
      
        # True if the entity is an MDVC summary entity, i.e. it might not be mentioned
        # directly on the query, but it is the product of resolving a set of explicit
        # annotations. E.g. "2014 FIFA World Cup" can be the summary for the query: [
        # soccer world cup in brazil] even though none of the names of the entity is
        # mentioned on the query. Summary nodes can also be synthetic, i.e. have a /t/
        # mid, as they represent the intersection between a set of regular annotations.
        # For more information, see http://go/mdvc-output.
        # Corresponds to the JSON property `isResolution`
        # @return [Boolean]
        attr_accessor :is_resolution
        alias_method :is_resolution?, :is_resolution
      
        # All mentions of a given concept grouped by segments. For Webref, there are
        # many different kinds of segment, such as content, title and anchors; while for
        # QRef, there is only one segment called CONTENT. For QRef this field contains
        # the primary output of the annotator, and for WebRef it together with
        # topicality_score does.
        # Corresponds to the JSON property `segmentMentions`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMentions>]
        attr_accessor :segment_mentions
      
        # Rank of the entity when sorted by topicality score.
        # Corresponds to the JSON property `topicalityRank`
        # @return [Fixnum]
        attr_accessor :topicality_rank
      
        # The WebRef topicality score of the entity for this document. This score
        # indicates how related is the entity to the overall topic of the document. See
        # https://goto.google.com/topicality-score for details. This field is not
        # present in QRef output. Note that the topicality and the confidence score are
        # orthogonal measures. It is possible that the annotator is absolutely sure that
        # an entity is mentioned in a given range in the document, but this entity may
        # be unrelated to the overall topic of the page (e.g. the entity "RSS" is
        # mentioned in the footer of appleinsider.com). In this case the mention has a
        # very high confidence score, but very low topicality score.
        # Corresponds to the JSON property `topicalityScore`
        # @return [Float]
        attr_accessor :topicality_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @detailed_entity_scores = args[:detailed_entity_scores] if args.key?(:detailed_entity_scores)
          @explained_range_info = args[:explained_range_info] if args.key?(:explained_range_info)
          @is_implicit = args[:is_implicit] if args.key?(:is_implicit)
          @is_resolution = args[:is_resolution] if args.key?(:is_resolution)
          @segment_mentions = args[:segment_mentions] if args.key?(:segment_mentions)
          @topicality_rank = args[:topicality_rank] if args.key?(:topicality_rank)
          @topicality_score = args[:topicality_score] if args.key?(:topicality_score)
        end
      end
      
      # Provides some debug info for the entity. This data shown to engineers (for
      # debugging) and to raters (so it ultimately impacts eval metrics), but is also
      # used to train ML models (see below). IMPORTANT: Despite the proto naming, this
      # data has production quality impact. The data below is mostly human-readable
      # text that is useful to help engineers with debugging. However the text is also
      # used as input to machine-learned natural language processing models, which are
      # used in production Webref.
      class RepositoryWebrefEntityDebugInfo
        include Google::Apis::Core::Hashable
      
        # Internal flag to mark this data as restricted. This flag should never be set
        # in data in the final entityjoins, it is only used during the preprocessing
        # pipeline.
        # Corresponds to the JSON property `containsRestrictedData`
        # @return [Boolean]
        attr_accessor :contains_restricted_data
        alias_method :contains_restricted_data?, :contains_restricted_data
      
        # A human-readable description of the entity. This can range from brief, machine-
        # generated notes to lengthy human-written paragraphs from Wikipedia.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The language (III LanguageCode) of the `title` and `description` fields.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Internal score to merge debug info. should not set in final entityjoins.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # A short human-readable name/title of the entity, similar to what is displayed
        # at the top of a Hume page. Suitable to be displayed in a list.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Link to a page with more information about the entity (internal Hume page,
        # external Wikipedia page, etc.).
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contains_restricted_data = args[:contains_restricted_data] if args.key?(:contains_restricted_data)
          @description = args[:description] if args.key?(:description)
          @language = args[:language] if args.key?(:language)
          @score = args[:score] if args.key?(:score)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Next available tag: 35. Represents all the information that we have for a
      # given entity.
      class RepositoryWebrefEntityJoin
        include Google::Apis::Core::Hashable
      
        # The identifier of a WebrefEntity (see webref-entities.proto). IMPORTANT:
        # Please consider reading this proto through GetWebrefEntityMid() in webref-
        # entities-util.h, because this proto may: a) contain both freebase_mid and
        # concept_id (this is frequently the case to avoid breaking downstream clients),
        # b) only contain freebase_mid or only contain concept_id (as the other one is
        # technically redundant), c) contain neither of them or be missing entirely (
        # potentially in future).
        # Corresponds to the JSON property `annotatedEntityId`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityId]
        attr_accessor :annotated_entity_id
      
        # This field contains reference pages for this entity. A reference page is a
        # page that is highly topical for this entity, which can be used to mine
        # additional information about this entity. Example reference pages for Apple
        # Inc. would be the composite docs for "http://en.wikipedia.org/wiki/Apple_Inc."
        # and http://www.apple.com. For actors or movies, you can also have the imdb
        # page. Also see: http://go/refx-pages.
        # Corresponds to the JSON property `cdoc`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedCompositeDoc>]
        attr_accessor :cdoc
      
        # The context names (with scores) of this entity. The difference to regular
        # names (aka name_info) is that context names are not used for finding mentions
        # in a document as they consist of names somehow related to the entity (e.g.
        # name "fisherman s wharf" for the entity "Gary Danko"). Used for reconciling
        # freebase and oyster.
        # Corresponds to the JSON property `contextNameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefGlobalNameInfo>]
        attr_accessor :context_name_info
      
        # Debug information about the entity.
        # Corresponds to the JSON property `debugInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityDebugInfo>]
        attr_accessor :debug_info
      
        # A message to collect annotator performance data.
        # Corresponds to the JSON property `enricherAnnotatorProfile`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotatorProfile]
        attr_accessor :enricher_annotator_profile
      
        # Top level proto for enricher specific debug data that is only displayed in the
        # Webref demo and should not be used for anything production-related. Next id: 4.
        # Corresponds to the JSON property `enricherDebugData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEnricherDebugData]
        attr_accessor :enricher_debug_data
      
        # Additional metadata about the entity, that can be derived from the "raw data" (
        # composite doc, domain specific data...), or come from other sources. Next
        # available tag is 35.
        # Corresponds to the JSON property `extraData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefExtraMetadata]
        attr_accessor :extra_data
      
        # Human ratings (e.g. ratings from EWOK). This is typically only populated in
        # the evaluation pipelines (e.g. P@5).
        # Corresponds to the JSON property `humanRatings`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefHumanRatings]
        attr_accessor :human_ratings
      
        # Contains all links (with scores) that Webref knows for this entity. Links are
        # relationships between entities. The data in this field is very important for
        # the quality of the model.
        # Corresponds to the JSON property `linkInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefGlobalLinkInfo>]
        attr_accessor :link_info
      
        # Contains all names (with scores) that Webref knows for this entity. The data
        # in this field is very important for the quality of the model.
        # Corresponds to the JSON property `nameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefGlobalNameInfo>]
        attr_accessor :name_info
      
        # If you add any field, make sure to add it in reffresh to the empty checks at
        # the end of the corresponding name extractor processors (extract-*-names.cc).
        # Corresponds to the JSON property `nameSignals`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameSignals]
        attr_accessor :name_signals
      
        # Represents a unique id for each entity. It contains the domain, entity type
        # and a legacy_id that is unique within that space. This protocol buffer stems
        # from a time when we were building our model based on entities from different
        # sources. Nowadays the domain_name and entity_type_name can be ignored and the
        # legacy_id is the Knowledge Graph mid except in some WebRef internal pipelines
        # such as reconciliation where it is still a vertical specific id. Current
        # usages (see GetKey and SetKey in entity-join-util.cc): domain_name = "
        # FreebaseDomain", entity_type_name = "Topic" domain_name = "GeoDomain",
        # entity_type_name = "Geo" domain_name = "ProductsDomain", entity_type_name = "
        # Product" domain_name = "ProductsDomain", entity_type_name = "ProductCluster"
        # domain_name = "UniversalDomain", entity_type_name = "Concept"
        # Corresponds to the JSON property `preprocessingId`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAbsoluteLegacyId]
        attr_accessor :preprocessing_id
      
        # Contains names and names metadata used by Refcon.
        # Corresponds to the JSON property `refconNameInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefRefconRefconNameInfo>]
        attr_accessor :refcon_name_info
      
        # An entity can have metadata from various data sources. Generally speaking all
        # sources will be / should be reconciled into a single KG Topic entry. However,
        # in some cases we pull in additional chunks of metadata from these sources;
        # these are stored in this field. For example a local business could have a KG
        # entry (topic proto), wikipedia entry (WikiJoin) and a MapFacts entry (Feature
        # proto).
        # Corresponds to the JSON property `representation`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefDomainSpecificRepresentation>]
        attr_accessor :representation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotated_entity_id = args[:annotated_entity_id] if args.key?(:annotated_entity_id)
          @cdoc = args[:cdoc] if args.key?(:cdoc)
          @context_name_info = args[:context_name_info] if args.key?(:context_name_info)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @enricher_annotator_profile = args[:enricher_annotator_profile] if args.key?(:enricher_annotator_profile)
          @enricher_debug_data = args[:enricher_debug_data] if args.key?(:enricher_debug_data)
          @extra_data = args[:extra_data] if args.key?(:extra_data)
          @human_ratings = args[:human_ratings] if args.key?(:human_ratings)
          @link_info = args[:link_info] if args.key?(:link_info)
          @name_info = args[:name_info] if args.key?(:name_info)
          @name_signals = args[:name_signals] if args.key?(:name_signals)
          @preprocessing_id = args[:preprocessing_id] if args.key?(:preprocessing_id)
          @refcon_name_info = args[:refcon_name_info] if args.key?(:refcon_name_info)
          @representation = args[:representation] if args.key?(:representation)
        end
      end
      
      # Metadata about the nature of the link.
      class RepositoryWebrefEntityLinkMetadata
        include Google::Apis::Core::Hashable
      
        # A bitmap of bool values associated with a link kind. Next available tag: 12
        # Corresponds to the JSON property `aggregateFlags`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLinkKindFlags]
        attr_accessor :aggregate_flags
      
        # Information about all the link kinds associated with the link.
        # Corresponds to the JSON property `kindInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLinkKindInfo>]
        attr_accessor :kind_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregate_flags = args[:aggregate_flags] if args.key?(:aggregate_flags)
          @kind_info = args[:kind_info] if args.key?(:kind_info)
        end
      end
      
      # All link data for a given source.
      class RepositoryWebrefEntityLinkSource
        include Google::Apis::Core::Hashable
      
        # KG-property if the SourceType is associated with a KG-property (TOPIC_PROPERTY,
        # NEW_TOPIC_PROPERTY).
        # Corresponds to the JSON property `kgProperty`
        # @return [String]
        attr_accessor :kg_property
      
        # Score in [0, \infty) that represents how relatively likely it is to see that
        # entity cooccurring with the main entity (in the entity join). A value of 1.0
        # means that the two entities are basically independent. The higher the more
        # likely (relatively to the individual entity probabilities) they are to cooccur.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @kg_property = args[:kg_property] if args.key?(:kg_property)
          @score = args[:score] if args.key?(:score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Stores all human ratings collected for a given entity name.
      class RepositoryWebrefEntityNameRatings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Every entity name receives one or a few ratings from human raters.
        # Corresponds to the JSON property `ratings`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityNameRatingsEntityNameRating>]
        attr_accessor :ratings
      
        # Multiple tags can be assigned to a rated entity name. The tags can be used
        # when computing metrics in the Name Eval, so that different metrics are
        # computed separately for different sets of examples that have the same tag.
        # Corresponds to the JSON property `tags`
        # @return [Array<String>]
        attr_accessor :tags
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @name = args[:name] if args.key?(:name)
          @ratings = args[:ratings] if args.key?(:ratings)
          @tags = args[:tags] if args.key?(:tags)
        end
      end
      
      # 
      class RepositoryWebrefEntityNameRatingsEntityNameRating
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Represents a score for an entity. Next available tag: 39.
      class RepositoryWebrefEntityNameScore
        include Google::Apis::Core::Hashable
      
        # If the EntityNameScore is part of a bootstrapped model, then this field
        # contains the score_ratio from the previous model ("Model 0"). If Model 0 does
        # not have a corresponding entry, because it did not know about this name for
        # this entity, then bootstrapping_previous_iteration is left empty.
        # Corresponds to the JSON property `bootstrappingPreviousIteration`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefBootstrappingScore]
        attr_accessor :bootstrapping_previous_iteration
      
        # Confidence that this name is a trusted name of the entity. A reasonable
        # threshold for name trust is 0.6. A name can be trusted and still have very low
        # score_ratio, esp. if it is ambiguous (e.g. 'mercury') and/or not the dominant
        # interpretation (e.g. "siberian husky" -> /m/06krnsr (a book)).
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Debug information about the entity.
        # Corresponds to the JSON property `debugInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityDebugInfo>]
        attr_accessor :debug_info
      
        # Source and score data, this is internal to refx (e.g. for demo/debug).
        # Corresponds to the JSON property `debugVariantSignals`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameVariantSignals>]
        attr_accessor :debug_variant_signals
      
        # Next available tag: 35. Represents all the information that we have for a
        # given entity.
        # Corresponds to the JSON property `entity`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityJoin]
        attr_accessor :entity
      
        # Stores region specific score ratios for the entity when it is significantly
        # different from the language version above.
        # Corresponds to the JSON property `extendedScoreRatio`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefExtendedEntityNameScore>]
        attr_accessor :extended_score_ratio
      
        # Include this name in the name lookup table.
        # Corresponds to the JSON property `includeInModel`
        # @return [Boolean]
        attr_accessor :include_in_model
        alias_method :include_in_model?, :include_in_model
      
        # Transient field, only used in bootstrap pipeline.
        # Corresponds to the JSON property `internalBootstrapIsOpenWorld`
        # @return [Boolean]
        attr_accessor :internal_bootstrap_is_open_world
        alias_method :internal_bootstrap_is_open_world?, :internal_bootstrap_is_open_world
      
        # 
        # Corresponds to the JSON property `internalIsClusterParent`
        # @return [Boolean]
        attr_accessor :internal_is_cluster_parent
        alias_method :internal_is_cluster_parent?, :internal_is_cluster_parent
      
        # Set to true iff the concept is cluster parent and the name can be a name for
        # any child of the cluster. (e.g. 'starbucks' is cluster_global for the [
        # Starbucks] chain cluster).
        # Corresponds to the JSON property `isClusterGlobal`
        # @return [Boolean]
        attr_accessor :is_cluster_global
        alias_method :is_cluster_global?, :is_cluster_global
      
        # Documened at: repository/webref/universal/webref_data/enricher/entity-data.h
        # Corresponds to the JSON property `isDropped`
        # @return [Boolean]
        attr_accessor :is_dropped
        alias_method :is_dropped?, :is_dropped
      
        # Only for context names: Whether this EntityNameScore represents an entity that
        # was dominant in the search results but was not annotated by QRef during
        # learning. Matchless result contexts are useful for bootstrapping, where
        # different model iterations may have different names and thus context scores
        # from Model 0 that are inconsistent with the names from Model 1.
        # Corresponds to the JSON property `isMatchlessResultContext`
        # @return [Boolean]
        attr_accessor :is_matchless_result_context
        alias_method :is_matchless_result_context?, :is_matchless_result_context
      
        # Documened at: repository/webref/universal/webref_data/enricher/entity-data.h
        # Corresponds to the JSON property `isPruned`
        # @return [Boolean]
        attr_accessor :is_pruned
        alias_method :is_pruned?, :is_pruned
      
        # The id of the entity.
        # Corresponds to the JSON property `mid`
        # @return [Fixnum]
        attr_accessor :mid
      
        # Metadata about a name. There are two metadata protos, whose content is meant
        # to be similar but their usage different: NameEntityMetadata for readability
        # and ConceptNameMetadata for size / decoding speed. NameEntityMetadata is
        # propagated to GlobalNameInfo and EntityJoin tables, while ConceptNameMetadata
        # is propagated from EntityJoins to the name matching tables and later to the
        # Webref's/QRef's output. To add a new metadata field in the Names pipeline, and
        # propagate it to EntityJoins and Names matching tables, it is necessary to: (1)
        # Add the field to NameEntityMetadata, and a corresponding data representation
        # in ConceptNameMetadata. (2) Populate the field in NameVariantSignals.
        # name_metadata, from any source. This can be done in a corresponding
        # NameProcessor. (3) Update the library name-metadata.h/cc to make sure that the
        # metadata field is: a) merged correctly when merging two NameSignals; and b)
        # transformed to the corresponding field in ConceptNameMetadata proto. Next
        # available tag: 22.
        # Corresponds to the JSON property `nameMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameEntityMetadata]
        attr_accessor :name_metadata
      
        # Metadata of segment range, which is annotated by this entity.
        # Corresponds to the JSON property `rangeMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefRangeMetadata>]
        attr_accessor :range_metadata
      
        # The absolute score of that entity. score = artificial_score +
        # volume_based_score
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Ratio between this entity score and the total score over all entities. This is
        # including the "open world" information if it was estimated.
        # Corresponds to the JSON property `scoreRatio`
        # @return [Float]
        attr_accessor :score_ratio
      
        # When this field is true, we consider this context name as candidate in
        # Enricher's names pipeline.
        # Corresponds to the JSON property `useAsNameCandidate`
        # @return [Boolean]
        attr_accessor :use_as_name_candidate
        alias_method :use_as_name_candidate?, :use_as_name_candidate
      
        # Absolute score that comes from quantitative sources such as navboost clicks,
        # anchors, etc. artificial_score = score - volume_based_score
        # Corresponds to the JSON property `volumeBasedScore`
        # @return [Float]
        attr_accessor :volume_based_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bootstrapping_previous_iteration = args[:bootstrapping_previous_iteration] if args.key?(:bootstrapping_previous_iteration)
          @confidence = args[:confidence] if args.key?(:confidence)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @debug_variant_signals = args[:debug_variant_signals] if args.key?(:debug_variant_signals)
          @entity = args[:entity] if args.key?(:entity)
          @extended_score_ratio = args[:extended_score_ratio] if args.key?(:extended_score_ratio)
          @include_in_model = args[:include_in_model] if args.key?(:include_in_model)
          @internal_bootstrap_is_open_world = args[:internal_bootstrap_is_open_world] if args.key?(:internal_bootstrap_is_open_world)
          @internal_is_cluster_parent = args[:internal_is_cluster_parent] if args.key?(:internal_is_cluster_parent)
          @is_cluster_global = args[:is_cluster_global] if args.key?(:is_cluster_global)
          @is_dropped = args[:is_dropped] if args.key?(:is_dropped)
          @is_matchless_result_context = args[:is_matchless_result_context] if args.key?(:is_matchless_result_context)
          @is_pruned = args[:is_pruned] if args.key?(:is_pruned)
          @mid = args[:mid] if args.key?(:mid)
          @name_metadata = args[:name_metadata] if args.key?(:name_metadata)
          @range_metadata = args[:range_metadata] if args.key?(:range_metadata)
          @score = args[:score] if args.key?(:score)
          @score_ratio = args[:score_ratio] if args.key?(:score_ratio)
          @use_as_name_candidate = args[:use_as_name_candidate] if args.key?(:use_as_name_candidate)
          @volume_based_score = args[:volume_based_score] if args.key?(:volume_based_score)
        end
      end
      
      # Represents the data for a given source of names, including all entity scores.
      # Notice that a source of name can be just a signal like a multiplier. Next
      # available tag: 8.
      class RepositoryWebrefEntityNameSource
        include Google::Apis::Core::Hashable
      
        # All the entity-name scores from that source. Keyed by the EntityNameScore.
        # entity_id field.
        # Corresponds to the JSON property `entityScore`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityNameScore>]
        attr_accessor :entity_score
      
        # Describes where the data comes from.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_score = args[:entity_score] if args.key?(:entity_score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Keeps a set of scores about an entity. Next available tag: 20.
      class RepositoryWebrefEntityScores
        include Google::Apis::Core::Hashable
      
        # Probability that any given name of this entity is fully capitalized.
        # Corresponds to the JSON property `allCapsProb`
        # @return [Float]
        attr_accessor :all_caps_prob
      
        # This field is only for debugging and link weight experiments. It stores the
        # entity's idf from the alpha model. Alpha idfs are used for link weight
        # computations and available during model omega building via
        # enricher_current_entity_idf_for_link_direction.
        # Corresponds to the JSON property `alphaEntityIdf`
        # @return [Float]
        attr_accessor :alpha_entity_idf
      
        # Probability that the entity is a common ngram (e.g. from dictionary).
        # Corresponds to the JSON property `commonNgramProb`
        # @return [Float]
        attr_accessor :common_ngram_prob
      
        # The final (model omega) idf of an entity. Equals log2(1 / probability of the
        # entity to appear in a document). This probability is currently estimated from
        # its names (i.e. it is a sum of the name frequency weighted by P(entity | name))
        # .
        # Corresponds to the JSON property `entityIdf`
        # @return [Float]
        attr_accessor :entity_idf
      
        # Probability that any given name of this entity is capitalized.
        # Corresponds to the JSON property `nameCapitalizationProb`
        # @return [Float]
        attr_accessor :name_capitalization_prob
      
        # The following fields are deprecated and should eventually be removed. They use
        # data and rules that have not been refreshed for ~10y and KG has changed a lot
        # in the meantime.
        # Corresponds to the JSON property `personProb`
        # @return [Float]
        attr_accessor :person_prob
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_caps_prob = args[:all_caps_prob] if args.key?(:all_caps_prob)
          @alpha_entity_idf = args[:alpha_entity_idf] if args.key?(:alpha_entity_idf)
          @common_ngram_prob = args[:common_ngram_prob] if args.key?(:common_ngram_prob)
          @entity_idf = args[:entity_idf] if args.key?(:entity_idf)
          @name_capitalization_prob = args[:name_capitalization_prob] if args.key?(:name_capitalization_prob)
          @person_prob = args[:person_prob] if args.key?(:person_prob)
        end
      end
      
      # Information about all ranges explained by the entity or any other entity it
      # implies. For example, the Zurich entity may explain both tokens "Zurich" and "
      # Switzerland" in [FIFA Zurich Switzerland], the first directly, the other via
      # implication. Only used in the context of query annotation.
      class RepositoryWebrefExplainedRangeInfo
        include Google::Apis::Core::Hashable
      
        # All ranges explained by the entity.
        # Corresponds to the JSON property `explainedRange`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefExplainedRangeInfoExplainedRange>]
        attr_accessor :explained_range
      
        # 
        # Corresponds to the JSON property `geoQueryCoverage`
        # @return [String]
        attr_accessor :geo_query_coverage
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @explained_range = args[:explained_range] if args.key?(:explained_range)
          @geo_query_coverage = args[:geo_query_coverage] if args.key?(:geo_query_coverage)
        end
      end
      
      # A range of the annotated document explained by an entity.
      class RepositoryWebrefExplainedRangeInfoExplainedRange
        include Google::Apis::Core::Hashable
      
        # A single Mention within a segment as defined by SegmentMentions.SegmentType
        # Corresponds to the JSON property `mention`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMention]
        attr_accessor :mention
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mention = args[:mention] if args.key?(:mention)
        end
      end
      
      # Used to store region-specific score ratio per entity. Next available tag: 4.
      class RepositoryWebrefExtendedEntityNameScore
        include Google::Apis::Core::Hashable
      
        # The domain name of the website, e.g. "play.google.com".
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # The region in the III standard (http://go/iii). Eg. "US", "GB"
        # Corresponds to the JSON property `region`
        # @return [String]
        attr_accessor :region
      
        # Score ratio for the entity, same as the EntityNameScore score ratio.
        # Corresponds to the JSON property `scoreRatio`
        # @return [Float]
        attr_accessor :score_ratio
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
          @region = args[:region] if args.key?(:region)
          @score_ratio = args[:score_ratio] if args.key?(:score_ratio)
        end
      end
      
      # Additional metadata about the entity, that can be derived from the "raw data" (
      # composite doc, domain specific data...), or come from other sources. Next
      # available tag is 35.
      class RepositoryWebrefExtraMetadata
        include Google::Apis::Core::Hashable
      
        # For a book entity, store its book editions metadata. Used by Juggernaut to do /
        # book/book_edition recon, see ariane/265006. This field is used by Juggernaut
        # only.
        # Corresponds to the JSON property `bookEditionMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefBookEditionMetadata>]
        attr_accessor :book_edition_metadata
      
        # All informations about category types of the entity.
        # Corresponds to the JSON property `categoryInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefCategoryInfo]
        attr_accessor :category_info
      
        # Metadata about clusters. See go/webref-variants for details. Next available
        # tag: 6.
        # Corresponds to the JSON property `clusterMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefClusterMetadata]
        attr_accessor :cluster_metadata
      
        # Information that can be used to display the entity (e.g. title, image...).
        # Corresponds to the JSON property `displayInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefDisplayInfo]
        attr_accessor :display_info
      
        # Keeps a set of scores about an entity. Next available tag: 20.
        # Corresponds to the JSON property `entityScores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityScores]
        attr_accessor :entity_scores
      
        # An entity in KG that represents the same (or equivalent) entity in the real
        # world. In particular, this is used for mid-forwarding: when de-duping entities
        # in KG, the old ids represent the exact same entity as the one they were merged
        # with. So when we see one id in the query and the other in a document, they are
        # treated as the same entity.
        # Corresponds to the JSON property `equivalentEntityId`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityId>]
        attr_accessor :equivalent_entity_id
      
        # Geo-specific information about the entity. Next available tag: 34.
        # Corresponds to the JSON property `geoMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefGeoMetadataProto]
        attr_accessor :geo_metadata
      
        # Metadata related to KC attributes and Question & Answer triggering. Next
        # available tag: 2.
        # Corresponds to the JSON property `kcAttributeMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefKcAttributeMetadata]
        attr_accessor :kc_attribute_metadata
      
        # A list of entities that are latent given this entity. For example, "Lionel
        # Messi" can have the latent entity "FC Barcelona". See go/refx-latent-entities
        # for detailed description.
        # Corresponds to the JSON property `latentEntities`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLatentEntities]
        attr_accessor :latent_entities
      
        # Metadata about MDVC (go/mdvc). Next available tag: 18.
        # Corresponds to the JSON property `mdvcMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefMdvcMetadata]
        attr_accessor :mdvc_metadata
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `otherMetadata`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :other_metadata
      
        # The primary recording mid of a recording cluster entity. Used by Juggernaut to
        # do /music/recording recon, see b/139901317. The primary recording is unique to
        # a recording cluster. This field is used by Juggernaut only.
        # Corresponds to the JSON property `primaryRecording`
        # @return [Fixnum]
        attr_accessor :primary_recording
      
        # Products-specific information about the entity. Next available tag: 16.
        # Corresponds to the JSON property `productMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefProductMetadata]
        attr_accessor :product_metadata
      
        # # LINT.ThenChange( //depot/google3/repository/webref/evaluation/query/metrics/
        # util.cc)
        # Corresponds to the JSON property `specialEntityType`
        # @return [String]
        attr_accessor :special_entity_type
      
        # 
        # Corresponds to the JSON property `specialWord`
        # @return [Array<Google::Apis::ContentwarehouseV1::MapsQualitySpecialWordsProto>]
        attr_accessor :special_word
      
        # Metadata about support transfer rules defined for this entity.
        # Corresponds to the JSON property `supportTransferRules`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSupportTransferRule>]
        attr_accessor :support_transfer_rules
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @book_edition_metadata = args[:book_edition_metadata] if args.key?(:book_edition_metadata)
          @category_info = args[:category_info] if args.key?(:category_info)
          @cluster_metadata = args[:cluster_metadata] if args.key?(:cluster_metadata)
          @display_info = args[:display_info] if args.key?(:display_info)
          @entity_scores = args[:entity_scores] if args.key?(:entity_scores)
          @equivalent_entity_id = args[:equivalent_entity_id] if args.key?(:equivalent_entity_id)
          @geo_metadata = args[:geo_metadata] if args.key?(:geo_metadata)
          @kc_attribute_metadata = args[:kc_attribute_metadata] if args.key?(:kc_attribute_metadata)
          @latent_entities = args[:latent_entities] if args.key?(:latent_entities)
          @mdvc_metadata = args[:mdvc_metadata] if args.key?(:mdvc_metadata)
          @other_metadata = args[:other_metadata] if args.key?(:other_metadata)
          @primary_recording = args[:primary_recording] if args.key?(:primary_recording)
          @product_metadata = args[:product_metadata] if args.key?(:product_metadata)
          @special_entity_type = args[:special_entity_type] if args.key?(:special_entity_type)
          @special_word = args[:special_word] if args.key?(:special_word)
          @support_transfer_rules = args[:support_transfer_rules] if args.key?(:support_transfer_rules)
        end
      end
      
      # 
      class RepositoryWebrefFatcatCategory
        include Google::Apis::Core::Hashable
      
        # Category normalized name (for debug purposes). For example, for category "/
        # Beauty & Fitness" the debug_id would be "beauty_and_fitness".
        # Corresponds to the JSON property `debugId`
        # @return [String]
        attr_accessor :debug_id
      
        # The category ID from verticals4. See go/verticals4 and where we read them in
        # http://google3/repository/webref/preprocessing/fatcat-categories.cc
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # The relative weight of the category within a distribution.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_id = args[:debug_id] if args.key?(:debug_id)
          @id = args[:id] if args.key?(:id)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Submessage for forwarding urls in DocumentMetadata.
      class RepositoryWebrefForwardingUrls
        include Google::Apis::Core::Hashable
      
        # Urls that forward to this url. Used for url -> topical entity entries.
        # Corresponds to the JSON property `forwardingUrl`
        # @return [Array<String>]
        attr_accessor :forwarding_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @forwarding_url = args[:forwarding_url] if args.key?(:forwarding_url)
        end
      end
      
      # ---------------------------------------------------------------------------
      # Enums defining the available modifier options.
      class RepositoryWebrefFprintModifierProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `capitalization`
        # @return [String]
        attr_accessor :capitalization
      
        # 
        # Corresponds to the JSON property `enclosing`
        # @return [String]
        attr_accessor :enclosing
      
        # i18.languages.Language enum defined in i18n/languages/proto/languages.proto
        # UNKNOWN_LANGUAGE
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `namespaceType`
        # @return [String]
        attr_accessor :namespace_type
      
        # 
        # Corresponds to the JSON property `punctuation`
        # @return [String]
        attr_accessor :punctuation
      
        # 
        # Corresponds to the JSON property `sentence`
        # @return [String]
        attr_accessor :sentence
      
        # 
        # Corresponds to the JSON property `sourceType`
        # @return [String]
        attr_accessor :source_type
      
        # 
        # Corresponds to the JSON property `stemming`
        # @return [String]
        attr_accessor :stemming
      
        # 
        # Corresponds to the JSON property `style`
        # @return [String]
        attr_accessor :style
      
        # 
        # Corresponds to the JSON property `tokenType`
        # @return [String]
        attr_accessor :token_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @capitalization = args[:capitalization] if args.key?(:capitalization)
          @enclosing = args[:enclosing] if args.key?(:enclosing)
          @language = args[:language] if args.key?(:language)
          @namespace_type = args[:namespace_type] if args.key?(:namespace_type)
          @punctuation = args[:punctuation] if args.key?(:punctuation)
          @sentence = args[:sentence] if args.key?(:sentence)
          @source_type = args[:source_type] if args.key?(:source_type)
          @stemming = args[:stemming] if args.key?(:stemming)
          @style = args[:style] if args.key?(:style)
          @token_type = args[:token_type] if args.key?(:token_type)
        end
      end
      
      # The Freebase type information.
      class RepositoryWebrefFreebaseType
        include Google::Apis::Core::Hashable
      
        # Optional - for inferred types the principal source of information.
        # Corresponds to the JSON property `provenance`
        # @return [Array<String>]
        attr_accessor :provenance
      
        # Optional score. Not present in KG directly but e.g. in WPCat.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Mid of this type. Equivalent to type_name, but is more compact. When present,
        # overrides type_name (which can be omitted in this case to save space).
        # Corresponds to the JSON property `typeMid`
        # @return [Fixnum]
        attr_accessor :type_mid
      
        # e.g.: "/business/industry", "/book/book_subject", "/people/person"...
        # Corresponds to the JSON property `typeName`
        # @return [String]
        attr_accessor :type_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provenance = args[:provenance] if args.key?(:provenance)
          @score = args[:score] if args.key?(:score)
          @type_mid = args[:type_mid] if args.key?(:type_mid)
          @type_name = args[:type_name] if args.key?(:type_name)
        end
      end
      
      # Identifies the segment index for Webref SegmentTypes not covered by other *
      # Indices messages.
      class RepositoryWebrefGenericIndices
        include Google::Apis::Core::Hashable
      
        # The segment index.
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
        end
      end
      
      # Geo-specific information about the entity. Next available tag: 34.
      class RepositoryWebrefGeoMetadataProto
        include Google::Apis::Core::Hashable
      
        # This class represents an address, partial address, or address range. It is
        # intended to be attached to features to identify their address(es). Some
        # important points about addresses: - The addresses in the Geo Schema do *not*
        # include a component for the name of the feature, i.e. they are not self-
        # referential. For example, the name of a feature might be "Zack's Pizza" and
        # its address would be "123 Main Street". Similarly, streets, cities, and
        # counties do not include themselves as part of their address. The address of "
        # Seattle" is "King County, Washington, USA". If want to construct an address
        # that *does* include the feature name, you can simply prepend it to the other
        # address components. - Lakes, mountains, and other natural features do not
        # normally have addresses. Countries also do not have addresses because they are
        # at the top of the political hierarchy. - Address components in the Geo Schema
        # are listed in a particular order, independent of the conventions used by the
        # country in which they occur. The basic order is "smallest to largest" starting
        # with street numbers and routes, then political features, and ending with
        # postal features. The exact rules are defined by the implementation of the
        # AddressComponentOrdering::IsLessThan() function. - Some types of address
        # components may occur more than once in an address. For example, a UK address
        # with a "dependent thoroughfare" would have two components of TYPE_ROUTE (i.e.
        # street names). These are listed in the order they are normally written.
        # Corresponds to the JSON property `address`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreAddressProto]
        attr_accessor :address
      
        # 
        # Corresponds to the JSON property `addressSynonyms`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefGeoMetadataProtoAddressSynonym>]
        attr_accessor :address_synonyms
      
        # Area in km^2 of the feature if the feature has polygon.
        # Corresponds to the JSON property `areaKm2`
        # @return [Float]
        attr_accessor :area_km2
      
        # A latitude-longitude rectangle, represented as two diagonally opposite points "
        # lo" and "hi". The rectangle is considered to be a closed region, i.e. it
        # includes its boundary. The latitude bounds must be in the range -90 to 90
        # degrees inclusive, and the longitude bounds must be in the range -180 to 180
        # degrees inclusive. Various cases include: - If lo == hi, the rectangle
        # consists of a single point. - If lo.longitude > hi.longitude, the longitude
        # range is "inverted" (the rectangle crosses the 180 degree longitude line). -
        # If lo.longitude == -180 degrees and hi.longitude = 180 degrees, the rectangle
        # includes all longitudes. - If lo.longitude = 180 degrees and hi.longitude = -
        # 180 degrees, the longitude range is empty. - If lo.latitude > hi.latitude, the
        # latitude range is empty.
        # Corresponds to the JSON property `bound`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreRectProto]
        attr_accessor :bound
      
        # Country code of the country of the entity. Only available in qref-metadata.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # The geographic location (center) and geometry of this entity. See geostore.
        # FeatureProto for more details.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :location
      
        # A name for a Feature (street name, point of interest, city, building, etc). We
        # currently use NameProto for two essentially disjoint purposes: 1. Common names,
        # which can be language-specific, or have other kinds of variations. 2. Opaque
        # IDs, such as postal codes, which only have the `text` field set, and
        # potentially some flags. This includes internal-only features like template ids.
        # Each NameProto representing a common name corresponds to an assertion that a
        # fluent speaker or writer of a language would recognize NameProto.text to name
        # the given feature in that language. As such, NameProtos are stored in a
        # repeated field, often having: 1. multiple names with the same text and varying
        # languages, and 2. multiple names with the same language and varying texts.
        # Corresponds to the JSON property `name`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreNameProto]
        attr_accessor :name
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `oysterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :oyster_id
      
        # Numerical country code, converted with i18n/identifiers/
        # stableinternalregionconverter.h. It is the same as country_code, but it is
        # available in the annotator model (and takes less space).
        # Corresponds to the JSON property `stableIntegerCountryCode`
        # @return [Fixnum]
        attr_accessor :stable_integer_country_code
      
        # Timezone if the feature is contained inside one.
        # Corresponds to the JSON property `timezone`
        # @return [String]
        attr_accessor :timezone
      
        # Information about the geographic location (center) extracted from the
        # wikijoins.
        # Corresponds to the JSON property `wpLocation`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWikipediaGeocode>]
        attr_accessor :wp_location
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @address = args[:address] if args.key?(:address)
          @address_synonyms = args[:address_synonyms] if args.key?(:address_synonyms)
          @area_km2 = args[:area_km2] if args.key?(:area_km2)
          @bound = args[:bound] if args.key?(:bound)
          @country_code = args[:country_code] if args.key?(:country_code)
          @location = args[:location] if args.key?(:location)
          @name = args[:name] if args.key?(:name)
          @oyster_id = args[:oyster_id] if args.key?(:oyster_id)
          @stable_integer_country_code = args[:stable_integer_country_code] if args.key?(:stable_integer_country_code)
          @timezone = args[:timezone] if args.key?(:timezone)
          @wp_location = args[:wp_location] if args.key?(:wp_location)
        end
      end
      
      # Terms from AddressComponent proto that we can use as address synonyms. At the
      # time of annotation we have the entire AddressProto, however we can't use it
      # all due to size. So only store relevant pieces of components (defined in
      # superroot/impls/localweb/s2_synoyms.h).
      class RepositoryWebrefGeoMetadataProtoAddressSynonym
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # The type of the geocoded address. e.g. Road, Lake, Ocean, building. This comes
        # from TypeCategory field in geostore/base/proto/feature.proto
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @name = args[:name] if args.key?(:name)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Groups together the LinkInfo for all locales.
      class RepositoryWebrefGlobalLinkInfo
        include Google::Apis::Core::Hashable
      
        # A short human-readable name/title of the entity, similar to what is displayed
        # at the top of a Hume page. Do not use for any production purpose as it does
        # not provide guarantees for stability or policy checks (access requirements).
        # Corresponds to the JSON property `debugTitle`
        # @return [String]
        attr_accessor :debug_title
      
        # Whether this is a BoostedPrimaryWeight link. For these links in some cases a
        # higher weight is used for primary scoring.
        # Corresponds to the JSON property `isBoostedPrimaryWeightLink`
        # @return [Boolean]
        attr_accessor :is_boosted_primary_weight_link
        alias_method :is_boosted_primary_weight_link?, :is_boosted_primary_weight_link
      
        # The mid of the linked entity.
        # Corresponds to the JSON property `targetMid`
        # @return [Fixnum]
        attr_accessor :target_mid
      
        # The information about this link for each locale.
        # Corresponds to the JSON property `variantInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLinkInfo>]
        attr_accessor :variant_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_title = args[:debug_title] if args.key?(:debug_title)
          @is_boosted_primary_weight_link = args[:is_boosted_primary_weight_link] if args.key?(:is_boosted_primary_weight_link)
          @target_mid = args[:target_mid] if args.key?(:target_mid)
          @variant_info = args[:variant_info] if args.key?(:variant_info)
        end
      end
      
      # Groups together the NameInfo for all variants of a given name. The variants of
      # a name have the same normalized string, but they have a different original
      # string and/or a different language/region. Example: For the name "apple",
      # there may be variants such as "apple|en", "apple|en|US", "apple|de", "Apple|en"
      # ...
      class RepositoryWebrefGlobalNameInfo
        include Google::Apis::Core::Hashable
      
        # The normalized name.
        # Corresponds to the JSON property `normalizedName`
        # @return [String]
        attr_accessor :normalized_name
      
        # All the variants of this name together with associated information such as
        # score, sources, etc.
        # Corresponds to the JSON property `variantInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefNameInfo>]
        attr_accessor :variant_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized_name = args[:normalized_name] if args.key?(:normalized_name)
          @variant_info = args[:variant_info] if args.key?(:variant_info)
        end
      end
      
      # 
      class RepositoryWebrefHumanRatings
        include Google::Apis::Core::Hashable
      
        # Human ratings of webref annotations (document-level ratings, mention-level
        # ratings, etc.).
        # Corresponds to the JSON property `annotationRatings`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotationRatings]
        attr_accessor :annotation_ratings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_ratings = args[:annotation_ratings] if args.key?(:annotation_ratings)
        end
      end
      
      # Identifies a set of Image NavBoost queries in the CompositeDoc. Each
      # CompositeDoc can contain several images, so we store the image index from the
      # CompositeDoc::doc_images with the index of the particular query inside
      # ImageData::image_data_navboost.
      class RepositoryWebrefImageQueryIndices
        include Google::Apis::Core::Hashable
      
        # / The index of the source image in CompositeDoc::doc_images.
        # Corresponds to the JSON property `imageIndex`
        # @return [Fixnum]
        attr_accessor :image_index
      
        # Identifies a set of NavBoost queries in the CompositeDoc. Typically these
        # queries were collapsed by WebRef into a single query and they were treated by
        # the annotator as equivalent. They all contain the same mentions (at the same
        # offsets).
        # Corresponds to the JSON property `queryIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefQueryIndices]
        attr_accessor :query_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_index = args[:image_index] if args.key?(:image_index)
          @query_index = args[:query_index] if args.key?(:query_index)
        end
      end
      
      # Identifies the source of Spore segments in the CompositeDoc.
      class RepositoryWebrefJuggernautIndices
        include Google::Apis::Core::Hashable
      
        # Index within the proto. Several indices are necessary in case of nested
        # repeated fields. The data can be accessed as follows: TOPICS:
        # topic_annotations.kg_schema_topic(index(0)) .property_value(index(1)) .value(
        # index(2)); TRIPLES: reconcile_request.triple(index(0));
        # Corresponds to the JSON property `index`
        # @return [Array<Fixnum>]
        attr_accessor :index
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index = args[:index] if args.key?(:index)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Metadata related to KC attributes and Question & Answer triggering. Next
      # available tag: 2.
      class RepositoryWebrefKcAttributeMetadata
        include Google::Apis::Core::Hashable
      
        # Equivalent kc attribute id for the given entity if applicable. E.g. for
        # Daughter (/m/029wnx) this will be 'kc:/people/person:daughter'.
        # Corresponds to the JSON property `equivalentAttributeId`
        # @return [String]
        attr_accessor :equivalent_attribute_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @equivalent_attribute_id = args[:equivalent_attribute_id] if args.key?(:equivalent_attribute_id)
        end
      end
      
      # See go/kg-collections
      class RepositoryWebrefKgCollection
        include Google::Apis::Core::Hashable
      
        # A human friendly identifier (collection hrid). NOTE: The field name is a
        # misnomer, this is the preferred field to use in production.
        # Corresponds to the JSON property `debugId`
        # @return [String]
        attr_accessor :debug_id
      
        # Identifier of the collection, usually a MID (/m/xyz or /g/zyw). NOTE: In most
        # cases, this is not the id that should be used, debug_id is the preferred
        # identifier. The main reason is the this is not a stable id (mid for collection
        # sometimes shift around).
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_id = args[:debug_id] if args.key?(:debug_id)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A list of entities that are latent given this entity. For example, "Lionel
      # Messi" can have the latent entity "FC Barcelona". See go/refx-latent-entities
      # for detailed description.
      class RepositoryWebrefLatentEntities
        include Google::Apis::Core::Hashable
      
        # Latent entities with associated metadata including source of the relationship.
        # This is pruned ("compacted") from the concept table and will never reach the
        # annotator.
        # Corresponds to the JSON property `latentEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLatentEntity>]
        attr_accessor :latent_entity
      
        # List of broader MIDs from the Sports Hierarchy. Named incorrectly, it does not
        # contain all latent mids.
        # Corresponds to the JSON property `latentMid`
        # @return [Array<String>]
        attr_accessor :latent_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @latent_entity = args[:latent_entity] if args.key?(:latent_entity)
          @latent_mid = args[:latent_mid] if args.key?(:latent_mid)
        end
      end
      
      # Metadata about a latent entity and its relationship to a given child. See go/
      # hits.
      class RepositoryWebrefLatentEntity
        include Google::Apis::Core::Hashable
      
        # The relatedness score of the two entities corresponding to each source above.
        # Corresponds to the JSON property `broaderImportance`
        # @return [Array<Float>]
        attr_accessor :broader_importance
      
        # The mid of the latent entity.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The sources this generalization relationship is coming from.
        # Corresponds to the JSON property `sources`
        # @return [Array<String>]
        attr_accessor :sources
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @broader_importance = args[:broader_importance] if args.key?(:broader_importance)
          @mid = args[:mid] if args.key?(:mid)
          @sources = args[:sources] if args.key?(:sources)
        end
      end
      
      # LexicalAnnotation is public lightweight serving structure for both WordGraph
      # features and LWT annotations to expose lexical information downstream from
      # RefX, e.g. in LooseParser.
      class RepositoryWebrefLexicalAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lexicalRange`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLexicalRange>]
        attr_accessor :lexical_range
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lexical_range = args[:lexical_range] if args.key?(:lexical_range)
        end
      end
      
      # A single understood lexicon of the |category| on byte range from |begin_offset|
      # (inclusive) to |end_offset| (exclusive). The byte range could be a subtoken
      # range or span across multiple tokens.
      class RepositoryWebrefLexicalRange
        include Google::Apis::Core::Hashable
      
        # Byte offset of the begin of the |category|.
        # Corresponds to the JSON property `beginOffset`
        # @return [Fixnum]
        attr_accessor :begin_offset
      
        # 
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # Direction defines the relation between the measurable aspect and the facet.
        # Corresponds to the JSON property `direction`
        # @return [String]
        attr_accessor :direction
      
        # Byte offset of the end of the |category|.
        # Corresponds to the JSON property `endOffset`
        # @return [Fixnum]
        attr_accessor :end_offset
      
        # The mid of the facet associated with ASPECT category.
        # Corresponds to the JSON property `facetMid`
        # @return [Fixnum]
        attr_accessor :facet_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin_offset = args[:begin_offset] if args.key?(:begin_offset)
          @category = args[:category] if args.key?(:category)
          @direction = args[:direction] if args.key?(:direction)
          @end_offset = args[:end_offset] if args.key?(:end_offset)
          @facet_mid = args[:facet_mid] if args.key?(:facet_mid)
        end
      end
      
      # Necessary information of lightweight token pattern with entity retrieval to
      # pass to downstream clients. For example: FpTokenRange: normalized_text: "
      # zurichben" language: Hungarian retrieved_entity: /m/08966 (with name "zurich")
      # will get: MatchedLightweightToken: LightweightTokenType: "LOCATIVE"
      # begin_offset: 6 end_offset: 9 pattern_id: 8141703461898598811
      # source_entity_index: 0 FpTokenRange: normalized_text: "egyesult allamokott"
      # language: Hungarian retrieved_entity: /m/09c7w0 (with name "egyesult allamok")
      # will get: MatchedLightweightToken: LightweightTokenType: "LOCATIVE"
      # begin_offset: 16 end_offset: 19 pattern_id: 10449962977910715124
      # source_entity_index: 0 Note that begin_offset and end_offset marks the input
      # byte range of the matched input text. For example, if the input text is [
      # tannlegas] in Norwegian, this matches with the rewrite rule "*e:*as" to
      # transform "tannlegas" to "tannlege". The matched byte range is [7, 9) on "as",
      # therefore begin_offset = 7 and end_offset = 9. This must not be confused with
      # the rewritten range [7, 8) on "e". Also, keep in mind these are byte offsets,
      # not codepoints.
      class RepositoryWebrefLightweightTokensMatchedLightweightToken
        include Google::Apis::Core::Hashable
      
        # The byte offset of the beging of the additional lightweight token match. e.g.
        # the prefix pattern of the circumfix.
        # Corresponds to the JSON property `additionalBeginOffset`
        # @return [Fixnum]
        attr_accessor :additional_begin_offset
      
        # The byte offset of the end of the additional lightweight token match. e.g. the
        # suffix pattern of the circumfix.
        # Corresponds to the JSON property `additionalEndOffset`
        # @return [Fixnum]
        attr_accessor :additional_end_offset
      
        # The byte offset of the begin of the lightweight token match within each range.
        # The default value of -1 (std::string::npos) means that there's no affix or
        # adposition detected.
        # Corresponds to the JSON property `beginOffset`
        # @return [Fixnum]
        attr_accessor :begin_offset
      
        # The byte offset of the end of the lightweight token match within each range.
        # The default value of 0 means that there's no affix or adposition detected.
        # Corresponds to the JSON property `endOffset`
        # @return [Fixnum]
        attr_accessor :end_offset
      
        # Matched pattern Id which will be used to retrieve back pattern features.
        # Pattern id is only populated for Enricher model.
        # Corresponds to the JSON property `patternId`
        # @return [Fixnum]
        attr_accessor :pattern_id
      
        # The index of the source entity in the resulting WebrefEntities or
        # WebrefEntitiesWrapper, to which the lightweight token rule is applied. This
        # field is only populated at the end of Qref scorer when we are sure which
        # source entity should output.
        # Corresponds to the JSON property `sourceEntityIndex`
        # @return [Fixnum]
        attr_accessor :source_entity_index
      
        # The type of the lightweight token match, which provides the semantic
        # information.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_begin_offset = args[:additional_begin_offset] if args.key?(:additional_begin_offset)
          @additional_end_offset = args[:additional_end_offset] if args.key?(:additional_end_offset)
          @begin_offset = args[:begin_offset] if args.key?(:begin_offset)
          @end_offset = args[:end_offset] if args.key?(:end_offset)
          @pattern_id = args[:pattern_id] if args.key?(:pattern_id)
          @source_entity_index = args[:source_entity_index] if args.key?(:source_entity_index)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Collects all lightweight token patterns for each CandidateMention or Mention.
      class RepositoryWebrefLightweightTokensPerMentionLightweightToken
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matchedLightweightToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLightweightTokensMatchedLightweightToken>]
        attr_accessor :matched_lightweight_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matched_lightweight_token = args[:matched_lightweight_token] if args.key?(:matched_lightweight_token)
        end
      end
      
      # Collects all lightweight token patterns for each NameToConceptEntry.
      class RepositoryWebrefLightweightTokensPerNameLightweightToken
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matchedLightweightToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefLightweightTokensMatchedLightweightToken>]
        attr_accessor :matched_lightweight_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matched_lightweight_token = args[:matched_lightweight_token] if args.key?(:matched_lightweight_token)
        end
      end
      
      # Represents all information we have about a specific/localized link. Next
      # available tag: 11.
      class RepositoryWebrefLinkInfo
        include Google::Apis::Core::Hashable
      
        # The score aggregated from all sources.
        # Corresponds to the JSON property `aggregatedScore`
        # @return [Float]
        attr_accessor :aggregated_score
      
        # The EntityJoin keeps bi-directional links, but for some applications we only
        # need them in one direction. This value indicates whether this is the preferred
        # direction to keep. (We usually prefer keeping the link from the less common to
        # the more common entity for performance reasons). For categorical links the
        # preferred direction is from child to parent.
        # Corresponds to the JSON property `isPreferredDirection`
        # @return [Boolean]
        attr_accessor :is_preferred_direction
        alias_method :is_preferred_direction?, :is_preferred_direction
      
        # Metadata about the nature of the link.
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityLinkMetadata]
        attr_accessor :metadata
      
        # The per-source scores.
        # Corresponds to the JSON property `source`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityLinkSource>]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_score = args[:aggregated_score] if args.key?(:aggregated_score)
          @is_preferred_direction = args[:is_preferred_direction] if args.key?(:is_preferred_direction)
          @metadata = args[:metadata] if args.key?(:metadata)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # A bitmap of bool values associated with a link kind. Next available tag: 12
      class RepositoryWebrefLinkKindFlags
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cluster`
        # @return [String]
        attr_accessor :cluster
      
        # 
        # Corresponds to the JSON property `geoContainment`
        # @return [String]
        attr_accessor :geo_containment
      
        # 
        # Corresponds to the JSON property `implication`
        # @return [String]
        attr_accessor :implication
      
        # 
        # Corresponds to the JSON property `latentEntity`
        # @return [String]
        attr_accessor :latent_entity
      
        # 
        # Corresponds to the JSON property `mdvc`
        # @return [String]
        attr_accessor :mdvc
      
        # 
        # Corresponds to the JSON property `property`
        # @return [String]
        attr_accessor :property
      
        # 
        # Corresponds to the JSON property `resolution`
        # @return [String]
        attr_accessor :resolution
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cluster = args[:cluster] if args.key?(:cluster)
          @geo_containment = args[:geo_containment] if args.key?(:geo_containment)
          @implication = args[:implication] if args.key?(:implication)
          @latent_entity = args[:latent_entity] if args.key?(:latent_entity)
          @mdvc = args[:mdvc] if args.key?(:mdvc)
          @property = args[:property] if args.key?(:property)
          @resolution = args[:resolution] if args.key?(:resolution)
        end
      end
      
      # Information about one of the types of a linked entity.
      class RepositoryWebrefLinkKindInfo
        include Google::Apis::Core::Hashable
      
        # A bitmap of bool values associated with a link kind. Next available tag: 12
        # Corresponds to the JSON property `flags`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLinkKindFlags]
        attr_accessor :flags
      
        # Link name extracted from Knowledge Card facts.
        # Corresponds to the JSON property `kcLinkName`
        # @return [String]
        attr_accessor :kc_link_name
      
        # If the link was extracted from a property, the name of the property. Can start
        # with an exclamation mark "!" to indicate that the inverse relationship is
        # specified. (e.g. "!/tv/tv_series_episode/series" is the inverse of "tv/
        # tv_program/episodes").
        # Corresponds to the JSON property `topicPropertyName`
        # @return [String]
        attr_accessor :topic_property_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flags = args[:flags] if args.key?(:flags)
          @kc_link_name = args[:kc_link_name] if args.key?(:kc_link_name)
          @topic_property_name = args[:topic_property_name] if args.key?(:topic_property_name)
        end
      end
      
      # Next available tag: 8.
      class RepositoryWebrefLocalizedString
        include Google::Apis::Core::Hashable
      
        # The domain name from which results come, e.g. "play.google.com".
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # ---------------------------------------------------------------------------
        # Enums defining the available modifier options.
        # Corresponds to the JSON property `fprintModifier`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefFprintModifierProto]
        attr_accessor :fprint_modifier
      
        # The language in the III standard (http://go/iii)
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `normalizedString`
        # @return [String]
        attr_accessor :normalized_string
      
        # 
        # Corresponds to the JSON property `originalString`
        # @return [String]
        attr_accessor :original_string
      
        # The region in the III standard (http://go/iii)
        # Corresponds to the JSON property `region`
        # @return [String]
        attr_accessor :region
      
        # Which querybase pipeline the data comes from.
        # Corresponds to the JSON property `sourceType`
        # @return [String]
        attr_accessor :source_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
          @fprint_modifier = args[:fprint_modifier] if args.key?(:fprint_modifier)
          @language = args[:language] if args.key?(:language)
          @normalized_string = args[:normalized_string] if args.key?(:normalized_string)
          @original_string = args[:original_string] if args.key?(:original_string)
          @region = args[:region] if args.key?(:region)
          @source_type = args[:source_type] if args.key?(:source_type)
        end
      end
      
      # Metadata about MDVC (go/mdvc). Next available tag: 18.
      class RepositoryWebrefMdvcMetadata
        include Google::Apis::Core::Hashable
      
        # Undergoing migration into the PerVertical message. Avoid using it. Concept ids
        # of MDVC dimensions of this concept.
        # Corresponds to the JSON property `dimension`
        # @return [Array<Fixnum>]
        attr_accessor :dimension
      
        # Undergoing migration into the PerVertical message. Avoid using it. List of
        # encoded mids to be expanded in WebRef/QRef output whenever this entity gets
        # annotated. Will be populated in the annotators once static data is deprecated.
        # b/78866814.
        # Corresponds to the JSON property `expandedOutputConceptId`
        # @return [Array<Fixnum>]
        attr_accessor :expanded_output_concept_id
      
        # Undergoing migration into the PerVertical message. Avoid using it. Concept ids
        # of MDVC generalizations of this concept.
        # Corresponds to the JSON property `generalization`
        # @return [Array<Fixnum>]
        attr_accessor :generalization
      
        # True iff the topic is synthetically created during by MDVC extraction.
        # Corresponds to the JSON property `isSynthetic`
        # @return [Boolean]
        attr_accessor :is_synthetic
        alias_method :is_synthetic?, :is_synthetic
      
        # Data, specific to particular verticals.
        # Corresponds to the JSON property `perVertical`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMdvcMetadataPerVertical>]
        attr_accessor :per_vertical
      
        # 
        # Corresponds to the JSON property `queryToLongRunningStoryDataset`
        # @return [Google::Apis::ContentwarehouseV1::NewsReconServiceLrsQ2lrs2QueryToLrsDataset]
        attr_accessor :query_to_long_running_story_dataset
      
        # Undergoing migration into the PerVertical message. Avoid using it. Resolution
        # priority for this entity. In case a query has many possible resolutions, only
        # the ones with the highest resolution priority are annotated.
        # Corresponds to the JSON property `resolutionPriority`
        # @return [Fixnum]
        attr_accessor :resolution_priority
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dimension = args[:dimension] if args.key?(:dimension)
          @expanded_output_concept_id = args[:expanded_output_concept_id] if args.key?(:expanded_output_concept_id)
          @generalization = args[:generalization] if args.key?(:generalization)
          @is_synthetic = args[:is_synthetic] if args.key?(:is_synthetic)
          @per_vertical = args[:per_vertical] if args.key?(:per_vertical)
          @query_to_long_running_story_dataset = args[:query_to_long_running_story_dataset] if args.key?(:query_to_long_running_story_dataset)
          @resolution_priority = args[:resolution_priority] if args.key?(:resolution_priority)
        end
      end
      
      # Per-vertical part. Next available tag: 19
      class RepositoryWebrefMdvcMetadataPerVertical
        include Google::Apis::Core::Hashable
      
        # Concept ids compatible with this topic: specializations and/or ones having
        # this concept as a dimension. Always includes the topic itself.
        # Corresponds to the JSON property `compatibleIds`
        # @return [Array<Fixnum>]
        attr_accessor :compatible_ids
      
        # Concept ids of the dimension values of this topic.
        # Corresponds to the JSON property `dimensionIds`
        # @return [Array<Fixnum>]
        attr_accessor :dimension_ids
      
        # Concept ids to annotate whenever this entity is annotated.
        # Corresponds to the JSON property `expandedOutputIds`
        # @return [Array<Fixnum>]
        attr_accessor :expanded_output_ids
      
        # Concept ids of the generalizations of this topic.
        # Corresponds to the JSON property `generalizationIds`
        # @return [Array<Fixnum>]
        attr_accessor :generalization_ids
      
        # True if the topic is considered a "core topic" for the vertical.
        # Corresponds to the JSON property `isCore`
        # @return [Boolean]
        attr_accessor :is_core
        alias_method :is_core?, :is_core
      
        # If true, the entity is a dimension for some entities in the vertical.
        # Corresponds to the JSON property `isDimension`
        # @return [Boolean]
        attr_accessor :is_dimension
        alias_method :is_dimension?, :is_dimension
      
        # If true, the entity is a generalization for some entities in the vertical.
        # Corresponds to the JSON property `isGeneralization`
        # @return [Boolean]
        attr_accessor :is_generalization
        alias_method :is_generalization?, :is_generalization
      
        # Resolution priority for this entity. If there are many possible resolutions to
        # a MDVC understanding, only the ones with the highest priority are annotated.
        # Corresponds to the JSON property `resolutionPriority`
        # @return [Fixnum]
        attr_accessor :resolution_priority
      
        # Fingerprints that identify the topic's sub-verticals, if any.
        # Corresponds to the JSON property `subVerticalFp`
        # @return [Array<Fixnum>]
        attr_accessor :sub_vertical_fp
      
        # Name of the vertical this message is about.
        # Corresponds to the JSON property `verticalName`
        # @return [String]
        attr_accessor :vertical_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compatible_ids = args[:compatible_ids] if args.key?(:compatible_ids)
          @dimension_ids = args[:dimension_ids] if args.key?(:dimension_ids)
          @expanded_output_ids = args[:expanded_output_ids] if args.key?(:expanded_output_ids)
          @generalization_ids = args[:generalization_ids] if args.key?(:generalization_ids)
          @is_core = args[:is_core] if args.key?(:is_core)
          @is_dimension = args[:is_dimension] if args.key?(:is_dimension)
          @is_generalization = args[:is_generalization] if args.key?(:is_generalization)
          @resolution_priority = args[:resolution_priority] if args.key?(:resolution_priority)
          @sub_vertical_fp = args[:sub_vertical_fp] if args.key?(:sub_vertical_fp)
          @vertical_name = args[:vertical_name] if args.key?(:vertical_name)
        end
      end
      
      # Multiple entities can be identified on a document or query. Each entity can be
      # mentioned several times in different positions on the document or query. This
      # message describes a single mention of the entity. Note that a mention can be
      # either explicit or implicit mentions. All explicit mentions refer to exact
      # range in the document where the entity occurred, but implicit mentions may or
      # may not have corresponding range. Next available tag number: 40
      class RepositoryWebrefMention
        include Google::Apis::Core::Hashable
      
        # Whether this mention was created by CloseAnswers on Postref. This bit is
        # populated into corresponding intent_query through Aqua.
        # Corresponds to the JSON property `addedByCloseAnswers`
        # @return [Boolean]
        attr_accessor :added_by_close_answers
        alias_method :added_by_close_answers?, :added_by_close_answers
      
        # If the mention's range is discontinuous, additional ranges that are a part of
        # the mention but are not included in the begin/end range above.
        # Corresponds to the JSON property `additionalExplainedRange`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionAdditionalExplainedRange>]
        attr_accessor :additional_explained_range
      
        # The [begin, end) byte offset, compatible with the Goldmine DocState
        # representation. - For CONTENT, TITLE, META_CONTENT_TAG and IMG_ALT_TAG
        # segments, the offsets are relative to the beginning of the document content. -
        # For ANCHOR, QUERY, URL, IMAGE_QUERY, CONTEXT_ENTITY, CONTEXT_QUERY,
        # SPORE_GRAPH, INSTANT_QUERY and VIDEO_TRANSCRIPT segments, the offsets are
        # relative to the beginning of the corresponding (sub-)segment or text from doc
        # attachment. The (indexing.annotations.goldmine) options are marks for Goldmine
        # AnnotationsFinder to locate begin and end offsets in order to extract them
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # The [begin end) token offsets in the Goldmine DocState. They follow similar
        # rules as "begin" and "end" above, but for tokens rather than byte offsets.
        # These fields are currently only populated by the query annotator.
        # Corresponds to the JSON property `beginTokenIndex`
        # @return [Fixnum]
        attr_accessor :begin_token_index
      
        # For a compound mention, the references to the entity and mention of the
        # components. Each compound_mention claims one or more 'mrf' fields from the
        # WebrefEntity owning this mention. Use QueryJoinToMeaningStructConverter to
        # expand compound mentions into complete MRF.
        # Corresponds to the JSON property `compoundMention`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionCompoundMention>]
        attr_accessor :compound_mention
      
        # A probabilistic score describing how certain the annotator is that this exact
        # range in the document or query refers to the entity. Probability that a
        # mention is correct corresponds to confidence score roughly as follows: 0.3 ->
        # 75% 0.5 -> 87% 0.7 -> 89% 0.9 -> 94% 1.0 -> 98% However if you consider all
        # mentions with a score above 0.3, then most of these will have scores close to
        # 1, so the overall precision of these mentions is around 95%.
        # Corresponds to the JSON property `confidenceScore`
        # @return [Float]
        attr_accessor :confidence_score
      
        # Debug information.
        # Corresponds to the JSON property `debugInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionDebugInfo]
        attr_accessor :debug_info
      
        # Additional detailed scores about this mention.
        # Corresponds to the JSON property `detailedMentionScores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefDetailedMentionScores]
        attr_accessor :detailed_mention_scores
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `endTokenIndex`
        # @return [Fixnum]
        attr_accessor :end_token_index
      
        # Information used by the evaluation tools to mark mentions annotations as
        # correct/incorrect. This will never be annotated in production (would be nice
        # if was, though :-)).
        # Corresponds to the JSON property `evalInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionEvalInfo]
        attr_accessor :eval_info
      
        # DEPRECATED and not populated anymore.
        # Corresponds to the JSON property `interpretationNumber`
        # @return [Array<Fixnum>]
        attr_accessor :interpretation_number
      
        # True if the entity is mentioned implicitly. Note that a mention can be
        # implicit *and* have a non-empty range, for example if the entity is Sports,
        # and this is inferred from the mention of "gym".
        # Corresponds to the JSON property `isImplicit`
        # @return [Boolean]
        attr_accessor :is_implicit
        alias_method :is_implicit?, :is_implicit
      
        # LexicalAnnotation is public lightweight serving structure for both WordGraph
        # features and LWT annotations to expose lexical information downstream from
        # RefX, e.g. in LooseParser.
        # Corresponds to the JSON property `lexicalAnnotation`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLexicalAnnotation]
        attr_accessor :lexical_annotation
      
        # Qref & Postref only: Set to true for candidates part of qref candidate output
        # for which there was no mention in qref. Internal to qref and LooseParsing. Do
        # not use outside of these systems.
        # Corresponds to the JSON property `lowConfidence`
        # @return [Boolean]
        attr_accessor :low_confidence
        alias_method :low_confidence?, :low_confidence
      
        # Refcon-only: Annotated span in Refcon-normalized textual format, corresponding
        # to the [begin end) offset interval in the CDoc. It will only be populated for
        # CDocs originated from Docjoin extraction.
        # Corresponds to the JSON property `matchingText`
        # @return [String]
        attr_accessor :matching_text
      
        # Metadata proto to be stored in concept tables. Note: Name table only stores
        # name_type_mask for better performance. Remember to change NameToConceptEntry
        # if you add a field to this proto.
        # Corresponds to the JSON property `nameMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefConceptNameMetadata]
        attr_accessor :name_metadata
      
        # Whether the mention is a non-locational reference to a geographical entity.
        # Ranges from 0 (locational) to 1 (non-locational).
        # Corresponds to the JSON property `nonLocationalScore`
        # @return [Float]
        attr_accessor :non_locational_score
      
        # Collects all lightweight token patterns for each CandidateMention or Mention.
        # Corresponds to the JSON property `perMentionLightweightToken`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLightweightTokensPerMentionLightweightToken]
        attr_accessor :per_mention_lightweight_token
      
        # Details about personalization and contextual scoring decisions from
        # Personalized Query Understanding (go/pqu). This message represents information
        # about what kind of biasing was applied, including what type of data were used
        # and how strongly. Intended to be used by client code for fine-tuning necessary
        # ranking or triggering logic if it's not possible to rely on the aggregated
        # annotation confidence alone. To minimize unwanted dependencies and incorrect
        # usage of the data this proto has restricted visibility. Please reach out to
        # refx-pqu@google.com if you want to have access. Next id: 2
        # Corresponds to the JSON property `personalizationContextOutputs`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPersonalizationContextOutputs]
        attr_accessor :personalization_context_outputs
      
        # The prior probability of the entity for this mention.
        # Corresponds to the JSON property `priorProbability`
        # @return [Float]
        attr_accessor :prior_probability
      
        # Whether the mention is a reference (e.g. it could be resolved to an entity
        # coming from personal data) or not, currently only used for personal
        # resolutions. Scores from 0 (not a reference) to 1 (reference). Use at your own
        # risk as they are subject to change, advised to talk to refx-personal first.
        # Corresponds to the JSON property `referenceScore`
        # @return [Float]
        attr_accessor :reference_score
      
        # Whether the mention is a resolution or not, currently only used for personal
        # resolutions. Scores from 0 (not a resolution) to 1 (resolution). Use at your
        # own risk as they are subject to change, advised to talk to refx-personal first.
        # Corresponds to the JSON property `resolutionScore`
        # @return [Float]
        attr_accessor :resolution_score
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `stuff`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :stuff
      
        # LINT.IfChange Some document segments may consist of multiple sub-segments (e.g.
        # a document might have multiple anchors or navboost queries). SubSegmentIndex
        # contains all information needed to identify the sub-segment (e.g. specific
        # query, query feature or or anchor) where the mention is located.
        # Corresponds to the JSON property `subsegmentIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSubSegmentIndex]
        attr_accessor :subsegment_index
      
        # Confidence for the time_offset_ms annotation, quantized to values in range 0-
        # 127 (see speech::VideoASRServerUtil::ConfidenceQuantize for how the
        # quantization was done). Confidence can be empty for special characters (e.g.
        # spaces).
        # Corresponds to the JSON property `timeOffsetConfidence`
        # @return [Fixnum]
        attr_accessor :time_offset_confidence
      
        # Timestamp that this mention appeared in the video. The field is only populated
        # for VIDEO_TRANSCRIPT when the byte offset is the same. It is extracted from
        # cdoc.doc_videos.content_based_metadata.transcript_asr.transcript.timestamp.
        # Corresponds to the JSON property `timeOffsetMs`
        # @return [Fixnum]
        attr_accessor :time_offset_ms
      
        # Confidence that this name is a trusted name of the entity. This is set only in
        # case the confidence is higher than an internal threshold (see
        # ConceptProbability).
        # Corresponds to the JSON property `trustedNameConfidence`
        # @return [Float]
        attr_accessor :trusted_name_confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @added_by_close_answers = args[:added_by_close_answers] if args.key?(:added_by_close_answers)
          @additional_explained_range = args[:additional_explained_range] if args.key?(:additional_explained_range)
          @begin = args[:begin] if args.key?(:begin)
          @begin_token_index = args[:begin_token_index] if args.key?(:begin_token_index)
          @compound_mention = args[:compound_mention] if args.key?(:compound_mention)
          @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
          @debug_info = args[:debug_info] if args.key?(:debug_info)
          @detailed_mention_scores = args[:detailed_mention_scores] if args.key?(:detailed_mention_scores)
          @end = args[:end] if args.key?(:end)
          @end_token_index = args[:end_token_index] if args.key?(:end_token_index)
          @eval_info = args[:eval_info] if args.key?(:eval_info)
          @interpretation_number = args[:interpretation_number] if args.key?(:interpretation_number)
          @is_implicit = args[:is_implicit] if args.key?(:is_implicit)
          @lexical_annotation = args[:lexical_annotation] if args.key?(:lexical_annotation)
          @low_confidence = args[:low_confidence] if args.key?(:low_confidence)
          @matching_text = args[:matching_text] if args.key?(:matching_text)
          @name_metadata = args[:name_metadata] if args.key?(:name_metadata)
          @non_locational_score = args[:non_locational_score] if args.key?(:non_locational_score)
          @per_mention_lightweight_token = args[:per_mention_lightweight_token] if args.key?(:per_mention_lightweight_token)
          @personalization_context_outputs = args[:personalization_context_outputs] if args.key?(:personalization_context_outputs)
          @prior_probability = args[:prior_probability] if args.key?(:prior_probability)
          @reference_score = args[:reference_score] if args.key?(:reference_score)
          @resolution_score = args[:resolution_score] if args.key?(:resolution_score)
          @stuff = args[:stuff] if args.key?(:stuff)
          @subsegment_index = args[:subsegment_index] if args.key?(:subsegment_index)
          @time_offset_confidence = args[:time_offset_confidence] if args.key?(:time_offset_confidence)
          @time_offset_ms = args[:time_offset_ms] if args.key?(:time_offset_ms)
          @trusted_name_confidence = args[:trusted_name_confidence] if args.key?(:trusted_name_confidence)
        end
      end
      
      # Additional ranges covered by the mention. Next available tag: 5
      class RepositoryWebrefMentionAdditionalExplainedRange
        include Google::Apis::Core::Hashable
      
        # Like begin/end, begin_token_index/end_token_index above.
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # 
        # Corresponds to the JSON property `beginTokenIndex`
        # @return [Fixnum]
        attr_accessor :begin_token_index
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `endTokenIndex`
        # @return [Fixnum]
        attr_accessor :end_token_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @begin_token_index = args[:begin_token_index] if args.key?(:begin_token_index)
          @end = args[:end] if args.key?(:end)
          @end_token_index = args[:end_token_index] if args.key?(:end_token_index)
        end
      end
      
      # Reference to a component of a compound mention. Next available tag: 5
      class RepositoryWebrefMentionComponent
        include Google::Apis::Core::Hashable
      
        # The indices to identify the entity within the WebrefEntities.entities, the
        # segment within its EntityAnnotations.segment_mentions, and the mention within
        # that segment. entity_index is always guaranteed to be set, but
        # segment_mentions_index and mention_index are omitted if the component
        # reference is implicit.
        # Corresponds to the JSON property `entityIndex`
        # @return [Fixnum]
        attr_accessor :entity_index
      
        # The source of the compound has designated this component as the head. Only one
        # of the components can be a head, but it's possible none are.
        # Corresponds to the JSON property `isHeadComponent`
        # @return [Boolean]
        attr_accessor :is_head_component
        alias_method :is_head_component?, :is_head_component
      
        # 
        # Corresponds to the JSON property `mentionIndex`
        # @return [Fixnum]
        attr_accessor :mention_index
      
        # 
        # Corresponds to the JSON property `segmentMentionsIndex`
        # @return [Fixnum]
        attr_accessor :segment_mentions_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_index = args[:entity_index] if args.key?(:entity_index)
          @is_head_component = args[:is_head_component] if args.key?(:is_head_component)
          @mention_index = args[:mention_index] if args.key?(:mention_index)
          @segment_mentions_index = args[:segment_mentions_index] if args.key?(:segment_mentions_index)
        end
      end
      
      # A single compound mention. Next available tag: 3
      class RepositoryWebrefMentionCompoundMention
        include Google::Apis::Core::Hashable
      
        # References to the component mentions which the MRF needs to be fully expanded.
        # It is guaranteed that for a given set of components there exists only a single
        # CompoundMention, i.e. the CompoundMentions are deduped to be unique so each
        # set of components is present only once. The ArgumentValue of the WebrefEntity.
        # mrf refer to these components via ComponentReference; it is guaranteed there
        # are as many components as the MRF expression refers to.
        # Corresponds to the JSON property `component`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionComponent>]
        attr_accessor :component
      
        # The WebrefEntity.mrf indices which this compound applies to. There can be at
        # most one CompoundMention which claims an MRF index, but it is possible there
        # are MRF expressions which are not claimed by any CompoundMention.
        # Corresponds to the JSON property `mrfIndex`
        # @return [Array<Fixnum>]
        attr_accessor :mrf_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @component = args[:component] if args.key?(:component)
          @mrf_index = args[:mrf_index] if args.key?(:mrf_index)
        end
      end
      
      # 
      class RepositoryWebrefMentionDebugInfo
        include Google::Apis::Core::Hashable
      
        # A clean version of text. This is mostly used for compatibility with other
        # Goldmine annotators.
        # Corresponds to the JSON property `cleanText`
        # @return [String]
        attr_accessor :clean_text
      
        # Optional debug information.
        # Corresponds to the JSON property `infoString`
        # @return [Array<String>]
        attr_accessor :info_string
      
        # A snippet of the parsed text (html tags removed) in the page around this
        # mention. Useful for human evaluation of the quality of the annotations.
        # Outputted by WebrefAnnotator if --webref_output_mention_snippet_size is set to
        # a value greater than 0.
        # Corresponds to the JSON property `snippet`
        # @return [String]
        attr_accessor :snippet
      
        # Original UTF-8 document text occurring in the range [begin, end).
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @clean_text = args[:clean_text] if args.key?(:clean_text)
          @info_string = args[:info_string] if args.key?(:info_string)
          @snippet = args[:snippet] if args.key?(:snippet)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # 
      class RepositoryWebrefMentionEvalInfo
        include Google::Apis::Core::Hashable
      
        # Weight of the mention used in the ATM score.
        # Corresponds to the JSON property `atmWeight`
        # @return [Float]
        attr_accessor :atm_weight
      
        # The aggregate numerical rating of this mention. 0.0 means completely incorrect,
        # and 1.0 completely correct.
        # Corresponds to the JSON property `rating`
        # @return [Float]
        attr_accessor :rating
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @atm_weight = args[:atm_weight] if args.key?(:atm_weight)
          @rating = args[:rating] if args.key?(:rating)
        end
      end
      
      # Per document mention ratings. Next id: 10
      class RepositoryWebrefMentionRatings
        include Google::Apis::Core::Hashable
      
        # Byte offsets of the mention.
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `mentionMatch`
        # @return [Array<String>]
        attr_accessor :mention_match
      
        # 
        # Corresponds to the JSON property `singleMentionRating`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionRatingsSingleMentionRating>]
        attr_accessor :single_mention_rating
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @end = args[:end] if args.key?(:end)
          @mention_match = args[:mention_match] if args.key?(:mention_match)
          @single_mention_rating = args[:single_mention_rating] if args.key?(:single_mention_rating)
        end
      end
      
      # Next available tag: 11
      class RepositoryWebrefMentionRatingsSingleMentionRating
        include Google::Apis::Core::Hashable
      
        # Set for mentions got from the new topicality template. True if the raters
        # checked this range as being a good range for the entity. If the range is not
        # correct we demote the mention score. This field is only used in template
        # version V1. From template version V2 and forward it is now set via
        # phrase_refer.
        # Corresponds to the JSON property `isCorrectRange`
        # @return [Boolean]
        attr_accessor :is_correct_range
        alias_method :is_correct_range?, :is_correct_range
      
        # 
        # Corresponds to the JSON property `mentionMatch`
        # @return [String]
        attr_accessor :mention_match
      
        # 
        # Corresponds to the JSON property `mentionRelevant`
        # @return [String]
        attr_accessor :mention_relevant
      
        # 
        # Corresponds to the JSON property `phraseRefer`
        # @return [String]
        attr_accessor :phrase_refer
      
        # Whether rater can understand the topic.
        # Corresponds to the JSON property `raterCanUnderstandTopic`
        # @return [Boolean]
        attr_accessor :rater_can_understand_topic
        alias_method :rater_can_understand_topic?, :rater_can_understand_topic
      
        # The source of the rating, possibly a golden set external to EWOK.
        # Corresponds to the JSON property `ratingSource`
        # @return [String]
        attr_accessor :rating_source
      
        # 
        # Corresponds to the JSON property `resultCount`
        # @return [Fixnum]
        attr_accessor :result_count
      
        # 
        # Corresponds to the JSON property `taskData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTaskData]
        attr_accessor :task_data
      
        # 
        # Corresponds to the JSON property `topicMentionedInResult`
        # @return [Array<String>]
        attr_accessor :topic_mentioned_in_result
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_correct_range = args[:is_correct_range] if args.key?(:is_correct_range)
          @mention_match = args[:mention_match] if args.key?(:mention_match)
          @mention_relevant = args[:mention_relevant] if args.key?(:mention_relevant)
          @phrase_refer = args[:phrase_refer] if args.key?(:phrase_refer)
          @rater_can_understand_topic = args[:rater_can_understand_topic] if args.key?(:rater_can_understand_topic)
          @rating_source = args[:rating_source] if args.key?(:rating_source)
          @result_count = args[:result_count] if args.key?(:result_count)
          @task_data = args[:task_data] if args.key?(:task_data)
          @topic_mentioned_in_result = args[:topic_mentioned_in_result] if args.key?(:topic_mentioned_in_result)
        end
      end
      
      # Collects signals from one query used for prior learning.
      class RepositoryWebrefNameDebugInfo
        include Google::Apis::Core::Hashable
      
        # List of per-candidate signals derived from annotation of this query.
        # Corresponds to the JSON property `candidates`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefNameDebugInfoCandidateInfo>]
        attr_accessor :candidates
      
        # Next available tag: 8.
        # Corresponds to the JSON property `query`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLocalizedString]
        attr_accessor :query
      
        # Query weight used in learning.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @candidates = args[:candidates] if args.key?(:candidates)
          @query = args[:query] if args.key?(:query)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # Collects signals from one query and one candidate. Next available tag: 9
      class RepositoryWebrefNameDebugInfoCandidateInfo
        include Google::Apis::Core::Hashable
      
        # Whether the entity is purely from strong result entities, and is matchless in
        # query annotation.
        # Corresponds to the JSON property `isMatchlessResultContext`
        # @return [Boolean]
        attr_accessor :is_matchless_result_context
        alias_method :is_matchless_result_context?, :is_matchless_result_context
      
        # Mid of the candidate entity or empty string for the full world.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Debug name of the entity (not usually populated).
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `resultEntityScore`
        # @return [Float]
        attr_accessor :result_entity_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_matchless_result_context = args[:is_matchless_result_context] if args.key?(:is_matchless_result_context)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
          @result_entity_score = args[:result_entity_score] if args.key?(:result_entity_score)
        end
      end
      
      # Represents all information we have about a specific/localized name. Next
      # available tag: 13. NOTE: If you add a field to the NameInfo proto and wish to
      # retain it *after* the GlobalNameInfo merging steps in //r/w/enricher/pipeline:
      # topic-enricher-flume-main then the appropriate combining logic for turning a
      # flume stream of NameInfo protos into a single NameInfo must be updated with
      # the new field in mind, in either or both of CombineContextNameInfosFn/
      # CombineNameInfosFn. If not, the newly added field will be ignored during the
      # merging steps (presumably because it is a transient field or a debug field
      # that is not necessary to be retained).
      class RepositoryWebrefNameInfo
        include Google::Apis::Core::Hashable
      
        # Represents the aggregated score of the entities for a given name, aggregated
        # over all sources. Next available tag: 3.
        # Corresponds to the JSON property `aggregatedScores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAggregatedEntityNameScores]
        attr_accessor :aggregated_scores
      
        # Information on categories annotated on the range.
        # Corresponds to the JSON property `annotatedCategory`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotatedCategoryInfo>]
        attr_accessor :annotated_category
      
        # DEBUG ONLY: stores a list of queries with per-candidate scores about signals
        # used for prior learning.
        # Corresponds to the JSON property `debugDetails`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefNameDebugInfo>]
        attr_accessor :debug_details
      
        # Field which decides if this NameInfo should be included in model creation.
        # Corresponds to the JSON property `includeInModel`
        # @return [Boolean]
        attr_accessor :include_in_model
        alias_method :include_in_model?, :include_in_model
      
        # Next available tag: 8.
        # Corresponds to the JSON property `name`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLocalizedString]
        attr_accessor :name
      
        # This proto is filled with n-gram data during model building.
        # Corresponds to the JSON property `ngramData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefUniversalNgramData]
        attr_accessor :ngram_data
      
        # Collects all lightweight token patterns for each NameToConceptEntry.
        # Corresponds to the JSON property `perNameLightweightToken`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLightweightTokensPerNameLightweightToken]
        attr_accessor :per_name_lightweight_token
      
        # Represents some name-specific scores. (Unlike EntityNameScore, these scores
        # are independent of the entities the name is associated with). These scores are
        # available for each name as well as for each name/source. Next available tag:
        # 31.
        # Corresponds to the JSON property `scores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefNameScores]
        attr_accessor :scores
      
        # The per-source scores.
        # Corresponds to the JSON property `source`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityNameSource>]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_scores = args[:aggregated_scores] if args.key?(:aggregated_scores)
          @annotated_category = args[:annotated_category] if args.key?(:annotated_category)
          @debug_details = args[:debug_details] if args.key?(:debug_details)
          @include_in_model = args[:include_in_model] if args.key?(:include_in_model)
          @name = args[:name] if args.key?(:name)
          @ngram_data = args[:ngram_data] if args.key?(:ngram_data)
          @per_name_lightweight_token = args[:per_name_lightweight_token] if args.key?(:per_name_lightweight_token)
          @scores = args[:scores] if args.key?(:scores)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Represents some name-specific scores. (Unlike EntityNameScore, these scores
      # are independent of the entities the name is associated with). These scores are
      # available for each name as well as for each name/source. Next available tag:
      # 31.
      class RepositoryWebrefNameScores
        include Google::Apis::Core::Hashable
      
        # Approximates volume of this name including entities we don't have in our set.
        # This is useful to estimate the size of the "open world". For example, this
        # field can be equal to the total number of clicks for the query. Note that for
        # now, we ignore the number of clicks but just use the idf if available.
        # Corresponds to the JSON property `completeWorldVolume`
        # @return [Float]
        attr_accessor :complete_world_volume
      
        # The fringe score in [0, 1] for this context name. This is only populated for
        # full-query context names.
        # Corresponds to the JSON property `contextFringeScore`
        # @return [Float]
        attr_accessor :context_fringe_score
      
        # The amount of evidence available for this context name.
        # Corresponds to the JSON property `contextWeight`
        # @return [Float]
        attr_accessor :context_weight
      
        # The idf of this name.
        # Corresponds to the JSON property `idfScore`
        # @return [Float]
        attr_accessor :idf_score
      
        # 'Raw' open world is computed based on ngram count data. For some names however,
        # we modify the open world based on entities associated with them. This field
        # contains the additive open world modifier. open_world_volume = raw open world +
        # open_world_volume_modifier
        # Corresponds to the JSON property `openWorldVolumeModifier`
        # @return [Float]
        attr_accessor :open_world_volume_modifier
      
        # The total score of that name/source. It describes how much data we have for
        # that name/source. It can for example be the sum of all the entity scores for
        # this name.
        # Corresponds to the JSON property `totalScore`
        # @return [Float]
        attr_accessor :total_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @complete_world_volume = args[:complete_world_volume] if args.key?(:complete_world_volume)
          @context_fringe_score = args[:context_fringe_score] if args.key?(:context_fringe_score)
          @context_weight = args[:context_weight] if args.key?(:context_weight)
          @idf_score = args[:idf_score] if args.key?(:idf_score)
          @open_world_volume_modifier = args[:open_world_volume_modifier] if args.key?(:open_world_volume_modifier)
          @total_score = args[:total_score] if args.key?(:total_score)
        end
      end
      
      # An N-gram context encountered on the document.
      class RepositoryWebrefNgramContext
        include Google::Apis::Core::Hashable
      
        # The entities that were annotated on the context
        # Corresponds to the JSON property `mention`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefNgramMention>]
        attr_accessor :mention
      
        # The context (original) text.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # The weight of the context on the document; depends on how many times we saw
        # the string in the document.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mention = args[:mention] if args.key?(:mention)
          @text = args[:text] if args.key?(:text)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # A mention that has been matched in the context (or a substring of it).
      class RepositoryWebrefNgramMention
        include Google::Apis::Core::Hashable
      
        # The entity the mention was referring to.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The average score the mention was given across all occurrences of the n-gram.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Oyster type information.
      class RepositoryWebrefOysterType
        include Google::Apis::Core::Hashable
      
        # The Oyster feature type, which provides a rough categorization. This is a
        # value of the enum geostore.FeatureProto.TypeCategory.
        # Corresponds to the JSON property `featureType`
        # @return [Fixnum]
        attr_accessor :feature_type
      
        # The container for all GConceptInstances associated with a feature.
        # Corresponds to the JSON property `gconcepts`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreOntologyRawGConceptInstanceContainerProto]
        attr_accessor :gconcepts
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @gconcepts = args[:gconcepts] if args.key?(:gconcepts)
        end
      end
      
      # 
      class RepositoryWebrefPatternInfo
        include Google::Apis::Core::Hashable
      
        # The confidence we can trust this pattern.
        # Corresponds to the JSON property `matchProbability`
        # @return [Float]
        attr_accessor :match_probability
      
        # Whether other slots is mentioned in annotator. If they is no other slot, it is
        # set to true.
        # Corresponds to the JSON property `otherSlotsMentioned`
        # @return [Boolean]
        attr_accessor :other_slots_mentioned
        alias_method :other_slots_mentioned?, :other_slots_mentioned
      
        # The corresponding patterns matched on this candidate, which contains the
        # pattern string and the slot number of the candidate in this pattern, such as [|
        # /athletes|vs|/athletes|]_1.
        # Corresponds to the JSON property `pattern`
        # @return [String]
        attr_accessor :pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @match_probability = args[:match_probability] if args.key?(:match_probability)
          @other_slots_mentioned = args[:other_slots_mentioned] if args.key?(:other_slots_mentioned)
          @pattern = args[:pattern] if args.key?(:pattern)
        end
      end
      
      # Per document ratings relevance ratings. Next id: 21.
      class RepositoryWebrefPerDocRelevanceRating
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contentRelevant`
        # @return [String]
        attr_accessor :content_relevant
      
        # 
        # Corresponds to the JSON property `deprecatedItemId`
        # @return [Fixnum]
        attr_accessor :deprecated_item_id
      
        # 
        # Corresponds to the JSON property `deprecatedProjectId`
        # @return [Fixnum]
        attr_accessor :deprecated_project_id
      
        # 
        # Corresponds to the JSON property `deprecatedTaskId`
        # @return [Fixnum]
        attr_accessor :deprecated_task_id
      
        # How this rating is displayed in the evals, pre-computed from the other fields.
        # Corresponds to the JSON property `displayString`
        # @return [String]
        attr_accessor :display_string
      
        # The url of the ewok task that resulted in this rating. Example: https://
        # furball.corp.google.com/project/view-item?itemId=1&projectId=2
        # Corresponds to the JSON property `furballUrl`
        # @return [String]
        attr_accessor :furball_url
      
        # 
        # Corresponds to the JSON property `itemDescription`
        # @return [String]
        attr_accessor :item_description
      
        # 
        # Corresponds to the JSON property `itemId`
        # @return [Fixnum]
        attr_accessor :item_id
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # If the topic is about a business chain, whether the
        # Corresponds to the JSON property `pageIsAboutChain`
        # @return [String]
        attr_accessor :page_is_about_chain
      
        # If true, content_relevance is set to NONE.
        # Corresponds to the JSON property `pageNotLoaded`
        # @return [Boolean]
        attr_accessor :page_not_loaded
        alias_method :page_not_loaded?, :page_not_loaded
      
        # 
        # Corresponds to the JSON property `projectId`
        # @return [Fixnum]
        attr_accessor :project_id
      
        # Whether rater can understand the topic.
        # Corresponds to the JSON property `raterCanUnderstandTopic`
        # @return [Boolean]
        attr_accessor :rater_can_understand_topic
        alias_method :rater_can_understand_topic?, :rater_can_understand_topic
      
        # Floating point representation of the `content_relevant` field.
        # Corresponds to the JSON property `ratingScore`
        # @return [Float]
        attr_accessor :rating_score
      
        # Information about what the raters saw, how the information was presented to
        # them, or how they interacted with the task. Next id: 6
        # Corresponds to the JSON property `taskDetails`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTaskDetails]
        attr_accessor :task_details
      
        # 
        # Corresponds to the JSON property `taskId`
        # @return [Fixnum]
        attr_accessor :task_id
      
        # 
        # Corresponds to the JSON property `taskStatus`
        # @return [String]
        attr_accessor :task_status
      
        # 
        # Corresponds to the JSON property `taskUser`
        # @return [Fixnum]
        attr_accessor :task_user
      
        # Metadata for task-level ratings. Not filled for aggregated doc-level ratings.
        # Corresponds to the JSON property `templateId`
        # @return [Fixnum]
        attr_accessor :template_id
      
        # Whether the topic is about a business chain.
        # Corresponds to the JSON property `topicIsChain`
        # @return [String]
        attr_accessor :topic_is_chain
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_relevant = args[:content_relevant] if args.key?(:content_relevant)
          @deprecated_item_id = args[:deprecated_item_id] if args.key?(:deprecated_item_id)
          @deprecated_project_id = args[:deprecated_project_id] if args.key?(:deprecated_project_id)
          @deprecated_task_id = args[:deprecated_task_id] if args.key?(:deprecated_task_id)
          @display_string = args[:display_string] if args.key?(:display_string)
          @furball_url = args[:furball_url] if args.key?(:furball_url)
          @item_description = args[:item_description] if args.key?(:item_description)
          @item_id = args[:item_id] if args.key?(:item_id)
          @language = args[:language] if args.key?(:language)
          @page_is_about_chain = args[:page_is_about_chain] if args.key?(:page_is_about_chain)
          @page_not_loaded = args[:page_not_loaded] if args.key?(:page_not_loaded)
          @project_id = args[:project_id] if args.key?(:project_id)
          @rater_can_understand_topic = args[:rater_can_understand_topic] if args.key?(:rater_can_understand_topic)
          @rating_score = args[:rating_score] if args.key?(:rating_score)
          @task_details = args[:task_details] if args.key?(:task_details)
          @task_id = args[:task_id] if args.key?(:task_id)
          @task_status = args[:task_status] if args.key?(:task_status)
          @task_user = args[:task_user] if args.key?(:task_user)
          @template_id = args[:template_id] if args.key?(:template_id)
          @topic_is_chain = args[:topic_is_chain] if args.key?(:topic_is_chain)
        end
      end
      
      # Aggregates ratings by url/doc_fp.
      class RepositoryWebrefPerDocRelevanceRatings
        include Google::Apis::Core::Hashable
      
        # - In topicality ratings this is Fingerprint2011() of the normalized cdoc. - In
        # query-mention ratings this is a hash of the QueryJoin. - In doc-content-
        # mention ratings this is a hash of a QueryJoin in which the mention rating task
        # has been embedded. -
        # Corresponds to the JSON property `docFp`
        # @return [Fixnum]
        attr_accessor :doc_fp
      
        # Per document ratings relevance ratings. Next id: 21.
        # Corresponds to the JSON property `docLevelRating`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPerDocRelevanceRating]
        attr_accessor :doc_level_rating
      
        # 
        # Corresponds to the JSON property `entityNameRating`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityNameRatings>]
        attr_accessor :entity_name_rating
      
        # 
        # Corresponds to the JSON property `listMembership`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefToprefListMembership>]
        attr_accessor :list_membership
      
        # 
        # Corresponds to the JSON property `mentionRating`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMentionRatings>]
        attr_accessor :mention_rating
      
        # 
        # Corresponds to the JSON property `pageClassification`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefToprefPageClassification>]
        attr_accessor :page_classification
      
        # 
        # Corresponds to the JSON property `taskLevelRating`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPerDocRelevanceRating>]
        attr_accessor :task_level_rating
      
        # - In topicality ratings this is the url of the document. - In query-mention
        # ratings this is the query in format "en:US:query text". - In doc-content-
        # mention ratings this is %x:%s where %x is the hex doc_fp of the cdoc (TODO(b/
        # 139799592) or sometimes the doc_fp below), and %s is the text of the eval
        # range. - In entity-name ratings this is the MID of the entity.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_fp = args[:doc_fp] if args.key?(:doc_fp)
          @doc_level_rating = args[:doc_level_rating] if args.key?(:doc_level_rating)
          @entity_name_rating = args[:entity_name_rating] if args.key?(:entity_name_rating)
          @list_membership = args[:list_membership] if args.key?(:list_membership)
          @mention_rating = args[:mention_rating] if args.key?(:mention_rating)
          @page_classification = args[:page_classification] if args.key?(:page_classification)
          @task_level_rating = args[:task_level_rating] if args.key?(:task_level_rating)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Key-Value-like message to store values associated with a personalization type.
      # Next id: 3
      class RepositoryWebrefPersonalizationContextOutput
        include Google::Apis::Core::Hashable
      
        # Score corresponding to some kind of biasing strength which was applied. The
        # exact semantics of this score is subject to further changes. Don't make
        # assumptions about specific values or ranges. Values > 0 represents that a
        # boost was applied. Values < 0 represents that a penalty was appled.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @score = args[:score] if args.key?(:score)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Details about personalization and contextual scoring decisions from
      # Personalized Query Understanding (go/pqu). This message represents information
      # about what kind of biasing was applied, including what type of data were used
      # and how strongly. Intended to be used by client code for fine-tuning necessary
      # ranking or triggering logic if it's not possible to rely on the aggregated
      # annotation confidence alone. To minimize unwanted dependencies and incorrect
      # usage of the data this proto has restricted visibility. Please reach out to
      # refx-pqu@google.com if you want to have access. Next id: 2
      class RepositoryWebrefPersonalizationContextOutputs
        include Google::Apis::Core::Hashable
      
        # Detailed output scores per personalization type.
        # Corresponds to the JSON property `outputs`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPersonalizationContextOutput>]
        attr_accessor :outputs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @outputs = args[:outputs] if args.key?(:outputs)
        end
      end
      
      # Metadata about a name. There are two metadata protos, whose content is meant
      # to be similar but their usage different: NameEntityMetadata for readability
      # and ConceptNameMetadata for size / decoding speed. NameEntityMetadata is
      # propagated to GlobalNameInfo and EntityJoin tables, while ConceptNameMetadata
      # is propagated from EntityJoins to the name matching tables and later to the
      # Webref's/QRef's output. To add a new metadata field in the Names pipeline, and
      # propagate it to EntityJoins and Names matching tables, it is necessary to: (1)
      # Add the field to NameEntityMetadata, and a corresponding data representation
      # in ConceptNameMetadata. (2) Populate the field in NameVariantSignals.
      # name_metadata, from any source. This can be done in a corresponding
      # NameProcessor. (3) Update the library name-metadata.h/cc to make sure that the
      # metadata field is: a) merged correctly when merging two NameSignals; and b)
      # transformed to the corresponding field in ConceptNameMetadata proto. Next
      # available tag: 22.
      class RepositoryWebrefPreprocessingNameEntityMetadata
        include Google::Apis::Core::Hashable
      
        # There is a limit of entities per name for which we can keep name signals and
        # score. This flag is set to true for names that by-passed per-name-scoring, as
        # there were too many entities for the name.
        # Corresponds to the JSON property `isBypassedName`
        # @return [Boolean]
        attr_accessor :is_bypassed_name
        alias_method :is_bypassed_name?, :is_bypassed_name
      
        # This name is a generated compound name to pass primary pruning.
        # Corresponds to the JSON property `isCompoundName`
        # @return [Boolean]
        attr_accessor :is_compound_name
        alias_method :is_compound_name?, :is_compound_name
      
        # Indicates special compound retrieval keys, like "Compound $mid1 $mid2", see
        # repository/webref/universal/util/compound-retrieval.h
        # Corresponds to the JSON property `isCompoundRetrievalKey`
        # @return [Boolean]
        attr_accessor :is_compound_retrieval_key
        alias_method :is_compound_retrieval_key?, :is_compound_retrieval_key
      
        # This is set to true if the entity corresponds to a dictionary term.
        # Corresponds to the JSON property `isDictionaryTerm`
        # @return [Boolean]
        attr_accessor :is_dictionary_term
        alias_method :is_dictionary_term?, :is_dictionary_term
      
        # If true, this name is an event retrieval key.
        # Corresponds to the JSON property `isEventRetrievalKey`
        # @return [Boolean]
        attr_accessor :is_event_retrieval_key
        alias_method :is_event_retrieval_key?, :is_event_retrieval_key
      
        # This name is generated from other names.
        # Corresponds to the JSON property `isGeneratedName`
        # @return [Boolean]
        attr_accessor :is_generated_name
        alias_method :is_generated_name?, :is_generated_name
      
        # This name is a generated street name.
        # Corresponds to the JSON property `isGeneratedStreetname`
        # @return [Boolean]
        attr_accessor :is_generated_streetname
        alias_method :is_generated_streetname?, :is_generated_streetname
      
        # This name is added by name propagation in hierarchy.
        # Corresponds to the JSON property `isHierarchyPropagated`
        # @return [Boolean]
        attr_accessor :is_hierarchy_propagated
        alias_method :is_hierarchy_propagated?, :is_hierarchy_propagated
      
        # This name is an ISBN.
        # Corresponds to the JSON property `isIsbn`
        # @return [Boolean]
        attr_accessor :is_isbn
        alias_method :is_isbn?, :is_isbn
      
        # This name comes from recording lyrics content.
        # Corresponds to the JSON property `isLyricsContent`
        # @return [Boolean]
        attr_accessor :is_lyrics_content
        alias_method :is_lyrics_content?, :is_lyrics_content
      
        # This name is a phone number.
        # Corresponds to the JSON property `isPhoneNumber`
        # @return [Boolean]
        attr_accessor :is_phone_number
        alias_method :is_phone_number?, :is_phone_number
      
        # This name is used for refcon.
        # Corresponds to the JSON property `isRefconName`
        # @return [Boolean]
        attr_accessor :is_refcon_name
        alias_method :is_refcon_name?, :is_refcon_name
      
        # This name is a reference name, only for internal usage, this name should not
        # go into matching table without support of other signals.
        # Corresponds to the JSON property `isReferenceName`
        # @return [Boolean]
        attr_accessor :is_reference_name
        alias_method :is_reference_name?, :is_reference_name
      
        # This name is the URL of a reference page.
        # Corresponds to the JSON property `isRefpageUrl`
        # @return [Boolean]
        attr_accessor :is_refpage_url
        alias_method :is_refpage_url?, :is_refpage_url
      
        # This name is generated from a reverse unique property of the entity.
        # Corresponds to the JSON property `isReverseUniquePropertyName`
        # @return [Boolean]
        attr_accessor :is_reverse_unique_property_name
        alias_method :is_reverse_unique_property_name?, :is_reverse_unique_property_name
      
        # This name is a strong identifier for this entity.
        # Corresponds to the JSON property `isStrongIdentifier`
        # @return [Boolean]
        attr_accessor :is_strong_identifier
        alias_method :is_strong_identifier?, :is_strong_identifier
      
        # Set if the name is coming from synonyms.
        # Corresponds to the JSON property `isSynonymOrFuzzyMatch`
        # @return [Boolean]
        attr_accessor :is_synonym_or_fuzzy_match
        alias_method :is_synonym_or_fuzzy_match?, :is_synonym_or_fuzzy_match
      
        # If true, this name is a trusted name if it is in ALLCAPS.
        # Corresponds to the JSON property `isTrustedAllcapsName`
        # @return [Boolean]
        attr_accessor :is_trusted_allcaps_name
        alias_method :is_trusted_allcaps_name?, :is_trusted_allcaps_name
      
        # If true, do not do tokenization when compute fprint hash for this name.
        # Corresponds to the JSON property `isUnnormalizedName`
        # @return [Boolean]
        attr_accessor :is_unnormalized_name
        alias_method :is_unnormalized_name?, :is_unnormalized_name
      
        # This name is clearly not generated(aka. at least one source of this name is
        # not generated). This field is added for simplifying generated name tag while
        # merging. Do not use this metadata directly.
        # Corresponds to the JSON property `notGeneratedName`
        # @return [Boolean]
        attr_accessor :not_generated_name
        alias_method :not_generated_name?, :not_generated_name
      
        # Original versions of the name (before normalization). Used as query for the
        # entity by Explicit Entity Search.
        # Corresponds to the JSON property `originalNames`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingOriginalNames]
        attr_accessor :original_names
      
        # Whether or not to suppress tokenization on this name.
        # Corresponds to the JSON property `suppressTokenization`
        # @return [Boolean]
        attr_accessor :suppress_tokenization
        alias_method :suppress_tokenization?, :suppress_tokenization
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_bypassed_name = args[:is_bypassed_name] if args.key?(:is_bypassed_name)
          @is_compound_name = args[:is_compound_name] if args.key?(:is_compound_name)
          @is_compound_retrieval_key = args[:is_compound_retrieval_key] if args.key?(:is_compound_retrieval_key)
          @is_dictionary_term = args[:is_dictionary_term] if args.key?(:is_dictionary_term)
          @is_event_retrieval_key = args[:is_event_retrieval_key] if args.key?(:is_event_retrieval_key)
          @is_generated_name = args[:is_generated_name] if args.key?(:is_generated_name)
          @is_generated_streetname = args[:is_generated_streetname] if args.key?(:is_generated_streetname)
          @is_hierarchy_propagated = args[:is_hierarchy_propagated] if args.key?(:is_hierarchy_propagated)
          @is_isbn = args[:is_isbn] if args.key?(:is_isbn)
          @is_lyrics_content = args[:is_lyrics_content] if args.key?(:is_lyrics_content)
          @is_phone_number = args[:is_phone_number] if args.key?(:is_phone_number)
          @is_refcon_name = args[:is_refcon_name] if args.key?(:is_refcon_name)
          @is_reference_name = args[:is_reference_name] if args.key?(:is_reference_name)
          @is_refpage_url = args[:is_refpage_url] if args.key?(:is_refpage_url)
          @is_reverse_unique_property_name = args[:is_reverse_unique_property_name] if args.key?(:is_reverse_unique_property_name)
          @is_strong_identifier = args[:is_strong_identifier] if args.key?(:is_strong_identifier)
          @is_synonym_or_fuzzy_match = args[:is_synonym_or_fuzzy_match] if args.key?(:is_synonym_or_fuzzy_match)
          @is_trusted_allcaps_name = args[:is_trusted_allcaps_name] if args.key?(:is_trusted_allcaps_name)
          @is_unnormalized_name = args[:is_unnormalized_name] if args.key?(:is_unnormalized_name)
          @not_generated_name = args[:not_generated_name] if args.key?(:not_generated_name)
          @original_names = args[:original_names] if args.key?(:original_names)
          @suppress_tokenization = args[:suppress_tokenization] if args.key?(:suppress_tokenization)
        end
      end
      
      # Abstract, source independent scores. Next available tag: 7
      class RepositoryWebrefPreprocessingNameEntityScores
        include Google::Apis::Core::Hashable
      
        # An unnormalized measure of how much evidence we have that this name variant
        # refers to the key entity. Should be comparable to all scores from the same
        # source for: - other entities having the same name variant - the open world
        # score computed for this name variant
        # Corresponds to the JSON property `priorScore`
        # @return [Float]
        attr_accessor :prior_score
      
        # Prior score come from source that is quantifiable. artificial_score =
        # prior_score - volume_based_score.
        # Corresponds to the JSON property `volumeBasedScore`
        # @return [Float]
        attr_accessor :volume_based_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @prior_score = args[:prior_score] if args.key?(:prior_score)
          @volume_based_score = args[:volume_based_score] if args.key?(:volume_based_score)
        end
      end
      
      # If you add any field, make sure to add it in reffresh to the empty checks at
      # the end of the corresponding name extractor processors (extract-*-names.cc).
      class RepositoryWebrefPreprocessingNameSignals
        include Google::Apis::Core::Hashable
      
        # The set of name candidates and their signals for a given entity.
        # Corresponds to the JSON property `normalizedNameData`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNormalizedNameData>]
        attr_accessor :normalized_name_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized_name_data = args[:normalized_name_data] if args.key?(:normalized_name_data)
        end
      end
      
      # Represents a single name with all its signal, like language, sources and
      # confidences.
      class RepositoryWebrefPreprocessingNameVariantData
        include Google::Apis::Core::Hashable
      
        # Sources providing this name variant and their metadata. NOTE: by convention we
        # only allow one proto per source.
        # Corresponds to the JSON property `variantSignals`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameVariantSignals>]
        attr_accessor :variant_signals
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @variant_signals = args[:variant_signals] if args.key?(:variant_signals)
        end
      end
      
      # Next available tag: 33.
      class RepositoryWebrefPreprocessingNameVariantSignals
        include Google::Apis::Core::Hashable
      
        # Abstract, source independent scores. Next available tag: 7
        # Corresponds to the JSON property `scores`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameEntityScores]
        attr_accessor :scores
      
        # The source of this NameVariantSignals proto
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @scores = args[:scores] if args.key?(:scores)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Aggregation of all names of an entity that normalize to the same string.
      class RepositoryWebrefPreprocessingNormalizedNameData
        include Google::Apis::Core::Hashable
      
        # Name variants and their signals by source. All these name variants normalize
        # to @normalized_name given their locales. NOTE: This includes metadata
        # aggregated for the normalized name.
        # Corresponds to the JSON property `nameVariantData`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingNameVariantData>]
        attr_accessor :name_variant_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name_variant_data = args[:name_variant_data] if args.key?(:name_variant_data)
        end
      end
      
      # 
      class RepositoryWebrefPreprocessingOriginalNames
        include Google::Apis::Core::Hashable
      
        # The total number of original names that a normalized name has (all versions
        # from all different sources).
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # 
        # Corresponds to the JSON property `name`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingOriginalNamesOriginalName>]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # 
      class RepositoryWebrefPreprocessingOriginalNamesOriginalName
        include Google::Apis::Core::Hashable
      
        # The total number of different sources from where this version of the original
        # name comes from.
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Score estimating how good this original name is: - some sources are considered
        # more authoritative than others (e.g. KG) - a name found in more sources is
        # better.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # The sources this name comes from.
        # Corresponds to the JSON property `source`
        # @return [Array<Fixnum>]
        attr_accessor :source
      
        # One original name version.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @score = args[:score] if args.key?(:score)
          @source = args[:source] if args.key?(:source)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Proto with metadata related to why a particular cdoc was selected for an
      # entityjoin.
      class RepositoryWebrefPreprocessingUrlMatchingMetadata
        include Google::Apis::Core::Hashable
      
        # The sources the url was suggested by.
        # Corresponds to the JSON property `source`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingUrlSourceInfo>]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Information about where the url comes from.
      class RepositoryWebrefPreprocessingUrlSourceInfo
        include Google::Apis::Core::Hashable
      
        # Source information for the old reference url Freebase schema.
        # Corresponds to the JSON property `deprecatedOldSchema`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingUrlSourceInfoOldSchema]
        attr_accessor :deprecated_old_schema
      
        # Source information for the new reference url Freebase schema.
        # Corresponds to the JSON property `newSchema`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingUrlSourceInfoNewSchema]
        attr_accessor :new_schema
      
        # 
        # Corresponds to the JSON property `originalUrl`
        # @return [String]
        attr_accessor :original_url
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_old_schema = args[:deprecated_old_schema] if args.key?(:deprecated_old_schema)
          @new_schema = args[:new_schema] if args.key?(:new_schema)
          @original_url = args[:original_url] if args.key?(:original_url)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Source information for the new reference url Freebase schema.
      class RepositoryWebrefPreprocessingUrlSourceInfoNewSchema
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `sourceProperty`
        # @return [String]
        attr_accessor :source_property
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_property = args[:source_property] if args.key?(:source_property)
        end
      end
      
      # Source information for the old reference url Freebase schema.
      class RepositoryWebrefPreprocessingUrlSourceInfoOldSchema
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isOfficial`
        # @return [Boolean]
        attr_accessor :is_official
        alias_method :is_official?, :is_official
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_official = args[:is_official] if args.key?(:is_official)
        end
      end
      
      # A single processor counter stored as a pair of the counter name and the value.
      class RepositoryWebrefProcessorCounter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Fixnum]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Processor timings as produced by NestedPerfCounter, see google3/repository/
      # webref/base/nested-perf-counter.h.
      class RepositoryWebrefProcessorTiming
        include Google::Apis::Core::Hashable
      
        # Cpu instructions spent.
        # Corresponds to the JSON property `cpuInstructions`
        # @return [Fixnum]
        attr_accessor :cpu_instructions
      
        # A string identifying the processor timing context.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Document counters defined by processors. A processor can add and increment
        # counters with NestedPerfCounter::IncrementCounterBy. See go/webref-annotator-
        # metrics.
        # Corresponds to the JSON property `processorCounters`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefProcessorCounter>]
        attr_accessor :processor_counters
      
        # Nested measurements, see NestedPerfCounter::ScopedPerfCounter.
        # Corresponds to the JSON property `processorTimings`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefProcessorTiming>]
        attr_accessor :processor_timings
      
        # Wall time (in nanoseconds).
        # Corresponds to the JSON property `wallTimeNs`
        # @return [Fixnum]
        attr_accessor :wall_time_ns
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cpu_instructions = args[:cpu_instructions] if args.key?(:cpu_instructions)
          @name = args[:name] if args.key?(:name)
          @processor_counters = args[:processor_counters] if args.key?(:processor_counters)
          @processor_timings = args[:processor_timings] if args.key?(:processor_timings)
          @wall_time_ns = args[:wall_time_ns] if args.key?(:wall_time_ns)
        end
      end
      
      # Products-specific information about the entity. Next available tag: 16.
      class RepositoryWebrefProductMetadata
        include Google::Apis::Core::Hashable
      
        # Shopping product line ids (typically moka product line tag) of this entity.
        # Represents shopping product lines, such as iPhone or Canon EOS. Typically, we
        # expect only one id. But keeping repeated, in case we want to merge or
        # aggregate product lines. Using int64, as tag_id in commerce/datastore/
        # processors/moka/proto/moka_annotations.proto.
        # Corresponds to the JSON property `productLineId`
        # @return [Array<Fixnum>]
        attr_accessor :product_line_id
      
        # Additional shopping identifiers related to an entity or IQL function call.
        # This must be passed along to the shopping backend (go/o4) to aid in
        # fulfillment. Because the shopping data models do not always line up 1-1 with
        # KG entities and are not always reconciled with each other, the message may
        # contain multiple ids. Next id: 8 LINT.IfChange
        # Corresponds to the JSON property `shoppingIds`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryShoppingIds]
        attr_accessor :shopping_ids
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # All unique variant cluster ids (shopping's GPCs) of this entity.
        # Corresponds to the JSON property `variantClusterId`
        # @return [Array<Fixnum>]
        attr_accessor :variant_cluster_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @product_line_id = args[:product_line_id] if args.key?(:product_line_id)
          @shopping_ids = args[:shopping_ids] if args.key?(:shopping_ids)
          @type = args[:type] if args.key?(:type)
          @variant_cluster_id = args[:variant_cluster_id] if args.key?(:variant_cluster_id)
        end
      end
      
      # Identifies a set of NavBoost queries in the CompositeDoc. Typically these
      # queries were collapsed by WebRef into a single query and they were treated by
      # the annotator as equivalent. They all contain the same mentions (at the same
      # offsets).
      class RepositoryWebrefQueryIndices
        include Google::Apis::Core::Hashable
      
        # The set of indices in the NavBoostQuery::features() array that belong to the
        # collapsed features.
        # Corresponds to the JSON property `featuresIndex`
        # @return [Array<Fixnum>]
        attr_accessor :features_index
      
        # The index of the query in NavBoostDocument::queries() array.
        # Corresponds to the JSON property `queriesIndex`
        # @return [Fixnum]
        attr_accessor :queries_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @features_index = args[:features_index] if args.key?(:features_index)
          @queries_index = args[:queries_index] if args.key?(:queries_index)
        end
      end
      
      # The fields hold "non-entity" annotations of text.
      class RepositoryWebrefRangeAnnotations
        include Google::Apis::Core::Hashable
      
        # The actual mentions. Note SegmentMentions contains some fields specific to
        # entity annotation, and those are typically not populated here.
        # Corresponds to the JSON property `segmentMentions`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMentions>]
        attr_accessor :segment_mentions
      
        # The type of ranges contained in this message.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @segment_mentions = args[:segment_mentions] if args.key?(:segment_mentions)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Metadata keeper for an annotated range of a segment. Next available tag: 3.
      class RepositoryWebrefRangeMetadata
        include Google::Apis::Core::Hashable
      
        # Start index of range (within the segment) being annotated.
        # Corresponds to the JSON property `beginOffset`
        # @return [Fixnum]
        attr_accessor :begin_offset
      
        # Number of tokens in the range being annotated.
        # Corresponds to the JSON property `tokenCount`
        # @return [Fixnum]
        attr_accessor :token_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin_offset = args[:begin_offset] if args.key?(:begin_offset)
          @token_count = args[:token_count] if args.key?(:token_count)
        end
      end
      
      # Encapsulates the textual mention spans extracted from a document, split per
      # token.
      class RepositoryWebrefRefconDocumentMentionSpans
        include Google::Apis::Core::Hashable
      
        # Per token mention spans.
        # Corresponds to the JSON property `mentionSpan`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefRefconMentionSpans>]
        attr_accessor :mention_span
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mention_span = args[:mention_span] if args.key?(:mention_span)
        end
      end
      
      # Describes a mention annotated by Webref in the given document.
      class RepositoryWebrefRefconMentionSpans
        include Google::Apis::Core::Hashable
      
        # Segment types in which the mention appears. Now deprecated, because we only
        # care about CONTENT segments.
        # Corresponds to the JSON property `segment`
        # @return [Array<String>]
        attr_accessor :segment
      
        # Fingerprinted tokens which form the mention span. We are using 32-bit instead
        # of usual 64bit fingerprints - this greatly reduces the memory footprint while
        # still keeping the chance of collision reasonably low for our specific use case
        # (1 in 4 billion).
        # Corresponds to the JSON property `shortToken`
        # @return [Array<Fixnum>]
        attr_accessor :short_token
      
        # Fingerprinted tokens which form the mention span.
        # Corresponds to the JSON property `token`
        # @return [Array<Fixnum>]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @segment = args[:segment] if args.key?(:segment)
          @short_token = args[:short_token] if args.key?(:short_token)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # Contains high level search query statistics of the document.
      class RepositoryWebrefRefconQueryStats
        include Google::Apis::Core::Hashable
      
        # Total query count for the document from all the query terms. Can be used to
        # estimate the popularity of the document.
        # Corresponds to the JSON property `aggregatedQueryCount`
        # @return [Float]
        attr_accessor :aggregated_query_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_query_count = args[:aggregated_query_count] if args.key?(:aggregated_query_count)
        end
      end
      
      # Encapsulates additional CDoc metadata needed by Refcon.
      class RepositoryWebrefRefconRefconDocumentMetadata
        include Google::Apis::Core::Hashable
      
        # Contains high level search query statistics of the document.
        # Corresponds to the JSON property `queryStats`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefRefconQueryStats]
        attr_accessor :query_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @query_stats = args[:query_stats] if args.key?(:query_stats)
        end
      end
      
      # Refcon name representation in split concepts sstable. This is a simplified
      # version of repository_webref.GlobalNameInfo.
      class RepositoryWebrefRefconRefconNameInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `idfScore`
        # @return [Float]
        attr_accessor :idf_score
      
        # 
        # Corresponds to the JSON property `isGeneratedName`
        # @return [Boolean]
        attr_accessor :is_generated_name
        alias_method :is_generated_name?, :is_generated_name
      
        # 
        # Corresponds to the JSON property `isI18nName`
        # @return [Boolean]
        attr_accessor :is_i18n_name
        alias_method :is_i18n_name?, :is_i18n_name
      
        # 
        # Corresponds to the JSON property `isStrongIdentifier`
        # @return [Boolean]
        attr_accessor :is_strong_identifier
        alias_method :is_strong_identifier?, :is_strong_identifier
      
        # 
        # Corresponds to the JSON property `isTranslatedName`
        # @return [Boolean]
        attr_accessor :is_translated_name
        alias_method :is_translated_name?, :is_translated_name
      
        # Languages of the name, unknown language is not kept. TODO(b/145976266) Don't
        # use the deprecated language enum.
        # Corresponds to the JSON property `language`
        # @return [Array<Fixnum>]
        attr_accessor :language
      
        # Name prior to use. We read this from the prior for the "unknown" language.
        # Corresponds to the JSON property `namePrior`
        # @return [Float]
        attr_accessor :name_prior
      
        # The normalized name.
        # Corresponds to the JSON property `normalizedName`
        # @return [String]
        attr_accessor :normalized_name
      
        # Filled only if different than normalized_name.
        # Corresponds to the JSON property `originalName`
        # @return [String]
        attr_accessor :original_name
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @idf_score = args[:idf_score] if args.key?(:idf_score)
          @is_generated_name = args[:is_generated_name] if args.key?(:is_generated_name)
          @is_i18n_name = args[:is_i18n_name] if args.key?(:is_i18n_name)
          @is_strong_identifier = args[:is_strong_identifier] if args.key?(:is_strong_identifier)
          @is_translated_name = args[:is_translated_name] if args.key?(:is_translated_name)
          @language = args[:language] if args.key?(:language)
          @name_prior = args[:name_prior] if args.key?(:name_prior)
          @normalized_name = args[:normalized_name] if args.key?(:normalized_name)
          @original_name = args[:original_name] if args.key?(:original_name)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Signals used for mining new reference pages, set by the reference-page-scorer
      # processor.
      class RepositoryWebrefReferencePageScores
        include Google::Apis::Core::Hashable
      
        # Stores score for later offline voting to choose reference pages. If zero, it's
        # not a good book reference page.
        # Corresponds to the JSON property `bookScore`
        # @return [Float]
        attr_accessor :book_score
      
        # Fraction of importance_ratio (IR) that is explained by this entity and implied
        # entities. E.g. a page about a song with IR 0.2 for the song and 0.5 for the
        # artist actually has explained_normalized_topicality 0.7 for the song.
        # Corresponds to the JSON property `explainedNormalizedTopicality`
        # @return [Float]
        attr_accessor :explained_normalized_topicality
      
        # The raw topicality score of the primary entity.
        # Corresponds to the JSON property `firstScore`
        # @return [Float]
        attr_accessor :first_score
      
        # Whether the primary entity has any "special" links. Currently a link is
        # considered special if it has a good implication probability and has no
        # negative disambiguation probability.
        # Corresponds to the JSON property `hasSpecialLinks`
        # @return [Boolean]
        attr_accessor :has_special_links
        alias_method :has_special_links?, :has_special_links
      
        # The median mentions core of the primary entity.
        # Corresponds to the JSON property `medianMentionScore`
        # @return [Float]
        attr_accessor :median_mention_score
      
        # The navboost token coverage ratio. All queries are taken into account.
        # Corresponds to the JSON property `navboostCoverage`
        # @return [Float]
        attr_accessor :navboost_coverage
      
        # Reference page score used to select the reference page owner.
        # Corresponds to the JSON property `referencePageScore`
        # @return [Float]
        attr_accessor :reference_page_score
      
        # The score used to sort reference pages for a given entity. This score tries to
        # assign higher scores to reference pages that are more useful to the model
        # building.
        # Corresponds to the JSON property `referencePageSelectionScore`
        # @return [Float]
        attr_accessor :reference_page_selection_score
      
        # True if the entity is selected as the reference page owner.
        # Corresponds to the JSON property `selected`
        # @return [Boolean]
        attr_accessor :selected
        alias_method :selected?, :selected
      
        # A score in [0, 1] which indicates the single topicness of the entity.
        # Corresponds to the JSON property `singleTopicness`
        # @return [Float]
        attr_accessor :single_topicness
      
        # This should have the same semantic as single_topicness, and should replace it
        # in the long term.
        # Corresponds to the JSON property `singleTopicnessV2`
        # @return [Float]
        attr_accessor :single_topicness_v2
      
        # =================================== Signals for the single topicness. Only
        # filled in for the primary (i.e., top ranked) entity. The title token coverage
        # ratio.
        # Corresponds to the JSON property `titleCoverage`
        # @return [Float]
        attr_accessor :title_coverage
      
        # The sum of raw topicality scores for all entities in this page.
        # Corresponds to the JSON property `totalSum`
        # @return [Float]
        attr_accessor :total_sum
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @book_score = args[:book_score] if args.key?(:book_score)
          @explained_normalized_topicality = args[:explained_normalized_topicality] if args.key?(:explained_normalized_topicality)
          @first_score = args[:first_score] if args.key?(:first_score)
          @has_special_links = args[:has_special_links] if args.key?(:has_special_links)
          @median_mention_score = args[:median_mention_score] if args.key?(:median_mention_score)
          @navboost_coverage = args[:navboost_coverage] if args.key?(:navboost_coverage)
          @reference_page_score = args[:reference_page_score] if args.key?(:reference_page_score)
          @reference_page_selection_score = args[:reference_page_selection_score] if args.key?(:reference_page_selection_score)
          @selected = args[:selected] if args.key?(:selected)
          @single_topicness = args[:single_topicness] if args.key?(:single_topicness)
          @single_topicness_v2 = args[:single_topicness_v2] if args.key?(:single_topicness_v2)
          @title_coverage = args[:title_coverage] if args.key?(:title_coverage)
          @total_sum = args[:total_sum] if args.key?(:total_sum)
        end
      end
      
      # A single Mention within a segment as defined by SegmentMentions.SegmentType
      class RepositoryWebrefSegmentMention
        include Google::Apis::Core::Hashable
      
        # Multiple entities can be identified on a document or query. Each entity can be
        # mentioned several times in different positions on the document or query. This
        # message describes a single mention of the entity. Note that a mention can be
        # either explicit or implicit mentions. All explicit mentions refer to exact
        # range in the document where the entity occurred, but implicit mentions may or
        # may not have corresponding range. Next available tag number: 40
        # Corresponds to the JSON property `mention`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefMention]
        attr_accessor :mention
      
        # 
        # Corresponds to the JSON property `segmentType`
        # @return [String]
        attr_accessor :segment_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mention = args[:mention] if args.key?(:mention)
          @segment_type = args[:segment_type] if args.key?(:segment_type)
        end
      end
      
      # Annotations of a single docjoin segment. A CDoc has several distinct data
      # types which we call "segments" (see SegmentType for complete list).
      # SegmentMentions contains all the mentions for a given (document, segment) pair.
      # For queries there is only a single CONTENT segment.
      class RepositoryWebrefSegmentMentions
        include Google::Apis::Core::Hashable
      
        # A list of all the places the entity in question was annotated within this
        # segment. The (indexing.annotations.goldmine) option is for Goldmine
        # AnnotationsFinder to include Mention only when segment_type="CONTENT"
        # Corresponds to the JSON property `mention`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefMention>]
        attr_accessor :mention
      
        # 
        # Corresponds to the JSON property `segmentType`
        # @return [String]
        attr_accessor :segment_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mention = args[:mention] if args.key?(:mention)
          @segment_type = args[:segment_type] if args.key?(:segment_type)
        end
      end
      
      # A date range for an entity. E.g. lifespan of a person, release date of a movie,
      # ...
      class RepositoryWebrefSemanticDateRange
        include Google::Apis::Core::Hashable
      
        # Indicates how confident we are this extracted range is relevant to a document (
        # document to be infered from context).
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # End date extracted from the entity along end_source_property.
        # Corresponds to the JSON property `end`
        # @return [String]
        attr_accessor :end
      
        # KG-property that links the entity to the end date.
        # Corresponds to the JSON property `endSourceProperty`
        # @return [String]
        attr_accessor :end_source_property
      
        # Entity from which this range was extracted.
        # Corresponds to the JSON property `sourceEntityMid`
        # @return [String]
        attr_accessor :source_entity_mid
      
        # Start date extracted from the entity along start_source_property.
        # Corresponds to the JSON property `start`
        # @return [String]
        attr_accessor :start
      
        # KG-property that links the entity to the start date.
        # Corresponds to the JSON property `startSourceProperty`
        # @return [String]
        attr_accessor :start_source_property
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @end = args[:end] if args.key?(:end)
          @end_source_property = args[:end_source_property] if args.key?(:end_source_property)
          @source_entity_mid = args[:source_entity_mid] if args.key?(:source_entity_mid)
          @start = args[:start] if args.key?(:start)
          @start_source_property = args[:start_source_property] if args.key?(:start_source_property)
        end
      end
      
      # Represents a subpart of the anchor data of the docjoins, but is much smaller.
      # When we build this SimplifiedAnchor from the anchor data of the docjoins, by
      # specifying the option separate_onsite_anchors to SimplifiedAnchorsBuilder, we
      # can also separate the onsite anchors from the other (offdomain) anchors. So
      # onsite anchors and offdomain anchors will have their own count, score,
      # normalized score, and total volume (.._offdomain and .._onsite fields). For
      # example, if there are 10 onsite anchors and 20 offdomain anchors for the
      # anchor text "mountain view", then the count_from_onsite is 10, and the
      # count_from_offdomain is 20 when we separate onsite anchors out. Otherwise (if
      # we don't separate onsite anchors), the count is 30 (10 + 20) and we don't have
      # values in the .._offdomain and .._onsite fields.
      class RepositoryWebrefSimplifiedAnchor
        include Google::Apis::Core::Hashable
      
        # Identifies a set of anchors in the CompositeDoc. Typically these anchors were
        # collapsed by WebRef into a single anchor and they were treated by the
        # annotator as equivalent. They all contain the same mentions (at the same
        # offsets).
        # Corresponds to the JSON property `anchorIndices`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAnchorIndices]
        attr_accessor :anchor_indices
      
        # Next available tag: 8.
        # Corresponds to the JSON property `anchorText`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefLocalizedString]
        attr_accessor :anchor_text
      
        # The number of times we see this anchor text.
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Count, score, normalized score, and volume of offdomain anchors.
        # Corresponds to the JSON property `countFromOffdomain`
        # @return [Fixnum]
        attr_accessor :count_from_offdomain
      
        # Count, score, normalized score, and volume of onsite anchors.
        # Corresponds to the JSON property `countFromOnsite`
        # @return [Fixnum]
        attr_accessor :count_from_onsite
      
        # The normalized score, which is computed from the score and the total_volume.
        # Corresponds to the JSON property `normalizedScore`
        # @return [Float]
        attr_accessor :normalized_score
      
        # 
        # Corresponds to the JSON property `normalizedScoreFromOffdomain`
        # @return [Float]
        attr_accessor :normalized_score_from_offdomain
      
        # 
        # Corresponds to the JSON property `normalizedScoreFromOnsite`
        # @return [Float]
        attr_accessor :normalized_score_from_onsite
      
        # The sum/aggregate of the anchor scores that have the same text.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # The sum/aggregate of the anchor scores that direct to a fragment and have the
        # same text.
        # Corresponds to the JSON property `scoreFromFragment`
        # @return [Float]
        attr_accessor :score_from_fragment
      
        # 
        # Corresponds to the JSON property `scoreFromOffdomain`
        # @return [Float]
        attr_accessor :score_from_offdomain
      
        # 
        # Corresponds to the JSON property `scoreFromOffdomainFragment`
        # @return [Float]
        attr_accessor :score_from_offdomain_fragment
      
        # 
        # Corresponds to the JSON property `scoreFromOnsite`
        # @return [Float]
        attr_accessor :score_from_onsite
      
        # 
        # Corresponds to the JSON property `scoreFromOnsiteFragment`
        # @return [Float]
        attr_accessor :score_from_onsite_fragment
      
        # The sum/aggregate of the anchor scores that direct to a different wiki title
        # and have the same text. NOTE: url direct to a fragment score is not included
        # in this value.
        # Corresponds to the JSON property `scoreFromRedirect`
        # @return [Float]
        attr_accessor :score_from_redirect
      
        # The total score volume used for normalization.
        # Corresponds to the JSON property `totalVolume`
        # @return [Float]
        attr_accessor :total_volume
      
        # 
        # Corresponds to the JSON property `totalVolumeFromOffdomain`
        # @return [Float]
        attr_accessor :total_volume_from_offdomain
      
        # 
        # Corresponds to the JSON property `totalVolumeFromOnsite`
        # @return [Float]
        attr_accessor :total_volume_from_onsite
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_indices = args[:anchor_indices] if args.key?(:anchor_indices)
          @anchor_text = args[:anchor_text] if args.key?(:anchor_text)
          @count = args[:count] if args.key?(:count)
          @count_from_offdomain = args[:count_from_offdomain] if args.key?(:count_from_offdomain)
          @count_from_onsite = args[:count_from_onsite] if args.key?(:count_from_onsite)
          @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
          @normalized_score_from_offdomain = args[:normalized_score_from_offdomain] if args.key?(:normalized_score_from_offdomain)
          @normalized_score_from_onsite = args[:normalized_score_from_onsite] if args.key?(:normalized_score_from_onsite)
          @score = args[:score] if args.key?(:score)
          @score_from_fragment = args[:score_from_fragment] if args.key?(:score_from_fragment)
          @score_from_offdomain = args[:score_from_offdomain] if args.key?(:score_from_offdomain)
          @score_from_offdomain_fragment = args[:score_from_offdomain_fragment] if args.key?(:score_from_offdomain_fragment)
          @score_from_onsite = args[:score_from_onsite] if args.key?(:score_from_onsite)
          @score_from_onsite_fragment = args[:score_from_onsite_fragment] if args.key?(:score_from_onsite_fragment)
          @score_from_redirect = args[:score_from_redirect] if args.key?(:score_from_redirect)
          @total_volume = args[:total_volume] if args.key?(:total_volume)
          @total_volume_from_offdomain = args[:total_volume_from_offdomain] if args.key?(:total_volume_from_offdomain)
          @total_volume_from_onsite = args[:total_volume_from_onsite] if args.key?(:total_volume_from_onsite)
        end
      end
      
      # 
      class RepositoryWebrefSimplifiedAnchors
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchor`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedAnchor>]
        attr_accessor :anchor
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor = args[:anchor] if args.key?(:anchor)
        end
      end
      
      # Represents an information which is very close to composite doc, but compresses
      # how the anchors are represented to save space. Next available tag: 15.
      class RepositoryWebrefSimplifiedCompositeDoc
        include Google::Apis::Core::Hashable
      
        # The composite doc anchors trimmed and transformed in a smaller data structure
        # and aggregated (if they have the exact same text).
        # Corresponds to the JSON property `anchors`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedAnchors]
        attr_accessor :anchors
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `cdocContainer`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :cdoc_container
      
        # Encapsulates the textual mention spans extracted from a document, split per
        # token.
        # Corresponds to the JSON property `documentMentionSpans`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefRefconDocumentMentionSpans]
        attr_accessor :document_mention_spans
      
        # Proto with metadata related to why a particular cdoc was selected for an
        # entityjoin.
        # Corresponds to the JSON property `matchingMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefPreprocessingUrlMatchingMetadata]
        attr_accessor :matching_metadata
      
        # 
        # Corresponds to the JSON property `obsoleteAnchorsWithoutInterwiki`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSimplifiedAnchors]
        attr_accessor :obsolete_anchors_without_interwiki
      
        # Encapsulates additional CDoc metadata needed by Refcon.
        # Corresponds to the JSON property `refconDocumentMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefRefconRefconDocumentMetadata]
        attr_accessor :refcon_document_metadata
      
        # 
        # Corresponds to the JSON property `sourceSnapshotType`
        # @return [String]
        attr_accessor :source_snapshot_type
      
        # The URL, populated independently of whether we have a CompositeDoc proto. If
        # the cdoc exists, the url is the same as CompositeDoc.doc.url.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `webrefOutlinks`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :webref_outlinks
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchors = args[:anchors] if args.key?(:anchors)
          @cdoc_container = args[:cdoc_container] if args.key?(:cdoc_container)
          @document_mention_spans = args[:document_mention_spans] if args.key?(:document_mention_spans)
          @matching_metadata = args[:matching_metadata] if args.key?(:matching_metadata)
          @obsolete_anchors_without_interwiki = args[:obsolete_anchors_without_interwiki] if args.key?(:obsolete_anchors_without_interwiki)
          @refcon_document_metadata = args[:refcon_document_metadata] if args.key?(:refcon_document_metadata)
          @source_snapshot_type = args[:source_snapshot_type] if args.key?(:source_snapshot_type)
          @url = args[:url] if args.key?(:url)
          @webref_outlinks = args[:webref_outlinks] if args.key?(:webref_outlinks)
        end
      end
      
      # LINT.IfChange Some document segments may consist of multiple sub-segments (e.g.
      # a document might have multiple anchors or navboost queries). SubSegmentIndex
      # contains all information needed to identify the sub-segment (e.g. specific
      # query, query feature or or anchor) where the mention is located.
      class RepositoryWebrefSubSegmentIndex
        include Google::Apis::Core::Hashable
      
        # Identifies a set of anchors in the CompositeDoc. Typically these anchors were
        # collapsed by WebRef into a single anchor and they were treated by the
        # annotator as equivalent. They all contain the same mentions (at the same
        # offsets).
        # Corresponds to the JSON property `anchorIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefAnchorIndices]
        attr_accessor :anchor_index
      
        # Identifies the segment index for Webref SegmentTypes not covered by other *
        # Indices messages.
        # Corresponds to the JSON property `genericIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefGenericIndices]
        attr_accessor :generic_index
      
        # Identifies a set of Image NavBoost queries in the CompositeDoc. Each
        # CompositeDoc can contain several images, so we store the image index from the
        # CompositeDoc::doc_images with the index of the particular query inside
        # ImageData::image_data_navboost.
        # Corresponds to the JSON property `imageQueryIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefImageQueryIndices]
        attr_accessor :image_query_index
      
        # Identifies the source of Spore segments in the CompositeDoc.
        # Corresponds to the JSON property `jgnIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefJuggernautIndices]
        attr_accessor :jgn_index
      
        # Identifies a set of NavBoost queries in the CompositeDoc. Typically these
        # queries were collapsed by WebRef into a single query and they were treated by
        # the annotator as equivalent. They all contain the same mentions (at the same
        # offsets).
        # Corresponds to the JSON property `queryIndex`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefQueryIndices]
        attr_accessor :query_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_index = args[:anchor_index] if args.key?(:anchor_index)
          @generic_index = args[:generic_index] if args.key?(:generic_index)
          @image_query_index = args[:image_query_index] if args.key?(:image_query_index)
          @jgn_index = args[:jgn_index] if args.key?(:jgn_index)
          @query_index = args[:query_index] if args.key?(:query_index)
        end
      end
      
      # Each SupportTransferRule proto represents a single STBR (go/stbr) rule. These
      # rules are attached to entities (called STBR sources). Each rule attached to an
      # STBR source talks about a single entity (called STBR target). If an STBR
      # source gets annotated, its attached rules result in creation of annotations
      # for corresponding STBR targets. An STBR source might have more than one STBR
      # rule attached to it. STBR rules allow us to address cases where otherwise
      # annotations for what people say do not match what people mean. For example, a
      # query [france vs spain] uses names of countries while in sports context the
      # query would actually be about national sports teams of those countries. In
      # other words, STBR rules have meaning of "in this particular context (see
      # domain + target_collection fields below) a mention of this particular STBR
      # source (the entity this rule is attached to) actually should be treated as
      # that STBR target (see the target field below)". To describe the meaning of
      # STBR settings (proto fields below), we are going to use a hypothetical example
      # of an STBR rule making Search stack treat annotations for /m/France as
      # annotations for /m/Louis_XIV, since he was the one saying "I am the state". In
      # this example /m/France is going to be the STBR source. NOTICE: When adding new
      # fields also update client::support_transfer::SortDeterministically to ensure
      # deterministic sorting of the SupportTransferRule objects. Next available tag:
      # 11. LINT.IfChange
      class RepositoryWebrefSupportTransferRule
        include Google::Apis::Core::Hashable
      
        # If set to true, allow STBR targets to trigger intents like ShowEntity that do
        # not have explicit lists of allowed collections, accepting entities with any
        # collections instead. This setting together with target_collection define what
        # intents are allowed to be triggered by the STBR target. Be careful with
        # setting this option to 'true', as in the case of our example the query [france]
        # would result in the knowledge panel for the monarch. Louis XIV might've
        # wanted such a behaviour, but you are probably not him.
        # Corresponds to the JSON property `allowWildcardIntents`
        # @return [Boolean]
        attr_accessor :allow_wildcard_intents
        alias_method :allow_wildcard_intents?, :allow_wildcard_intents
      
        # Name of Aqua grammar domain this STBR rule is restricted to. If the domain is
        # set to anything other than "default", the STBR rule is only going to result in
        # an annotation for the STBR target inside of the Aqua domain of the
        # corresponding name. If there is no such Aqua domain, the rule is going to be
        # ignored. The default value of string "default" for domain makes it possible
        # for the STBR rule to be used inside Loose Parser.
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        # Whether this rule points from an STBR target to its STBR source. This field is
        # an internal implementation detail that is not configurable by customers.
        # Inside QRewrite we have to keep track of relations between entities. Among
        # other things it is useful to remember which STBR target a given STBR source
        # came from. For that purpose we attach an STBR proto to the STBR target,
        # reversing the rule, i.e, putting STBR source's mid as the target etc. For this
        # reversed rule we set is_reverse_link to true.
        # Corresponds to the JSON property `isReverseLink`
        # @return [Boolean]
        attr_accessor :is_reverse_link
        alias_method :is_reverse_link?, :is_reverse_link
      
        # STBR doesn't just create annotations for STBR targets. It also can modify
        # search result support (useful in PostRef) in order for web pages supporting
        # the STBR source to also support the STBR target. Otherwise in PostRef
        # annotations for STBR targets are going to be demoted, resulting in the STBR
        # rule potentially not affecting anything. Regarding treatment of this result
        # support, STBR has 3 possible modes that for historical reasons are represented
        # as 2 booleans - mentions_only and support_share. No more than one of these
        # bools is supposed to be set to 'true' for a rule. Setting both to 'true' at
        # once would lead to undefined behaviour. These 3 modes are: 1. (default) All
        # the support gets assigned to the STBR target. The STBR source is left with no
        # support. To be extra sure, interpretations that still managed to get triggered
        # by STBR source are suppressed later unless STBR target has no interpretations
        # of its own. In other words this is "we are pretty sure that if France is
        # mentioned in a query that might be talking about a person, we want to treat
        # the query as if it is about Louis XIV". This mode would result in a query [age
        # of france] being treated as [age of louis xiv], while [population of france]
        # still being about the country unless [population of louis xiv] matches some
        # intents. For this mode both mentions_only and support_share should be set to '
        # false'. 2. Support is shared between STBR source ans STBR target. That allows
        # both STBR source and STBR target to trigger some intents with KScorer later
        # deciding which intent is better. In other words, this is "when it is not clear
        # whether a query is about France of Louis XIV, provide KScorer with both
        # options and let it decide". For this mode mentions_only should be set to '
        # false' and support_share should be set to 'true'. 3. While annotations for the
        # STBR target are created, no support is given to those annotations. This is
        # more like "we are mostly sure that a mention of France is about the country,
        # but just for a rare case it is about the monarch, we would like to have Louis
        # XIV annotated". For this mode mentions_only should be set to 'true' and
        # support_share should be set to 'false'.
        # Corresponds to the JSON property `mentionsOnly`
        # @return [Boolean]
        attr_accessor :mentions_only
        alias_method :mentions_only?, :mentions_only
      
        # 
        # Corresponds to the JSON property `supportShare`
        # @return [Boolean]
        attr_accessor :support_share
        alias_method :support_share?, :support_share
      
        # Mid of the STBR target, e.g. "/m/04pwg" for Louis XIV.
        # Corresponds to the JSON property `target`
        # @return [String]
        attr_accessor :target
      
        # See go/kg-collections
        # Corresponds to the JSON property `targetCollection`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefKgCollection]
        attr_accessor :target_collection
      
        # The user country this rule is for. Rules only take effect if the country is
        # not set, set to an empty string or matches the country that is detected for
        # the user - like the country user issued the query from. E.g. "US" for the
        # United States.
        # Corresponds to the JSON property `userCountry`
        # @return [String]
        attr_accessor :user_country
      
        # User language this rule is for. Rules only take effect if the language is not
        # set, set to an empty string or matches the language that is detected for the
        # user's query. E.g. set it to "en" if you want the STBR rule to only work for
        # users working from computers with English being set as the main language. Keep
        # it unset if you want the rule not to depend on local language settings of user'
        # s computer.
        # Corresponds to the JSON property `userLanguage`
        # @return [String]
        attr_accessor :user_language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @allow_wildcard_intents = args[:allow_wildcard_intents] if args.key?(:allow_wildcard_intents)
          @domain = args[:domain] if args.key?(:domain)
          @is_reverse_link = args[:is_reverse_link] if args.key?(:is_reverse_link)
          @mentions_only = args[:mentions_only] if args.key?(:mentions_only)
          @support_share = args[:support_share] if args.key?(:support_share)
          @target = args[:target] if args.key?(:target)
          @target_collection = args[:target_collection] if args.key?(:target_collection)
          @user_country = args[:user_country] if args.key?(:user_country)
          @user_language = args[:user_language] if args.key?(:user_language)
        end
      end
      
      # 
      class RepositoryWebrefTaskData
        include Google::Apis::Core::Hashable
      
        # Signals about quality of data that was shown to raters. If document/query and
        # concept description are readable.
        # Corresponds to the JSON property `isReadable`
        # @return [Boolean]
        attr_accessor :is_readable
        alias_method :is_readable?, :is_readable
      
        # 
        # Corresponds to the JSON property `itemId`
        # @return [Fixnum]
        attr_accessor :item_id
      
        # 
        # Corresponds to the JSON property `projectId`
        # @return [Fixnum]
        attr_accessor :project_id
      
        # Information about what the raters saw, how the information was presented to
        # them, or how they interacted with the task. Next id: 6
        # Corresponds to the JSON property `taskDetails`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTaskDetails]
        attr_accessor :task_details
      
        # 
        # Corresponds to the JSON property `taskId`
        # @return [Fixnum]
        attr_accessor :task_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_readable = args[:is_readable] if args.key?(:is_readable)
          @item_id = args[:item_id] if args.key?(:item_id)
          @project_id = args[:project_id] if args.key?(:project_id)
          @task_details = args[:task_details] if args.key?(:task_details)
          @task_id = args[:task_id] if args.key?(:task_id)
        end
      end
      
      # Information about what the raters saw, how the information was presented to
      # them, or how they interacted with the task. Next id: 6
      class RepositoryWebrefTaskDetails
        include Google::Apis::Core::Hashable
      
        # The id of the experiment in case we are dealing with a refx data experiment.
        # Should only be set in case of data experiments to gather topicality ratings,
        # in order to allow separating these ratings from regular ratings.
        # Corresponds to the JSON property `experimentId`
        # @return [String]
        attr_accessor :experiment_id
      
        # 
        # Corresponds to the JSON property `lastSubmitTimestamp`
        # @return [Fixnum]
        attr_accessor :last_submit_timestamp
      
        # 
        # Corresponds to the JSON property `topicDescription`
        # @return [String]
        attr_accessor :topic_description
      
        # 
        # Corresponds to the JSON property `topicName`
        # @return [String]
        attr_accessor :topic_name
      
        # 
        # Corresponds to the JSON property `topicUrl`
        # @return [String]
        attr_accessor :topic_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @experiment_id = args[:experiment_id] if args.key?(:experiment_id)
          @last_submit_timestamp = args[:last_submit_timestamp] if args.key?(:last_submit_timestamp)
          @topic_description = args[:topic_description] if args.key?(:topic_description)
          @topic_name = args[:topic_name] if args.key?(:topic_name)
          @topic_url = args[:topic_url] if args.key?(:topic_url)
        end
      end
      
      # Entity-level classification. Template: experimental/topref/eval_entities/
      # template.jhtml
      class RepositoryWebrefToprefListMembership
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `member`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefToprefListMembershipListMember>]
        attr_accessor :member
      
        # 
        # Corresponds to the JSON property `taskData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTaskData]
        attr_accessor :task_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @member = args[:member] if args.key?(:member)
          @task_data = args[:task_data] if args.key?(:task_data)
        end
      end
      
      # 
      class RepositoryWebrefToprefListMembershipListMember
        include Google::Apis::Core::Hashable
      
        # The identifier of a WebrefEntity (see webref-entities.proto). IMPORTANT:
        # Please consider reading this proto through GetWebrefEntityMid() in webref-
        # entities-util.h, because this proto may: a) contain both freebase_mid and
        # concept_id (this is frequently the case to avoid breaking downstream clients),
        # b) only contain freebase_mid or only contain concept_id (as the other one is
        # technically redundant), c) contain neither of them or be missing entirely (
        # potentially in future).
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityId]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `isMember`
        # @return [String]
        attr_accessor :is_member
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @is_member = args[:is_member] if args.key?(:is_member)
        end
      end
      
      # Top-level page classification. Template: experimental/topref/eval_main/
      # template.jhtml
      class RepositoryWebrefToprefPageClassification
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isList`
        # @return [String]
        attr_accessor :is_list
      
        # 
        # Corresponds to the JSON property `isListTypeCorrect`
        # @return [String]
        attr_accessor :is_list_type_correct
      
        # 
        # Corresponds to the JSON property `isRanking`
        # @return [String]
        attr_accessor :is_ranking
      
        # 
        # Corresponds to the JSON property `isToplist`
        # @return [String]
        attr_accessor :is_toplist
      
        # A string generated based on the main collection of the list. E.g., /collection/
        # geo/restaurant => "Restaurants" retrieved by following the /base/schemastaging/
        # context_name/plural in KG.
        # Corresponds to the JSON property `listType`
        # @return [String]
        attr_accessor :list_type
      
        # "repeated" because we potentially evaluate several (up to 5) title candidates
        # for the page.
        # Corresponds to the JSON property `ratedTitle`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefToprefPageClassificationRatedTitle>]
        attr_accessor :rated_title
      
        # 
        # Corresponds to the JSON property `taskData`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTaskData]
        attr_accessor :task_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_list = args[:is_list] if args.key?(:is_list)
          @is_list_type_correct = args[:is_list_type_correct] if args.key?(:is_list_type_correct)
          @is_ranking = args[:is_ranking] if args.key?(:is_ranking)
          @is_toplist = args[:is_toplist] if args.key?(:is_toplist)
          @list_type = args[:list_type] if args.key?(:list_type)
          @rated_title = args[:rated_title] if args.key?(:rated_title)
          @task_data = args[:task_data] if args.key?(:task_data)
        end
      end
      
      # 
      class RepositoryWebrefToprefPageClassificationRatedTitle
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `isGood`
        # @return [String]
        attr_accessor :is_good
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_good = args[:is_good] if args.key?(:is_good)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class RepositoryWebrefTripleAnnotation
        include Google::Apis::Core::Hashable
      
        # Triple annotation confidence_score (value between 0 and 1). Higher values
        # correspond to higher confidence.
        # Corresponds to the JSON property `confidenceScore`
        # @return [Float]
        attr_accessor :confidence_score
      
        # The information in this triple is implied by other triple(s) in the document.
        # Corresponds to the JSON property `isImplied`
        # @return [Boolean]
        attr_accessor :is_implied
        alias_method :is_implied?, :is_implied
      
        # Set to true if this triple is present in the webref model as either a link or
        # property value. This implies that the information is in the Knowledge Graph.
        # Note that it can happen that a triple is in KG but not present in the webref
        # model.
        # Corresponds to the JSON property `kgVerified`
        # @return [Boolean]
        attr_accessor :kg_verified
        alias_method :kg_verified?, :kg_verified
      
        # Occurrences of the triple on the document
        # Corresponds to the JSON property `mentions`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefTripleMention>]
        attr_accessor :mentions
      
        # The mid of the predicate kg-property(-ies). In order, in the case of multihop
        # links.
        # Corresponds to the JSON property `predMid`
        # @return [Array<Fixnum>]
        attr_accessor :pred_mid
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `stuff`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :stuff
      
        # A Triple is a representation of data with a Subject, a Predicate, and an
        # Object, For example: (Triple, IS-A, "data representation"). Triples are a very
        # good representation of data where the relationship between data points is
        # significant, because the Object of a Triple can be the Subject of another
        # Triple: (Triple, HAS-A, Subject) (Subject, IS-A, "Term of a proposition") The
        # ease with which Triples can represent relationships makes them an excellent
        # candidate for representing graphs. Next id: 21
        # Corresponds to the JSON property `triple`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeGraphTriple]
        attr_accessor :triple
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
          @is_implied = args[:is_implied] if args.key?(:is_implied)
          @kg_verified = args[:kg_verified] if args.key?(:kg_verified)
          @mentions = args[:mentions] if args.key?(:mentions)
          @pred_mid = args[:pred_mid] if args.key?(:pred_mid)
          @stuff = args[:stuff] if args.key?(:stuff)
          @triple = args[:triple] if args.key?(:triple)
        end
      end
      
      # Represents a collection of triples annotated by Webref/Webit. Included in
      # WebrefEntities
      class RepositoryWebrefTripleAnnotations
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefTripleAnnotation>]
        attr_accessor :annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotations = args[:annotations] if args.key?(:annotations)
        end
      end
      
      # 
      class RepositoryWebrefTripleMention
        include Google::Apis::Core::Hashable
      
        # A single Mention within a segment as defined by SegmentMentions.SegmentType
        # Corresponds to the JSON property `predMention`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMention]
        attr_accessor :pred_mention
      
        # The [begin, end) byte offset of the document scope where this triple was
        # annotated. This corresponds to a table row or a text sentence where the triple
        # was identified. The sub_mention can be outside the scope when the subject is
        # inferred from the table title.
        # Corresponds to the JSON property `scopeBegin`
        # @return [Fixnum]
        attr_accessor :scope_begin
      
        # 
        # Corresponds to the JSON property `scopeEnd`
        # @return [Fixnum]
        attr_accessor :scope_end
      
        # Fingerprint2011 of space-joined SAFT tokens in the scope.
        # Corresponds to the JSON property `scopeFprint`
        # @return [Fixnum]
        attr_accessor :scope_fprint
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `stuff`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :stuff
      
        # A single Mention within a segment as defined by SegmentMentions.SegmentType
        # Corresponds to the JSON property `subMention`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMention]
        attr_accessor :sub_mention
      
        # A single Mention within a segment as defined by SegmentMentions.SegmentType
        # Corresponds to the JSON property `valueMention`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefSegmentMention]
        attr_accessor :value_mention
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pred_mention = args[:pred_mention] if args.key?(:pred_mention)
          @scope_begin = args[:scope_begin] if args.key?(:scope_begin)
          @scope_end = args[:scope_end] if args.key?(:scope_end)
          @scope_fprint = args[:scope_fprint] if args.key?(:scope_fprint)
          @stuff = args[:stuff] if args.key?(:stuff)
          @sub_mention = args[:sub_mention] if args.key?(:sub_mention)
          @value_mention = args[:value_mention] if args.key?(:value_mention)
        end
      end
      
      # This proto is filled with n-gram data during model building.
      class RepositoryWebrefUniversalNgramData
        include Google::Apis::Core::Hashable
      
        # IDF of the n-gram.
        # Corresponds to the JSON property `idf`
        # @return [Float]
        attr_accessor :idf
      
        # Probability that the n-gram is a plural form of a word. This information is
        # extracted from SAFT annotations of queries. See HasPluralProperty().
        # Corresponds to the JSON property `pluralProb`
        # @return [Float]
        attr_accessor :plural_prob
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @idf = args[:idf] if args.key?(:idf)
          @plural_prob = args[:plural_prob] if args.key?(:plural_prob)
        end
      end
      
      # Detailed statistics about the annotations in the document. Contains, for
      # example, the number of ranges with name matches, the number of entities
      # matched, and the number of entities with mentions. This information can be
      # used to tune some WebRef-internal scoring functions based on existing
      # annotations (e.g., document-length normalization in global link support). Next
      # available tag: 10.
      class RepositoryWebrefWebrefAnnotationStats
        include Google::Apis::Core::Hashable
      
        # The relative weight of the document, used when aggregating information from
        # multiple documents.
        # Corresponds to the JSON property `docWeight`
        # @return [Float]
        attr_accessor :doc_weight
      
        # Extracted n-grams context scores (in cdoc language, weighted by doc_weight)
        # output if webref_populate_annotation_ngrams is enabled.
        # Corresponds to the JSON property `ngramContext`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefNgramContext>]
        attr_accessor :ngram_context
      
        # The total number of candidates.
        # Corresponds to the JSON property `numCandidates`
        # @return [Fixnum]
        attr_accessor :num_candidates
      
        # The total number of concepts with at least 1 candidate.
        # Corresponds to the JSON property `numConceptsWithCandidates`
        # @return [Fixnum]
        attr_accessor :num_concepts_with_candidates
      
        # The total number of concepts with at least 1 mention.
        # Corresponds to the JSON property `numConceptsWithMentions`
        # @return [Fixnum]
        attr_accessor :num_concepts_with_mentions
      
        # The total number of RangeData objects with at least one candidate.
        # Corresponds to the JSON property `numRangesWithCandidates`
        # @return [Fixnum]
        attr_accessor :num_ranges_with_candidates
      
        # Statistics for each token type.
        # Corresponds to the JSON property `statsPerType`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotationStatsPerType>]
        attr_accessor :stats_per_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_weight = args[:doc_weight] if args.key?(:doc_weight)
          @ngram_context = args[:ngram_context] if args.key?(:ngram_context)
          @num_candidates = args[:num_candidates] if args.key?(:num_candidates)
          @num_concepts_with_candidates = args[:num_concepts_with_candidates] if args.key?(:num_concepts_with_candidates)
          @num_concepts_with_mentions = args[:num_concepts_with_mentions] if args.key?(:num_concepts_with_mentions)
          @num_ranges_with_candidates = args[:num_ranges_with_candidates] if args.key?(:num_ranges_with_candidates)
          @stats_per_type = args[:stats_per_type] if args.key?(:stats_per_type)
        end
      end
      
      # Annotation metadata for an individual entity.
      class RepositoryWebrefWebrefAttachmentMetadata
        include Google::Apis::Core::Hashable
      
        # Oyster Feature Type.
        # Corresponds to the JSON property `featureType`
        # @return [String]
        attr_accessor :feature_type
      
        # Indicates which entity this message belongs to: encoded_mid[index].
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # Latitude and longitude of the location. Same format as geostore.PointProto.
        # Corresponds to the JSON property `latE7`
        # @return [Fixnum]
        attr_accessor :lat_e7
      
        # 
        # Corresponds to the JSON property `lngE7`
        # @return [Fixnum]
        attr_accessor :lng_e7
      
        # A globally unique identifier associated with each feature. We use 128-bit
        # identifiers so that we have lots of bits available to distinguish between
        # features. The feature id currently consists of a 64-bit "cell id" that **
        # sometimes** corresponds to the approximate centroid of the feature, plus a 64-
        # bit fingerprint of other identifying information. See more on each respective
        # field in its comments. Feature ids are first assigned when the data is created
        # in MapFacts. After initial creation of the feature, they are immutable. This
        # means that the only properties that you should rely on are that they are
        # unique, and that cell_ids often - but not always - preserve spatial locality.
        # The degree of locality varies as the feature undergoes geometry changes, and
        # should not in general be considered a firm guarantee of the location of any
        # particular feature. In fact, some locationless features have randomized cell
        # IDs! Consumers of FeatureProtos from Mapfacts are guaranteed that fprints in
        # the id field of features will be globally unique. Using the fprint allows
        # consumers who don't need the spatial benefit of cell ids to uniquely identify
        # features in a 64-bit address space. This property is not guaranteed for other
        # sources of FeatureProtos.
        # Corresponds to the JSON property `oysterId`
        # @return [Google::Apis::ContentwarehouseV1::GeostoreFeatureIdProto]
        attr_accessor :oyster_id
      
        # This field is populated for at most one entity. If it is populated, it
        # indicates how confident we are to claim that the page is only about this
        # entity (either it's an official web presence of the entity, or something like
        # a wikipedia page about the entity). For space reasons this is represented as a
        # fixed-point integer with two decimal points precision. Convert it to the
        # interval [0,1] using the following formula: float single_topicness =
        # single_topicness_e2 / 100.f
        # Corresponds to the JSON property `singleTopicnessE2`
        # @return [Fixnum]
        attr_accessor :single_topicness_e2
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @index = args[:index] if args.key?(:index)
          @lat_e7 = args[:lat_e7] if args.key?(:lat_e7)
          @lng_e7 = args[:lng_e7] if args.key?(:lng_e7)
          @oyster_id = args[:oyster_id] if args.key?(:oyster_id)
          @single_topicness_e2 = args[:single_topicness_e2] if args.key?(:single_topicness_e2)
        end
      end
      
      # All information that applies globally to the document. Next available tag: 11
      class RepositoryWebrefWebrefDocumentInfo
        include Google::Apis::Core::Hashable
      
        # Information about the document which is not produced by webref, typically
        # copied from the docjoin. Next available tag: 15
        # Corresponds to the JSON property `documentMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefDocumentMetadata]
        attr_accessor :document_metadata
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `extensions`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :extensions
      
        # Information about the outlinks of an annotated document. Next available tag: 3
        # Corresponds to the JSON property `outlinkInfos`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefOutlinkInfos]
        attr_accessor :outlink_infos
      
        # The content (CONTENT section 0) as parsed by WebrefParser. Only used by //r/w/
        # postprocessing/idf/idf-pipeline for document ngram idf computation. Populated
        # when the annotator is run with webref_populate_parsed_content Each
        # webref_parsed_content_sentence represents one sentence of the context where
        # saft annotations were used to determine the sentence boundaries. See r/w/
        # universal/processors/saft/saft-sentence-helper.h for details.
        # Corresponds to the JSON property `webrefParsedContentSentence`
        # @return [Array<String>]
        attr_accessor :webref_parsed_content_sentence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @document_metadata = args[:document_metadata] if args.key?(:document_metadata)
          @extensions = args[:extensions] if args.key?(:extensions)
          @outlink_infos = args[:outlink_infos] if args.key?(:outlink_infos)
          @webref_parsed_content_sentence = args[:webref_parsed_content_sentence] if args.key?(:webref_parsed_content_sentence)
        end
      end
      
      # Represents a collection of entities returned by the WebRef service. Next
      # available tag: 14.
      class RepositoryWebrefWebrefEntities
        include Google::Apis::Core::Hashable
      
        # Detailed statistics about the annotations in the document. Contains, for
        # example, the number of ranges with name matches, the number of entities
        # matched, and the number of entities with mentions. This information can be
        # used to tune some WebRef-internal scoring functions based on existing
        # annotations (e.g., document-length normalization in global link support). Next
        # available tag: 10.
        # Corresponds to the JSON property `annotationStats`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefAnnotationStats]
        attr_accessor :annotation_stats
      
        # Fingerprints checkpointing annotator stages, can be used to track the source
        # of diffs.
        # Corresponds to the JSON property `annotatorCheckpointFingerprints`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefAnnotatorCheckpointFprint>]
        attr_accessor :annotator_checkpoint_fingerprints
      
        # Categories of the document or query. This replaces the category_score found
        # under EntityAnnotations.
        # Corresponds to the JSON property `category`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefCategoryAnnotation>]
        attr_accessor :category
      
        # Dates ranges that are most relevant to the document. E.g. on a document about
        # Dune the 2021 movie, this might hold the release date of that movie.
        # Corresponds to the JSON property `dateRange`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefSemanticDateRange>]
        attr_accessor :date_range
      
        # All information that applies globally to the document. Next available tag: 11
        # Corresponds to the JSON property `documentInfo`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefDocumentInfo]
        attr_accessor :document_info
      
        # The annotated entities, with associated confidence scores and metadata. This
        # is the primary output of WebRef/QRef. In case of Webref output, entities are
        # sorted by decreasing topicality score.
        # Corresponds to the JSON property `entity`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntity>]
        attr_accessor :entity
      
        # These messages contain non-entity annotations of ranges in the document. This
        # might be used to hold part-of-speech annotations, stopword annotations, and
        # other range based information. The exclude_field option is for Goldmine
        # AnnotationsFinder to exclude ranged_annotations from retrieving annotation
        # entities
        # Corresponds to the JSON property `rangeAnnotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefRangeAnnotations>]
        attr_accessor :range_annotations
      
        # The status message returned by the annotator. Might not be populated on
        # success.
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefStatus]
        attr_accessor :status
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `stuff`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :stuff
      
        # Represents a collection of triples annotated by Webref/Webit. Included in
        # WebrefEntities
        # Corresponds to the JSON property `tripleAnnotations`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefTripleAnnotations]
        attr_accessor :triple_annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotation_stats = args[:annotation_stats] if args.key?(:annotation_stats)
          @annotator_checkpoint_fingerprints = args[:annotator_checkpoint_fingerprints] if args.key?(:annotator_checkpoint_fingerprints)
          @category = args[:category] if args.key?(:category)
          @date_range = args[:date_range] if args.key?(:date_range)
          @document_info = args[:document_info] if args.key?(:document_info)
          @entity = args[:entity] if args.key?(:entity)
          @range_annotations = args[:range_annotations] if args.key?(:range_annotations)
          @status = args[:status] if args.key?(:status)
          @stuff = args[:stuff] if args.key?(:stuff)
          @triple_annotations = args[:triple_annotations] if args.key?(:triple_annotations)
        end
      end
      
      # All information about a single entity available to WebRef. Next available tag:
      # 7
      class RepositoryWebrefWebrefEntity
        include Google::Apis::Core::Hashable
      
        # Information about links (e.g. implications) between the annotated entities.
        # Corresponds to the JSON property `annotatedRelationship`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityRelationship>]
        attr_accessor :annotated_relationship
      
        # All annotations for a given concept (in one document collection). Available
        # tags: [10-15], [19-]
        # Corresponds to the JSON property `annotations`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityAnnotations]
        attr_accessor :annotations
      
        # Information about the collections of this entity.
        # Corresponds to the JSON property `collections`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityCollections]
        attr_accessor :collections
      
        # Next available tag: 35. Represents all the information that we have for a
        # given entity.
        # Corresponds to the JSON property `entityJoin`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityJoin]
        attr_accessor :entity_join
      
        # The identifier of a WebrefEntity (see webref-entities.proto). IMPORTANT:
        # Please consider reading this proto through GetWebrefEntityMid() in webref-
        # entities-util.h, because this proto may: a) contain both freebase_mid and
        # concept_id (this is frequently the case to avoid breaking downstream clients),
        # b) only contain freebase_mid or only contain concept_id (as the other one is
        # technically redundant), c) contain neither of them or be missing entirely (
        # potentially in future).
        # Corresponds to the JSON property `id`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntityId]
        attr_accessor :id
      
        # MRF equivalent representations of this entity as a compound, one for each
        # unique MRF representation. Populated for compounds. Each MRF expression
        # contains a minimum FunctionCall structure wrapped in a nameless Argument
        # without signals and range data. This is not meant to be directly usable as MRF,
        # use QueryJoinToMeaningStructConverter to expand it into a usable form.
        # References to entities are made as component_reference ArgumentValue. Each
        # compound Mention of this entity (not all of its mentions need be compounds,
        # some may be plain entity mentions) have one or more compound_value fields
        # claiming these MRF expressions via their mrf_index. The compound_value has
        # nested components, one for each unique component_reference.index in the MRF
        # expression. The processing expectation is that each ArgumentValue which has a
        # component_reference has its contents discarded and replaced with the MRF for
        # the target entity and mention named by the compound_value.component. If the
        # target is not a compound, the ArgumentValue becomes a simple mid value and the
        # signals are taken from the entity and the mention. If the target is a compound
        # itself, the expansion continues recursively. If the target is a compound with
        # multiple MRFs, a cartesian product of recursive expansions may need to be
        # produced. Along with the component_reference we also emit an example value,
        # but this is purely for human consumption so it's easier to understand what the
        # full compound is like. The processing expectation remains that the
        # ArgumentValue containing a component_reference is completely discarded and
        # rebuilt with the reference target value. If the target has more than one MRF
        # expression, it's not specified which one will be used as an example, except
        # that the choice is guaranteed to be deterministic from run to run.
        # Corresponds to the JSON property `mrf`
        # @return [Array<Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryArgument>]
        attr_accessor :mrf
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotated_relationship = args[:annotated_relationship] if args.key?(:annotated_relationship)
          @annotations = args[:annotations] if args.key?(:annotations)
          @collections = args[:collections] if args.key?(:collections)
          @entity_join = args[:entity_join] if args.key?(:entity_join)
          @id = args[:id] if args.key?(:id)
          @mrf = args[:mrf] if args.key?(:mrf)
        end
      end
      
      # 
      class RepositoryWebrefWebrefEntityCollections
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `collection`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefKgCollection>]
        attr_accessor :collection
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection = args[:collection] if args.key?(:collection)
        end
      end
      
      # The identifier of a WebrefEntity (see webref-entities.proto). IMPORTANT:
      # Please consider reading this proto through GetWebrefEntityMid() in webref-
      # entities-util.h, because this proto may: a) contain both freebase_mid and
      # concept_id (this is frequently the case to avoid breaking downstream clients),
      # b) only contain freebase_mid or only contain concept_id (as the other one is
      # technically redundant), c) contain neither of them or be missing entirely (
      # potentially in future).
      class RepositoryWebrefWebrefEntityId
        include Google::Apis::Core::Hashable
      
        # The MID in integer format. Nowadays, this field contains the equivalent
        # representation of `freebase_mid`, i.e. what metaweb::ParseId() returns.
        # Corresponds to the JSON property `conceptId`
        # @return [Fixnum]
        attr_accessor :concept_id
      
        # The MID in the same format that is returned by metaweb::MidToString(), e.g. "/
        # m/02mjmr" or "/g/11b6vyscgb" or "/t/24bjj59_jbj9f".
        # Corresponds to the JSON property `freebaseMid`
        # @return [String]
        attr_accessor :freebase_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @concept_id = args[:concept_id] if args.key?(:concept_id)
          @freebase_mid = args[:freebase_mid] if args.key?(:freebase_mid)
        end
      end
      
      # Information regarding links between annotated entities. Next available tag: 5
      class RepositoryWebrefWebrefEntityRelationship
        include Google::Apis::Core::Hashable
      
        # The index of the entry in WebrefEntities.entity that the entity carrying this
        # field is linked to. This field must be set.
        # Corresponds to the JSON property `entityIndex`
        # @return [Fixnum]
        attr_accessor :entity_index
      
        # Metadata about the nature of the link.
        # Corresponds to the JSON property `linkMetadata`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefEntityLinkMetadata]
        attr_accessor :link_metadata
      
        # The weight of the link.
        # Corresponds to the JSON property `linkWeight`
        # @return [Float]
        attr_accessor :link_weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_index = args[:entity_index] if args.key?(:entity_index)
          @link_metadata = args[:link_metadata] if args.key?(:link_metadata)
          @link_weight = args[:link_weight] if args.key?(:link_weight)
        end
      end
      
      # *** THIS ATTACHMENT IS DEPRECATED, SEE go/udr/migrate-wma. ***. We still allow
      # legacy use case to exist (no forced migration), but we will not accept any new
      # usage of WMA, incl. from existing clients. UDR has the same features and can
      # be used similarly: - To consume the topical entities (+properties, incl.
      # hitcat, browsy, ...) go/udr/migrate-wma provides a migration with minimal
      # changes. - To consume IQL, please consult go/udr/superroot#access and go/
      # pianno team. The top-level proto used to store WebRef entities and IQL
      # expressions in Mustang/TG. The proto uses packed repeated fields and variable-
      # length integers in order to be as compact as possible. See http://b/5802389
      # and b/7473898 for details on other approaches that were considered and space/
      # readability/extensibility trade-offs made. Note: It is not recommeded to read
      # this proto directly. Clients of the attachment should use the decoder instead:
      # repository/webref/tools/kc/indexing/webref-attachment-decoder.h Next available
      # tag: 25
      class RepositoryWebrefWebrefMustangAttachment
        include Google::Apis::Core::Hashable
      
        # The confidence of the category. In the range [0, 100].
        # Corresponds to the JSON property `categoryConfidenceE2`
        # @return [Array<Fixnum>]
        attr_accessor :category_confidence_e2
      
        # See go/category-annotations-api about the story behind various types of
        # category annotations that are provided using the catmid token and
        # category_encoded_mid fields below. Some of these annotation types are
        # experimental, so please contact related-entities@ if you consider using this
        # data. For production uses, please: 1. Add your use-case to go/hits-clients. 2.
        # Subscribe to hits-users@ to receive general updates and info about
        # deprecations. To convert it to the string form use metaweb::MidToString(
        # encoded_mid) defined in metaweb/util/mid/mid.h The uint64-encoded MIDs of
        # HitCat categories. See google3/repository/webref/hits/hitcat/category.
        # textproto for the complete list of HitCat categories. Should have the same
        # number of elements as the category_confidence_e2 field.
        # Corresponds to the JSON property `categoryEncodedMid`
        # @return [Array<Fixnum>]
        attr_accessor :category_encoded_mid
      
        # The confidence scores of all entities in the encoded_mid array. For space
        # reasons this is also represented as a fixed-point integer with two decimal
        # precision. Convert it to confidence_score using the following formula: float
        # confidence_score = confidence_e2 / 100.0f Should have the same number of
        # elements as the encoded_mid field.
        # Corresponds to the JSON property `confidenceE2`
        # @return [Array<Fixnum>]
        attr_accessor :confidence_e2
      
        # The int64-encoded MIDs of the entities in the document sorted by topicality
        # score. To convert it to the string form use metaweb::MidToString(encoded_mid)
        # defined in metaweb/util/mid/mid.h Should have the same number of elements as
        # the topicality_e2 field.
        # Corresponds to the JSON property `encodedMid`
        # @return [Array<Fixnum>]
        attr_accessor :encoded_mid
      
        # Per-entity metadata. Not packed (not every entity has metadata). If you'd like
        # to add per-document metadata, see document_metadata instead.
        # Corresponds to the JSON property `entityMetadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefAttachmentMetadata>]
        attr_accessor :entity_metadata
      
        # Mustang/Kgraph attachment to encode IQL expressions annotated by Webref,
        # Pianno, and other applications. This is currently a prototype implementation.
        # The attachment is not yet output in production. Please contact simonz@ for
        # more info. The planned use-cases include: - Pianno page-level intents (go/
        # pianno-design). - Compound entity representations (go/compounds-in-refx). See
        # go/iql-in-wma for more details about IQL attachment and its encoding design.
        # Next available tag: 5
        # Corresponds to the JSON property `iqlAttachment`
        # @return [Google::Apis::ContentwarehouseV1::KnowledgeAnswersIntentQueryIndexingIqlAttachment]
        attr_accessor :iql_attachment
      
        # The indices of all the reference entities in encoded_mid that are authors of
        # the page. Not packed as in most cases when populated, it contains 1 element.
        # Corresponds to the JSON property `isAuthorIndex`
        # @return [Array<Fixnum>]
        attr_accessor :is_author_index
      
        # The indices of all the reference entities in encoded_mid that are publishers
        # of the page (e.g. /m/cnn on "http://www.cnn.com/foo/bar"). Not packed as in
        # most cases when populated, it contains 1 element.
        # Corresponds to the JSON property `isPublisherIndex`
        # @return [Array<Fixnum>]
        attr_accessor :is_publisher_index
      
        # Only populated when the document is a reference page for an entity. Contains
        # the indices of all reference entities in the encoded_mid and topicality_e2
        # arrays. Not packed as in most cases when populated, it contains 1 element.
        # Corresponds to the JSON property `referencePageIndex`
        # @return [Array<Fixnum>]
        attr_accessor :reference_page_index
      
        # The topicality scores of all entities in the encoded_mid array. For space
        # reasons this is represented as a fixed-point integer with two decimal points
        # precision. Convert it to topicality_score using the following formula: float
        # topicality_score = topicality_e2 / 100.f Should have the same number of
        # elements as the encoded_mid field.
        # Corresponds to the JSON property `topicalityE2`
        # @return [Array<Fixnum>]
        attr_accessor :topicality_e2
      
        # The uint64-encoded MID of the unbound intents generated by Pianno. An unbound
        # intent is the annotation of an intent without slots arguments (e.g. Age)
        # declared in Intent Catalog. See go/pianno-asteroid-belt-migration for details.
        # We only keep the top unbound intents with the highest orbit scores. Should
        # have the same number of elements as unbound_intent_score_e2.
        # Corresponds to the JSON property `unboundIntentMid`
        # @return [Array<Fixnum>]
        attr_accessor :unbound_intent_mid
      
        # The confidence of the unbound intent. represented as a fixed-point integer
        # with two decimal precision. In the range [0, 100]. Should have the same number
        # of elements as unbound_intent_mid.
        # Corresponds to the JSON property `unboundIntentScoreE2`
        # @return [Array<Fixnum>]
        attr_accessor :unbound_intent_score_e2
      
        # [Experimental code. Do not use ] Entities that webref identified as being the
        # same concept (undermerged).
        # Corresponds to the JSON property `undermergedMembers`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefMustangAttachmentUndermergedMembers>]
        attr_accessor :undermerged_members
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_confidence_e2 = args[:category_confidence_e2] if args.key?(:category_confidence_e2)
          @category_encoded_mid = args[:category_encoded_mid] if args.key?(:category_encoded_mid)
          @confidence_e2 = args[:confidence_e2] if args.key?(:confidence_e2)
          @encoded_mid = args[:encoded_mid] if args.key?(:encoded_mid)
          @entity_metadata = args[:entity_metadata] if args.key?(:entity_metadata)
          @iql_attachment = args[:iql_attachment] if args.key?(:iql_attachment)
          @is_author_index = args[:is_author_index] if args.key?(:is_author_index)
          @is_publisher_index = args[:is_publisher_index] if args.key?(:is_publisher_index)
          @reference_page_index = args[:reference_page_index] if args.key?(:reference_page_index)
          @topicality_e2 = args[:topicality_e2] if args.key?(:topicality_e2)
          @unbound_intent_mid = args[:unbound_intent_mid] if args.key?(:unbound_intent_mid)
          @unbound_intent_score_e2 = args[:unbound_intent_score_e2] if args.key?(:unbound_intent_score_e2)
          @undermerged_members = args[:undermerged_members] if args.key?(:undermerged_members)
        end
      end
      
      # 
      class RepositoryWebrefWebrefMustangAttachmentUndermergedMembers
        include Google::Apis::Core::Hashable
      
        # Experimental code, do not use.
        # Corresponds to the JSON property `encodedMid`
        # @return [Array<Fixnum>]
        attr_accessor :encoded_mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encoded_mid = args[:encoded_mid] if args.key?(:encoded_mid)
        end
      end
      
      # Information about the outlinks for one specific target URL, from a given
      # annotated document. Next available tag: 7
      class RepositoryWebrefWebrefOutlinkInfo
        include Google::Apis::Core::Hashable
      
        # The length in bytes of such a link (including internal spaces); e.g. if the
        # link text is "click here" then the length is 10.
        # Corresponds to the JSON property `byteLength`
        # @return [Array<Fixnum>]
        attr_accessor :byte_length
      
        # The byte offset of the start of a link with this target URL, in the content of
        # the annotated document.
        # Corresponds to the JSON property `byteOffset`
        # @return [Array<Fixnum>]
        attr_accessor :byte_offset
      
        # Whether this is a nofollow link (https://en.wikipedia.org/wiki/Nofollow). If
        # the page has multiple links to the same url, all of them must be nofollow to
        # set this field.
        # Corresponds to the JSON property `isNofollow`
        # @return [Boolean]
        attr_accessor :is_nofollow
        alias_method :is_nofollow?, :is_nofollow
      
        # The topicality_weight for each link with this target URL.
        # Corresponds to the JSON property `topicalityWeight`
        # @return [Array<Float>]
        attr_accessor :topicality_weight
      
        # The target URL of the link.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @byte_length = args[:byte_length] if args.key?(:byte_length)
          @byte_offset = args[:byte_offset] if args.key?(:byte_offset)
          @is_nofollow = args[:is_nofollow] if args.key?(:is_nofollow)
          @topicality_weight = args[:topicality_weight] if args.key?(:topicality_weight)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Information about the outlinks of an annotated document. Next available tag: 3
      class RepositoryWebrefWebrefOutlinkInfos
        include Google::Apis::Core::Hashable
      
        # Information about each target URL referred to in the document's outlinks. If a
        # given URL has multiple links, they are grouped in a single WebrefLinkInfo.
        # Corresponds to the JSON property `outlinkInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefOutlinkInfo>]
        attr_accessor :outlink_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @outlink_info = args[:outlink_info] if args.key?(:outlink_info)
        end
      end
      
      # 
      class RepositoryWebrefWebrefStatus
        include Google::Apis::Core::Hashable
      
        # The epoch of the Webref static data (the name-filter.data file). As of Dec
        # 2020 in prod Goldmine (in webref_daily_full_model_static_data) this value is
        # over from the alpha model static data, since this is where most of the parts
        # come from. I.e. the value does not correspond to the actual model being used.
        # Corresponds to the JSON property `dataEpoch`
        # @return [String]
        attr_accessor :data_epoch
      
        # Wire-format for a Status object
        # Corresponds to the JSON property `utilStatus`
        # @return [Google::Apis::ContentwarehouseV1::UtilStatusProto]
        attr_accessor :util_status
      
        # The version number of the annotator (the cl the binary was built from). Must
        # be enabled via a command line flag. See also the Goldmine's indexing::
        # annotations::AnnotationMeta proto.
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_epoch = args[:data_epoch] if args.key?(:data_epoch)
          @util_status = args[:util_status] if args.key?(:util_status)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Information about a Wikipedia category (typically at the bottom of the page).
      class RepositoryWebrefWikipediaCategory
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `categoryName`
        # @return [String]
        attr_accessor :category_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_name = args[:category_name] if args.key?(:category_name)
        end
      end
      
      # Geocodes extracted from the wikijoins.
      class RepositoryWebrefWikipediaGeocode
        include Google::Apis::Core::Hashable
      
        # The location as extracted from the wikijoins.
        # Corresponds to the JSON property `location`
        # @return [Google::Apis::ContentwarehouseV1::GeostorePointProto]
        attr_accessor :location
      
        # The source contains the url field from the wikijoins.
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @location = args[:location] if args.key?(:location)
          @source_url = args[:source_url] if args.key?(:source_url)
        end
      end
      
      # //////////////////////////////////////////////////////////////////////////////
      # Conjunction: a single AND clause that contains multiple disjunctions.
      class ResearchScamCoscamConjunction
        include Google::Apis::Core::Hashable
      
        # disjunction_id / is_positive *MUST* have the same length. They specify a set
        # of disjunctions that make up this conjunction. The conjunction will be active
        # iff *all* of the positive disjunctions are active and *all* of the negative
        # disjunctions are inactive.
        # Corresponds to the JSON property `disjunctionId`
        # @return [Array<Fixnum>]
        attr_accessor :disjunction_id
      
        # 
        # Corresponds to the JSON property `isPositive`
        # @return [Array<Boolean>]
        attr_accessor :is_positive
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @disjunction_id = args[:disjunction_id] if args.key?(:disjunction_id)
          @is_positive = args[:is_positive] if args.key?(:is_positive)
        end
      end
      
      # //////////////////////////////////////////////////////////////////////////////
      # Disjunction: a single OR clause that contains multiple group:token tuples.
      class ResearchScamCoscamDisjunction
        include Google::Apis::Core::Hashable
      
        # key - a uint64 key that uniquely identifies this disjunction.
        # Corresponds to the JSON property `key`
        # @return [Fixnum]
        attr_accessor :key
      
        # groups - the group:token tuples that make up this disjunction. The disjunction
        # will be active if *any* off the group:token tuples are present in a request.
        # Corresponds to the JSON property `tokenGroups`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamTokenGroup>]
        attr_accessor :token_groups
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @token_groups = args[:token_groups] if args.key?(:token_groups)
        end
      end
      
      # Each EasyConjunction represents an AND-of-ORs block.
      class ResearchScamCoscamEasyConjunction
        include Google::Apis::Core::Hashable
      
        # disjunctions is the set of OR clauses that
        # Corresponds to the JSON property `disjunctions`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamEasyDisjunction>]
        attr_accessor :disjunctions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @disjunctions = args[:disjunctions] if args.key?(:disjunctions)
        end
      end
      
      # Each EasyDisjunction represents one OR clause.
      class ResearchScamCoscamEasyDisjunction
        include Google::Apis::Core::Hashable
      
        # If is_positive is set to false, then the entire disjunction is negated, and
        # will be true only if none of its members is true.
        # Corresponds to the JSON property `isPositive`
        # @return [Boolean]
        attr_accessor :is_positive
        alias_method :is_positive?, :is_positive
      
        # token_groups - the group:token tuples that make up this disjunction. The
        # disjunction will be active if *any* off the group:token tuples are present in
        # a request.
        # Corresponds to the JSON property `tokenGroups`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamTokenGroup>]
        attr_accessor :token_groups
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_positive = args[:is_positive] if args.key?(:is_positive)
          @token_groups = args[:token_groups] if args.key?(:token_groups)
        end
      end
      
      # Each EasyRestrictDefinition represents an OR-of-ANDs-of-ORs block.
      class ResearchScamCoscamEasyRestrictDefinition
        include Google::Apis::Core::Hashable
      
        # conjunctions is the set of AND-of-ORs blocks.
        # Corresponds to the JSON property `conjunctions`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamEasyConjunction>]
        attr_accessor :conjunctions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conjunctions = args[:conjunctions] if args.key?(:conjunctions)
        end
      end
      
      # //////////////////////////////////////////////////////////////////////////////
      # RestrictDefinition: the set of conjunctions and disjunctions that define a
      # single OR-of-ANDs-of-ORs restrict definition.
      class ResearchScamCoscamRestrictDefinition
        include Google::Apis::Core::Hashable
      
        # conjunctions - each conjunction is an AND-of-ORs; if any of these conjunctions
        # match, then the entire restrict matches.
        # Corresponds to the JSON property `conjunctions`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamConjunction>]
        attr_accessor :conjunctions
      
        # disjunctions - each disjunction is an OR clause.
        # Corresponds to the JSON property `disjunctions`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamDisjunction>]
        attr_accessor :disjunctions
      
        # subs_key - ignore. Only used for testing.
        # Corresponds to the JSON property `subsKey`
        # @return [Fixnum]
        attr_accessor :subs_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @conjunctions = args[:conjunctions] if args.key?(:conjunctions)
          @disjunctions = args[:disjunctions] if args.key?(:disjunctions)
          @subs_key = args[:subs_key] if args.key?(:subs_key)
        end
      end
      
      # //////////////////////////////////////////////////////////////////////////////
      # RestrictTokensV2: a set of group:token tuples, collated by group.
      class ResearchScamCoscamRestrictTokensV2
        include Google::Apis::Core::Hashable
      
        # token_groups - group:token tuples, collated by group.
        # Corresponds to the JSON property `tokenGroups`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamCoscamTokenGroup>]
        attr_accessor :token_groups
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @token_groups = args[:token_groups] if args.key?(:token_groups)
        end
      end
      
      # 
      class ResearchScamCoscamTokenGroup
        include Google::Apis::Core::Hashable
      
        # debug_token_strings - (optional) strings that should be used for human-
        # friendly printing. NOT used by the matching engine!
        # Corresponds to the JSON property `debugTokenStrings`
        # @return [Array<String>]
        attr_accessor :debug_token_strings
      
        # name - the name of the token group.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # tokens - a list of tokens, stored by their Fingerprint2011 hash.
        # Corresponds to the JSON property `tokens`
        # @return [Array<Fixnum>]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_token_strings = args[:debug_token_strings] if args.key?(:debug_token_strings)
          @name = args[:name] if args.key?(:name)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # ===================================================================== #
      # GenericFeatureVector Last tag used: 23
      class ResearchScamGenericFeatureVector
        include Google::Apis::Core::Hashable
      
        # The class label of this datapoint. This should be populated if ScaM is being
        # used for nearest-neighbor-based classification.
        # Corresponds to the JSON property `classLabel`
        # @return [String]
        attr_accessor :class_label
      
        # This subproto contains configuration for crowding. Crowding is a constraint on
        # a neighbor list produced by nearest neighbor search requiring that no more
        # than some value k' of the k neighbors returned have the same value of
        # crowding_attribute.
        # Corresponds to the JSON property `crowding`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamGenericFeatureVectorCrowding]
        attr_accessor :crowding
      
        # Optional point id that can contain an arbitrary (unrestricted in content)
        # value except when the data is provided via SSTable (sharded or not). In the
        # case of SSTable the data_id_str must be set for _all_ points in all shards or
        # the SSTable keys will be used as the values for the data_id_str of the
        # respective points. In either SSTable case--data_id_str provided explicitly or
        # via the key--the values must be unique across all shards.
        # Corresponds to the JSON property `dataIdStr`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data_id_str
      
        # A timestamp after which this datapoint is considered no longer valid and is
        # eligible for deletion. The exact meaning varies with application/configuration.
        # Corresponds to the JSON property `expirationTimestamp`
        # @return [String]
        attr_accessor :expiration_timestamp
      
        # DEPRECATED: - this field can safely be left unspecified. For dense vectors,
        # dimensionality is inferred from the number of values specified, and must be
        # identical to this, or unspecified. For sparse vectors, the default value is
        # correct for most users, and allows use of 64-bit hash values for feature
        # indices.
        # Corresponds to the JSON property `featureDim`
        # @return [Fixnum]
        attr_accessor :feature_dim
      
        # - for SPARSE vectors, specifies indices of the nonzero dimensions whose
        # values are specified by the , , or field. This field is not used when
        # specifying dense vectors.
        # Corresponds to the JSON property `featureIndex`
        # @return [Array<Fixnum>]
        attr_accessor :feature_index
      
        # Describes the type of feature values.
        # Corresponds to the JSON property `featureType`
        # @return [String]
        attr_accessor :feature_type
      
        # 
        # Corresponds to the JSON property `featureValueDouble`
        # @return [Array<Float>]
        attr_accessor :feature_value_double
      
        # Actual feature vector. Only one of the following should be populated. This
        # list has to be kept in sync with FeatureType enum. NOTES: Binary features are
        # stored as ones or zeroes in feature_value_int64. Floating point values (
        # feature_value_float, feature_value_double) may not be NaN.
        # Corresponds to the JSON property `featureValueFloat`
        # @return [Array<Float>]
        attr_accessor :feature_value_float
      
        # 
        # Corresponds to the JSON property `featureValueInt64`
        # @return [Array<Fixnum>]
        attr_accessor :feature_value_int64
      
        # 
        # Corresponds to the JSON property `featureValueString`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :feature_value_string
      
        # Metadata that may be populated if this GFV was transformed into fixed-point
        # from a floating-point GFV.
        # Corresponds to the JSON property `fixedPointMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamGenericFeatureVectorFixedPointMetadata]
        attr_accessor :fixed_point_metadata
      
        # Describes if data has been normalized and the type.
        # Corresponds to the JSON property `normType`
        # @return [String]
        attr_accessor :norm_type
      
        # Metadata to encode query-specific information. This may include
        # NeighborSelectionOverride, pre-computed query tokenization, etc..
        # Corresponds to the JSON property `queryMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamQueryMetadata]
        attr_accessor :query_metadata
      
        # RestrictTokens - used to perform "restricted searches" where boolean rules are
        # used to filter the subset of the database eligible for matching. We currently
        # support V1 and V3 restrict systems. V3 restrict is a superset of V1 restrict.
        # New users are encouraged to use V3 directly for its rich features and cleaner
        # semantics. See the document go/scam-v3-restricts, or read the comments in //
        # research/scam/proto/restricts.proto for details. Nevertheless, V1 restrict is
        # still supported by ScaM team. There's some minor tradeoff of performance
        # between V1 and V3. User may prefer V1 over V3 if performance is the first
        # priority. However, the CPU cost between V1 and V3 should be very minor. -------
        # -------------------------------------------------------------------- The
        # semantics of V1 restrict is described below: V1 "forward" restricts: The
        # dataset defines a many:many mapping between the database points and a token
        # space. Each token names a set of tokens and each database point is a member of
        # zero-to-many tokens. Queries specify zero-to-many whitelist and blacklist
        # tokens that activate database points according to the following rules: * If
        # whitelist_token is populated, the search will be restricted to points named by
        # at least one whitelist token. If whitelist_token is empty, all points are
        # whitelisted by default. * If blacklist_token is populated, it overrides the
        # whitelist. Points named by a blacklisted token are *not* searched. * Note that,
        # if neither whitelist_token nor blacklist_token is populated, the search
        # remains unrestricted. ---------------------------------------------------------
        # ------------------ V1 "reverse" restricts: Each database point is whitelisted
        # and/or blacklisted for zero or more tokens, specified by whitelist_token and
        # blacklist_token fields. Each query specifies zero or more tokens, and the same
        # rules apply: * If a point's whitelist_token is populated, the point will only
        # be searched if the query has at least one matching whitelist token. If
        # whitelist_token is empty, the point is always whitelisted by default. * If a
        # point's blacklist_token is populated, it overrides the whitelist. The point
        # will be ignored for any query with a matching blacklist token. * Note that, if
        # neither whitelist_token nor blacklist_token is populated, the point will
        # always be searched. NEXT ID TO USE: 9
        # Corresponds to the JSON property `restrictTokens`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamGenericFeatureVectorRestrictTokens]
        attr_accessor :restrict_tokens
      
        # 
        # Corresponds to the JSON property `tokens`
        # @return [Array<Fixnum>]
        attr_accessor :tokens
      
        # This field allows application-specific metadata to be stored in a GFV. This
        # information may be used by custom binaries or in pre- or postprocessing
        # outside of ScaM. Use cases include but are not limited to: * Dataset IDs, if
        # multiple datasets are multiplexed into one physical file or network location. *
        # An alternative, possibly more human-readable representation of the data
        # represented by this GFV, for e.g. debugging purposes. * Outputting the
        # contents of this field verbatim to the metadata field of the NearestNeighbors.
        # Neighbor proto.
        # Corresponds to the JSON property `userinfo`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :userinfo
      
        # DEPRECATED fields. Ignored by ScaM binaries. Do not use.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @class_label = args[:class_label] if args.key?(:class_label)
          @crowding = args[:crowding] if args.key?(:crowding)
          @data_id_str = args[:data_id_str] if args.key?(:data_id_str)
          @expiration_timestamp = args[:expiration_timestamp] if args.key?(:expiration_timestamp)
          @feature_dim = args[:feature_dim] if args.key?(:feature_dim)
          @feature_index = args[:feature_index] if args.key?(:feature_index)
          @feature_type = args[:feature_type] if args.key?(:feature_type)
          @feature_value_double = args[:feature_value_double] if args.key?(:feature_value_double)
          @feature_value_float = args[:feature_value_float] if args.key?(:feature_value_float)
          @feature_value_int64 = args[:feature_value_int64] if args.key?(:feature_value_int64)
          @feature_value_string = args[:feature_value_string] if args.key?(:feature_value_string)
          @fixed_point_metadata = args[:fixed_point_metadata] if args.key?(:fixed_point_metadata)
          @norm_type = args[:norm_type] if args.key?(:norm_type)
          @query_metadata = args[:query_metadata] if args.key?(:query_metadata)
          @restrict_tokens = args[:restrict_tokens] if args.key?(:restrict_tokens)
          @tokens = args[:tokens] if args.key?(:tokens)
          @userinfo = args[:userinfo] if args.key?(:userinfo)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # This subproto contains configuration for crowding. Crowding is a constraint on
      # a neighbor list produced by nearest neighbor search requiring that no more
      # than some value k' of the k neighbors returned have the same value of
      # crowding_attribute.
      class ResearchScamGenericFeatureVectorCrowding
        include Google::Apis::Core::Hashable
      
        # The value of the crowding attribute for this document. The maximum number of
        # neighbors to return per crowding attribute value (
        # per_crowding_attribute_num_neighbors) is configured per-query. This field is
        # ignored if per_crowding_attribute_num_neighbors is larger than the total
        # number of neighbors to return for a given query.
        # Corresponds to the JSON property `crowdingAttribute`
        # @return [Fixnum]
        attr_accessor :crowding_attribute
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crowding_attribute = args[:crowding_attribute] if args.key?(:crowding_attribute)
        end
      end
      
      # Metadata that may be populated if this GFV was transformed into fixed-point
      # from a floating-point GFV.
      class ResearchScamGenericFeatureVectorFixedPointMetadata
        include Google::Apis::Core::Hashable
      
        # The squared L2 norm of the original (pre-fixed-point transformation) GFV. Used
        # for computing squared L2 distance.
        # Corresponds to the JSON property `squaredL2Norm`
        # @return [Float]
        attr_accessor :squared_l2_norm
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @squared_l2_norm = args[:squared_l2_norm] if args.key?(:squared_l2_norm)
        end
      end
      
      # RestrictTokens - used to perform "restricted searches" where boolean rules are
      # used to filter the subset of the database eligible for matching. We currently
      # support V1 and V3 restrict systems. V3 restrict is a superset of V1 restrict.
      # New users are encouraged to use V3 directly for its rich features and cleaner
      # semantics. See the document go/scam-v3-restricts, or read the comments in //
      # research/scam/proto/restricts.proto for details. Nevertheless, V1 restrict is
      # still supported by ScaM team. There's some minor tradeoff of performance
      # between V1 and V3. User may prefer V1 over V3 if performance is the first
      # priority. However, the CPU cost between V1 and V3 should be very minor. -------
      # -------------------------------------------------------------------- The
      # semantics of V1 restrict is described below: V1 "forward" restricts: The
      # dataset defines a many:many mapping between the database points and a token
      # space. Each token names a set of tokens and each database point is a member of
      # zero-to-many tokens. Queries specify zero-to-many whitelist and blacklist
      # tokens that activate database points according to the following rules: * If
      # whitelist_token is populated, the search will be restricted to points named by
      # at least one whitelist token. If whitelist_token is empty, all points are
      # whitelisted by default. * If blacklist_token is populated, it overrides the
      # whitelist. Points named by a blacklisted token are *not* searched. * Note that,
      # if neither whitelist_token nor blacklist_token is populated, the search
      # remains unrestricted. ---------------------------------------------------------
      # ------------------ V1 "reverse" restricts: Each database point is whitelisted
      # and/or blacklisted for zero or more tokens, specified by whitelist_token and
      # blacklist_token fields. Each query specifies zero or more tokens, and the same
      # rules apply: * If a point's whitelist_token is populated, the point will only
      # be searched if the query has at least one matching whitelist token. If
      # whitelist_token is empty, the point is always whitelisted by default. * If a
      # point's blacklist_token is populated, it overrides the whitelist. The point
      # will be ignored for any query with a matching blacklist token. * Note that, if
      # neither whitelist_token nor blacklist_token is populated, the point will
      # always be searched. NEXT ID TO USE: 9
      class ResearchScamGenericFeatureVectorRestrictTokens
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `blacklistToken`
        # @return [Array<Fixnum>]
        attr_accessor :blacklist_token
      
        # //////////////////////////////////////////////////////////////////////////////
        # RestrictDefinition: the set of conjunctions and disjunctions that define a
        # single OR-of-ANDs-of-ORs restrict definition.
        # Corresponds to the JSON property `definition`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamCoscamRestrictDefinition]
        attr_accessor :definition
      
        # Each EasyRestrictDefinition represents an OR-of-ANDs-of-ORs block.
        # Corresponds to the JSON property `easyDefinition`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamCoscamEasyRestrictDefinition]
        attr_accessor :easy_definition
      
        # B) Token Definitions (V1 Restricts) In "forward" mode: defined on database
        # points In "reverse" mode: defined on queries
        # Corresponds to the JSON property `tokenMembership`
        # @return [Array<Fixnum>]
        attr_accessor :token_membership
      
        # //////////////////////////////////////////////////////////////////////////////
        # RestrictTokensV2: a set of group:token tuples, collated by group.
        # Corresponds to the JSON property `tokens`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamCoscamRestrictTokensV2]
        attr_accessor :tokens
      
        # Only ONE of the following sections should be used: A) V3 restricts. Defined in
        # //research/scam/proto/restricts.proto
        # Corresponds to the JSON property `v3`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamV3Restrict]
        attr_accessor :v3
      
        # If this field is not empty, when query is in V1 restricts while database is in
        # V3 restricts, SCaM will update V1 query to V3 automatically instead of sending
        # error messages. When updating query from V1 to V3, SCaM server will use this
        # field to fillin the 'namespace' field.
        # Corresponds to the JSON property `v3CompatibleNamespace`
        # @return [String]
        attr_accessor :v3_compatible_namespace
      
        # C) Whitelist / Blacklist Definitions (V1 Restricts) In "forward" mode: defined
        # on queries In "reverse" mode: defined on database points
        # Corresponds to the JSON property `whitelistToken`
        # @return [Array<Fixnum>]
        attr_accessor :whitelist_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blacklist_token = args[:blacklist_token] if args.key?(:blacklist_token)
          @definition = args[:definition] if args.key?(:definition)
          @easy_definition = args[:easy_definition] if args.key?(:easy_definition)
          @token_membership = args[:token_membership] if args.key?(:token_membership)
          @tokens = args[:tokens] if args.key?(:tokens)
          @v3 = args[:v3] if args.key?(:v3)
          @v3_compatible_namespace = args[:v3_compatible_namespace] if args.key?(:v3_compatible_namespace)
          @whitelist_token = args[:whitelist_token] if args.key?(:whitelist_token)
        end
      end
      
      # All nearest neighbors for one data point. Last tag used: 5
      class ResearchScamNearestNeighbors
        include Google::Apis::Core::Hashable
      
        # Data point for which we computed nearest neighbors. This field is set based on
        # the data_id_str field in the QueryRequest GFV (or SSTable key if data_id_str
        # is not present), and thus can be arbitrary data, e.g. docid, URL, query string.
        # Corresponds to the JSON property `docid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :docid
      
        # Metadata about the query. This field is populated if and only if: 1) ScaM is
        # running in offline query-database or online mode and; 2) The metadata is
        # directly fetched from the userinfo field inside GFV and; 3) MetadataConfig.
        # userinfo.set_user_info_for_query is set to true. The field name is kept as "
        # metadata" for consistency with neighbors.
        # Corresponds to the JSON property `metadata`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :metadata
      
        # All its neighbors.
        # Corresponds to the JSON property `neighbor`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamNearestNeighborsNeighbor>]
        attr_accessor :neighbor
      
        # Last used tag = 8
        # Corresponds to the JSON property `neighborSelectionOverride`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamNeighborSelectionOverride]
        attr_accessor :neighbor_selection_override
      
        # ===================================================================== #
        # GenericFeatureVector Last tag used: 23
        # Corresponds to the JSON property `query`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamGenericFeatureVector]
        attr_accessor :query
      
        # The version ID of the server that responded to this query, if one was
        # specified. This field is not populated for offline (i.e. Flume rather than RPC)
        # search.
        # Corresponds to the JSON property `retrievedVersion`
        # @return [String]
        attr_accessor :retrieved_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @docid = args[:docid] if args.key?(:docid)
          @metadata = args[:metadata] if args.key?(:metadata)
          @neighbor = args[:neighbor] if args.key?(:neighbor)
          @neighbor_selection_override = args[:neighbor_selection_override] if args.key?(:neighbor_selection_override)
          @query = args[:query] if args.key?(:query)
          @retrieved_version = args[:retrieved_version] if args.key?(:retrieved_version)
        end
      end
      
      # 
      class ResearchScamNearestNeighborsNeighbor
        include Google::Apis::Core::Hashable
      
        # If crowding is enabled, the crowding attribute of this neighbor will be stored
        # here.
        # Corresponds to the JSON property `crowdingAttribute`
        # @return [Fixnum]
        attr_accessor :crowding_attribute
      
        # This could be exact or approximate distance.
        # Corresponds to the JSON property `distance`
        # @return [Float]
        attr_accessor :distance
      
        # Neighbor data point. This field is set based on the data_id_str field in the
        # GFV of the data point in the database (or SSTable key if data_id_str is not
        # present), and thus can be arbitrary data, e.g. docid, URL, query string.
        # Corresponds to the JSON property `docid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :docid
      
        # Metadata about the neighbor. This is returned under some configurations as a
        # serialized proto. The specific proto depends on which metadata is configured
        # to be returned.
        # Corresponds to the JSON property `metadata`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :metadata
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @crowding_attribute = args[:crowding_attribute] if args.key?(:crowding_attribute)
          @distance = args[:distance] if args.key?(:distance)
          @docid = args[:docid] if args.key?(:docid)
          @metadata = args[:metadata] if args.key?(:metadata)
        end
      end
      
      # Last used tag = 8
      class ResearchScamNeighborSelectionOverride
        include Google::Apis::Core::Hashable
      
        # The distance threshold to use for approximate search before exact reordering
        # is performed, if exact reordering is performed. If this is not set and exact
        # reordering is enabled, a reasonable default value will be chosen using a
        # heuristic specified in ScamConfig.ExactReordering.
        # NeighborSelectionOverrideHeuristics. This field is ignored if exact reordering
        # is not enabled. This value must be non-NaN if set.
        # Corresponds to the JSON property `approxEpsilonDistance`
        # @return [Float]
        attr_accessor :approx_epsilon_distance
      
        # The number of neighbors to find via approximate search before exact reordering
        # is performed. If this is not set and exact reordering is enabled, a reasonable
        # default value will be chosen using the heuristic specified in ScamConfig.
        # ExactReordering.NeighborSelectionOverrideHeuristics. This field is ignored if
        # exact reordering is not enabled. This value must be > 0 if set.
        # Corresponds to the JSON property `approxNumNeighbors`
        # @return [Fixnum]
        attr_accessor :approx_num_neighbors
      
        # The maximum distance at which to return a neighbor. If this proto is used, at
        # least one of this and num_neighbors must be set. The default is infinity,
        # effectively returning num_neighbors neighbors regardless of distance. This
        # value must be non-NaN if set.
        # Corresponds to the JSON property `epsilonDistance`
        # @return [Float]
        attr_accessor :epsilon_distance
      
        # The maximum number of neighbors to return. If this proto is used, at least one
        # of this and epsilon_distance must be set. The default is the largest value
        # representable as an int32, effectively returning all neighbors within
        # epsilon_distance. This value must be > 0 if set.
        # Corresponds to the JSON property `numNeighbors`
        # @return [Fixnum]
        attr_accessor :num_neighbors
      
        # If populated, this is the maximum number of neighbors that may be returned
        # from a single shard. If not populated, up to num_neighbors neighbors are
        # returned from each shard. Setting his to a smaller value than num_neighbors
        # will increase speed at the expense of accuray by requiring cross-shard merging
        # of fewer neighbors. If this value is set, num_neighbors must also be set and
        # this value must be <= num_neighbors and >= num_neighbors / number of shards.
        # If set, this value must always be > 0.
        # Corresponds to the JSON property `numSingleShardNeighbors`
        # @return [Fixnum]
        attr_accessor :num_single_shard_neighbors
      
        # The maximum number of neighbors to return for a single value of the crowding
        # attribute. The crowding attribute is specified per-datapoint in the
        # GenericFeatureVector proto, or the Document proto for sparse logistic models.
        # Crowding is described more thoroughly in research/scam/utils/crowding_top_n.h.
        # NOTES: Crowding is effectivley enabled if this value is less than
        # num_neighbors.
        # Corresponds to the JSON property `perCrowdingAttributeNumNeighbors`
        # @return [Fixnum]
        attr_accessor :per_crowding_attribute_num_neighbors
      
        # The maximum number of neighbors to return from the approximate portion of the
        # nearest-neighbor search algorithm, within each shard, for a single value of
        # the crowding attribute, before performing exact reordering. Ignored if exact
        # reordering is disabled for this dataset.
        # Corresponds to the JSON property `perCrowdingAttributePreReorderingNumNeighbors`
        # @return [Fixnum]
        attr_accessor :per_crowding_attribute_pre_reordering_num_neighbors
      
        # Note: currently not implemented for all database shard subclasses! Contact
        # ScaM before using. Overrides max_spill_centers for tree-X hybrid searchers
        # configured with FIXED_NUMBER_OF_CENTERS spilling. The max_spill_centers in the
        # ScaM config is used if this field isn't set. Only valid if: * Used on a tree-X
        # hybrid ScaM config with FIXED_NUMBER_OF_CENTERS. * Value is greater than zero
        # and at most equal to num_children.
        # Corresponds to the JSON property `treeXHybridLeavesSearchedOverride`
        # @return [Fixnum]
        attr_accessor :tree_x_hybrid_leaves_searched_override
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @approx_epsilon_distance = args[:approx_epsilon_distance] if args.key?(:approx_epsilon_distance)
          @approx_num_neighbors = args[:approx_num_neighbors] if args.key?(:approx_num_neighbors)
          @epsilon_distance = args[:epsilon_distance] if args.key?(:epsilon_distance)
          @num_neighbors = args[:num_neighbors] if args.key?(:num_neighbors)
          @num_single_shard_neighbors = args[:num_single_shard_neighbors] if args.key?(:num_single_shard_neighbors)
          @per_crowding_attribute_num_neighbors = args[:per_crowding_attribute_num_neighbors] if args.key?(:per_crowding_attribute_num_neighbors)
          @per_crowding_attribute_pre_reordering_num_neighbors = args[:per_crowding_attribute_pre_reordering_num_neighbors] if args.key?(:per_crowding_attribute_pre_reordering_num_neighbors)
          @tree_x_hybrid_leaves_searched_override = args[:tree_x_hybrid_leaves_searched_override] if args.key?(:tree_x_hybrid_leaves_searched_override)
        end
      end
      
      # Structure to hold the response time for a node. Last used: 3
      class ResearchScamOnlineSearchLatencyStats
        include Google::Apis::Core::Hashable
      
        # An estimate of the CPU time used for this query on the machine associated with
        # task_id, from when the query was received to when the response was ready to
        # send, in seconds. Caveats: 1. Does not account for CPU time spent serializing,
        # deserializing, compressing or decompressing protos within Stubby. 2. Does not
        # account for cleanup time after response has been sent.
        # Corresponds to the JSON property `cpuTime`
        # @return [Float]
        attr_accessor :cpu_time
      
        # Task number associated with response time measurements.
        # Corresponds to the JSON property `taskId`
        # @return [Fixnum]
        attr_accessor :task_id
      
        # Wall time taken on the machine associated with task_id from when the query was
        # received to when the response was ready to send, in seconds. This time
        # excludes the time spent sending the response and the time to perform cleanup
        # operations after the response is sent.
        # Corresponds to the JSON property `wallTime`
        # @return [Float]
        attr_accessor :wall_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cpu_time = args[:cpu_time] if args.key?(:cpu_time)
          @task_id = args[:task_id] if args.key?(:task_id)
          @wall_time = args[:wall_time] if args.key?(:wall_time)
        end
      end
      
      # Metadata to encode query-specific information. This may include
      # NeighborSelectionOverride, pre-computed query tokenization, etc..
      class ResearchScamQueryMetadata
        include Google::Apis::Core::Hashable
      
        # Last used tag = 8
        # Corresponds to the JSON property `neighborSelectionOverride`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScamNeighborSelectionOverride]
        attr_accessor :neighbor_selection_override
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @neighbor_selection_override = args[:neighbor_selection_override] if args.key?(:neighbor_selection_override)
        end
      end
      
      # Response to a query. The main result is the nearest neighbor list, but we also
      # optionally include debugging information if the appropriate field is set in
      # the request. Last used: 8
      class ResearchScamQueryResponse
        include Google::Apis::Core::Hashable
      
        # Debugging fields: The wall and CPU time used by each query on each machine.
        # For successful queries, there will be one entry here for each machine that the
        # query used if QueryRequest.enable_latency_stats was enabled. For unsuccessful
        # queries, the contents of this field will be undefined. NOTE: The following
        # accounting rules apply in batched mode, assuming there are
        # Corresponds to the JSON property `latency`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamOnlineSearchLatencyStats>]
        attr_accessor :latency
      
        # The number of non-root machines for which a DEADLINE_EXCEEDED error occurred
        # when they were contacted. This value does NOT include machines for which no
        # reply was received because their parent machine timed out. Therefore,
        # num_total_machines may be larger than num_ok_machines +
        # num_unreachable_machines + num_deadline_exceeded_machines.
        # Corresponds to the JSON property `numDeadlineExceededMachines`
        # @return [Fixnum]
        attr_accessor :num_deadline_exceeded_machines
      
        # Number of machines that contributed to the results; this might be less than
        # the total number of machines if a machine has failed. The impact of a single
        # machine failure could be larger than just one machine, if it happens to be one
        # of the machines involved in distributing the query and collecting results.
        # Corresponds to the JSON property `numOkMachines`
        # @return [Fixnum]
        attr_accessor :num_ok_machines
      
        # The number of machines used in this service for the dataset that was queried.
        # If everything went right, this should be equal to num_ok_machines. If
        # num_ok_machines < num_total_machines, some neighbors may be missing from
        # results.
        # Corresponds to the JSON property `numTotalMachines`
        # @return [Fixnum]
        attr_accessor :num_total_machines
      
        # The number of non-root machines for which an UNREACHABLE error occurred when
        # they were contacted. This value does NOT include machines that were implicitly
        # unreachable because their parent machine was not reachable. Therefore,
        # num_total_machines may be larger than num_ok_machines +
        # num_unreachable_machines + num_deadline_exceeded_machines.
        # Corresponds to the JSON property `numUnreachableMachines`
        # @return [Fixnum]
        attr_accessor :num_unreachable_machines
      
        # The number of "active" datapoints for each dataset, i.e. points that are
        # whitelisted by restricts and could be returned if they were close enough to
        # the query. For successful queries, there will be one entry here for each
        # dataset queried, if QueryRequest.enable_restrict_stats was true. For partially-
        # successful successful queries, this field will contain results
        # Corresponds to the JSON property `restrictStats`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamRestrictStats>]
        attr_accessor :restrict_stats
      
        # The results for each dataset searched. If per_dataset_parameters was empty in
        # QueryRequest then this will have one entry, the results for dataset 0. If
        # per_dataset_parameters was not empty in QueryRequest, this will contain the
        # results for each dataset queried, in order corresponding to the order of
        # QueryRequest.per_dataset_parameters.
        # Corresponds to the JSON property `results`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamNearestNeighbors>]
        attr_accessor :results
      
        # Wire-format for a Status object
        # Corresponds to the JSON property `status`
        # @return [Google::Apis::ContentwarehouseV1::UtilStatusProto]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @latency = args[:latency] if args.key?(:latency)
          @num_deadline_exceeded_machines = args[:num_deadline_exceeded_machines] if args.key?(:num_deadline_exceeded_machines)
          @num_ok_machines = args[:num_ok_machines] if args.key?(:num_ok_machines)
          @num_total_machines = args[:num_total_machines] if args.key?(:num_total_machines)
          @num_unreachable_machines = args[:num_unreachable_machines] if args.key?(:num_unreachable_machines)
          @restrict_stats = args[:restrict_stats] if args.key?(:restrict_stats)
          @results = args[:results] if args.key?(:results)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # Structure to hold the number of active and total datapoints for a given
      # dataset, as defined below. Last used: 2
      class ResearchScamRestrictStats
        include Google::Apis::Core::Hashable
      
        # The number of datapoints that are whitelisted by restricts specified for this
        # query, across all shards for which the query executed successfully. In other
        # words, this represents the number of datapoints that could potentially be
        # returned if they were close enough to the query according to the selected
        # distance measure. If restricts are disabled, this will be equal to
        # num_total_datapoints.
        # Corresponds to the JSON property `numActiveDatapoints`
        # @return [Fixnum]
        attr_accessor :num_active_datapoints
      
        # The number of total datapoints in all shards of this dataset for which the
        # query executed successfully. This is returned for convenience so that a ratio
        # can be easily computed, and so that num_active_datapoints can be put in
        # perspective for partially successful queries, i.e. queries where only some
        # shards were successful.
        # Corresponds to the JSON property `numTotalDatapoints`
        # @return [Fixnum]
        attr_accessor :num_total_datapoints
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_active_datapoints = args[:num_active_datapoints] if args.key?(:num_active_datapoints)
          @num_total_datapoints = args[:num_total_datapoints] if args.key?(:num_total_datapoints)
        end
      end
      
      # 
      class ResearchScamTokenNamespace
        include Google::Apis::Core::Hashable
      
        # ////////////////////////////////////////////////////////////////////////////
        # NAMESPACE - the string name of the namespace that this proto is specifying,
        # such as "color", "shape", "geo", or "tags". Recall that your overall query is
        # an AND across namespaces.
        # Corresponds to the JSON property `namespace`
        # @return [String]
        attr_accessor :namespace
      
        # ////////////////////////////////////////////////////////////////////////////
        # BLACKLIST - Blacklisting can be used to implement more complex scenarios. The
        # blacklist fields have exactly the same format as the token fields, but
        # represents a negation. When a token is blacklisted, then matches will be
        # excluded whenever the other datapoint has that token. For example, if a query
        # specifies `color: red, blue, !purple`, then that query will match datapoints
        # that are red or blue, but if those points are also purple, then they will be
        # excluded even if they are red/blue. Note that, due to symmetry, if one of the
        # database points is `red, !blue`, that point will be excluded from queries that
        # specify blue. Lastly, note that namespaces with *only* blacklist tokens behave
        # similar to empty namespaces, in that `color: !purple` would match blue or red
        # datapoints, as long as those datapoints don't also have the purple token.
        # Corresponds to the JSON property `stringBlacklistTokens`
        # @return [Array<String>]
        attr_accessor :string_blacklist_tokens
      
        # ////////////////////////////////////////////////////////////////////////////
        # TOKENS - Conceptually, each token names a set datapoints. The field(s) below
        # are for declaring the tokens that name the datapoint that this TokenNamespace
        # proto is attached to. For convenience, we support either string or uint64
        # tokens. Internally, the restricts system is based on uint64s, but for many
        # applications, strings are the more natural format, and they should be
        # preferred whenever this is the case. * When only uint64s are specified, they
        # will be used as-is. * When only strings are specified, they will be converted
        # to uint64s via Fingerprint2011. (See "Note on the safety of Fingerprint2011").
        # * ADVANCED: When both fields are specified, the uint64s are used as-is. Note
        # that, when both fields are used, they *must* have the same number of entries,
        # and the system will assume that your strings correspond 1:1 with the list of
        # uint64 tokens. * EDGE CASE: All matching is done in the uint64 space, so, I'm
        # not sure why you'd do this, but if, eg, your database uses strings, and your
        # queries specify the Fingerprint2011 hashes of those strings, matching will
        # work, and this is a specified behavior. Note on the safety of Fingerprint2011:
        # Unless you have well over 1M+ unique string tokens, you can safely assume that
        # every string will map to a unique 64-bit token. Internally, both Mustang and
        # PSI use Fingerprint2011 to hash arbitrary strings into uint64 tokens, and
        # assume, without validation, that each 64-bit token is unique. And the math
        # backs up this assumption: If we are using a "perfect" hashing function (and
        # Fingerprint2011 is close-enough for our purposes), and we then hash 1M unique
        # tokens into a 64-bit space, there's still better than 99.9999% odds that all
        # tokens are collision-free, nearly as good as the odds for the datacenter's
        # continued existence. Scenarios for having both the string and uint64 token
        # forms: * Probably none that matter to you. Just use the strings directly. *
        # You could have uint64 enum values, yet want to include the string values for
        # debugging purposes. Note that it *is* supported to use a proprietary string =>
        # uint64 mapping, assuming that it is consistent, and that you always specify
        # the uint64 values. * The mixer-tier in a multi-shard deployment might convert
        # the strings into uint64s to avoid redundant hashing overhead on the leaves,
        # yet keep the string tokens to preserve proto-level debugging. * When strings
        # are present, I reserve the right to use them for making logging "better", but,
        # thusfar, there are 0 examples of this.
        # Corresponds to the JSON property `stringTokens`
        # @return [Array<String>]
        attr_accessor :string_tokens
      
        # 
        # Corresponds to the JSON property `uint64BlacklistTokens`
        # @return [Array<Fixnum>]
        attr_accessor :uint64_blacklist_tokens
      
        # 
        # Corresponds to the JSON property `uint64Tokens`
        # @return [Array<Fixnum>]
        attr_accessor :uint64_tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @namespace = args[:namespace] if args.key?(:namespace)
          @string_blacklist_tokens = args[:string_blacklist_tokens] if args.key?(:string_blacklist_tokens)
          @string_tokens = args[:string_tokens] if args.key?(:string_tokens)
          @uint64_blacklist_tokens = args[:uint64_blacklist_tokens] if args.key?(:uint64_blacklist_tokens)
          @uint64_tokens = args[:uint64_tokens] if args.key?(:uint64_tokens)
        end
      end
      
      # 
      class ResearchScamV3Restrict
        include Google::Apis::Core::Hashable
      
        # ////////////////////////////////////////////////////////////////////////////
        # NAMESPACES - a repeating field, where each entry specifies the set of tokens,
        # within a single namespace, that apply to the query, or database point, on
        # which this V3Restrict proto is defined. Note that: * Your overall query is an
        # AND across namespaces. * Explicitly specifying a namespace with 0 tokens is
        # identical to omitting that namespace. ie, "`ns:`" == "". * It is an error to
        # specify the same namespace more than once per instance of the V3Restrict proto.
        # Corresponds to the JSON property `namespaces`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScamTokenNamespace>]
        attr_accessor :namespaces
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @namespaces = args[:namespaces] if args.key?(:namespaces)
        end
      end
      
      # Information on the catalog that this dataset comes from. Next ID: 5
      class ResearchScienceSearchCatalog
        include Google::Apis::Core::Hashable
      
        # catalog description
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # catalog mid
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # catalog name
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # catalog url
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @mid = args[:mid] if args.key?(:mid)
          @name = args[:name] if args.key?(:name)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Reference to the citation in Google scholar.
      class ResearchScienceSearchCitation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `citation`
        # @return [String]
        attr_accessor :citation
      
        # IMPORTANT: It is unsafe to accept this message from an untrusted source, since
        # it's trivial for an attacker to forge serialized messages that don't fulfill
        # the type's safety contract -- for example, it could contain attacker
        # controlled script. A system which receives a SafeHtmlProto implicitly trusts
        # the producer of the SafeHtmlProto. So, it's generally safe to return this
        # message in RPC responses, but generally unsafe to accept it in RPC requests.
        # Corresponds to the JSON property `safeHtmlCitation`
        # @return [Google::Apis::ContentwarehouseV1::WebutilHtmlTypesSafeHtmlProto]
        attr_accessor :safe_html_citation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @citation = args[:citation] if args.key?(:citation)
          @safe_html_citation = args[:safe_html_citation] if args.key?(:safe_html_citation)
        end
      end
      
      # The dataset in downloadable form. There can be multiple data download entries
      # for different file types. Next ID: 6
      class ResearchScienceSearchDataDownload
        include Google::Apis::Core::Hashable
      
        # Size of the download, as a string from the provider. May include units.
        # Corresponds to the JSON property `contentSize`
        # @return [String]
        attr_accessor :content_size
      
        # URL for downloading the data
        # Corresponds to the JSON property `downloadUrl`
        # @return [String]
        attr_accessor :download_url
      
        # File format at the link (ASCII, CSV, etc.)
        # Corresponds to the JSON property `fileFormat`
        # @return [String]
        attr_accessor :file_format
      
        # Pragmatic classification of file formats - for filtering purposes
        # Corresponds to the JSON property `fileFormatClass`
        # @return [String]
        attr_accessor :file_format_class
      
        # Data size information, consists of a numeric value and a unit. Next ID: 3
        # Corresponds to the JSON property `parsedContentSize`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDataSize]
        attr_accessor :parsed_content_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content_size = args[:content_size] if args.key?(:content_size)
          @download_url = args[:download_url] if args.key?(:download_url)
          @file_format = args[:file_format] if args.key?(:file_format)
          @file_format_class = args[:file_format_class] if args.key?(:file_format_class)
          @parsed_content_size = args[:parsed_content_size] if args.key?(:parsed_content_size)
        end
      end
      
      # Data size information, consists of a numeric value and a unit. Next ID: 3
      class ResearchScienceSearchDataSize
        include Google::Apis::Core::Hashable
      
        # Data size value, in the provided size unit
        # Corresponds to the JSON property `size`
        # @return [Float]
        attr_accessor :size
      
        # The data size unit
        # Corresponds to the JSON property `unit`
        # @return [String]
        attr_accessor :unit
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @size = args[:size] if args.key?(:size)
          @unit = args[:unit] if args.key?(:unit)
        end
      end
      
      # Representation of fields that contain dates. The formattes version, if present,
      # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
      # string. Next ID: 3
      class ResearchScienceSearchDate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `formatted`
        # @return [String]
        attr_accessor :formatted
      
        # 
        # Corresponds to the JSON property `unformatted`
        # @return [String]
        attr_accessor :unformatted
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatted = args[:formatted] if args.key?(:formatted)
          @unformatted = args[:unformatted] if args.key?(:unformatted)
        end
      end
      
      # Stores the classification info of each field of study label.
      class ResearchScienceSearchFieldOfStudyInfo
        include Google::Apis::Core::Hashable
      
        # The classification source that determines the field of study label.
        # Corresponds to the JSON property `classificationSource`
        # @return [String]
        attr_accessor :classification_source
      
        # If set to true, it means that the probability is at least the threshold value
        # specified from the corresponding saved model config. Thresholds for different
        # fields may be different.
        # Corresponds to the JSON property `isAboveThreshold`
        # @return [String]
        attr_accessor :is_above_threshold
      
        # A label that represents the field of study.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # A score between [0, 1] outputted from the classifier indicating the
        # probability for being a YES instance.
        # Corresponds to the JSON property `probability`
        # @return [Float]
        attr_accessor :probability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @classification_source = args[:classification_source] if args.key?(:classification_source)
          @is_above_threshold = args[:is_above_threshold] if args.key?(:is_above_threshold)
          @label = args[:label] if args.key?(:label)
          @probability = args[:probability] if args.key?(:probability)
        end
      end
      
      # Distribution license information. Next ID: 6
      class ResearchScienceSearchLicense
        include Google::Apis::Core::Hashable
      
        # A fingerprint id generated based on the license_class, URL or text. Since the
        # knowledge graph requires a unique string id for the license but any filed of
        # license can be empty, a fingerprint id can serve as a compact identifier
        # representing the non-empty sub-fields.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # A value from a controlled vocabulary that uniquely identifies a license.
        # Unless this is set to LICENSE_CLASS_UNDEFINED_NO_MATCH or
        # LICENSE_CLASS_UNDEFINED_CONTRADICTING_MATCHES other fields in this message
        # should be empty.
        # Corresponds to the JSON property `licenseClass`
        # @return [String]
        attr_accessor :license_class
      
        # mid for the license.
        # Corresponds to the JSON property `licenseMid`
        # @return [String]
        attr_accessor :license_mid
      
        # The text (usually, the name) of the distribution license.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # The url for the distribution license.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @license_class = args[:license_class] if args.key?(:license_class)
          @license_mid = args[:license_mid] if args.key?(:license_mid)
          @text = args[:text] if args.key?(:text)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Describes the spatial information about a value in spatial-coverage definition
      # of a dataset. Next ID: 9
      class ResearchScienceSearchLocation
        include Google::Apis::Core::Hashable
      
        # Coordinates of the corners of the polygon in the form "lat1 long1 lat2 long2"
        # Corresponds to the JSON property `boxCoordinates`
        # @return [String]
        attr_accessor :box_coordinates
      
        # Coordinates for the circle area defined by its center and radius: "lat long,
        # radius"
        # Corresponds to the JSON property `circleCoordinates`
        # @return [String]
        attr_accessor :circle_coordinates
      
        # mids for locations that contain loctions in .
        # Corresponds to the JSON property `containedInMid`
        # @return [Array<String>]
        attr_accessor :contained_in_mid
      
        # mids for locations covering the dataset, contained in the . A region may
        # contain multiple locations that are identified by mids.
        # Corresponds to the JSON property `locationMid`
        # @return [Array<String>]
        attr_accessor :location_mid
      
        # Labels (in the preferred language of the dataset) for the mids in .
        # Corresponds to the JSON property `locationMidLabel`
        # @return [Array<String>]
        attr_accessor :location_mid_label
      
        # The original name for the area covered by the dataset.
        # Corresponds to the JSON property `locationName`
        # @return [String]
        attr_accessor :location_name
      
        # Latitude and longitude for a single point in the form of "lat,long".
        # Corresponds to the JSON property `pointCoordinates`
        # @return [String]
        attr_accessor :point_coordinates
      
        # Unformatted coordinates describing the region.
        # Corresponds to the JSON property `unformattedCoordinates`
        # @return [String]
        attr_accessor :unformatted_coordinates
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @box_coordinates = args[:box_coordinates] if args.key?(:box_coordinates)
          @circle_coordinates = args[:circle_coordinates] if args.key?(:circle_coordinates)
          @contained_in_mid = args[:contained_in_mid] if args.key?(:contained_in_mid)
          @location_mid = args[:location_mid] if args.key?(:location_mid)
          @location_mid_label = args[:location_mid_label] if args.key?(:location_mid_label)
          @location_name = args[:location_name] if args.key?(:location_name)
          @point_coordinates = args[:point_coordinates] if args.key?(:point_coordinates)
          @unformatted_coordinates = args[:unformatted_coordinates] if args.key?(:unformatted_coordinates)
        end
      end
      
      # The information representing one navboost query for the dataset source_url.
      class ResearchScienceSearchNavboostQueryInfo
        include Google::Apis::Core::Hashable
      
        # imp_count stores an estimate of the number of impressions for this tuple.
        # Corresponds to the JSON property `impCount`
        # @return [Float]
        attr_accessor :imp_count
      
        # lcc_count stores an estimate of the number of long clicks for this tuple. NOTE:
        # It is similar to query_doc_count, but calculated in different manner.
        # Corresponds to the JSON property `lccCount`
        # @return [Float]
        attr_accessor :lcc_count
      
        # The query string.
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        # The query_count stores the counts on this query.
        # Corresponds to the JSON property `queryCount`
        # @return [Float]
        attr_accessor :query_count
      
        # The query_doc_count stores the number of long-clicks on this pair.
        # Corresponds to the JSON property `queryDocCount`
        # @return [Float]
        attr_accessor :query_doc_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @imp_count = args[:imp_count] if args.key?(:imp_count)
          @lcc_count = args[:lcc_count] if args.key?(:lcc_count)
          @query = args[:query] if args.key?(:query)
          @query_count = args[:query_count] if args.key?(:query_count)
          @query_doc_count = args[:query_doc_count] if args.key?(:query_doc_count)
        end
      end
      
      # Organization, such as the source of a dataset or a funder NOTE:
      # source_organization_mid and source_organization_mid_label should always have
      # the same length: the mid and label correspond to each other. We don't use a
      # map for consistency with Location and if we switch to map, we should switch to
      # it in both. Next ID: 6
      class ResearchScienceSearchOrganization
        include Google::Apis::Core::Hashable
      
        # KG mid for the organization or person.
        # Corresponds to the JSON property `organizationMid`
        # @return [Array<String>]
        attr_accessor :organization_mid
      
        # Label (in the preferred language of the dataset) for the mid.
        # Corresponds to the JSON property `organizationMidLabel`
        # @return [Array<String>]
        attr_accessor :organization_mid_label
      
        # Unreconciled organization name. We store it here only if there are no
        # organization_mid values present.
        # Corresponds to the JSON property `organizationName`
        # @return [String]
        attr_accessor :organization_name
      
        # Original organization url
        # Corresponds to the JSON property `organizationUrl`
        # @return [String]
        attr_accessor :organization_url
      
        # Original name before reconciliation; empty if not reconciled.
        # Corresponds to the JSON property `originalOrganizationName`
        # @return [String]
        attr_accessor :original_organization_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @organization_mid = args[:organization_mid] if args.key?(:organization_mid)
          @organization_mid_label = args[:organization_mid_label] if args.key?(:organization_mid_label)
          @organization_name = args[:organization_name] if args.key?(:organization_name)
          @organization_url = args[:organization_url] if args.key?(:organization_url)
          @original_organization_name = args[:original_organization_name] if args.key?(:original_organization_name)
        end
      end
      
      # A proto for storing inferred and reconciled metadata for Science Search. Next
      # available tag: 69
      class ResearchScienceSearchReconciledMetadata
        include Google::Apis::Core::Hashable
      
        # Alternate names and acronyms for the dataset.
        # Corresponds to the JSON property `alternateName`
        # @return [Array<String>]
        attr_accessor :alternate_name
      
        # A string representation of the authors of the dataset, collected from author
        # and creator in raw metadata. The exact format (e.g., comma-separated, etc.) is
        # up to the extender that populates this field. The assumption is that this
        # string may appear in the UI "as is".
        # Corresponds to the JSON property `authorList`
        # @return [String]
        attr_accessor :author_list
      
        # Information on the catalog that this dataset comes from. Next ID: 5
        # Corresponds to the JSON property `catalog`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchCatalog]
        attr_accessor :catalog
      
        # Compact Identifiers (for example "RRID:SCR_002088") that can be resolved by
        # Identifiers.org or N2T.net meta-resolvers.
        # Corresponds to the JSON property `compactIdentifier`
        # @return [Array<String>]
        attr_accessor :compact_identifier
      
        # Compact Identifier(s) extracted from the citation field. Like in the case of
        # DOI(s) those identify the articles related to the dataset rather than the
        # dataset itself.
        # Corresponds to the JSON property `compactIdentifierFromCitation`
        # @return [Array<String>]
        attr_accessor :compact_identifier_from_citation
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `coverageEndDate`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :coverage_end_date
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `coverageStartDate`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :coverage_start_date
      
        # The dataset in downloadable form. There can be multiple data download entries
        # for different file types.
        # Corresponds to the JSON property `dataDownload`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchDataDownload>]
        attr_accessor :data_download
      
        # A hash of the raw metadata fields used by the QualityExtender.
        # Corresponds to the JSON property `datasetClassificationFieldsHash`
        # @return [Fixnum]
        attr_accessor :dataset_classification_fields_hash
      
        # Probability that the entity is in fact a dataset (in contrast to spam or
        # website labelled as dataset that does not describe a dataset).
        # Corresponds to the JSON property `datasetClassificationScore`
        # @return [Float]
        attr_accessor :dataset_classification_score
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `dateCreated`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :date_created
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `dateModified`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :date_modified
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `datePublished`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :date_published
      
        # Representation of fields that contain dates. The formattes version, if present,
        # contains ISO 8601 formatted date or range. Otherwise, it is an unformatted
        # string. Next ID: 3
        # Corresponds to the JSON property `dateUpdated`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchDate]
        attr_accessor :date_updated
      
        # 
        # Corresponds to the JSON property `denylistStatus`
        # @return [Array<String>]
        attr_accessor :denylist_status
      
        # Description of the dataset.
        # Corresponds to the JSON property `description`
        # @return [Array<String>]
        attr_accessor :description
      
        # Description of the dataset converted to HTML.
        # Corresponds to the JSON property `descriptionInHtml`
        # @return [Array<String>]
        attr_accessor :description_in_html
      
        # The DOI for the dataset. We assume that there is only one.
        # Corresponds to the JSON property `doi`
        # @return [String]
        attr_accessor :doi
      
        # DOI(s) extracted from the citation field. In contrast to the "doi" field these
        # DOIs identify the articles related to the dataset rather than the dataset
        # itself.
        # Corresponds to the JSON property `doiFromCitation`
        # @return [Array<String>]
        attr_accessor :doi_from_citation
      
        # Field of study: a general, high-level classification of the dataset. This is
        # only populated during indexing time and it is only populated if the
        # classification_source is KNOWLEDGE_GRAPH or it's above inference threshold.
        # Corresponds to the JSON property `fieldOfStudy`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchFieldOfStudyInfo>]
        attr_accessor :field_of_study
      
        # The fingerprint of basic fields from DatasetMetadata, including: - name -
        # description DEPRECATED
        # Corresponds to the JSON property `fingerprint`
        # @return [Fixnum]
        attr_accessor :fingerprint
      
        # Funder of the dataset.
        # Corresponds to the JSON property `funder`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchOrganization>]
        attr_accessor :funder
      
        # Indicates if the dataset has table summaries. This field is only populated
        # during indexing time.
        # Corresponds to the JSON property `hasTableSummaries`
        # @return [Boolean]
        attr_accessor :has_table_summaries
        alias_method :has_table_summaries?, :has_table_summaries
      
        # A unique id for the dataset. For the data from Spore, this is the spore id,
        # such as, for example "http://accession.nodc.noaa.gov/8500223#__sid=js0"
        # REQUIRED
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # An identifier as provided by the dataset itself.
        # Corresponds to the JSON property `identifierFromSource`
        # @return [Array<String>]
        attr_accessor :identifier_from_source
      
        # The image urls provided by the dataset (e.g., for thumbnail images).
        # Corresponds to the JSON property `imageUrl`
        # @return [Array<String>]
        attr_accessor :image_url
      
        # Index of this dataset in its cluster of replicas.
        # Corresponds to the JSON property `indexInCluster`
        # @return [Fixnum]
        attr_accessor :index_in_cluster
      
        # Indicates if the dataset is available for free or behind a paywal http://
        # schema.org/isAccessibleForFree
        # Corresponds to the JSON property `isAccessibleForFree`
        # @return [String]
        attr_accessor :is_accessible_for_free
      
        # A resource (most likely another dataset) from which this dataset is derived or
        # from which it is a modification or adaption. http://schema.org/isBasedOn
        # Corresponds to the JSON property `isBasedOn`
        # @return [Array<String>]
        attr_accessor :is_based_on
      
        # Keywords describing the dataset.
        # Corresponds to the JSON property `keyword`
        # @return [Array<String>]
        attr_accessor :keyword
      
        # The 2-letter language code for the source page for the dataset. Same as the
        # language code in source_url_docjoin_info. Populated only when generating
        # output for indexing.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # License for the dataset.
        # Corresponds to the JSON property `license`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchLicense>]
        attr_accessor :license
      
        # License for the dataset. DEPRECATED
        # Corresponds to the JSON property `licenseDeprecated`
        # @return [Array<String>]
        attr_accessor :license_deprecated
      
        # A technique or technology used in a Dataset corresponding to the method used
        # for measuring the corresponding variable(s) (described using variableMeasured).
        # http://schema.org/measurementTechnique
        # Corresponds to the JSON property `measurementTechnique`
        # @return [Array<String>]
        attr_accessor :measurement_technique
      
        # Mentioned URLs in the description.
        # Corresponds to the JSON property `mentionedUrls`
        # @return [Array<String>]
        attr_accessor :mentioned_urls
      
        # 
        # Corresponds to the JSON property `metadataType`
        # @return [String]
        attr_accessor :metadata_type
      
        # The names of the dataset.
        # Corresponds to the JSON property `name`
        # @return [Array<String>]
        attr_accessor :name
      
        # The number of datasets at the same source url as this dataset.
        # Corresponds to the JSON property `numberOfDatasetsAtSourceUrl`
        # @return [Fixnum]
        attr_accessor :number_of_datasets_at_source_url
      
        # The number of articles that reference this dataset.
        # Corresponds to the JSON property `numberOfScholarCitations`
        # @return [Fixnum]
        attr_accessor :number_of_scholar_citations
      
        # 
        # Corresponds to the JSON property `publication`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchCitation>]
        attr_accessor :publication
      
        # The url for the article that (likely) describes this dataset.
        # Corresponds to the JSON property `relatedArticleUrl`
        # @return [String]
        attr_accessor :related_article_url
      
        # The info of replicas of this dataset.
        # Corresponds to the JSON property `replica`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchReplica>]
        attr_accessor :replica
      
        # Ids for other instances (not different versions) of this dataset.
        # Corresponds to the JSON property `sameAs`
        # @return [Array<String>]
        attr_accessor :same_as
      
        # Query string to send to Scholar to obtain the best approximation of citations
        # to the dataset.
        # Corresponds to the JSON property `scholarQuery`
        # @return [String]
        attr_accessor :scholar_query
      
        # Data and associated metadata for a scholarly pdf article.
        # Corresponds to the JSON property `scholarlyArticle`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchScholarlyArticle]
        attr_accessor :scholarly_article
      
        # Source of the dataset: unifies provider, creator, author, publisher etc.
        # Corresponds to the JSON property `sourceOrganization`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchOrganization>]
        attr_accessor :source_organization
      
        # Source url from which we gathered the metadata
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # The proto containing all the information we extracted from docjoin, for the
        # source_url of the dataset. NEXT TAG: 17
        # Corresponds to the JSON property `sourceUrlDocjoinInfo`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchSourceUrlDocjoinInfo]
        attr_accessor :source_url_docjoin_info
      
        # Locations that describe spatial coverage of the data. If the data covers
        # multiple locations then each value corresponds to one such location,
        # describing its coordinates, mid, etc.
        # Corresponds to the JSON property `spatialCoverage`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchLocation>]
        attr_accessor :spatial_coverage
      
        # Top salient term labels that describe the dataset document body.
        # Corresponds to the JSON property `topSalientTermLabel`
        # @return [Array<String>]
        attr_accessor :top_salient_term_label
      
        # urls for the dataset, including doi.
        # Corresponds to the JSON property `url`
        # @return [Array<String>]
        attr_accessor :url
      
        # Variables that the data in the dataset captures (e.g., pressure, salinity,
        # temperature). For now, these are just strings.
        # Corresponds to the JSON property `variable`
        # @return [Array<String>]
        attr_accessor :variable
      
        # Stores the information about each cluster of versions. Versions are defined in
        # go/s2-versioning. Next available tag: 4
        # Corresponds to the JSON property `versionClusterInfo`
        # @return [Google::Apis::ContentwarehouseV1::ResearchScienceSearchVersionClusterInfo]
        attr_accessor :version_cluster_info
      
        # A hash of the raw metadata fields used by the VersionEmbeddingExtender.
        # Corresponds to the JSON property `versionEmbeddingFieldsHash`
        # @return [Fixnum]
        attr_accessor :version_embedding_fields_hash
      
        # An embedding for the dataset to be used by the VersionAggregator.
        # Corresponds to the JSON property `versionEmbeddingVector`
        # @return [Array<Float>]
        attr_accessor :version_embedding_vector
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alternate_name = args[:alternate_name] if args.key?(:alternate_name)
          @author_list = args[:author_list] if args.key?(:author_list)
          @catalog = args[:catalog] if args.key?(:catalog)
          @compact_identifier = args[:compact_identifier] if args.key?(:compact_identifier)
          @compact_identifier_from_citation = args[:compact_identifier_from_citation] if args.key?(:compact_identifier_from_citation)
          @coverage_end_date = args[:coverage_end_date] if args.key?(:coverage_end_date)
          @coverage_start_date = args[:coverage_start_date] if args.key?(:coverage_start_date)
          @data_download = args[:data_download] if args.key?(:data_download)
          @dataset_classification_fields_hash = args[:dataset_classification_fields_hash] if args.key?(:dataset_classification_fields_hash)
          @dataset_classification_score = args[:dataset_classification_score] if args.key?(:dataset_classification_score)
          @date_created = args[:date_created] if args.key?(:date_created)
          @date_modified = args[:date_modified] if args.key?(:date_modified)
          @date_published = args[:date_published] if args.key?(:date_published)
          @date_updated = args[:date_updated] if args.key?(:date_updated)
          @denylist_status = args[:denylist_status] if args.key?(:denylist_status)
          @description = args[:description] if args.key?(:description)
          @description_in_html = args[:description_in_html] if args.key?(:description_in_html)
          @doi = args[:doi] if args.key?(:doi)
          @doi_from_citation = args[:doi_from_citation] if args.key?(:doi_from_citation)
          @field_of_study = args[:field_of_study] if args.key?(:field_of_study)
          @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
          @funder = args[:funder] if args.key?(:funder)
          @has_table_summaries = args[:has_table_summaries] if args.key?(:has_table_summaries)
          @id = args[:id] if args.key?(:id)
          @identifier_from_source = args[:identifier_from_source] if args.key?(:identifier_from_source)
          @image_url = args[:image_url] if args.key?(:image_url)
          @index_in_cluster = args[:index_in_cluster] if args.key?(:index_in_cluster)
          @is_accessible_for_free = args[:is_accessible_for_free] if args.key?(:is_accessible_for_free)
          @is_based_on = args[:is_based_on] if args.key?(:is_based_on)
          @keyword = args[:keyword] if args.key?(:keyword)
          @language_code = args[:language_code] if args.key?(:language_code)
          @license = args[:license] if args.key?(:license)
          @license_deprecated = args[:license_deprecated] if args.key?(:license_deprecated)
          @measurement_technique = args[:measurement_technique] if args.key?(:measurement_technique)
          @mentioned_urls = args[:mentioned_urls] if args.key?(:mentioned_urls)
          @metadata_type = args[:metadata_type] if args.key?(:metadata_type)
          @name = args[:name] if args.key?(:name)
          @number_of_datasets_at_source_url = args[:number_of_datasets_at_source_url] if args.key?(:number_of_datasets_at_source_url)
          @number_of_scholar_citations = args[:number_of_scholar_citations] if args.key?(:number_of_scholar_citations)
          @publication = args[:publication] if args.key?(:publication)
          @related_article_url = args[:related_article_url] if args.key?(:related_article_url)
          @replica = args[:replica] if args.key?(:replica)
          @same_as = args[:same_as] if args.key?(:same_as)
          @scholar_query = args[:scholar_query] if args.key?(:scholar_query)
          @scholarly_article = args[:scholarly_article] if args.key?(:scholarly_article)
          @source_organization = args[:source_organization] if args.key?(:source_organization)
          @source_url = args[:source_url] if args.key?(:source_url)
          @source_url_docjoin_info = args[:source_url_docjoin_info] if args.key?(:source_url_docjoin_info)
          @spatial_coverage = args[:spatial_coverage] if args.key?(:spatial_coverage)
          @top_salient_term_label = args[:top_salient_term_label] if args.key?(:top_salient_term_label)
          @url = args[:url] if args.key?(:url)
          @variable = args[:variable] if args.key?(:variable)
          @version_cluster_info = args[:version_cluster_info] if args.key?(:version_cluster_info)
          @version_embedding_fields_hash = args[:version_embedding_fields_hash] if args.key?(:version_embedding_fields_hash)
          @version_embedding_vector = args[:version_embedding_vector] if args.key?(:version_embedding_vector)
        end
      end
      
      # Stores the information about a dataset replica. Next ID: 5
      class ResearchScienceSearchReplica
        include Google::Apis::Core::Hashable
      
        # The name of the catalog that the replica comes from.
        # Corresponds to the JSON property `catalogName`
        # @return [String]
        attr_accessor :catalog_name
      
        # The url of the catalog that the replica comes from.
        # Corresponds to the JSON property `catalogUrl`
        # @return [String]
        attr_accessor :catalog_url
      
        # The index of this replica in a cluster of replicas.
        # Corresponds to the JSON property `indexInCluster`
        # @return [Fixnum]
        attr_accessor :index_in_cluster
      
        # Url for the replica.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @catalog_name = args[:catalog_name] if args.key?(:catalog_name)
          @catalog_url = args[:catalog_url] if args.key?(:catalog_url)
          @index_in_cluster = args[:index_in_cluster] if args.key?(:index_in_cluster)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Data and associated metadata for a scholarly pdf article.
      class ResearchScienceSearchScholarlyArticle
        include Google::Apis::Core::Hashable
      
        # Proto containing all of the Scholar Metadata for this article.
        # Corresponds to the JSON property `citation`
        # @return [Google::Apis::ContentwarehouseV1::ScienceCitation]
        attr_accessor :citation
      
        # contains the image of the figure or table cropped out of the pdf page encoded
        # as a PNG.
        # Corresponds to the JSON property `figureOrTableImage`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :figure_or_table_image
      
        # Contains the text (as detected by OCR) contained inside the image of the
        # figure or table.
        # Corresponds to the JSON property `figureOrTableOcrText`
        # @return [String]
        attr_accessor :figure_or_table_ocr_text
      
        # The url of the landing page for the scholarly article.
        # Corresponds to the JSON property `landingPageUrl`
        # @return [String]
        attr_accessor :landing_page_url
      
        # The page number where the table and figure is located in the original pdf
        # document.
        # Corresponds to the JSON property `pageNumber`
        # @return [Fixnum]
        attr_accessor :page_number
      
        # The url where the pdf file is located for the scholarly article.
        # Corresponds to the JSON property `pdfDownloadUrl`
        # @return [String]
        attr_accessor :pdf_download_url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @citation = args[:citation] if args.key?(:citation)
          @figure_or_table_image = args[:figure_or_table_image] if args.key?(:figure_or_table_image)
          @figure_or_table_ocr_text = args[:figure_or_table_ocr_text] if args.key?(:figure_or_table_ocr_text)
          @landing_page_url = args[:landing_page_url] if args.key?(:landing_page_url)
          @page_number = args[:page_number] if args.key?(:page_number)
          @pdf_download_url = args[:pdf_download_url] if args.key?(:pdf_download_url)
        end
      end
      
      # The proto containing all the information we extracted from docjoin, for the
      # source_url of the dataset. NEXT TAG: 17
      class ResearchScienceSearchSourceUrlDocjoinInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dataSource`
        # @return [String]
        attr_accessor :data_source
      
        # The url used to display in the google search results.
        # Corresponds to the JSON property `displayUrl`
        # @return [String]
        attr_accessor :display_url
      
        # The docid of the document.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # A set of entities from /collection/field_of_studies in knowledge graph schema (
        # http://shortn/_ldBsa14lo8).
        # Corresponds to the JSON property `fieldOfStudyEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchSourceUrlDocjoinInfoWebrefEntityInfo>]
        attr_accessor :field_of_study_entity
      
        # Index tiers (BASE, UNIFIED_ZEPPELIN, etc) that the document belongs to. NOTE:
        # Each document may belong to multiple tiers. NOTE: The original data type is an
        # enum CompositeDoc::SubIndexType. However we don't want to depend on segindexer/
        # compositedoc.proto because the proto is too large. Instead, we use
        # CompositeDoc::SubIndexType_Name( subindexid) to convert into a string
        # representation. To convert string back to CompositeDoc::SubIndexType, use
        # CompositeDoc::SubIndexType_Parse.
        # Corresponds to the JSON property `indexTier`
        # @return [Array<String>]
        attr_accessor :index_tier
      
        # The language of the document in the string representation of LanguageCode.
        # Converts from Language Enum to LanguageCode through i18n/identifiers/
        # langenclanguagecodeconverter.h Please use i18n/identifiers/
        # languagecodeconverter.h for converting between LanguageCode and string
        # representation.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # The syntactic date of a dataset document that reflects the publication date of
        # the content.
        # Corresponds to the JSON property `latestPageUpdateDate`
        # @return [String]
        attr_accessor :latest_page_update_date
      
        # A sequence of Navboost queries for the dataset source_url.
        # Corresponds to the JSON property `navboostQuery`
        # @return [Array<Google::Apis::ContentwarehouseV1::ResearchScienceSearchNavboostQueryInfo>]
        attr_accessor :navboost_query
      
        # The page rank of the document.
        # Corresponds to the JSON property `pagerank`
        # @return [Fixnum]
        attr_accessor :pagerank
      
        # The result of PetacatAnnotator. Each result contains: 1. RephilClusters; 2. At
        # most 5 verticals from each taxonomy, sorted by the probabilities in descending
        # order. 3. Binary classification results about page types and sensitive content.
        # The types of taxonomies include: verticals4, geo, verticals4_geo,
        # products_services, icm_im_audiences and icm_im_audiences_dev.
        # Corresponds to the JSON property `petacatInfo`
        # @return [Google::Apis::ContentwarehouseV1::FatcatCompactDocClassification]
        attr_accessor :petacat_info
      
        # SalientTermSet is a collection of terms (unigrams and bigrams) with associated
        # weights that can describe something. The "salient terms".
        # Corresponds to the JSON property `salientTerms`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTermSet]
        attr_accessor :salient_terms
      
        # Science per-doc data for inclusion in websearch.
        # Corresponds to the JSON property `scholarInfo`
        # @return [Google::Apis::ContentwarehouseV1::ScienceIndexSignal]
        attr_accessor :scholar_info
      
        # A set of entities from WebRef annotations that are in SPORE_GRAPH.
        # Corresponds to the JSON property `sporeGraphMid`
        # @return [Array<String>]
        attr_accessor :spore_graph_mid
      
        # The title of the document.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # A set of top entities from WebrefAnnotation, top is defined by topicality
        # score, see go/topicality-score for detail. DEPRECATED. See label_to_mids_map
        # instead.
        # Corresponds to the JSON property `topEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntity>]
        attr_accessor :top_entity
      
        # The url of the document.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_source = args[:data_source] if args.key?(:data_source)
          @display_url = args[:display_url] if args.key?(:display_url)
          @docid = args[:docid] if args.key?(:docid)
          @field_of_study_entity = args[:field_of_study_entity] if args.key?(:field_of_study_entity)
          @index_tier = args[:index_tier] if args.key?(:index_tier)
          @language_code = args[:language_code] if args.key?(:language_code)
          @latest_page_update_date = args[:latest_page_update_date] if args.key?(:latest_page_update_date)
          @navboost_query = args[:navboost_query] if args.key?(:navboost_query)
          @pagerank = args[:pagerank] if args.key?(:pagerank)
          @petacat_info = args[:petacat_info] if args.key?(:petacat_info)
          @salient_terms = args[:salient_terms] if args.key?(:salient_terms)
          @scholar_info = args[:scholar_info] if args.key?(:scholar_info)
          @spore_graph_mid = args[:spore_graph_mid] if args.key?(:spore_graph_mid)
          @title = args[:title] if args.key?(:title)
          @top_entity = args[:top_entity] if args.key?(:top_entity)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # The mid and description of a WebRefEntity.
      class ResearchScienceSearchSourceUrlDocjoinInfoWebrefEntityInfo
        include Google::Apis::Core::Hashable
      
        # The English description of the mid from the KG.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The KG identifier of the WebrefEntity.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # Stores the information about each cluster of versions. Versions are defined in
      # go/s2-versioning. Next available tag: 4
      class ResearchScienceSearchVersionClusterInfo
        include Google::Apis::Core::Hashable
      
        # Index of this dataset in its cluster of versions.
        # Corresponds to the JSON property `indexInVersionCluster`
        # @return [Fixnum]
        attr_accessor :index_in_version_cluster
      
        # The number of versions in a Version Cluster. This is equivalent to cluster
        # size.
        # Corresponds to the JSON property `numVersions`
        # @return [Fixnum]
        attr_accessor :num_versions
      
        # A fingerprint id of the cluster of versions this dataset belongs to. This is a
        # hash of a dataset_id in the cluster.
        # Corresponds to the JSON property `versionClusterId`
        # @return [Fixnum]
        attr_accessor :version_cluster_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @index_in_version_cluster = args[:index_in_version_cluster] if args.key?(:index_in_version_cluster)
          @num_versions = args[:num_versions] if args.key?(:num_versions)
          @version_cluster_id = args[:version_cluster_id] if args.key?(:version_cluster_id)
        end
      end
      
      # Next ID: 11
      class RichsnippetsDataObject
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AccessKey`
        # @return [String]
        attr_accessor :access_key
      
        # 
        # Corresponds to the JSON property `attribute`
        # @return [Array<Google::Apis::ContentwarehouseV1::RichsnippetsDataObjectAttribute>]
        attr_accessor :attribute
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The object type.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_key = args[:access_key] if args.key?(:access_key)
          @attribute = args[:attribute] if args.key?(:attribute)
          @source = args[:source] if args.key?(:source)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Other attributes of the object.
      class RichsnippetsDataObjectAttribute
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cdata`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :cdata
      
        # idata holds integer data under the attribute name, and could be interpreted
        # differently according to the attribute name. Example: stores the ImadeData.
        # docid used to generate thumbnails. idata will not be automatically converted
        # into xml (the default behavior), but the behavior can be overwritten if
        # necessary.
        # Corresponds to the JSON property `idata`
        # @return [Fixnum]
        attr_accessor :idata
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `subobject`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :subobject
      
        # Whether we should tokenize the value and cdata when generating restricts from
        # this attribute.
        # Corresponds to the JSON property `tokenize`
        # @return [Boolean]
        attr_accessor :tokenize
        alias_method :tokenize?, :tokenize
      
        # Either of cdata or value should be present.
        # Corresponds to the JSON property `value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cdata = args[:cdata] if args.key?(:cdata)
          @idata = args[:idata] if args.key?(:idata)
          @name = args[:name] if args.key?(:name)
          @subobject = args[:subobject] if args.key?(:subobject)
          @tokenize = args[:tokenize] if args.key?(:tokenize)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class RichsnippetsPageMap
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DataObject`
        # @return [Array<Google::Apis::ContentwarehouseV1::RichsnippetsDataObject>]
        attr_accessor :data_object
      
        # If ignore_data_object is set to true, pagemap attachment is processed
        # regardless of whether data object is present or not.
        # Corresponds to the JSON property `ignoreDataObject`
        # @return [Boolean]
        attr_accessor :ignore_data_object
        alias_method :ignore_data_object?, :ignore_data_object
      
        # 
        # Corresponds to the JSON property `src`
        # @return [String]
        attr_accessor :src
      
        # 
        # Corresponds to the JSON property `templatetype`
        # @return [Array<Google::Apis::ContentwarehouseV1::RichsnippetsPageMapTemplateType>]
        attr_accessor :templatetype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data_object = args[:data_object] if args.key?(:data_object)
          @ignore_data_object = args[:ignore_data_object] if args.key?(:ignore_data_object)
          @src = args[:src] if args.key?(:src)
          @templatetype = args[:templatetype] if args.key?(:templatetype)
        end
      end
      
      # Unused fields
      class RichsnippetsPageMapTemplateType
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `src`
        # @return [String]
        attr_accessor :src
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @src = args[:src] if args.key?(:src)
        end
      end
      
      # Flexible multi-vertical classification output. The output for each vertical
      # should be defined as a proto extension to this proto. When defining an
      # extension for a new vertical please follow the format: message NewVertical `
      # extend safesearch.VideoClassifierOutput ` optional NewVertical
      # classifier_output_extension = ; ` optional safesearch.VideoVerticalOutput
      # vertical_output = 1; ` SafeSearch verticals only: Please also update this
      # message with a new extension declaration. For more details on extension
      # declaration please refer to http://go/proto-proposals/extension-declarations.
      # Please refer to http://go/proto2-extensions for details on message extensions.
      # LINT.IfChange next extension id: 5
      class SafesearchVideoClassifierOutput
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # SafeSearch video content classification scores are computed based on go/
      # golden7 video features. To access these scores see the library at: google3/
      # quality/safesearch/video/api/video_score_info.h
      class SafesearchVideoContentSignals
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `scores`
        # @return [Hash<String,Float>]
        attr_accessor :scores
      
        # 
        # Corresponds to the JSON property `versionTag`
        # @return [String]
        attr_accessor :version_tag
      
        # Flexible multi-vertical classification output. The output for each vertical
        # should be defined as a proto extension to this proto. When defining an
        # extension for a new vertical please follow the format: message NewVertical `
        # extend safesearch.VideoClassifierOutput ` optional NewVertical
        # classifier_output_extension = ; ` optional safesearch.VideoVerticalOutput
        # vertical_output = 1; ` SafeSearch verticals only: Please also update this
        # message with a new extension declaration. For more details on extension
        # declaration please refer to http://go/proto-proposals/extension-declarations.
        # Please refer to http://go/proto2-extensions for details on message extensions.
        # LINT.IfChange next extension id: 5
        # Corresponds to the JSON property `videoClassifierOutput`
        # @return [Google::Apis::ContentwarehouseV1::SafesearchVideoClassifierOutput]
        attr_accessor :video_classifier_output
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @scores = args[:scores] if args.key?(:scores)
          @version_tag = args[:version_tag] if args.key?(:version_tag)
          @video_classifier_output = args[:video_classifier_output] if args.key?(:video_classifier_output)
        end
      end
      
      # An input into the citation prediction model.
      class ScholarCitationPredictionSignal
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `metricType`
        # @return [String]
        attr_accessor :metric_type
      
        # 
        # Corresponds to the JSON property `signalType`
        # @return [String]
        attr_accessor :signal_type
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @metric_type = args[:metric_type] if args.key?(:metric_type)
          @signal_type = args[:signal_type] if args.key?(:signal_type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class ScienceCitation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AbstractDisplay`
        # @return [String]
        attr_accessor :abstract_display
      
        # Version of abstract field for display. Contains unsanitized XML/HTML.
        # Corresponds to the JSON property `AbstractHtml`
        # @return [String]
        attr_accessor :abstract_html
      
        # Leftovers from AbstractHtml. These are usually unrecognized xml/html entities
        # or xml/html tags
        # Corresponds to the JSON property `AbstractHtmlLeftOver`
        # @return [String]
        attr_accessor :abstract_html_left_over
      
        # 
        # Corresponds to the JSON property `AbstractLanguage`
        # @return [String]
        attr_accessor :abstract_language
      
        # 
        # Corresponds to the JSON property `AbstractSource`
        # @return [String]
        attr_accessor :abstract_source
      
        # 
        # Corresponds to the JSON property `AbstractText`
        # @return [String]
        attr_accessor :abstract_text
      
        # Fingerprint of the URL after applying crawl and aggregate rewrites. Different
        # citations with the same AlternateVersionID must have the same VersionID, but
        # not necessarily vice versa. Omitted when identical to the VersionID.
        # Corresponds to the JSON property `AlternateVersionID`
        # @return [Fixnum]
        attr_accessor :alternate_version_id
      
        # All the anchor text (before, after, formal, etc) for this citation in the
        # referring page.
        # Corresponds to the JSON property `Anchors`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationAnchor>]
        attr_accessor :anchors
      
        # e.g. hep-ph
        # Corresponds to the JSON property `ArxivSection`
        # @return [String]
        attr_accessor :arxiv_section
      
        # whether this citation had an "et al" in the author list
        # Corresponds to the JSON property `AuthorListHasEtAl`
        # @return [Boolean]
        attr_accessor :author_list_has_et_al
        alias_method :author_list_has_et_al?, :author_list_has_et_al
      
        # 
        # Corresponds to the JSON property `AuthorMetatagLeftOver`
        # @return [String]
        attr_accessor :author_metatag_left_over
      
        # Global document identifier - only available when building increments over a
        # known base index. This id is from the base index.
        # Corresponds to the JSON property `BaseGlobalID`
        # @return [Fixnum]
        attr_accessor :base_global_id
      
        # Set when building an incremental index. Whereas BaseGlobalID is the ID of the
        # corresponding base cluster, the local ID is the ID of an individual citation
        # within that base cluster that corresponds to this reparse.
        # Corresponds to the JSON property `BaseLocalID`
        # @return [Fixnum]
        attr_accessor :base_local_id
      
        # one bit per author
        # Corresponds to the JSON property `BorrowedAuthors`
        # @return [Fixnum]
        attr_accessor :borrowed_authors
      
        # OR of FieldType
        # Corresponds to the JSON property `BorrowedFields`
        # @return [Fixnum]
        attr_accessor :borrowed_fields
      
        # 
        # Corresponds to the JSON property `Chapter`
        # @return [String]
        attr_accessor :chapter
      
        # citation src: dblp/crossref/paper etc
        # Corresponds to the JSON property `CitationSource`
        # @return [Fixnum]
        attr_accessor :citation_source
      
        # url where record came from
        # Corresponds to the JSON property `CitationSourceUrl`
        # @return [String]
        attr_accessor :citation_source_url
      
        # DEPRECATED: use CitationSource
        # Corresponds to the JSON property `CitationSrc`
        # @return [String]
        attr_accessor :citation_src
      
        # Used for logging, recommendations, and sort-by-date. Contains the earliest
        # discovery date of the cluster, adjusted for earlier publication dates. Stored
        # in Universal time scale (100 ns ticks since 0001 AD) because Unix timestamp
        # would lead to negative dates for pre-1970 docs.
        # Corresponds to the JSON property `ClusterDiscoveryDate`
        # @return [Fixnum]
        attr_accessor :cluster_discovery_date
      
        # Identifier for conference series - issn-lite
        # Corresponds to the JSON property `ConferenceId`
        # @return [String]
        attr_accessor :conference_id
      
        # 27 in the "27th conference on magical realism"
        # Corresponds to the JSON property `ConferenceNumber`
        # @return [Fixnum]
        attr_accessor :conference_number
      
        # If a citation is merged from a crawled version and a metadata version, keep
        # the normal docid fp of the crawled version for clustering FP of normal docid
        # of crawl version
        # Corresponds to the JSON property `CrawledDocid`
        # @return [Fixnum]
        attr_accessor :crawled_docid
      
        # 
        # Corresponds to the JSON property `DEPRECATEDMetadataSourceFile`
        # @return [String]
        attr_accessor :deprecated_metadata_source_file
      
        # these fields moved to DownloadURL where they belong
        # Corresponds to the JSON property `DEPRECATEDPublisherDisplayName`
        # @return [String]
        attr_accessor :deprecated_publisher_display_name
      
        # Digital Object Identifier
        # Corresponds to the JSON property `DOI`
        # @return [String]
        attr_accessor :doi
      
        # 
        # Corresponds to the JSON property `DblpId`
        # @return [String]
        attr_accessor :dblp_id
      
        # Local document identifier - url fingerprint if we know the url, or fingerprint
        # of all fields if we don't. Different urls have different local docids.
        # Corresponds to the JSON property `DocumentID`
        # @return [Fixnum]
        attr_accessor :document_id
      
        # Dspace uses handle.net handles
        # Corresponds to the JSON property `DspaceID`
        # @return [String]
        attr_accessor :dspace_id
      
        # 
        # Corresponds to the JSON property `Edition`
        # @return [String]
        attr_accessor :edition
      
        # 
        # Corresponds to the JSON property `Editor`
        # @return [Array<String>]
        attr_accessor :editor
      
        # 
        # Corresponds to the JSON property `FileCreationDay`
        # @return [Fixnum]
        attr_accessor :file_creation_day
      
        # zero-indexed field
        # Corresponds to the JSON property `FileCreationMonth`
        # @return [Fixnum]
        attr_accessor :file_creation_month
      
        # date of creation of the pdf/doc
        # Corresponds to the JSON property `FileCreationYear`
        # @return [Fixnum]
        attr_accessor :file_creation_year
      
        # 
        # Corresponds to the JSON property `ISBN`
        # @return [String]
        attr_accessor :isbn
      
        # 
        # Corresponds to the JSON property `ISBNVariant`
        # @return [Array<String>]
        attr_accessor :isbn_variant
      
        # 
        # Corresponds to the JSON property `ISSN`
        # @return [String]
        attr_accessor :issn
      
        # 
        # Corresponds to the JSON property `ISSNVariant`
        # @return [Array<String>]
        attr_accessor :issn_variant
      
        # Is this article expected to have been indexed in the incremental?
        # Corresponds to the JSON property `IncrementalExpected`
        # @return [Boolean]
        attr_accessor :incremental_expected
        alias_method :incremental_expected?, :incremental_expected
      
        # 
        # Corresponds to the JSON property `JOI`
        # @return [String]
        attr_accessor :joi
      
        # 
        # Corresponds to the JSON property `Keywords`
        # @return [Array<String>]
        attr_accessor :keywords
      
        # library of congress call number
        # Corresponds to the JSON property `LCCN`
        # @return [String]
        attr_accessor :lccn
      
        # 
        # Corresponds to the JSON property `Language`
        # @return [String]
        attr_accessor :language
      
        # The ScienceCitation is how metadata passes through the scholar system. For
        # legal, we use the normal ScienceCitation for the metadata/citation of legal
        # journals. For court/government documents (like opinions or statues), we wrap
        # it in the following embedded message
        # Corresponds to the JSON property `LegalCitation`
        # @return [Google::Apis::ContentwarehouseV1::LegalCitation]
        attr_accessor :legal_citation
      
        # If this is a target reference, the level of discussion of this reference.
        # Corresponds to the JSON property `LevelOfDiscussion`
        # @return [Fixnum]
        attr_accessor :level_of_discussion
      
        # random string data - unparsed
        # Corresponds to the JSON property `Note`
        # @return [String]
        attr_accessor :note
      
        # for display in gws
        # Corresponds to the JSON property `NumBackwardLinks`
        # @return [Fixnum]
        attr_accessor :num_backward_links
      
        # hack for legal rollout
        # Corresponds to the JSON property `NumBackwardLinksFromLegal`
        # @return [Fixnum]
        attr_accessor :num_backward_links_from_legal
      
        # numcited in WoS
        # Corresponds to the JSON property `NumBackwardLinksInWoS`
        # @return [Fixnum]
        attr_accessor :num_backward_links_in_wo_s
      
        # for display in gws
        # Corresponds to the JSON property `NumForwardLinks`
        # @return [Fixnum]
        attr_accessor :num_forward_links
      
        # good embedded refs
        # Corresponds to the JSON property `NumGoodEmbeddedRefs`
        # @return [Fixnum]
        attr_accessor :num_good_embedded_refs
      
        # If set, then we host this many pages of this citation's content. Note that
        # this field may be set to 0, in which case we should be hosting this content
        # but have failed. DEPRECATED, moved to DownloadURL
        # Corresponds to the JSON property `NumHostedPages`
        # @return [Fixnum]
        attr_accessor :num_hosted_pages
      
        # for display in gws
        # Corresponds to the JSON property `NumKeyQuotes`
        # @return [Fixnum]
        attr_accessor :num_key_quotes
      
        # for display in gws
        # Corresponds to the JSON property `NumRelated`
        # @return [Fixnum]
        attr_accessor :num_related
      
        # for experiments
        # Corresponds to the JSON property `NumRelated2`
        # @return [Fixnum]
        attr_accessor :num_related2
      
        # for experiments
        # Corresponds to the JSON property `NumRelated3`
        # @return [Fixnum]
        attr_accessor :num_related3
      
        # refs in marked section
        # Corresponds to the JSON property `NumSectionRefs`
        # @return [Fixnum]
        attr_accessor :num_section_refs
      
        # for display in gws
        # Corresponds to the JSON property `NumVersions`
        # @return [Fixnum]
        attr_accessor :num_versions
      
        # can be 1-3
        # Corresponds to the JSON property `Number`
        # @return [String]
        attr_accessor :number
      
        # 
        # Corresponds to the JSON property `OnlineDay`
        # @return [Fixnum]
        attr_accessor :online_day
      
        # OnlineMonth is a zero-indexed field (0 is January).
        # Corresponds to the JSON property `OnlineMonth`
        # @return [Fixnum]
        attr_accessor :online_month
      
        # 
        # Corresponds to the JSON property `OnlineYear`
        # @return [Fixnum]
        attr_accessor :online_year
      
        # eg ERIC doc number or TR number
        # Corresponds to the JSON property `OtherID`
        # @return [String]
        attr_accessor :other_id
      
        # 
        # Corresponds to the JSON property `PMCID`
        # @return [String]
        attr_accessor :pmcid
      
        # Pubmed ID
        # Corresponds to the JSON property `PMID`
        # @return [String]
        attr_accessor :pmid
      
        # Using string to handle all kinds of page specifications. Internal structure is
        # not really needed.
        # Corresponds to the JSON property `Pages`
        # @return [String]
        attr_accessor :pages
      
        # 
        # Corresponds to the JSON property `ParseSource`
        # @return [Fixnum]
        attr_accessor :parse_source
      
        # Note that an issued patent has a PatentNumber and can also have a
        # PatentApplicationNumber, whereas a patent application has a
        # PatentApplicationNumber and can also have a PatentPublicationNumber.
        # Corresponds to the JSON property `PatentApplicationNumber`
        # @return [String]
        attr_accessor :patent_application_number
      
        # patent classification e.g., "B24B 3100"
        # Corresponds to the JSON property `PatentClassification`
        # @return [Array<String>]
        attr_accessor :patent_classification
      
        # 2-letter country code where patent was issued, see ocean/metadata/
        # patent_record.proto::Patent_Record::country_code for EPO one patent pertains
        # to a list of countries.
        # Corresponds to the JSON property `PatentCountry`
        # @return [Array<String>]
        attr_accessor :patent_country
      
        # number according to USPTO/EPO/JPO scheme.
        # Corresponds to the JSON property `PatentNumber`
        # @return [String]
        attr_accessor :patent_number
      
        # one of the above
        # Corresponds to the JSON property `PatentOffice`
        # @return [Fixnum]
        attr_accessor :patent_office
      
        # 
        # Corresponds to the JSON property `PatentPublicationNumber`
        # @return [String]
        attr_accessor :patent_publication_number
      
        # for patents, publicationD/M/Y is the date of issue, not application
        # Corresponds to the JSON property `PublicationDay`
        # @return [Fixnum]
        attr_accessor :publication_day
      
        # month from bibtex PublicationMonth is a zero-indexed field (0 is January).
        # Corresponds to the JSON property `PublicationMonth`
        # @return [Fixnum]
        attr_accessor :publication_month
      
        # where published - subsumes booktitle, howpublished and journal from bibtex
        # Corresponds to the JSON property `PublicationVenue`
        # @return [String]
        attr_accessor :publication_venue
      
        # 
        # Corresponds to the JSON property `PublicationVenueVariant`
        # @return [Array<String>]
        attr_accessor :publication_venue_variant
      
        # year from bibtext full year
        # Corresponds to the JSON property `PublicationYear`
        # @return [Fixnum]
        attr_accessor :publication_year
      
        # address from bibtex
        # Corresponds to the JSON property `PublisherAddress`
        # @return [String]
        attr_accessor :publisher_address
      
        # 
        # Corresponds to the JSON property `PublisherId`
        # @return [String]
        attr_accessor :publisher_id
      
        # subsumes organization, school and institution from bibtex
        # Corresponds to the JSON property `PublisherOrg`
        # @return [String]
        attr_accessor :publisher_org
      
        # local journal number
        # Corresponds to the JSON property `PubvenueID`
        # @return [String]
        attr_accessor :pubvenue_id
      
        # bitmap of ReviewArticleTypeReasons
        # Corresponds to the JSON property `ReviewTypeReason`
        # @return [Fixnum]
        attr_accessor :review_type_reason
      
        # 
        # Corresponds to the JSON property `SICI`
        # @return [String]
        attr_accessor :sici
      
        # 
        # Corresponds to the JSON property `Series`
        # @return [String]
        attr_accessor :series
      
        # 
        # Corresponds to the JSON property `Title`
        # @return [String]
        attr_accessor :title
      
        # Version of title for display. Contains unsanitized HTML/XML.
        # Corresponds to the JSON property `TitleHtml`
        # @return [String]
        attr_accessor :title_html
      
        # Leftovers from TitleHtml. These are usually unrecognized xml/html entities or
        # xml/html tags
        # Corresponds to the JSON property `TitleHtmlLeftOver`
        # @return [String]
        attr_accessor :title_html_left_over
      
        # etal marker for the translated author list - just in case
        # Corresponds to the JSON property `TranslatedAuthorListHasEtAl`
        # @return [Boolean]
        attr_accessor :translated_author_list_has_et_al
        alias_method :translated_author_list_has_et_al?, :translated_author_list_has_et_al
      
        # ArticleType
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        # Email addresses found in the document that we weren't able to match
        # Corresponds to the JSON property `UnmatchedEmailAddr`
        # @return [Array<String>]
        attr_accessor :unmatched_email_addr
      
        # Author affiliations found in the document that we weren't able to match up to
        # specific authors.
        # Corresponds to the JSON property `UnmatchedInstitution`
        # @return [Array<String>]
        attr_accessor :unmatched_institution
      
        # Document version identifier - fingerprint of an id computed from the url, or
        # of bibliographic data from a publisher. Different urls for the same article
        # from the same source have the same version id (e.g., abstract, pdf version,
        # and html version).
        # Corresponds to the JSON property `VersionID`
        # @return [Fixnum]
        attr_accessor :version_id
      
        # 
        # Corresponds to the JSON property `Volume`
        # @return [Fixnum]
        attr_accessor :volume
      
        # Web of Science ID
        # Corresponds to the JSON property `WOSID`
        # @return [String]
        attr_accessor :wosid
      
        # Is this version of the article world viewable?
        # Corresponds to the JSON property `WorldViewable`
        # @return [Boolean]
        attr_accessor :world_viewable
        alias_method :world_viewable?, :world_viewable
      
        # 
        # Corresponds to the JSON property `accessurl`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationAccessUrl>]
        attr_accessor :accessurl
      
        # 
        # Corresponds to the JSON property `alternateabstract`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationAlternateAbstract>]
        attr_accessor :alternateabstract
      
        # 
        # Corresponds to the JSON property `alternatetitle`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationAlternateTitle>]
        attr_accessor :alternatetitle
      
        # 
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationAuthor>]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `category`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationCategory>]
        attr_accessor :category
      
        # 
        # Corresponds to the JSON property `downloadurl`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationDownloadUrl>]
        attr_accessor :downloadurl
      
        # 
        # Corresponds to the JSON property `funding`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationFunding>]
        attr_accessor :funding
      
        # 
        # Corresponds to the JSON property `referencediscussion`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationReferenceDiscussion>]
        attr_accessor :referencediscussion
      
        # 
        # Corresponds to the JSON property `subject`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationSubject>]
        attr_accessor :subject
      
        # 
        # Corresponds to the JSON property `translatedauthor`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationTranslatedAuthor>]
        attr_accessor :translatedauthor
      
        # 
        # Corresponds to the JSON property `unioncatalog`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceCitationUnionCatalog>]
        attr_accessor :unioncatalog
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abstract_display = args[:abstract_display] if args.key?(:abstract_display)
          @abstract_html = args[:abstract_html] if args.key?(:abstract_html)
          @abstract_html_left_over = args[:abstract_html_left_over] if args.key?(:abstract_html_left_over)
          @abstract_language = args[:abstract_language] if args.key?(:abstract_language)
          @abstract_source = args[:abstract_source] if args.key?(:abstract_source)
          @abstract_text = args[:abstract_text] if args.key?(:abstract_text)
          @alternate_version_id = args[:alternate_version_id] if args.key?(:alternate_version_id)
          @anchors = args[:anchors] if args.key?(:anchors)
          @arxiv_section = args[:arxiv_section] if args.key?(:arxiv_section)
          @author_list_has_et_al = args[:author_list_has_et_al] if args.key?(:author_list_has_et_al)
          @author_metatag_left_over = args[:author_metatag_left_over] if args.key?(:author_metatag_left_over)
          @base_global_id = args[:base_global_id] if args.key?(:base_global_id)
          @base_local_id = args[:base_local_id] if args.key?(:base_local_id)
          @borrowed_authors = args[:borrowed_authors] if args.key?(:borrowed_authors)
          @borrowed_fields = args[:borrowed_fields] if args.key?(:borrowed_fields)
          @chapter = args[:chapter] if args.key?(:chapter)
          @citation_source = args[:citation_source] if args.key?(:citation_source)
          @citation_source_url = args[:citation_source_url] if args.key?(:citation_source_url)
          @citation_src = args[:citation_src] if args.key?(:citation_src)
          @cluster_discovery_date = args[:cluster_discovery_date] if args.key?(:cluster_discovery_date)
          @conference_id = args[:conference_id] if args.key?(:conference_id)
          @conference_number = args[:conference_number] if args.key?(:conference_number)
          @crawled_docid = args[:crawled_docid] if args.key?(:crawled_docid)
          @deprecated_metadata_source_file = args[:deprecated_metadata_source_file] if args.key?(:deprecated_metadata_source_file)
          @deprecated_publisher_display_name = args[:deprecated_publisher_display_name] if args.key?(:deprecated_publisher_display_name)
          @doi = args[:doi] if args.key?(:doi)
          @dblp_id = args[:dblp_id] if args.key?(:dblp_id)
          @document_id = args[:document_id] if args.key?(:document_id)
          @dspace_id = args[:dspace_id] if args.key?(:dspace_id)
          @edition = args[:edition] if args.key?(:edition)
          @editor = args[:editor] if args.key?(:editor)
          @file_creation_day = args[:file_creation_day] if args.key?(:file_creation_day)
          @file_creation_month = args[:file_creation_month] if args.key?(:file_creation_month)
          @file_creation_year = args[:file_creation_year] if args.key?(:file_creation_year)
          @isbn = args[:isbn] if args.key?(:isbn)
          @isbn_variant = args[:isbn_variant] if args.key?(:isbn_variant)
          @issn = args[:issn] if args.key?(:issn)
          @issn_variant = args[:issn_variant] if args.key?(:issn_variant)
          @incremental_expected = args[:incremental_expected] if args.key?(:incremental_expected)
          @joi = args[:joi] if args.key?(:joi)
          @keywords = args[:keywords] if args.key?(:keywords)
          @lccn = args[:lccn] if args.key?(:lccn)
          @language = args[:language] if args.key?(:language)
          @legal_citation = args[:legal_citation] if args.key?(:legal_citation)
          @level_of_discussion = args[:level_of_discussion] if args.key?(:level_of_discussion)
          @note = args[:note] if args.key?(:note)
          @num_backward_links = args[:num_backward_links] if args.key?(:num_backward_links)
          @num_backward_links_from_legal = args[:num_backward_links_from_legal] if args.key?(:num_backward_links_from_legal)
          @num_backward_links_in_wo_s = args[:num_backward_links_in_wo_s] if args.key?(:num_backward_links_in_wo_s)
          @num_forward_links = args[:num_forward_links] if args.key?(:num_forward_links)
          @num_good_embedded_refs = args[:num_good_embedded_refs] if args.key?(:num_good_embedded_refs)
          @num_hosted_pages = args[:num_hosted_pages] if args.key?(:num_hosted_pages)
          @num_key_quotes = args[:num_key_quotes] if args.key?(:num_key_quotes)
          @num_related = args[:num_related] if args.key?(:num_related)
          @num_related2 = args[:num_related2] if args.key?(:num_related2)
          @num_related3 = args[:num_related3] if args.key?(:num_related3)
          @num_section_refs = args[:num_section_refs] if args.key?(:num_section_refs)
          @num_versions = args[:num_versions] if args.key?(:num_versions)
          @number = args[:number] if args.key?(:number)
          @online_day = args[:online_day] if args.key?(:online_day)
          @online_month = args[:online_month] if args.key?(:online_month)
          @online_year = args[:online_year] if args.key?(:online_year)
          @other_id = args[:other_id] if args.key?(:other_id)
          @pmcid = args[:pmcid] if args.key?(:pmcid)
          @pmid = args[:pmid] if args.key?(:pmid)
          @pages = args[:pages] if args.key?(:pages)
          @parse_source = args[:parse_source] if args.key?(:parse_source)
          @patent_application_number = args[:patent_application_number] if args.key?(:patent_application_number)
          @patent_classification = args[:patent_classification] if args.key?(:patent_classification)
          @patent_country = args[:patent_country] if args.key?(:patent_country)
          @patent_number = args[:patent_number] if args.key?(:patent_number)
          @patent_office = args[:patent_office] if args.key?(:patent_office)
          @patent_publication_number = args[:patent_publication_number] if args.key?(:patent_publication_number)
          @publication_day = args[:publication_day] if args.key?(:publication_day)
          @publication_month = args[:publication_month] if args.key?(:publication_month)
          @publication_venue = args[:publication_venue] if args.key?(:publication_venue)
          @publication_venue_variant = args[:publication_venue_variant] if args.key?(:publication_venue_variant)
          @publication_year = args[:publication_year] if args.key?(:publication_year)
          @publisher_address = args[:publisher_address] if args.key?(:publisher_address)
          @publisher_id = args[:publisher_id] if args.key?(:publisher_id)
          @publisher_org = args[:publisher_org] if args.key?(:publisher_org)
          @pubvenue_id = args[:pubvenue_id] if args.key?(:pubvenue_id)
          @review_type_reason = args[:review_type_reason] if args.key?(:review_type_reason)
          @sici = args[:sici] if args.key?(:sici)
          @series = args[:series] if args.key?(:series)
          @title = args[:title] if args.key?(:title)
          @title_html = args[:title_html] if args.key?(:title_html)
          @title_html_left_over = args[:title_html_left_over] if args.key?(:title_html_left_over)
          @translated_author_list_has_et_al = args[:translated_author_list_has_et_al] if args.key?(:translated_author_list_has_et_al)
          @type = args[:type] if args.key?(:type)
          @unmatched_email_addr = args[:unmatched_email_addr] if args.key?(:unmatched_email_addr)
          @unmatched_institution = args[:unmatched_institution] if args.key?(:unmatched_institution)
          @version_id = args[:version_id] if args.key?(:version_id)
          @volume = args[:volume] if args.key?(:volume)
          @wosid = args[:wosid] if args.key?(:wosid)
          @world_viewable = args[:world_viewable] if args.key?(:world_viewable)
          @accessurl = args[:accessurl] if args.key?(:accessurl)
          @alternateabstract = args[:alternateabstract] if args.key?(:alternateabstract)
          @alternatetitle = args[:alternatetitle] if args.key?(:alternatetitle)
          @author = args[:author] if args.key?(:author)
          @category = args[:category] if args.key?(:category)
          @downloadurl = args[:downloadurl] if args.key?(:downloadurl)
          @funding = args[:funding] if args.key?(:funding)
          @referencediscussion = args[:referencediscussion] if args.key?(:referencediscussion)
          @subject = args[:subject] if args.key?(:subject)
          @translatedauthor = args[:translatedauthor] if args.key?(:translatedauthor)
          @unioncatalog = args[:unioncatalog] if args.key?(:unioncatalog)
        end
      end
      
      # User-defined URL and its last access data for citation manager.
      class ScienceCitationAccessUrl
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AccessDay`
        # @return [Fixnum]
        attr_accessor :access_day
      
        # AccessMonth is a zero-indexed field (0 is January).
        # Corresponds to the JSON property `AccessMonth`
        # @return [Fixnum]
        attr_accessor :access_month
      
        # 
        # Corresponds to the JSON property `AccessYear`
        # @return [Fixnum]
        attr_accessor :access_year
      
        # 
        # Corresponds to the JSON property `UrlStr`
        # @return [String]
        attr_accessor :url_str
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_day = args[:access_day] if args.key?(:access_day)
          @access_month = args[:access_month] if args.key?(:access_month)
          @access_year = args[:access_year] if args.key?(:access_year)
          @url_str = args[:url_str] if args.key?(:url_str)
        end
      end
      
      # There are templated functions that fill the abstract fields designed to take
      # either ScienceCitation or ScienceCitation::AlternateAbstract, so these field
      # names must match those used for the primary abstract.
      class ScienceCitationAlternateAbstract
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `AbstractDisplay`
        # @return [String]
        attr_accessor :abstract_display
      
        # Version of abstract field for display. This may contain XML/HTML tags.
        # Corresponds to the JSON property `AbstractHtml`
        # @return [String]
        attr_accessor :abstract_html
      
        # Leftovers from AbstractHtml. These are usually unrecognized xml/html entities
        # or xml/html tags
        # Corresponds to the JSON property `AbstractHtmlLeftOver`
        # @return [String]
        attr_accessor :abstract_html_left_over
      
        # 
        # Corresponds to the JSON property `AbstractLanguage`
        # @return [String]
        attr_accessor :abstract_language
      
        # 
        # Corresponds to the JSON property `AbstractText`
        # @return [String]
        attr_accessor :abstract_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abstract_display = args[:abstract_display] if args.key?(:abstract_display)
          @abstract_html = args[:abstract_html] if args.key?(:abstract_html)
          @abstract_html_left_over = args[:abstract_html_left_over] if args.key?(:abstract_html_left_over)
          @abstract_language = args[:abstract_language] if args.key?(:abstract_language)
          @abstract_text = args[:abstract_text] if args.key?(:abstract_text)
        end
      end
      
      # alternate titles (including language where available)
      class ScienceCitationAlternateTitle
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `Title`
        # @return [String]
        attr_accessor :title
      
        # Version of title for display. Contains unsanitized HTML/XML.
        # Corresponds to the JSON property `TitleHtml`
        # @return [String]
        attr_accessor :title_html
      
        # Leftovers from TitleHtml. These are usually unrecognized xml/html entities or
        # xml/html tags
        # Corresponds to the JSON property `TitleHtmlLeftOver`
        # @return [String]
        attr_accessor :title_html_left_over
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @title = args[:title] if args.key?(:title)
          @title_html = args[:title_html] if args.key?(:title_html)
          @title_html_left_over = args[:title_html_left_over] if args.key?(:title_html_left_over)
        end
      end
      
      # The anchor class holds content relevant to a citation, for example, the text
      # before or after the citation that explains what the citation is about.
      class ScienceCitationAnchor
        include Google::Apis::Core::Hashable
      
        # Fingerprint of the referral document. The fingerprint should resist to small
        # variance in the document content. DO NOT USE IT!
        # Corresponds to the JSON property `DEPRECATEDSrcFP`
        # @return [Fixnum]
        attr_accessor :deprecated_src_fp
      
        # Number of times this anchor text appears, only consider the text itself
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # font face bitmask: kBold, kItalic, etc.
        # Corresponds to the JSON property `face`
        # @return [Fixnum]
        attr_accessor :face
      
        # font size, in px
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        # Space-delimited anchor words. Text that needs segmentation (like CJK or Thai)
        # is unsegmented. Generated by ScienceParseUtils::AppendTokenSeqToString()
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # one of the "Type" value defined below.
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        # weight of the anchor by looking where we get this anchor text. It can be PR,
        # court level, year, or the combination of differerent aspects. weights are 1 -
        # 128 defined as "Weights"
        # Corresponds to the JSON property `weight`
        # @return [Fixnum]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_src_fp = args[:deprecated_src_fp] if args.key?(:deprecated_src_fp)
          @count = args[:count] if args.key?(:count)
          @face = args[:face] if args.key?(:face)
          @size = args[:size] if args.key?(:size)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # author names should be in the order specified in the paper
      class ScienceCitationAuthor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Comment`
        # @return [String]
        attr_accessor :comment
      
        # not in bibtex - from paper
        # Corresponds to the JSON property `Department`
        # @return [String]
        attr_accessor :department
      
        # 
        # Corresponds to the JSON property `Email`
        # @return [String]
        attr_accessor :email
      
        # Tracks the GuessNameOrder case used to parse this author name, defaults to 0
        # simply means that GuessNameOrder wasn't used.
        # Corresponds to the JSON property `GuessOrderType`
        # @return [Fixnum]
        attr_accessor :guess_order_type
      
        # Author ID. Formatted as idtype:id
        # Corresponds to the JSON property `ID`
        # @return [Array<String>]
        attr_accessor :id
      
        # not in bibtex - from paper
        # Corresponds to the JSON property `Institution`
        # @return [String]
        attr_accessor :institution
      
        # 
        # Corresponds to the JSON property `IsCJKForeignName`
        # @return [Boolean]
        attr_accessor :is_cjk_foreign_name
        alias_method :is_cjk_foreign_name?, :is_cjk_foreign_name
      
        # 
        # Corresponds to the JSON property `IsCorrespondingAuthor`
        # @return [Boolean]
        attr_accessor :is_corresponding_author
        alias_method :is_corresponding_author?, :is_corresponding_author
      
        # 
        # Corresponds to the JSON property `LastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `OtherNames`
        # @return [String]
        attr_accessor :other_names
      
        # 
        # Corresponds to the JSON property `SourceText`
        # @return [String]
        attr_accessor :source_text
      
        # Type is one of the contributors types. Writers are the default.
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @comment = args[:comment] if args.key?(:comment)
          @department = args[:department] if args.key?(:department)
          @email = args[:email] if args.key?(:email)
          @guess_order_type = args[:guess_order_type] if args.key?(:guess_order_type)
          @id = args[:id] if args.key?(:id)
          @institution = args[:institution] if args.key?(:institution)
          @is_cjk_foreign_name = args[:is_cjk_foreign_name] if args.key?(:is_cjk_foreign_name)
          @is_corresponding_author = args[:is_corresponding_author] if args.key?(:is_corresponding_author)
          @last_name = args[:last_name] if args.key?(:last_name)
          @other_names = args[:other_names] if args.key?(:other_names)
          @source_text = args[:source_text] if args.key?(:source_text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class ScienceCitationCategory
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Name`
        # @return [String]
        attr_accessor :name
      
        # ontology/set of categories for the category
        # Corresponds to the JSON property `Type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Download URL mentioned in citation; we keep up to K of them LINT.IfChange
      class ScienceCitationDownloadUrl
        include Google::Apis::Core::Hashable
      
        # set if we know the landing page is broken
        # Corresponds to the JSON property `BrokenLandingPage`
        # @return [Boolean]
        attr_accessor :broken_landing_page
        alias_method :broken_landing_page?, :broken_landing_page
      
        # 
        # Corresponds to the JSON property `CanonicalUrlfp`
        # @return [Fixnum]
        attr_accessor :canonical_urlfp
      
        # checksum of the page
        # Corresponds to the JSON property `ContentChecksum`
        # @return [Fixnum]
        attr_accessor :content_checksum
      
        # makes gws display nicer :)
        # Corresponds to the JSON property `ContentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # seconds since the epoch
        # Corresponds to the JSON property `CrawlTimestamp`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp
      
        # metatag: URL; result was taken down
        # Corresponds to the JSON property `DMCANotice`
        # @return [String]
        attr_accessor :dmca_notice
      
        # publisher display name
        # Corresponds to the JSON property `DisplayOrg`
        # @return [String]
        attr_accessor :display_org
      
        # display preference score
        # Corresponds to the JSON property `DisplayPriority`
        # @return [Fixnum]
        attr_accessor :display_priority
      
        # 
        # Corresponds to the JSON property `DownloadDay`
        # @return [Fixnum]
        attr_accessor :download_day
      
        # DownloadMonth is a zero-indexed field (0 is January).
        # Corresponds to the JSON property `DownloadMonth`
        # @return [Fixnum]
        attr_accessor :download_month
      
        # no abbrv
        # Corresponds to the JSON property `DownloadYear`
        # @return [Fixnum]
        attr_accessor :download_year
      
        # first few lines of abstract'ish excerpt
        # Corresponds to the JSON property `ExcerptContent`
        # @return [String]
        attr_accessor :excerpt_content
      
        # label for excerpt (abstract, summary, ..)
        # Corresponds to the JSON property `ExcerptDebugLabel`
        # @return [String]
        attr_accessor :excerpt_debug_label
      
        # seconds since the epoch
        # Corresponds to the JSON property `FirstDiscovered`
        # @return [Fixnum]
        attr_accessor :first_discovered
      
        # explicit zero means hosting failed
        # Corresponds to the JSON property `HostedNumPages`
        # @return [Fixnum]
        attr_accessor :hosted_num_pages
      
        # 
        # Corresponds to the JSON property `HostedStartPage`
        # @return [Fixnum]
        attr_accessor :hosted_start_page
      
        # html title of the page
        # Corresponds to the JSON property `HtmlTitle`
        # @return [String]
        attr_accessor :html_title
      
        # is url included in a previous index
        # Corresponds to the JSON property `InPrevIndex`
        # @return [Boolean]
        attr_accessor :in_prev_index
        alias_method :in_prev_index?, :in_prev_index
      
        # indexing preference score
        # Corresponds to the JSON property `IndexPriority`
        # @return [Fixnum]
        attr_accessor :index_priority
      
        # e.g., in law_articles.pat
        # Corresponds to the JSON property `LegalMustInclude`
        # @return [Boolean]
        attr_accessor :legal_must_include
        alias_method :legal_must_include?, :legal_must_include
      
        # Whether this is likely the URL for an ahead print, at indexing time.
        # Corresponds to the JSON property `LikelyAheadPrint`
        # @return [Boolean]
        attr_accessor :likely_ahead_print
        alias_method :likely_ahead_print?, :likely_ahead_print
      
        # In the context of a given venue in Scholar Metrics, whether this URL likely
        # does not link to the current venue.
        # Corresponds to the JSON property `LikelyDifferentMetricsVenue`
        # @return [Boolean]
        attr_accessor :likely_different_metrics_venue
        alias_method :likely_different_metrics_venue?, :likely_different_metrics_venue
      
        # e.g., in legal_journals.pat
        # Corresponds to the JSON property `LikelyLegalJournal`
        # @return [Boolean]
        attr_accessor :likely_legal_journal
        alias_method :likely_legal_journal?, :likely_legal_journal
      
        # badurls_nocache at indexing time
        # Corresponds to the JSON property `LikelyNoCache`
        # @return [Boolean]
        attr_accessor :likely_no_cache
        alias_method :likely_no_cache?, :likely_no_cache
      
        # badurls_noreturngws at indexing time
        # Corresponds to the JSON property `LikelyNoIndex`
        # @return [Boolean]
        attr_accessor :likely_no_index
        alias_method :likely_no_index?, :likely_no_index
      
        # Likely to be free-to-read for everyone, after accounting for library links etc.
        # Corresponds to the JSON property `LikelyWorldViewable`
        # @return [Boolean]
        attr_accessor :likely_world_viewable
        alias_method :likely_world_viewable?, :likely_world_viewable
      
        # number of long paragraphs
        # Corresponds to the JSON property `LongChunkCount`
        # @return [Fixnum]
        attr_accessor :long_chunk_count
      
        # Incremental only: mark as NoIndexed if this is a reparse and the base version
        # is NoIndexed.
        # Corresponds to the JSON property `MaybeNoIndexReparse`
        # @return [Boolean]
        attr_accessor :maybe_no_index_reparse
        alias_method :maybe_no_index_reparse?, :maybe_no_index_reparse
      
        # url of publisher metadata file
        # Corresponds to the JSON property `MetadataUrl`
        # @return [String]
        attr_accessor :metadata_url
      
        # e.g., in science_articles.pat
        # Corresponds to the JSON property `MustInclude`
        # @return [Boolean]
        attr_accessor :must_include
        alias_method :must_include?, :must_include
      
        # metatag: don't show cached version
        # Corresponds to the JSON property `NoArchive`
        # @return [Boolean]
        attr_accessor :no_archive
        alias_method :no_archive?, :no_archive
      
        # metatag: don't display this url
        # Corresponds to the JSON property `NoIndex`
        # @return [Boolean]
        attr_accessor :no_index
        alias_method :no_index?, :no_index
      
        # metatag: don't show snippet
        # Corresponds to the JSON property `NoSnippet`
        # @return [Boolean]
        attr_accessor :no_snippet
        alias_method :no_snippet?, :no_snippet
      
        # Describes the viewability of ocean content.
        # Corresponds to the JSON property `OceanView`
        # @return [Google::Apis::ContentwarehouseV1::ScienceOceanView]
        attr_accessor :ocean_view
      
        # number of external URLs (in PDF).
        # Corresponds to the JSON property `OutLinkCount`
        # @return [Fixnum]
        attr_accessor :out_link_count
      
        # Number of pages in the pdf2html conversion output. Only set for PDFs. For a
        # partitioned PDF, this is the page count of the entire volume.
        # Corresponds to the JSON property `PageCount`
        # @return [Fixnum]
        attr_accessor :page_count
      
        # were references parsed in a previous index
        # Corresponds to the JSON property `ReferencesInPrevIndex`
        # @return [Boolean]
        attr_accessor :references_in_prev_index
        alias_method :references_in_prev_index?, :references_in_prev_index
      
        # ArticleType for this particular url
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `UrlAfterRedirects`
        # @return [String]
        attr_accessor :url_after_redirects
      
        # 
        # Corresponds to the JSON property `UrlStr`
        # @return [String]
        attr_accessor :url_str
      
        # number of words in content/body
        # Corresponds to the JSON property `WordCount`
        # @return [Fixnum]
        attr_accessor :word_count
      
        # metatag: is viewable by world
        # Corresponds to the JSON property `WorldViewable`
        # @return [Boolean]
        attr_accessor :world_viewable
        alias_method :world_viewable?, :world_viewable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @broken_landing_page = args[:broken_landing_page] if args.key?(:broken_landing_page)
          @canonical_urlfp = args[:canonical_urlfp] if args.key?(:canonical_urlfp)
          @content_checksum = args[:content_checksum] if args.key?(:content_checksum)
          @content_type = args[:content_type] if args.key?(:content_type)
          @crawl_timestamp = args[:crawl_timestamp] if args.key?(:crawl_timestamp)
          @dmca_notice = args[:dmca_notice] if args.key?(:dmca_notice)
          @display_org = args[:display_org] if args.key?(:display_org)
          @display_priority = args[:display_priority] if args.key?(:display_priority)
          @download_day = args[:download_day] if args.key?(:download_day)
          @download_month = args[:download_month] if args.key?(:download_month)
          @download_year = args[:download_year] if args.key?(:download_year)
          @excerpt_content = args[:excerpt_content] if args.key?(:excerpt_content)
          @excerpt_debug_label = args[:excerpt_debug_label] if args.key?(:excerpt_debug_label)
          @first_discovered = args[:first_discovered] if args.key?(:first_discovered)
          @hosted_num_pages = args[:hosted_num_pages] if args.key?(:hosted_num_pages)
          @hosted_start_page = args[:hosted_start_page] if args.key?(:hosted_start_page)
          @html_title = args[:html_title] if args.key?(:html_title)
          @in_prev_index = args[:in_prev_index] if args.key?(:in_prev_index)
          @index_priority = args[:index_priority] if args.key?(:index_priority)
          @legal_must_include = args[:legal_must_include] if args.key?(:legal_must_include)
          @likely_ahead_print = args[:likely_ahead_print] if args.key?(:likely_ahead_print)
          @likely_different_metrics_venue = args[:likely_different_metrics_venue] if args.key?(:likely_different_metrics_venue)
          @likely_legal_journal = args[:likely_legal_journal] if args.key?(:likely_legal_journal)
          @likely_no_cache = args[:likely_no_cache] if args.key?(:likely_no_cache)
          @likely_no_index = args[:likely_no_index] if args.key?(:likely_no_index)
          @likely_world_viewable = args[:likely_world_viewable] if args.key?(:likely_world_viewable)
          @long_chunk_count = args[:long_chunk_count] if args.key?(:long_chunk_count)
          @maybe_no_index_reparse = args[:maybe_no_index_reparse] if args.key?(:maybe_no_index_reparse)
          @metadata_url = args[:metadata_url] if args.key?(:metadata_url)
          @must_include = args[:must_include] if args.key?(:must_include)
          @no_archive = args[:no_archive] if args.key?(:no_archive)
          @no_index = args[:no_index] if args.key?(:no_index)
          @no_snippet = args[:no_snippet] if args.key?(:no_snippet)
          @ocean_view = args[:ocean_view] if args.key?(:ocean_view)
          @out_link_count = args[:out_link_count] if args.key?(:out_link_count)
          @page_count = args[:page_count] if args.key?(:page_count)
          @references_in_prev_index = args[:references_in_prev_index] if args.key?(:references_in_prev_index)
          @type = args[:type] if args.key?(:type)
          @url_after_redirects = args[:url_after_redirects] if args.key?(:url_after_redirects)
          @url_str = args[:url_str] if args.key?(:url_str)
          @word_count = args[:word_count] if args.key?(:word_count)
          @world_viewable = args[:world_viewable] if args.key?(:world_viewable)
        end
      end
      
      # 
      class ScienceCitationFunding
        include Google::Apis::Core::Hashable
      
        # values are from FundingAgency enum
        # Corresponds to the JSON property `Agency`
        # @return [Fixnum]
        attr_accessor :agency
      
        # Text name of the agency. For analysis. Plus for agencies that don't have an
        # enum.
        # Corresponds to the JSON property `AgencyName`
        # @return [String]
        attr_accessor :agency_name
      
        # Text block from which the funding entry was extracted. Intended to be used for
        # offline analysis.
        # Corresponds to the JSON property `DebugFundingTextBlock`
        # @return [String]
        attr_accessor :debug_funding_text_block
      
        # 
        # Corresponds to the JSON property `GrantNumber`
        # @return [String]
        attr_accessor :grant_number
      
        # funding recipient
        # Corresponds to the JSON property `Recipient`
        # @return [String]
        attr_accessor :recipient
      
        # Original text for the funding acknowledgement
        # Corresponds to the JSON property `SourceText`
        # @return [String]
        attr_accessor :source_text
      
        # Whether this funding info was added because this article was at the exclusive
        # repository for this agency.
        # Corresponds to the JSON property `UrlBasedFundingSource`
        # @return [Boolean]
        attr_accessor :url_based_funding_source
        alias_method :url_based_funding_source?, :url_based_funding_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @agency = args[:agency] if args.key?(:agency)
          @agency_name = args[:agency_name] if args.key?(:agency_name)
          @debug_funding_text_block = args[:debug_funding_text_block] if args.key?(:debug_funding_text_block)
          @grant_number = args[:grant_number] if args.key?(:grant_number)
          @recipient = args[:recipient] if args.key?(:recipient)
          @source_text = args[:source_text] if args.key?(:source_text)
          @url_based_funding_source = args[:url_based_funding_source] if args.key?(:url_based_funding_source)
        end
      end
      
      # If this is a source document, the levels of discussion of the references this
      # document cites.
      class ScienceCitationReferenceDiscussion
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Level`
        # @return [Fixnum]
        attr_accessor :level
      
        # 
        # Corresponds to the JSON property `TargetID`
        # @return [Fixnum]
        attr_accessor :target_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @level = args[:level] if args.key?(:level)
          @target_id = args[:target_id] if args.key?(:target_id)
        end
      end
      
      # subject classification
      class ScienceCitationSubject
        include Google::Apis::Core::Hashable
      
        # e.g., "eng"
        # Corresponds to the JSON property `Name`
        # @return [String]
        attr_accessor :name
      
        # [0,1]
        # Corresponds to the JSON property `Probability`
        # @return [Float]
        attr_accessor :probability
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @probability = args[:probability] if args.key?(:probability)
        end
      end
      
      # translated author names. we usually get these for non-english papers which
      # provide english title/author/abstract info
      class ScienceCitationTranslatedAuthor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Department`
        # @return [String]
        attr_accessor :department
      
        # 
        # Corresponds to the JSON property `Email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `GuessOrderType`
        # @return [Fixnum]
        attr_accessor :guess_order_type
      
        # 
        # Corresponds to the JSON property `Institution`
        # @return [String]
        attr_accessor :institution
      
        # 
        # Corresponds to the JSON property `Language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `LastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `OtherNames`
        # @return [String]
        attr_accessor :other_names
      
        # 
        # Corresponds to the JSON property `SourceText`
        # @return [String]
        attr_accessor :source_text
      
        # 
        # Corresponds to the JSON property `Type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @department = args[:department] if args.key?(:department)
          @email = args[:email] if args.key?(:email)
          @guess_order_type = args[:guess_order_type] if args.key?(:guess_order_type)
          @institution = args[:institution] if args.key?(:institution)
          @language = args[:language] if args.key?(:language)
          @last_name = args[:last_name] if args.key?(:last_name)
          @other_names = args[:other_names] if args.key?(:other_names)
          @source_text = args[:source_text] if args.key?(:source_text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Create UnionCatalog as a group if we want to later add book level informations.
      class ScienceCitationUnionCatalog
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `CanonicalUrlfp`
        # @return [Fixnum]
        attr_accessor :canonical_urlfp
      
        # url of catalog metadata file
        # Corresponds to the JSON property `MetadataUrl`
        # @return [String]
        attr_accessor :metadata_url
      
        # Information about the number of libraries the citation appears. It should be
        # useful for ranking.
        # Corresponds to the JSON property `NumLibraries`
        # @return [Fixnum]
        attr_accessor :num_libraries
      
        # Categories classification of the citation
        # Corresponds to the JSON property `Subject`
        # @return [Array<String>]
        attr_accessor :subject
      
        # UnionCatalog url to display to users
        # Corresponds to the JSON property `Url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_urlfp = args[:canonical_urlfp] if args.key?(:canonical_urlfp)
          @metadata_url = args[:metadata_url] if args.key?(:metadata_url)
          @num_libraries = args[:num_libraries] if args.key?(:num_libraries)
          @subject = args[:subject] if args.key?(:subject)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class ScienceIndexSignal
        include Google::Apis::Core::Hashable
      
        # Subscriber Access feature: List of Holdings IDs associated with this document.
        # Should be present only for the documents with 'VisiblePrefixTerms' being set.
        # Corresponds to the JSON property `HoldingsId`
        # @return [Array<Fixnum>]
        attr_accessor :holdings_id
      
        # Fingerprint of the html title of the page. This is useful for checking if we
        # have the same version of the page as websearch.
        # Corresponds to the JSON property `HtmlTitleFp`
        # @return [Fixnum]
        attr_accessor :html_title_fp
      
        # Index selection score for websearch, bigger is better: (0.5,1.0] - prefer
        # selection into the base index, (0.0,0.5] - prefer selection into the
        # supplemental index.
        # Corresponds to the JSON property `IndexSelectionScore`
        # @return [Float]
        attr_accessor :index_selection_score
      
        # Summary statistics.
        # Corresponds to the JSON property `NumBackwardLinks`
        # @return [Fixnum]
        attr_accessor :num_backward_links
      
        # 
        # Corresponds to the JSON property `NumRelated`
        # @return [Fixnum]
        attr_accessor :num_related
      
        # 
        # Corresponds to the JSON property `NumVersions`
        # @return [Fixnum]
        attr_accessor :num_versions
      
        # 
        # Corresponds to the JSON property `PublicationDay`
        # @return [Fixnum]
        attr_accessor :publication_day
      
        # 
        # Corresponds to the JSON property `PublicationMonth`
        # @return [Fixnum]
        attr_accessor :publication_month
      
        # Publication date.
        # Corresponds to the JSON property `PublicationYear`
        # @return [Fixnum]
        attr_accessor :publication_year
      
        # Remove this URL from the index - error page, broken landing page, etc.
        # DEPRECATED, was never used or even filled correctly.
        # Corresponds to the JSON property `RemoveLink`
        # @return [Boolean]
        attr_accessor :remove_link
        alias_method :remove_link?, :remove_link
      
        # For links from websearch to scholar.
        # Corresponds to the JSON property `ScholarId`
        # @return [Fixnum]
        attr_accessor :scholar_id
      
        # Title of the article. Its only filled in when the html title of the page isn't
        # good.
        # Corresponds to the JSON property `Title`
        # @return [String]
        attr_accessor :title
      
        # Length of document prefix that most users are likely to see. Only filled in
        # when we index subscription fulltext but most users see abstracts. This is a
        # conservative guesstimate - e.g., ACM shows fulltext to university/company
        # subscribers (including Google employees) based on user's IP address, but we
        # don't know subscriber IPs, so ACM's PDF pages would have ~500 in this field (
        # estimated length of abstract).
        # Corresponds to the JSON property `VisiblePrefixTerms`
        # @return [Fixnum]
        attr_accessor :visible_prefix_terms
      
        # 
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceIndexSignalAuthor>]
        attr_accessor :author
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @holdings_id = args[:holdings_id] if args.key?(:holdings_id)
          @html_title_fp = args[:html_title_fp] if args.key?(:html_title_fp)
          @index_selection_score = args[:index_selection_score] if args.key?(:index_selection_score)
          @num_backward_links = args[:num_backward_links] if args.key?(:num_backward_links)
          @num_related = args[:num_related] if args.key?(:num_related)
          @num_versions = args[:num_versions] if args.key?(:num_versions)
          @publication_day = args[:publication_day] if args.key?(:publication_day)
          @publication_month = args[:publication_month] if args.key?(:publication_month)
          @publication_year = args[:publication_year] if args.key?(:publication_year)
          @remove_link = args[:remove_link] if args.key?(:remove_link)
          @scholar_id = args[:scholar_id] if args.key?(:scholar_id)
          @title = args[:title] if args.key?(:title)
          @visible_prefix_terms = args[:visible_prefix_terms] if args.key?(:visible_prefix_terms)
          @author = args[:author] if args.key?(:author)
        end
      end
      
      # 
      class ScienceIndexSignalAuthor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `LastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `OtherNames`
        # @return [String]
        attr_accessor :other_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_name = args[:last_name] if args.key?(:last_name)
          @other_names = args[:other_names] if args.key?(:other_names)
        end
      end
      
      # Describes the viewability of ocean content.
      class ScienceOceanView
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `countryview`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScienceOceanViewCountryView>]
        attr_accessor :countryview
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @countryview = args[:countryview] if args.key?(:countryview)
        end
      end
      
      # 
      class ScienceOceanViewCountryView
        include Google::Apis::Core::Hashable
      
        # No CountryCode means default viewability. two letter code
        # Corresponds to the JSON property `CountryCode`
        # @return [String]
        attr_accessor :country_code
      
        # enum in ocean::LocaleViewability::ViewType
        # Corresponds to the JSON property `ViewType`
        # @return [Fixnum]
        attr_accessor :view_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @view_type = args[:view_type] if args.key?(:view_type)
        end
      end
      
      # Next tag: 43
      class SciencePerDocData
        include Google::Apis::Core::Hashable
      
        # The first hit position after the end of the abstract. We index the abstract
        # immediately after the body, so all hits between BodyEndPosition and
        # AbstractEndPosition are from the abstract.
        # Corresponds to the JSON property `AbstractEndPosition`
        # @return [Fixnum]
        attr_accessor :abstract_end_position
      
        # The first hit position past the last body hit.
        # Corresponds to the JSON property `BodyEndPosition`
        # @return [Fixnum]
        attr_accessor :body_end_position
      
        # Input features used to compute PredictedCitations.
        # Corresponds to the JSON property `CitationPredictionSignal`
        # @return [Array<Google::Apis::ContentwarehouseV1::ScholarCitationPredictionSignal>]
        attr_accessor :citation_prediction_signal
      
        # Used for sorting legal documents by court; e.g. Supreme Court > Appeals Court >
        # Trial Court
        # Corresponds to the JSON property `CourtLevel`
        # @return [Fixnum]
        attr_accessor :court_level
      
        # 
        # Corresponds to the JSON property `DEPRECATEDCrawlTime`
        # @return [Fixnum]
        attr_accessor :deprecated_crawl_time
      
        # The age in days since discovery date at the time of indexing. Used to compute
        # PredictedCitations.
        # Corresponds to the JSON property `DiscoveryAgeInDays`
        # @return [Fixnum]
        attr_accessor :discovery_age_in_days
      
        # Used for sorting articles by date, and as an input for recent-query ranking.
        # Stored in Universal time scale (100 ns ticks since 0001 AD).
        # Corresponds to the JSON property `DiscoveryTimestamp`
        # @return [Fixnum]
        attr_accessor :discovery_timestamp
      
        # citation-only marker - for use in scorer
        # Corresponds to the JSON property `IsCitationOnly`
        # @return [Boolean]
        attr_accessor :is_citation_only
        alias_method :is_citation_only?, :is_citation_only
      
        # Scoring penalty for non-scholarly articles. In the range [0, 1], with 0 being
        # no penalty and 1 being the full penalty.
        # Corresponds to the JSON property `NonScholarlinessPenalty`
        # @return [Float]
        attr_accessor :non_scholarliness_penalty
      
        # Summary statistics, for display in the FE.
        # Corresponds to the JSON property `NumBackwardLinks`
        # @return [Fixnum]
        attr_accessor :num_backward_links
      
        # 
        # Corresponds to the JSON property `NumRelated`
        # @return [Fixnum]
        attr_accessor :num_related
      
        # Used for exact title boost in Scholar, as of 1/7/2008.
        # Corresponds to the JSON property `NumTitleWords`
        # @return [Fixnum]
        attr_accessor :num_title_words
      
        # 
        # Corresponds to the JSON property `NumVersions`
        # @return [Fixnum]
        attr_accessor :num_versions
      
        # 
        # Corresponds to the JSON property `OffDomAnchors`
        # @return [Fixnum]
        attr_accessor :off_dom_anchors
      
        # 
        # Corresponds to the JSON property `OnSiteAnchors`
        # @return [Fixnum]
        attr_accessor :on_site_anchors
      
        # The predicted new citations for this document once it reaches 5 years after
        # its discovery date. Not set for: - Documents 5 years or older - Citation only
        # documents - Patents and legal documents
        # Corresponds to the JSON property `PredictedCitations`
        # @return [Float]
        attr_accessor :predicted_citations
      
        # The predicted new citations for this document over the next 5 years. This
        # differs from the PredictedCitations field in that this is set for documents of
        # all ages, whereas PredictedCitations is only set for new documents. This is
        # also a prediction over a fixed time interval, whereas the time interval for
        # PredictedCitations depends on the document's age.
        # Corresponds to the JSON property `PredictedCitationsNext5Years`
        # @return [Float]
        attr_accessor :predicted_citations_next5_years
      
        # 
        # Corresponds to the JSON property `PublicationDay`
        # @return [Fixnum]
        attr_accessor :publication_day
      
        # 
        # Corresponds to the JSON property `PublicationMonth`
        # @return [Fixnum]
        attr_accessor :publication_month
      
        # Publication date. Used both for ranking of recent articles and for display in
        # the FE.
        # Corresponds to the JSON property `PublicationYear`
        # @return [Fixnum]
        attr_accessor :publication_year
      
        # For links from websearch to scholar.
        # Corresponds to the JSON property `ScholarId`
        # @return [Fixnum]
        attr_accessor :scholar_id
      
        # DEPRECATED e.g., fp("med")
        # Corresponds to the JSON property `Subject`
        # @return [Fixnum]
        attr_accessor :subject
      
        # A string encoding the uni-, bi-, and trigram weights in the title. This is
        # encoded and decoded by science_search/util/title_ngrams.h.
        # Corresponds to the JSON property `TitleNgrams`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :title_ngrams
      
        # Anchor count info for scorer
        # Corresponds to the JSON property `TotalAnchors`
        # @return [Fixnum]
        attr_accessor :total_anchors
      
        # The type of the article - paper, review, patent, etc.
        # Corresponds to the JSON property `Type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `author`
        # @return [Array<Google::Apis::ContentwarehouseV1::SciencePerDocDataAuthor>]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `referencediscussion`
        # @return [Array<Google::Apis::ContentwarehouseV1::SciencePerDocDataReferenceDiscussion>]
        attr_accessor :referencediscussion
      
        # Section markers, sorted by begin_position, no overlapping.
        # Corresponds to the JSON property `section`
        # @return [Array<Google::Apis::ContentwarehouseV1::SciencePerDocDataSection>]
        attr_accessor :section
      
        # 
        # Corresponds to the JSON property `signal`
        # @return [Array<Google::Apis::ContentwarehouseV1::SciencePerDocDataSignal>]
        attr_accessor :signal
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abstract_end_position = args[:abstract_end_position] if args.key?(:abstract_end_position)
          @body_end_position = args[:body_end_position] if args.key?(:body_end_position)
          @citation_prediction_signal = args[:citation_prediction_signal] if args.key?(:citation_prediction_signal)
          @court_level = args[:court_level] if args.key?(:court_level)
          @deprecated_crawl_time = args[:deprecated_crawl_time] if args.key?(:deprecated_crawl_time)
          @discovery_age_in_days = args[:discovery_age_in_days] if args.key?(:discovery_age_in_days)
          @discovery_timestamp = args[:discovery_timestamp] if args.key?(:discovery_timestamp)
          @is_citation_only = args[:is_citation_only] if args.key?(:is_citation_only)
          @non_scholarliness_penalty = args[:non_scholarliness_penalty] if args.key?(:non_scholarliness_penalty)
          @num_backward_links = args[:num_backward_links] if args.key?(:num_backward_links)
          @num_related = args[:num_related] if args.key?(:num_related)
          @num_title_words = args[:num_title_words] if args.key?(:num_title_words)
          @num_versions = args[:num_versions] if args.key?(:num_versions)
          @off_dom_anchors = args[:off_dom_anchors] if args.key?(:off_dom_anchors)
          @on_site_anchors = args[:on_site_anchors] if args.key?(:on_site_anchors)
          @predicted_citations = args[:predicted_citations] if args.key?(:predicted_citations)
          @predicted_citations_next5_years = args[:predicted_citations_next5_years] if args.key?(:predicted_citations_next5_years)
          @publication_day = args[:publication_day] if args.key?(:publication_day)
          @publication_month = args[:publication_month] if args.key?(:publication_month)
          @publication_year = args[:publication_year] if args.key?(:publication_year)
          @scholar_id = args[:scholar_id] if args.key?(:scholar_id)
          @subject = args[:subject] if args.key?(:subject)
          @title_ngrams = args[:title_ngrams] if args.key?(:title_ngrams)
          @total_anchors = args[:total_anchors] if args.key?(:total_anchors)
          @type = args[:type] if args.key?(:type)
          @author = args[:author] if args.key?(:author)
          @referencediscussion = args[:referencediscussion] if args.key?(:referencediscussion)
          @section = args[:section] if args.key?(:section)
          @signal = args[:signal] if args.key?(:signal)
        end
      end
      
      # Used for exact author boost and for display in the FE.
      class SciencePerDocDataAuthor
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `IsCJK`
        # @return [Boolean]
        attr_accessor :is_cjk
        alias_method :is_cjk?, :is_cjk
      
        # 
        # Corresponds to the JSON property `LastName`
        # @return [String]
        attr_accessor :last_name
      
        # 
        # Corresponds to the JSON property `OtherNames`
        # @return [String]
        attr_accessor :other_names
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_cjk = args[:is_cjk] if args.key?(:is_cjk)
          @last_name = args[:last_name] if args.key?(:last_name)
          @other_names = args[:other_names] if args.key?(:other_names)
        end
      end
      
      # 
      class SciencePerDocDataReferenceDiscussion
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `Level`
        # @return [Fixnum]
        attr_accessor :level
      
        # 
        # Corresponds to the JSON property `TargetID`
        # @return [Fixnum]
        attr_accessor :target_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @level = args[:level] if args.key?(:level)
          @target_id = args[:target_id] if args.key?(:target_id)
        end
      end
      
      # 
      class SciencePerDocDataSection
        include Google::Apis::Core::Hashable
      
        # The first hit position at the start of the section.
        # Corresponds to the JSON property `beginPosition`
        # @return [Fixnum]
        attr_accessor :begin_position
      
        # Delta in hit position from the start of the section to the end.
        # Corresponds to the JSON property `numPositions`
        # @return [Fixnum]
        attr_accessor :num_positions
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin_position = args[:begin_position] if args.key?(:begin_position)
          @num_positions = args[:num_positions] if args.key?(:num_positions)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class SciencePerDocDataSignal
        include Google::Apis::Core::Hashable
      
        # Values for different metrics
        # Corresponds to the JSON property `avgCitations`
        # @return [Float]
        attr_accessor :avg_citations
      
        # Number of papers in the bucket for this paper/signal combination 16-bit value
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Count of papers with 10 or more citations (ge is >=) 16-bit value
        # Corresponds to the JSON property `geThres1Count`
        # @return [Fixnum]
        attr_accessor :ge_thres1_count
      
        # Count of papers with 50 or more citations 16-bit value
        # Corresponds to the JSON property `geThres2Count`
        # @return [Fixnum]
        attr_accessor :ge_thres2_count
      
        # Signal type dependent (for Journals refers to the year) index must refers to
        # years ago not absolute year. 8-bit value
        # Corresponds to the JSON property `index`
        # @return [Fixnum]
        attr_accessor :index
      
        # 
        # Corresponds to the JSON property `medianCitations`
        # @return [Float]
        attr_accessor :median_citations
      
        # 
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        # Authors own a part of a paper value. This is the cumulative weight. If all
        # papers falling into this bucket are single author papers, then weight will be
        # equal to 1.0. Otherwise it will be smaller.
        # Corresponds to the JSON property `weight`
        # @return [Float]
        attr_accessor :weight
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @avg_citations = args[:avg_citations] if args.key?(:avg_citations)
          @count = args[:count] if args.key?(:count)
          @ge_thres1_count = args[:ge_thres1_count] if args.key?(:ge_thres1_count)
          @ge_thres2_count = args[:ge_thres2_count] if args.key?(:ge_thres2_count)
          @index = args[:index] if args.key?(:index)
          @median_citations = args[:median_citations] if args.key?(:median_citations)
          @type = args[:type] if args.key?(:type)
          @weight = args[:weight] if args.key?(:weight)
        end
      end
      
      # Encapsulates sensitivity mode, source, and other metadata, used for ranking
      # when there are multiple sensitivies set by default sources (eg, followon,
      # query understanding, attentional entity).
      class SearchPolicyRankableSensitivity
        include Google::Apis::Core::Hashable
      
        # Propagated from knowledge.answers.sensitivity.Sensitivity account_provenance.
        # Any ambiguity between the data here and dasher_user should be resolved by the
        # conversion to pToken in http://source/search?q=symbol:
        # CreatePTokenFromSensitivity
        # Corresponds to the JSON property `accountProvenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualityQrewriteAccountProvenance>]
        attr_accessor :account_provenance
      
        # Attentional entities (AE) can be pulled from arguments of interpretations,
        # entities annotated by Aqua or QRef annotators, and entities mentioned in
        # Assistant's response and annotated by the fulfillment logic (see https://g3doc.
        # corp.google.com/quality/dialog_manager/attentional_entities/g3doc/overview.md#
        # overview). Sensitivity of AEs can be marked by (1) feature developers in a
        # Monastery frame, (2) code to infer the sensitivity from Argument provenance,
        # and (3) entity annotators, such as Aqua annotator and QRef annotator. See go/
        # sensitive-ae.
        # Corresponds to the JSON property `attentionalEntity`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivityAttentionalEntity]
        attr_accessor :attentional_entity
      
        # True iff the query is from a Dasher user.
        # Corresponds to the JSON property `dasherUser`
        # @return [Boolean]
        attr_accessor :dasher_user
        alias_method :dasher_user?, :dasher_user
      
        # Sensitivity is marked at end of the last turn. See go/followon-sensitivity for
        # more details.
        # Corresponds to the JSON property `followon`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivityFollowOn]
        attr_accessor :followon
      
        # Deprecated, do not use.
        # Corresponds to the JSON property `prefilter`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivityPrefilter]
        attr_accessor :prefilter
      
        # Sensitivity is produced by QU.
        # Corresponds to the JSON property `qu`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivityQueryUnderstanding]
        attr_accessor :qu
      
        # Key of a sensitivity.
        # Corresponds to the JSON property `sensitivityMode`
        # @return [String]
        attr_accessor :sensitivity_mode
      
        # Marks that this sensitivity is form a synthetic intent.
        # Corresponds to the JSON property `syntheticIntent`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivitySyntheticIntent]
        attr_accessor :synthetic_intent
      
        # Marks that this sensitivity is from fulfillment.
        # Corresponds to the JSON property `winningFulfillment`
        # @return [Google::Apis::ContentwarehouseV1::SearchPolicyRankableSensitivityFulfillment]
        attr_accessor :winning_fulfillment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_provenance = args[:account_provenance] if args.key?(:account_provenance)
          @attentional_entity = args[:attentional_entity] if args.key?(:attentional_entity)
          @dasher_user = args[:dasher_user] if args.key?(:dasher_user)
          @followon = args[:followon] if args.key?(:followon)
          @prefilter = args[:prefilter] if args.key?(:prefilter)
          @qu = args[:qu] if args.key?(:qu)
          @sensitivity_mode = args[:sensitivity_mode] if args.key?(:sensitivity_mode)
          @synthetic_intent = args[:synthetic_intent] if args.key?(:synthetic_intent)
          @winning_fulfillment = args[:winning_fulfillment] if args.key?(:winning_fulfillment)
        end
      end
      
      # Attentional entities (AE) can be pulled from arguments of interpretations,
      # entities annotated by Aqua or QRef annotators, and entities mentioned in
      # Assistant's response and annotated by the fulfillment logic (see https://g3doc.
      # corp.google.com/quality/dialog_manager/attentional_entities/g3doc/overview.md#
      # overview). Sensitivity of AEs can be marked by (1) feature developers in a
      # Monastery frame, (2) code to infer the sensitivity from Argument provenance,
      # and (3) entity annotators, such as Aqua annotator and QRef annotator. See go/
      # sensitive-ae.
      class SearchPolicyRankableSensitivityAttentionalEntity
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `aeOrigin`
        # @return [String]
        attr_accessor :ae_origin
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ae_origin = args[:ae_origin] if args.key?(:ae_origin)
        end
      end
      
      # Sensitivity is marked at end of the last turn. See go/followon-sensitivity for
      # more details.
      class SearchPolicyRankableSensitivityFollowOn
        include Google::Apis::Core::Hashable
      
        # Should e2e search candidates running in parallel with QU (eg. GBot) be blocked.
        # Corresponds to the JSON property `blockNonV2SearchBackends`
        # @return [Boolean]
        attr_accessor :block_non_v2_search_backends
        alias_method :block_non_v2_search_backends?, :block_non_v2_search_backends
      
        # Iff true this follow-on sensitivity will rank above the ones determined by
        # query understanding (QU).
        # Corresponds to the JSON property `ignoreQueryUnderstanding`
        # @return [Boolean]
        attr_accessor :ignore_query_understanding
        alias_method :ignore_query_understanding?, :ignore_query_understanding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @block_non_v2_search_backends = args[:block_non_v2_search_backends] if args.key?(:block_non_v2_search_backends)
          @ignore_query_understanding = args[:ignore_query_understanding] if args.key?(:ignore_query_understanding)
        end
      end
      
      # Marks that this sensitivity is from fulfillment.
      class SearchPolicyRankableSensitivityFulfillment
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Deprecated, do not use.
      class SearchPolicyRankableSensitivityPrefilter
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `propagateOnly`
        # @return [Boolean]
        attr_accessor :propagate_only
        alias_method :propagate_only?, :propagate_only
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @propagate_only = args[:propagate_only] if args.key?(:propagate_only)
        end
      end
      
      # Sensitivity is produced by QU.
      class SearchPolicyRankableSensitivityQueryUnderstanding
        include Google::Apis::Core::Hashable
      
        # QU dectects a sensitive intent with no sensitive content (eg., [Send email]).
        # This flag is only used to trigger a sensitive feature because as a precaution
        # all sensitive features should check current sensitivity mode before triggering;
        # but will NOT block any backends, which means all other features can compete
        # fairly.
        # Corresponds to the JSON property `intentOnlyNoPii`
        # @return [Boolean]
        attr_accessor :intent_only_no_pii
        alias_method :intent_only_no_pii?, :intent_only_no_pii
      
        # The rewritten query this sensitivity is for. Note different query rewrites
        # could produce different sensitivities.
        # Corresponds to the JSON property `rewrittenQuery`
        # @return [String]
        attr_accessor :rewritten_query
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @intent_only_no_pii = args[:intent_only_no_pii] if args.key?(:intent_only_no_pii)
          @rewritten_query = args[:rewritten_query] if args.key?(:rewritten_query)
        end
      end
      
      # Marks that this sensitivity is form a synthetic intent.
      class SearchPolicyRankableSensitivitySyntheticIntent
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Represents a principal who has authenticated as any kind of user which the
      # application understands. This is typically used for "wiki-like" security,
      # where anyone is allowed access so long as they can be held accountable for
      # that access. Since the purpose is knowing whom to blame, it is up to the
      # application to decide what kinds of users it knows how to blame. For example,
      # an application might choose to include GAIA users in "all authenticated users",
      # but not include MDB users. Nothing here.
      class SecurityCredentialsAllAuthenticatedUsersProto
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Represents a principal which possesses a particular secret string whose
      # cryptographic hash is specified here. CapTokens ("Capability Tokens") are used
      # in ACLProto. It's expected that ACLs with CapTokenHolders will strongly
      # enforce them by Keystore-wrapping crypto keys for the corresponding CapTokens.
      class SecurityCredentialsCapTokenHolderProto
        include Google::Apis::Core::Hashable
      
        # The hash of the corresponding capability token. The value is defined to be
        # identical to the one in acl.proto's CapTokenMetadata: 10-byte prefix of HMAC-
        # SHA1 of the token. The HMAC key is the following fixed (non-secret) 512-bit
        # value: 79b1c8f4 82baf523 b8a9ab4a e960f438 c45be041 11f1f222 e8a3f64d aeb05e3d
        # c3576acc ec649194 aede422c 4e48e0d1 ff21234a a6ed6b49 a7fa592e efd7bba3
        # Corresponds to the JSON property `tokenHmacSha1Prefix`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :token_hmac_sha1_prefix
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @token_hmac_sha1_prefix = args[:token_hmac_sha1_prefix] if args.key?(:token_hmac_sha1_prefix)
        end
      end
      
      # Represents the invitees or other users associated with a Babel Chat (see http:/
      # /goto/babel). Corresponds to GroupType CHAT in //social/graph/storage/proto/
      # data.proto.
      class SecurityCredentialsChatProto
        include Google::Apis::Core::Hashable
      
        # Chat IDs consist of alphanumeric characters and colons. Currently required.
        # Corresponds to the JSON property `chatId`
        # @return [String]
        attr_accessor :chat_id
      
        # The type of Chat members to consider, e.g. "all members" vs. "invitee" These
        # are defined by legacy_relation_id values in social.graph.storage.EdgeTypeEnum.
        # EdgeType enum options in social/graph/storage/proto/id.proto. See chat.pb (
        # defined in production/config/cdd/socialgraph/mixer_config/prod/
        # node_type_config) for all valid edge types associated with chat. Currently
        # required.
        # Corresponds to the JSON property `memberType`
        # @return [Fixnum]
        attr_accessor :member_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @chat_id = args[:chat_id] if args.key?(:chat_id)
          @member_type = args[:member_type] if args.key?(:member_type)
        end
      end
      
      # Represents a Google+ Circle. Currently (12/2011), a Circle is identical to the
      # ContactGroup with matching parameters, but Circle must only be used for true
      # Circles and not other Focus groups, and should be preferred over ContactGroup
      # where applicable. Soon it may become more efficient to check membership in a
      # Circle than in a ContactGroup (see http://go/superglue). Support for this
      # principal type is currently (12/2011) incomplete -- e.g., Keystore does not
      # support it yet (see b/5703421).
      class SecurityCredentialsCircleProto
        include Google::Apis::Core::Hashable
      
        # Circle ID is unique only relative to the owner's Gaia ID. Currently required.
        # Corresponds to the JSON property `circleId`
        # @return [Fixnum]
        attr_accessor :circle_id
      
        # The owner of the circle. Currently required.
        # Corresponds to the JSON property `ownerGaiaId`
        # @return [Fixnum]
        attr_accessor :owner_gaia_id
      
        # If present, then tests for membership in this circle must use data known to be
        # at least as fresh as the given (FBS-assigned) timestamp. See http://go/fbs-
        # consistent-read-after-important-write Before using this, be sure that any
        # service checking authorization against this circle supports checking
        # consistency timestamps. For example, as of 12/2011, Keystore only supports
        # this for the Moonshine configuration, and in others authorization checks will
        # fail if the timestamp is present.
        # Corresponds to the JSON property `requiredConsistencyTimestampUsec`
        # @return [Fixnum]
        attr_accessor :required_consistency_timestamp_usec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @circle_id = args[:circle_id] if args.key?(:circle_id)
          @owner_gaia_id = args[:owner_gaia_id] if args.key?(:owner_gaia_id)
          @required_consistency_timestamp_usec = args[:required_consistency_timestamp_usec] if args.key?(:required_consistency_timestamp_usec)
        end
      end
      
      # Principal associated with a Cloud Principal representing third party user.
      class SecurityCredentialsCloudPrincipalProto
        include Google::Apis::Core::Hashable
      
        # Format: "`identity-pool`:`subject`#" Details: go/cloud-principal-identifiers
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # A group of contacts for a given user, as described in http://cs/p#google3/
      # focus/backend/proto/backend.proto Historically (and in still-existing ACLs),
      # this was used to represent Google+ circles as well as contact groups, but this
      # use is now deprecated. New code should use the CIRCLE principal type to
      # represent Google+ circles.
      class SecurityCredentialsContactGroupProto
        include Google::Apis::Core::Hashable
      
        # Group ID is unique only relative to the owner's Gaia ID.
        # Corresponds to the JSON property `groupId`
        # @return [Fixnum]
        attr_accessor :group_id
      
        # 
        # Corresponds to the JSON property `ownerGaiaId`
        # @return [Fixnum]
        attr_accessor :owner_gaia_id
      
        # If present, then tests for membership in this ContactGroup must use data known
        # to be at least as fresh as the given (FBS-assigned) timestamp. See http://go/
        # fbs-consistent-read-after-important-write Before using this, be sure that any
        # service checking authorization against this group supports checking
        # consistency timestamps. For example, as of 12/2011, Keystore only supports
        # this for the Moonshine configuration, and in others authorization checks will
        # fail if the timestamp is present.
        # Corresponds to the JSON property `requiredConsistencyTimestampUsec`
        # @return [Fixnum]
        attr_accessor :required_consistency_timestamp_usec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @group_id = args[:group_id] if args.key?(:group_id)
          @owner_gaia_id = args[:owner_gaia_id] if args.key?(:owner_gaia_id)
          @required_consistency_timestamp_usec = args[:required_consistency_timestamp_usec] if args.key?(:required_consistency_timestamp_usec)
        end
      end
      
      # Represents a verified owner of the given email address. Note that a single
      # address may have many owners, and a single user may own many addresses. (All
      # lower-case, in display form -- see com.google.gaia.client.GaiaEmail)
      class SecurityCredentialsEmailOwnerProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
        end
      end
      
      # Represents the invitees or other users associated with a Google+ Event (see
      # http://goto/events-backend-design).
      class SecurityCredentialsEventProto
        include Google::Apis::Core::Hashable
      
        # Event IDs consist of alphanumeric characters and colons. Currently required.
        # Corresponds to the JSON property `eventId`
        # @return [String]
        attr_accessor :event_id
      
        # The type of Event members to consider, e.g. "all members" vs. "owners" vs. "
        # admins". These are defined by legacy_relation_id values in social.graph.
        # storage.EdgeTypeEnum.EdgeType enum options in social/graph/storage/proto/id.
        # proto. See event.pb (defined in production/config/cdd/socialgraph/mixer_config/
        # prod/node_type_config) for all valid edge types associated with event.
        # Currently required.
        # Corresponds to the JSON property `memberType`
        # @return [Fixnum]
        attr_accessor :member_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @event_id = args[:event_id] if args.key?(:event_id)
          @member_type = args[:member_type] if args.key?(:member_type)
        end
      end
      
      # 
      class SecurityCredentialsGaiaGroupProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `groupId`
        # @return [Fixnum]
        attr_accessor :group_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @group_id = args[:group_id] if args.key?(:group_id)
        end
      end
      
      # A Gaia account, which may represent a user, device, service account, etc. For
      # prod (@prod.google.com) accounts, use MdbUserProto instead.
      class SecurityCredentialsGaiaUserProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `userId`
        # @return [Fixnum]
        attr_accessor :user_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @user_id = args[:user_id] if args.key?(:user_id)
        end
      end
      
      # Represents a single host. Optionally, the MDB owner of the host can be
      # specified.
      class SecurityCredentialsHostProto
        include Google::Apis::Core::Hashable
      
        # Lower-case, fully qualified hostname.
        # Corresponds to the JSON property `hostName`
        # @return [String]
        attr_accessor :host_name
      
        # If present, then any checks that compare this Principal to LOAS peer info must
        # confirm the peer's machine owner is equal to 'host_owner'. If absent, then any
        # peer machine owner is acceptable.
        # Corresponds to the JSON property `hostOwner`
        # @return [String]
        attr_accessor :host_owner
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @host_name = args[:host_name] if args.key?(:host_name)
          @host_owner = args[:host_owner] if args.key?(:host_owner)
        end
      end
      
      # 
      class SecurityCredentialsLdapGroupProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `groupName`
        # @return [String]
        attr_accessor :group_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @group_name = args[:group_name] if args.key?(:group_name)
        end
      end
      
      # 
      class SecurityCredentialsLdapUserProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `userName`
        # @return [String]
        attr_accessor :user_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @user_name = args[:user_name] if args.key?(:user_name)
        end
      end
      
      # An entity from the MDB namespace that is to be interpreted as a group. If
      # using this for authorization, you should do an exact match of the peer role
      # against group_name or any of the names in the Chubby expansion of the MDB
      # group named group_name.
      class SecurityCredentialsMdbGroupProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `groupName`
        # @return [String]
        attr_accessor :group_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @group_name = args[:group_name] if args.key?(:group_name)
        end
      end
      
      # An entity from the MDB namespace that is to be interpreted as a user. If using
      # this for authorization, you should only do an exact match on the peer role
      # against user_name.
      class SecurityCredentialsMdbUserProto
        include Google::Apis::Core::Hashable
      
        # Do not set this field. Contact credentials-eng@ if you believe you absolutely
        # need to use it. This is the @prod.google.com Gaia ID that corresponds to the
        # MDB user, see go/authn-merge for details. This field may always be safely
        # ignored when performing an authorization check.
        # Corresponds to the JSON property `gaiaId`
        # @return [Fixnum]
        attr_accessor :gaia_id
      
        # 
        # Corresponds to the JSON property `userName`
        # @return [String]
        attr_accessor :user_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @gaia_id = args[:gaia_id] if args.key?(:gaia_id)
          @user_name = args[:user_name] if args.key?(:user_name)
        end
      end
      
      # Represents an OAuth consumer, a/k/a AuthSub target. These principals are
      # identified by domain name (e.g., example.com). Historically, Dasher domain
      # GAIA group IDs have been used instead, but that doesn't work: http://go/tricky-
      # gaia-ids
      class SecurityCredentialsOAuthConsumerProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `domain`
        # @return [String]
        attr_accessor :domain
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @domain = args[:domain] if args.key?(:domain)
        end
      end
      
      # See http://s/?fileprint=//depot/google3/security/authentication/postini/
      # auth_token.proto
      class SecurityCredentialsPostiniUserProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `postiniUserId`
        # @return [Fixnum]
        attr_accessor :postini_user_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @postini_user_id = args[:postini_user_id] if args.key?(:postini_user_id)
        end
      end
      
      # A Principal represents something to which permissions are assigned, often but
      # not always a user or group of some kind. It is most appropriate for use in
      # ACLs and authorization checks. Callers should prefer to use the wrapper
      # classes in google3/security/credentials/public/principal.h google3/java/com/
      # google/security/credentials/Principal.java google3/security/credentials/go/
      # principal.go unless direct proto access is essential. If you update this
      # protocol buffer, please update the wrapper classes as well.
      class SecurityCredentialsPrincipalProto
        include Google::Apis::Core::Hashable
      
        # Represents a principal who has authenticated as any kind of user which the
        # application understands. This is typically used for "wiki-like" security,
        # where anyone is allowed access so long as they can be held accountable for
        # that access. Since the purpose is knowing whom to blame, it is up to the
        # application to decide what kinds of users it knows how to blame. For example,
        # an application might choose to include GAIA users in "all authenticated users",
        # but not include MDB users. Nothing here.
        # Corresponds to the JSON property `allAuthenticatedUsers`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsAllAuthenticatedUsersProto]
        attr_accessor :all_authenticated_users
      
        # Represents a principal which possesses a particular secret string whose
        # cryptographic hash is specified here. CapTokens ("Capability Tokens") are used
        # in ACLProto. It's expected that ACLs with CapTokenHolders will strongly
        # enforce them by Keystore-wrapping crypto keys for the corresponding CapTokens.
        # Corresponds to the JSON property `capTokenHolder`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsCapTokenHolderProto]
        attr_accessor :cap_token_holder
      
        # Represents the invitees or other users associated with a Babel Chat (see http:/
        # /goto/babel). Corresponds to GroupType CHAT in //social/graph/storage/proto/
        # data.proto.
        # Corresponds to the JSON property `chat`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsChatProto]
        attr_accessor :chat
      
        # Represents a Google+ Circle. Currently (12/2011), a Circle is identical to the
        # ContactGroup with matching parameters, but Circle must only be used for true
        # Circles and not other Focus groups, and should be preferred over ContactGroup
        # where applicable. Soon it may become more efficient to check membership in a
        # Circle than in a ContactGroup (see http://go/superglue). Support for this
        # principal type is currently (12/2011) incomplete -- e.g., Keystore does not
        # support it yet (see b/5703421).
        # Corresponds to the JSON property `circle`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsCircleProto]
        attr_accessor :circle
      
        # Principal associated with a Cloud Principal representing third party user.
        # Corresponds to the JSON property `cloudPrincipal`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsCloudPrincipalProto]
        attr_accessor :cloud_principal
      
        # A group of contacts for a given user, as described in http://cs/p#google3/
        # focus/backend/proto/backend.proto Historically (and in still-existing ACLs),
        # this was used to represent Google+ circles as well as contact groups, but this
        # use is now deprecated. New code should use the CIRCLE principal type to
        # represent Google+ circles.
        # Corresponds to the JSON property `contactGroup`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsContactGroupProto]
        attr_accessor :contact_group
      
        # Represents a verified owner of the given email address. Note that a single
        # address may have many owners, and a single user may own many addresses. (All
        # lower-case, in display form -- see com.google.gaia.client.GaiaEmail)
        # Corresponds to the JSON property `emailOwner`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsEmailOwnerProto]
        attr_accessor :email_owner
      
        # Represents the invitees or other users associated with a Google+ Event (see
        # http://goto/events-backend-design).
        # Corresponds to the JSON property `event`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsEventProto]
        attr_accessor :event
      
        # scope = GAIA_GROUP
        # Corresponds to the JSON property `gaiaGroup`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsGaiaGroupProto]
        attr_accessor :gaia_group
      
        # A Gaia account, which may represent a user, device, service account, etc. For
        # prod (@prod.google.com) accounts, use MdbUserProto instead.
        # Corresponds to the JSON property `gaiaUser`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsGaiaUserProto]
        attr_accessor :gaia_user
      
        # Represents a single host. Optionally, the MDB owner of the host can be
        # specified.
        # Corresponds to the JSON property `host`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsHostProto]
        attr_accessor :host
      
        # scope = LDAP_GROUP
        # Corresponds to the JSON property `ldapGroup`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsLdapGroupProto]
        attr_accessor :ldap_group
      
        # scope = LDAP_USER
        # Corresponds to the JSON property `ldapUser`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsLdapUserProto]
        attr_accessor :ldap_user
      
        # An entity from the MDB namespace that is to be interpreted as a group. If
        # using this for authorization, you should do an exact match of the peer role
        # against group_name or any of the names in the Chubby expansion of the MDB
        # group named group_name.
        # Corresponds to the JSON property `mdbGroup`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsMdbGroupProto]
        attr_accessor :mdb_group
      
        # An entity from the MDB namespace that is to be interpreted as a user. If using
        # this for authorization, you should only do an exact match on the peer role
        # against user_name.
        # Corresponds to the JSON property `mdbUser`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsMdbUserProto]
        attr_accessor :mdb_user
      
        # Represents an OAuth consumer, a/k/a AuthSub target. These principals are
        # identified by domain name (e.g., example.com). Historically, Dasher domain
        # GAIA group IDs have been used instead, but that doesn't work: http://go/tricky-
        # gaia-ids
        # Corresponds to the JSON property `oauthConsumer`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsOAuthConsumerProto]
        attr_accessor :oauth_consumer
      
        # See http://s/?fileprint=//depot/google3/security/authentication/postini/
        # auth_token.proto
        # Corresponds to the JSON property `postiniUser`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsPostiniUserProto]
        attr_accessor :postini_user
      
        # Principal associated with a given RBAC role. This principal is used by Sphinx
        # Provisioning Service for RBAC (go/cedi-auth) provisionable (go/sphinx-rbacz-
        # design).
        # Corresponds to the JSON property `rbacRole`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsRbacRoleProto]
        attr_accessor :rbac_role
      
        # Principal associated with a given RBAC subject. This principal is used by
        # Sphinx Provisioning Service for RBAC (go/cedi-auth) provisionable (go/sphinx-
        # rbacz-design).
        # Corresponds to the JSON property `rbacSubject`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsRbacSubjectProto]
        attr_accessor :rbac_subject
      
        # A type of sharing target that points to some resource's ACL. Used to refer to
        # the set of Principals that have the given privilege ('role_id') for the given
        # resource ('application_id', 'object_id', 'object_part'). The meaning of '
        # role_id' is interpreted only by implementations of AclRpcService and is
        # usually dependent on 'application_id' All fields except object_part are
        # required. If present, object_part must be non-empty.
        # Corresponds to the JSON property `resourceRole`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsResourceRoleProto]
        attr_accessor :resource_role
      
        # This is only optional because required enums cannot be extended. Currently
        # required.
        # Corresponds to the JSON property `scope`
        # @return [String]
        attr_accessor :scope
      
        # Represents a principal who possesses a signing key corresponding to the
        # verification key or keyset described here.
        # Corresponds to the JSON property `signingKeyPossessor`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsSigningKeyPossessorProto]
        attr_accessor :signing_key_possessor
      
        # Represents a principal which possesses a particular, presumably secret, string.
        # Useful for things like "auth keys," used for anonymous sharing. Since
        # representing this principal with the actual secret included reveals the secret,
        # it's best if the requisite condition is enforced in some other way, for
        # example via Keystore wrapping attributes (Keystore will unwrap only if the
        # specified secret, aka "attribute", is presented). All that's stored here is an
        # identifying label.
        # Corresponds to the JSON property `simpleSecretHolder`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsSimpleSecretHolderProto]
        attr_accessor :simple_secret_holder
      
        # Represents a user pseudonym. Pseudonyms are linked accounts on Google and
        # third-party services (e.g. YouTube or Twitter) and are described by a Social
        # Graph Node.
        # Corresponds to the JSON property `socialGraphNode`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsSocialGraphNodeProto]
        attr_accessor :social_graph_node
      
        # Represents the set of members (of a given type) in a Google+ Square (see http:/
        # /go/squares). A Square with default member_type is currently (1/2012)
        # identical to the GaiaGroup with the same ID, but that is expected to change
        # soon (see http://go/superglue). Support for this principal type is currently (
        # 1/2012) incomplete -- e.g., Keystore does not support it yet (see b/5703421).
        # Corresponds to the JSON property `square`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsSquareProto]
        attr_accessor :square
      
        # scope = YOUTUBE_USER
        # Corresponds to the JSON property `youtubeUser`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsYoutubeUserProto]
        attr_accessor :youtube_user
      
        # See go/zwieback. New uses of Zwieback sessions must be approved via go/
        # zwieback-request.
        # Corresponds to the JSON property `zwiebackSession`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsZwiebackSessionProto]
        attr_accessor :zwieback_session
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_authenticated_users = args[:all_authenticated_users] if args.key?(:all_authenticated_users)
          @cap_token_holder = args[:cap_token_holder] if args.key?(:cap_token_holder)
          @chat = args[:chat] if args.key?(:chat)
          @circle = args[:circle] if args.key?(:circle)
          @cloud_principal = args[:cloud_principal] if args.key?(:cloud_principal)
          @contact_group = args[:contact_group] if args.key?(:contact_group)
          @email_owner = args[:email_owner] if args.key?(:email_owner)
          @event = args[:event] if args.key?(:event)
          @gaia_group = args[:gaia_group] if args.key?(:gaia_group)
          @gaia_user = args[:gaia_user] if args.key?(:gaia_user)
          @host = args[:host] if args.key?(:host)
          @ldap_group = args[:ldap_group] if args.key?(:ldap_group)
          @ldap_user = args[:ldap_user] if args.key?(:ldap_user)
          @mdb_group = args[:mdb_group] if args.key?(:mdb_group)
          @mdb_user = args[:mdb_user] if args.key?(:mdb_user)
          @oauth_consumer = args[:oauth_consumer] if args.key?(:oauth_consumer)
          @postini_user = args[:postini_user] if args.key?(:postini_user)
          @rbac_role = args[:rbac_role] if args.key?(:rbac_role)
          @rbac_subject = args[:rbac_subject] if args.key?(:rbac_subject)
          @resource_role = args[:resource_role] if args.key?(:resource_role)
          @scope = args[:scope] if args.key?(:scope)
          @signing_key_possessor = args[:signing_key_possessor] if args.key?(:signing_key_possessor)
          @simple_secret_holder = args[:simple_secret_holder] if args.key?(:simple_secret_holder)
          @social_graph_node = args[:social_graph_node] if args.key?(:social_graph_node)
          @square = args[:square] if args.key?(:square)
          @youtube_user = args[:youtube_user] if args.key?(:youtube_user)
          @zwieback_session = args[:zwieback_session] if args.key?(:zwieback_session)
        end
      end
      
      # Principal associated with a given RBAC role. This principal is used by Sphinx
      # Provisioning Service for RBAC (go/cedi-auth) provisionable (go/sphinx-rbacz-
      # design).
      class SecurityCredentialsRbacRoleProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `objectId`
        # @return [String]
        attr_accessor :object_id_prop
      
        # DEPRECATED as of 01.11.2019
        # Corresponds to the JSON property `rbacNamespace`
        # @return [String]
        attr_accessor :rbac_namespace
      
        # Format: "RbacNamespaceName.RbacRoleName(/field=value)*", e.g., "hr.v1.Reader",
        # "hr.v1.Reader/language=EN_US/country=USA/room=NYC-9th-11A201".
        # Corresponds to the JSON property `rbacRoleName`
        # @return [String]
        attr_accessor :rbac_role_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
          @rbac_namespace = args[:rbac_namespace] if args.key?(:rbac_namespace)
          @rbac_role_name = args[:rbac_role_name] if args.key?(:rbac_role_name)
        end
      end
      
      # Principal associated with a given RBAC subject. This principal is used by
      # Sphinx Provisioning Service for RBAC (go/cedi-auth) provisionable (go/sphinx-
      # rbacz-design).
      class SecurityCredentialsRbacSubjectProto
        include Google::Apis::Core::Hashable
      
        # Format "username" without "@domain", e.g., "bogdand".
        # Corresponds to the JSON property `username`
        # @return [String]
        attr_accessor :username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @username = args[:username] if args.key?(:username)
        end
      end
      
      # A type of sharing target that points to some resource's ACL. Used to refer to
      # the set of Principals that have the given privilege ('role_id') for the given
      # resource ('application_id', 'object_id', 'object_part'). The meaning of '
      # role_id' is interpreted only by implementations of AclRpcService and is
      # usually dependent on 'application_id' All fields except object_part are
      # required. If present, object_part must be non-empty.
      class SecurityCredentialsResourceRoleProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `applicationId`
        # @return [String]
        attr_accessor :application_id
      
        # 
        # Corresponds to the JSON property `objectId`
        # @return [String]
        attr_accessor :object_id_prop
      
        # 
        # Corresponds to the JSON property `objectPart`
        # @return [String]
        attr_accessor :object_part
      
        # 
        # Corresponds to the JSON property `roleId`
        # @return [Fixnum]
        attr_accessor :role_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_id = args[:application_id] if args.key?(:application_id)
          @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
          @object_part = args[:object_part] if args.key?(:object_part)
          @role_id = args[:role_id] if args.key?(:role_id)
        end
      end
      
      # Represents a principal who possesses a signing key corresponding to the
      # verification key or keyset described here.
      class SecurityCredentialsSigningKeyPossessorProto
        include Google::Apis::Core::Hashable
      
        # This value must be from the KeyMetadata.Type enum in keymaster.proto.
        # Corresponds to the JSON property `keymasterKeyType`
        # @return [Fixnum]
        attr_accessor :keymaster_key_type
      
        # The actual verification key bytes corresponding to the above type.
        # Corresponds to the JSON property `serializedVerificationKey`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :serialized_verification_key
      
        # The binary serialized Keymaster SerializedReader of a public keyset. The
        # keyset must contain exactly one key. N.B.: If this field is populated,
        # serialized_verification_key should be set to the empty string and
        # keymaster_key_type should be set to zero.
        # Corresponds to the JSON property `serializedVerificationKeyset`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :serialized_verification_keyset
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @keymaster_key_type = args[:keymaster_key_type] if args.key?(:keymaster_key_type)
          @serialized_verification_key = args[:serialized_verification_key] if args.key?(:serialized_verification_key)
          @serialized_verification_keyset = args[:serialized_verification_keyset] if args.key?(:serialized_verification_keyset)
        end
      end
      
      # Represents a principal which possesses a particular, presumably secret, string.
      # Useful for things like "auth keys," used for anonymous sharing. Since
      # representing this principal with the actual secret included reveals the secret,
      # it's best if the requisite condition is enforced in some other way, for
      # example via Keystore wrapping attributes (Keystore will unwrap only if the
      # specified secret, aka "attribute", is presented). All that's stored here is an
      # identifying label.
      class SecurityCredentialsSimpleSecretHolderProto
        include Google::Apis::Core::Hashable
      
        # SimpleSecretProto (in authenticator.proto) and SimpleSecretHolderProto (below)
        # share the notion of a "label", which identifies a particular secret without (
        # hopefully) revealing the secret. Note that a SimpleSecretLabel only
        # disambiguates between secrets used to get access to some particular object.
        # Two different secrets that apply to two different objects could have the same
        # label. For example, in the common sharing model, each object has no more than
        # one "auth key". Therefore, the label for an auth key simply has type =
        # AUTH_KEY with no additional information. In theory, we could add some sort of
        # resource ID to SimpleSecretLabel to make it more explicit. However, in
        # practice, this is never really needed. A SimpleSecret for one object is never
        # used to authorize a request on some other object, so there is no ambiguity.
        # Also, since SimpleSecrets must obviously be unguessable, there is no risk that
        # a SimpleSecret intended for one object will accidentally grant access to
        # another.
        # Corresponds to the JSON property `label`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsSimpleSecretLabelProto]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # SimpleSecretProto (in authenticator.proto) and SimpleSecretHolderProto (below)
      # share the notion of a "label", which identifies a particular secret without (
      # hopefully) revealing the secret. Note that a SimpleSecretLabel only
      # disambiguates between secrets used to get access to some particular object.
      # Two different secrets that apply to two different objects could have the same
      # label. For example, in the common sharing model, each object has no more than
      # one "auth key". Therefore, the label for an auth key simply has type =
      # AUTH_KEY with no additional information. In theory, we could add some sort of
      # resource ID to SimpleSecretLabel to make it more explicit. However, in
      # practice, this is never really needed. A SimpleSecret for one object is never
      # used to authorize a request on some other object, so there is no ambiguity.
      # Also, since SimpleSecrets must obviously be unguessable, there is no risk that
      # a SimpleSecret intended for one object will accidentally grant access to
      # another.
      class SecurityCredentialsSimpleSecretLabelProto
        include Google::Apis::Core::Hashable
      
        # ***DEPRECATED (3-Oct-2011) *** This field should be deleted when code stops
        # using CAP_TOKEN labels. Used when type = CAP_TOKEN. When a CAP_TOKEN label
        # appears in a SimpleSecretHolder Principal, |capability_id| must be filled in
        # to identify one of the capabilities on the ACL. When a CAP_TOKEN label appears
        # in a SimpleSecret Authenticator, it is NOT necessary to fill in |capability_id|
        # -- ACL Service will find the ID by searching all capabilities on the ACL for
        # one associated with the token given by the SimpleSecret's secret data. If |
        # capability_id| is specified, though, then the Authenticator will only be
        # accepted if it actually matches that particular token ID.
        # Corresponds to the JSON property `capabilityId`
        # @return [Fixnum]
        attr_accessor :capability_id
      
        # Used when type = GENERIC_SECRET
        # Corresponds to the JSON property `genericLabel`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :generic_label
      
        # Used when type == INVITE.
        # Corresponds to the JSON property `inviteId`
        # @return [Fixnum]
        attr_accessor :invite_id
      
        # This is optional because required enums cannot be extended.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @capability_id = args[:capability_id] if args.key?(:capability_id)
          @generic_label = args[:generic_label] if args.key?(:generic_label)
          @invite_id = args[:invite_id] if args.key?(:invite_id)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Represents a user pseudonym. Pseudonyms are linked accounts on Google and
      # third-party services (e.g. YouTube or Twitter) and are described by a Social
      # Graph Node.
      class SecurityCredentialsSocialGraphNodeProto
        include Google::Apis::Core::Hashable
      
        # The fields from ccc/socialgraph/socialgraphnode.proto:SgnNode that uniquely
        # identify a social graph node. The 'ident' field is not included here because
        # its value can be changed.
        # Corresponds to the JSON property `sgnDomain`
        # @return [String]
        attr_accessor :sgn_domain
      
        # 
        # Corresponds to the JSON property `sgnPk`
        # @return [String]
        attr_accessor :sgn_pk
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @sgn_domain = args[:sgn_domain] if args.key?(:sgn_domain)
          @sgn_pk = args[:sgn_pk] if args.key?(:sgn_pk)
        end
      end
      
      # Represents the set of members (of a given type) in a Google+ Square (see http:/
      # /go/squares). A Square with default member_type is currently (1/2012)
      # identical to the GaiaGroup with the same ID, but that is expected to change
      # soon (see http://go/superglue). Support for this principal type is currently (
      # 1/2012) incomplete -- e.g., Keystore does not support it yet (see b/5703421).
      class SecurityCredentialsSquareProto
        include Google::Apis::Core::Hashable
      
        # The type of Square members to consider, e.g. "all members" vs. "owners" vs. "
        # admins". These are defined by legacy_relation_id values in social.graph.
        # storage.EdgeTypeEnum.EdgeType enum options in social/graph/storage/proto/id.
        # proto. See square.pb (defined in production/config/cdd/socialgraph/
        # mixer_config/prod/node_type_config) for all valid edge types associated with
        # square. Currently required.
        # Corresponds to the JSON property `memberType`
        # @return [Fixnum]
        attr_accessor :member_type
      
        # Currently required.
        # Corresponds to the JSON property `squareId`
        # @return [Fixnum]
        attr_accessor :square_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @member_type = args[:member_type] if args.key?(:member_type)
          @square_id = args[:square_id] if args.key?(:square_id)
        end
      end
      
      # 
      class SecurityCredentialsYoutubeUserProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `youtubeUserId`
        # @return [Fixnum]
        attr_accessor :youtube_user_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @youtube_user_id = args[:youtube_user_id] if args.key?(:youtube_user_id)
        end
      end
      
      # See go/zwieback. New uses of Zwieback sessions must be approved via go/
      # zwieback-request.
      class SecurityCredentialsZwiebackSessionProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `zwiebackSessionId`
        # @return [Fixnum]
        attr_accessor :zwieback_session_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @zwieback_session_id = args[:zwieback_session_id] if args.key?(:zwieback_session_id)
        end
      end
      
      # Sentence boundaries.
      class SentenceBoundaryAnnotations
        include Google::Apis::Core::Hashable
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # 
        # Corresponds to the JSON property `instance`
        # @return [Array<Google::Apis::ContentwarehouseV1::SentenceBoundaryAnnotationsInstance>]
        attr_accessor :instance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @info = args[:info] if args.key?(:info)
          @instance = args[:instance] if args.key?(:instance)
        end
      end
      
      # 
      class SentenceBoundaryAnnotationsInstance
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # A clean version of .text() generated by using CleanText() and stripping
        # unnecessary whitespace.
        # Corresponds to the JSON property `cleanText`
        # @return [String]
        attr_accessor :clean_text
      
        # Plain text context from the page within which the annotation occurred.
        # Corresponds to the JSON property `context`
        # @return [String]
        attr_accessor :context
      
        # Byte offsets for the clean text context above.
        # Corresponds to the JSON property `contextBegin`
        # @return [Fixnum]
        attr_accessor :context_begin
      
        # 
        # Corresponds to the JSON property `contextEnd`
        # @return [Fixnum]
        attr_accessor :context_end
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # Original UTF-8 document text occurring in the range [begin, end).
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Used to mark the annotations selected to be indexed.
        # Corresponds to the JSON property `toIndex`
        # @return [Boolean]
        attr_accessor :to_index
        alias_method :to_index?, :to_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @clean_text = args[:clean_text] if args.key?(:clean_text)
          @context = args[:context] if args.key?(:context)
          @context_begin = args[:context_begin] if args.key?(:context_begin)
          @context_end = args[:context_end] if args.key?(:context_end)
          @end = args[:end] if args.key?(:end)
          @info = args[:info] if args.key?(:info)
          @text = args[:text] if args.key?(:text)
          @to_index = args[:to_index] if args.key?(:to_index)
        end
      end
      
      # This proto contains the sentiment and emotions that the user is exhibiting at
      # the time of the query. NEXT ID: 4
      class SentimentSentiment
        include Google::Apis::Core::Hashable
      
        # Polarity represents the sentiment towards the subject.
        # Corresponds to the JSON property `polarity`
        # @return [String]
        attr_accessor :polarity
      
        # The set of behavior signals that the user is expressing/demonstrating that is
        # detected by the sentiment analysis. These signals are used to help assistant
        # determine the proper response behavior. NEXT ID = 2
        # Corresponds to the JSON property `userBehaviors`
        # @return [Google::Apis::ContentwarehouseV1::SentimentSentimentBehaviors]
        attr_accessor :user_behaviors
      
        # Basic emotions. NEXT ID: 7
        # Corresponds to the JSON property `userEmotions`
        # @return [Google::Apis::ContentwarehouseV1::SentimentSentimentEmotions]
        attr_accessor :user_emotions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @polarity = args[:polarity] if args.key?(:polarity)
          @user_behaviors = args[:user_behaviors] if args.key?(:user_behaviors)
          @user_emotions = args[:user_emotions] if args.key?(:user_emotions)
        end
      end
      
      # The set of behavior signals that the user is expressing/demonstrating that is
      # detected by the sentiment analysis. These signals are used to help assistant
      # determine the proper response behavior. NEXT ID = 2
      class SentimentSentimentBehaviors
        include Google::Apis::Core::Hashable
      
        # The degree to which the user is showing politeness.
        # Corresponds to the JSON property `politeness`
        # @return [Float]
        attr_accessor :politeness
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @politeness = args[:politeness] if args.key?(:politeness)
        end
      end
      
      # Basic emotions. NEXT ID: 7
      class SentimentSentimentEmotions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anger`
        # @return [Fixnum]
        attr_accessor :anger
      
        # 
        # Corresponds to the JSON property `disgust`
        # @return [Fixnum]
        attr_accessor :disgust
      
        # 
        # Corresponds to the JSON property `fear`
        # @return [Fixnum]
        attr_accessor :fear
      
        # 
        # Corresponds to the JSON property `happiness`
        # @return [Fixnum]
        attr_accessor :happiness
      
        # 
        # Corresponds to the JSON property `sadness`
        # @return [Fixnum]
        attr_accessor :sadness
      
        # 
        # Corresponds to the JSON property `surprise`
        # @return [Fixnum]
        attr_accessor :surprise
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anger = args[:anger] if args.key?(:anger)
          @disgust = args[:disgust] if args.key?(:disgust)
          @fear = args[:fear] if args.key?(:fear)
          @happiness = args[:happiness] if args.key?(:happiness)
          @sadness = args[:sadness] if args.key?(:sadness)
          @surprise = args[:surprise] if args.key?(:surprise)
        end
      end
      
      # This message represents shingle-related information obtained from a document.
      class ShingleInfoPerDocData
        include Google::Apis::Core::Hashable
      
        # Total number of shingles in the document.
        # Corresponds to the JSON property `numShingles`
        # @return [Fixnum]
        attr_accessor :num_shingles
      
        # A list of all sources.
        # Corresponds to the JSON property `source`
        # @return [Array<Google::Apis::ContentwarehouseV1::ShingleSource>]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @num_shingles = args[:num_shingles] if args.key?(:num_shingles)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # This message represents a source of shingles. Used by ShingleInfoPerDocData.
      class ShingleSource
        include Google::Apis::Core::Hashable
      
        # Hash-value of the URL.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # Number of shingles originating from this source.
        # Corresponds to the JSON property `numShingles`
        # @return [Fixnum]
        attr_accessor :num_shingles
      
        # First-seen timestamp of the source.
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @num_shingles = args[:num_shingles] if args.key?(:num_shingles)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # Images inferred from context instead of propagated from Shopping backends. The
      # same image might be inferred via different means; then it may appear multiple
      # times in Offer.inferred_images list with different values of
      # inferred_image_type field.
      class ShoppingWebentityShoppingAnnotationInferredImage
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `inferredImageId`
        # @return [Fixnum]
        attr_accessor :inferred_image_id
      
        # 
        # Corresponds to the JSON property `inferredImageType`
        # @return [String]
        attr_accessor :inferred_image_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @inferred_image_id = args[:inferred_image_id] if args.key?(:inferred_image_id)
          @inferred_image_type = args[:inferred_image_type] if args.key?(:inferred_image_type)
        end
      end
      
      # Information about a rating provided for a product. This can represent an
      # aggregated rating if count is set. Next Id: 4
      class ShoppingWebentityShoppingAnnotationProductRating
        include Google::Apis::Core::Hashable
      
        # Number of ratings/reviews aggregated to create this product rating. If there
        # are no ratings yet, this field will be explicitly set to zero, so whether this
        # field is set should be checked using has_count.
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The value of this rating normalized between 0 and 5. This will not be set if
        # count is set to 0.
        # Corresponds to the JSON property `value`
        # @return [Float]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @source = args[:source] if args.key?(:source)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Versioning Information used for Logging Purposes. See go/sori-logjoining.
      class ShoppingWebentityShoppingAnnotationSoriVersionId
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `f1CommitTimestampMicros`
        # @return [Fixnum]
        attr_accessor :f1_commit_timestamp_micros
      
        # The serialized form of a SORI id. NOTE that this proto is stored in V4/O4
        # index and that new fields should not be added without getting an agreement
        # from the serving team as well.
        # Corresponds to the JSON property `opaqueSoriId`
        # @return [Google::Apis::ContentwarehouseV1::AdsShoppingReportingOffersSerializedSoriId]
        attr_accessor :opaque_sori_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @f1_commit_timestamp_micros = args[:f1_commit_timestamp_micros] if args.key?(:f1_commit_timestamp_micros)
          @opaque_sori_id = args[:opaque_sori_id] if args.key?(:opaque_sori_id)
        end
      end
      
      # Note: If you are going to populate any new field in this proto, you probably
      # need to go through the go/dj-new-field and go/index-changes process.
      class Sitemap
        include Google::Apis::Core::Hashable
      
        # DEPRECATED DEPRECATED DEPRECATED In case you didn't realize, these fields are (
        # and have been for some time) deprecated. We'll stop pushing their data to
        # production soon (probably Feb/09) and after a few weeks we'll probably remove
        # them.
        # Corresponds to the JSON property `DEPRECATEDSourceTitle`
        # @return [String]
        attr_accessor :deprecated_source_title
      
        # One Sitemap can contain multiple TargetGroups, but only one of them will be
        # displayed to the user - this decision will be made at displaying time and can
        # take into account various factors, such as the users' language and country,
        # currently running experiments, etc.
        # Corresponds to the JSON property `TargetGroups`
        # @return [Array<Google::Apis::ContentwarehouseV1::QualitySitemapTargetGroup>]
        attr_accessor :target_groups
      
        # 
        # Corresponds to the JSON property `deprecatedTarget`
        # @return [Array<Google::Apis::ContentwarehouseV1::SitemapDeprecatedTarget>]
        attr_accessor :deprecated_target
      
        # Enable site search.
        # Corresponds to the JSON property `searchInSite`
        # @return [Boolean]
        attr_accessor :search_in_site
        alias_method :search_in_site?, :search_in_site
      
        # 
        # Corresponds to the JSON property `sitemapType`
        # @return [String]
        attr_accessor :sitemap_type
      
        # prevents cross-domain forwarding
        # Corresponds to the JSON property `sourceOrgfp`
        # @return [Fixnum]
        attr_accessor :source_orgfp
      
        # 
        # Corresponds to the JSON property `sourceUrl`
        # @return [String]
        attr_accessor :source_url
      
        # A container for encapsulating a list of sub-results.
        # Corresponds to the JSON property `subresultList`
        # @return [Google::Apis::ContentwarehouseV1::QualitySitemapSubresultList]
        attr_accessor :subresult_list
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_source_title = args[:deprecated_source_title] if args.key?(:deprecated_source_title)
          @target_groups = args[:target_groups] if args.key?(:target_groups)
          @deprecated_target = args[:deprecated_target] if args.key?(:deprecated_target)
          @search_in_site = args[:search_in_site] if args.key?(:search_in_site)
          @sitemap_type = args[:sitemap_type] if args.key?(:sitemap_type)
          @source_orgfp = args[:source_orgfp] if args.key?(:source_orgfp)
          @source_url = args[:source_url] if args.key?(:source_url)
          @subresult_list = args[:subresult_list] if args.key?(:subresult_list)
        end
      end
      
      # 
      class SitemapDeprecatedTarget
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `DEPRECATEDAnchor`
        # @return [String]
        attr_accessor :deprecated_anchor
      
        # 
        # Corresponds to the JSON property `DEPRECATEDRunningAnchor`
        # @return [Boolean]
        attr_accessor :deprecated_running_anchor
        alias_method :deprecated_running_anchor?, :deprecated_running_anchor
      
        # 
        # Corresponds to the JSON property `DEPRECATEDTitle`
        # @return [String]
        attr_accessor :deprecated_title
      
        # 
        # Corresponds to the JSON property `displaytitle`
        # @return [String]
        attr_accessor :displaytitle
      
        # optional, exclude to save space
        # Corresponds to the JSON property `score`
        # @return [Fixnum]
        attr_accessor :score
      
        # 
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_anchor = args[:deprecated_anchor] if args.key?(:deprecated_anchor)
          @deprecated_running_anchor = args[:deprecated_running_anchor] if args.key?(:deprecated_running_anchor)
          @deprecated_title = args[:deprecated_title] if args.key?(:deprecated_title)
          @displaytitle = args[:displaytitle] if args.key?(:displaytitle)
          @score = args[:score] if args.key?(:score)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # This message is used for storing smartphone related information. Note:
      # MobilePerDocData is a similar message, but it's for lowend mobile.
      class SmartphonePerDocData
        include Google::Apis::Core::Hashable
      
        # If set, this page is a smartphone dup, a page serving equivalent contents as
        # another URL (desktop canonical), but in smartphone-optimized style. This field
        # holds the docid of the desktop canonical.
        # Corresponds to the JSON property `DEPRECATEDDesktopCanonicalDocid`
        # @return [Fixnum]
        attr_accessor :deprecated_desktop_canonical_docid
      
        # Mobile URL for homepages, predicted by the URL rewrite rules. See go/mobile-
        # homepage-prediction.
        # Corresponds to the JSON property `DEPRECATEDMobileHomepageDocid`
        # @return [Fixnum]
        attr_accessor :deprecated_mobile_homepage_docid
      
        # Indicates if the page is violating mobile ads density interstitial policy and
        # the voilation strength. See go/interstitials-for-ads and http://ariane/268642
        # for details. To save indexing space, we convert the double values in [0.0, 1.0]
        # to intergers in range [0, 1000] by using floor(value * 1000).
        # Corresponds to the JSON property `adsDensityInterstitialViolationStrength`
        # @return [Fixnum]
        attr_accessor :ads_density_interstitial_violation_strength
      
        # Indicates if the page serves error to smartphone crawler. go/ramsey-
        # sp404demotion
        # Corresponds to the JSON property `isErrorPage`
        # @return [Boolean]
        attr_accessor :is_error_page
        alias_method :is_error_page?, :is_error_page
      
        # Indicates if the page has mobile N-1 redirection. go/ramsey-n1demotion
        # Corresponds to the JSON property `isN1Redirect`
        # @return [Boolean]
        attr_accessor :is_n1_redirect
        alias_method :is_n1_redirect?, :is_n1_redirect
      
        # Indicates if the page is rendered in a friendly manner on smartphones. We use
        # this field as tri-state: "unset" means the rendering result classification is
        # not available, and "set as false" means that the page is rendered in
        # unfriendly manner on smartphones. See also go/modena-ranking.
        # Corresponds to the JSON property `isSmartphoneOptimized`
        # @return [Boolean]
        attr_accessor :is_smartphone_optimized
        alias_method :is_smartphone_optimized?, :is_smartphone_optimized
      
        # Indicates if the current URL serves error page to desktop crawler and non
        # error page to smartphone crawler.
        # Corresponds to the JSON property `isWebErrorMobileContent`
        # @return [Boolean]
        attr_accessor :is_web_error_mobile_content
        alias_method :is_web_error_mobile_content?, :is_web_error_mobile_content
      
        # The ratio of the area of the largest Flash to the render area.
        # Corresponds to the JSON property `maximumFlashRatio`
        # @return [Float]
        attr_accessor :maximum_flash_ratio
      
        # Mobile friendliness score in the range of [0, 100]. See go/modena-ranking.
        # Corresponds to the JSON property `mobileFriendlyScore`
        # @return [Fixnum]
        attr_accessor :mobile_friendly_score
      
        # Indicates if the page is violating mobile interstitial policy and should be
        # demoted. See go/interstitials-ranking-dd for details.
        # Corresponds to the JSON property `violatesMobileInterstitialPolicy`
        # @return [Boolean]
        attr_accessor :violates_mobile_interstitial_policy
        alias_method :violates_mobile_interstitial_policy?, :violates_mobile_interstitial_policy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deprecated_desktop_canonical_docid = args[:deprecated_desktop_canonical_docid] if args.key?(:deprecated_desktop_canonical_docid)
          @deprecated_mobile_homepage_docid = args[:deprecated_mobile_homepage_docid] if args.key?(:deprecated_mobile_homepage_docid)
          @ads_density_interstitial_violation_strength = args[:ads_density_interstitial_violation_strength] if args.key?(:ads_density_interstitial_violation_strength)
          @is_error_page = args[:is_error_page] if args.key?(:is_error_page)
          @is_n1_redirect = args[:is_n1_redirect] if args.key?(:is_n1_redirect)
          @is_smartphone_optimized = args[:is_smartphone_optimized] if args.key?(:is_smartphone_optimized)
          @is_web_error_mobile_content = args[:is_web_error_mobile_content] if args.key?(:is_web_error_mobile_content)
          @maximum_flash_ratio = args[:maximum_flash_ratio] if args.key?(:maximum_flash_ratio)
          @mobile_friendly_score = args[:mobile_friendly_score] if args.key?(:mobile_friendly_score)
          @violates_mobile_interstitial_policy = args[:violates_mobile_interstitial_policy] if args.key?(:violates_mobile_interstitial_policy)
        end
      end
      
      # For legacy purposes, cdocs contain a repeated list of *Entry, whereas it's
      # more convenient elsewhere to contain this information within its own protocol
      # buffer.
      class SmearedWebLandingPageEntry
        include Google::Apis::Core::Hashable
      
        # Source imagesearch docid
        # Corresponds to the JSON property `imagesearchDocid`
        # @return [Fixnum]
        attr_accessor :imagesearch_docid
      
        # Docid of web landing page
        # Corresponds to the JSON property `webDocid`
        # @return [Fixnum]
        attr_accessor :web_docid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @imagesearch_docid = args[:imagesearch_docid] if args.key?(:imagesearch_docid)
          @web_docid = args[:web_docid] if args.key?(:web_docid)
        end
      end
      
      # A simple 2D box represented by an (x, y) co-ordinate, width and height. Copied
      # from htmlrender_webkit_headless_proto.Document to avoid additional dependency.
      class SnapshotBox
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        # 
        # Corresponds to the JSON property `x`
        # @return [Fixnum]
        attr_accessor :x
      
        # 
        # Corresponds to the JSON property `y`
        # @return [Fixnum]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @width = args[:width] if args.key?(:width)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # 
      class SnapshotImageNode
        include Google::Apis::Core::Hashable
      
        # A simple 2D box represented by an (x, y) co-ordinate, width and height. Copied
        # from htmlrender_webkit_headless_proto.Document to avoid additional dependency.
        # Corresponds to the JSON property `boundingBox`
        # @return [Google::Apis::ContentwarehouseV1::SnapshotBox]
        attr_accessor :bounding_box
      
        # An image is considered external iff both: 1. The image appears in a link that
        # is not in the same org as the document, or the target URL is in a different
        # org. 2. The image src is not in the same org as the document.
        # Corresponds to the JSON property `isExternal`
        # @return [Boolean]
        attr_accessor :is_external
        alias_method :is_external?, :is_external
      
        # The absolute url of the image as present in the page.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
          @is_external = args[:is_external] if args.key?(:is_external)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class SnapshotSnapshotDocument
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `imageNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::SnapshotImageNode>]
        attr_accessor :image_node
      
        # 
        # Corresponds to the JSON property `metaNoPreview`
        # @return [Boolean]
        attr_accessor :meta_no_preview
        alias_method :meta_no_preview?, :meta_no_preview
      
        # These are set from tags in the web page:
        # Corresponds to the JSON property `metaNoSnippet`
        # @return [Boolean]
        attr_accessor :meta_no_snippet
        alias_method :meta_no_snippet?, :meta_no_snippet
      
        # The docshards are a FlatSSTable from (64-bit) urlfp to data containing the
        # information found in this protocol buffer. (It's not actually one of these PBs
        # for various performance reasons; instead, the DocumentFormat class handles
        # serialization and deserialization in our own way) Next available ID: 37
        # Corresponds to the JSON property `teradoc`
        # @return [Google::Apis::ContentwarehouseV1::TeragoogleDocumentInfo]
        attr_accessor :teradoc
      
        # 
        # Corresponds to the JSON property `textNode`
        # @return [Array<Google::Apis::ContentwarehouseV1::SnapshotTextNode>]
        attr_accessor :text_node
      
        # 
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_node = args[:image_node] if args.key?(:image_node)
          @meta_no_preview = args[:meta_no_preview] if args.key?(:meta_no_preview)
          @meta_no_snippet = args[:meta_no_snippet] if args.key?(:meta_no_snippet)
          @teradoc = args[:teradoc] if args.key?(:teradoc)
          @text_node = args[:text_node] if args.key?(:text_node)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class SnapshotSnapshotMetadata
        include Google::Apis::Core::Hashable
      
        # The number of distinct resources fetched to render the content. This may aid
        # the calculation of total page load time for user experience. For example, if
        # total_content_length is only a few dozen kilobytes, but that is from fetching
        # 100 distinct resources, total page load time might be much higher than the
        # total_content_length would otherwise infer.
        # Corresponds to the JSON property `countDistinctResources`
        # @return [Fixnum]
        attr_accessor :count_distinct_resources
      
        # The time at which the main resource of the Snapshot was fetched, in seconds
        # since epoch. Note that the various page dependencies may have been fetched at
        # much earlier points in time (hours, maybe days) and that this could be off
        # from the actual rendering time.
        # Corresponds to the JSON property `crawlTimestamp`
        # @return [Fixnum]
        attr_accessor :crawl_timestamp
      
        # 
        # Corresponds to the JSON property `snapshotDocument`
        # @return [Google::Apis::ContentwarehouseV1::SnapshotSnapshotDocument]
        attr_accessor :snapshot_document
      
        # The score here corresponds to the score in Snapshot, a number between 0.0 and
        # 1.0 (higher the better).
        # Corresponds to the JSON property `snapshotQualityScore`
        # @return [Float]
        attr_accessor :snapshot_quality_score
      
        # Number of bytes fetched to render the content. For example, to render a web
        # page, this value would include the HTML, stylesheets, images, and all other
        # dependencies. This can be used to calculate a coarse estimate of the total
        # page load time a user might experience.
        # Corresponds to the JSON property `totalContentSize`
        # @return [Fixnum]
        attr_accessor :total_content_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count_distinct_resources = args[:count_distinct_resources] if args.key?(:count_distinct_resources)
          @crawl_timestamp = args[:crawl_timestamp] if args.key?(:crawl_timestamp)
          @snapshot_document = args[:snapshot_document] if args.key?(:snapshot_document)
          @snapshot_quality_score = args[:snapshot_quality_score] if args.key?(:snapshot_quality_score)
          @total_content_size = args[:total_content_size] if args.key?(:total_content_size)
        end
      end
      
      # The SnapshotDocument contains a list of TextNode's. Each node contains a
      # string of text of the webpage, its bounding box in the agove snapshot image,
      # and its font size (in number of pixels in the snapshot, which could be a
      # fraction number since the snapshot image is typically shrinked). This list of
      # text nodes are extracted from the output from the rendering service:
      # htmlrender_webkit_headless_proto.Document The extraction is done by
      # TrimDocument defined in ./shared/doctrimmer.cc
      class SnapshotTextNode
        include Google::Apis::Core::Hashable
      
        # A simple 2D box represented by an (x, y) co-ordinate, width and height. Copied
        # from htmlrender_webkit_headless_proto.Document to avoid additional dependency.
        # Corresponds to the JSON property `boundingBox`
        # @return [Google::Apis::ContentwarehouseV1::SnapshotBox]
        attr_accessor :bounding_box
      
        # 
        # Corresponds to the JSON property `fontSize`
        # @return [Float]
        attr_accessor :font_size
      
        # One if the current text node is within a link; otherwise zero/not present.
        # Corresponds to the JSON property `inLink`
        # @return [Fixnum]
        attr_accessor :in_link
      
        # A value in the range [0,7] (zero if not present) indicating the most "powerful"
        # splitting tag since the last text node. See "enum Category" in mustang/
        # snippets/taginfo.h.
        # Corresponds to the JSON property `maxSplit`
        # @return [Fixnum]
        attr_accessor :max_split
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
          @font_size = args[:font_size] if args.key?(:font_size)
          @in_link = args[:in_link] if args.key?(:in_link)
          @max_split = args[:max_split] if args.key?(:max_split)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Extra snippet info used for snippet scoring / modification in superroot. Next
      # ID: 11
      class SnippetExtraInfo
        include Google::Apis::Core::Hashable
      
        # Candidates are ordered by their id.
        # Corresponds to the JSON property `candidateInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::SnippetExtraInfoSnippetCandidateInfo>]
        attr_accessor :candidate_info
      
        # Indicates that the snippet candidates all contain uesr quotes.
        # Corresponds to the JSON property `containUserQuotes`
        # @return [Boolean]
        attr_accessor :contain_user_quotes
        alias_method :contain_user_quotes?, :contain_user_quotes
      
        # Indicates if there are any vulgar snippet candidates.
        # Corresponds to the JSON property `containVulgarCandidates`
        # @return [Boolean]
        attr_accessor :contain_vulgar_candidates
        alias_method :contain_vulgar_candidates?, :contain_vulgar_candidates
      
        # Indicates whether the query relevance features is disabled or not in Muppet
        # scoring.
        # Corresponds to the JSON property `disableQueryFeatures`
        # @return [Boolean]
        attr_accessor :disable_query_features
        alias_method :disable_query_features?, :disable_query_features
      
        # Snippet candidate index selected by snippet brain model. This field will get
        # populated in SnippetFlow in superroot. go/snippets-brain
        # Corresponds to the JSON property `snippetBrainSelectedCandidateIndex`
        # @return [Fixnum]
        attr_accessor :snippet_brain_selected_candidate_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @candidate_info = args[:candidate_info] if args.key?(:candidate_info)
          @contain_user_quotes = args[:contain_user_quotes] if args.key?(:contain_user_quotes)
          @contain_vulgar_candidates = args[:contain_vulgar_candidates] if args.key?(:contain_vulgar_candidates)
          @disable_query_features = args[:disable_query_features] if args.key?(:disable_query_features)
          @snippet_brain_selected_candidate_index = args[:snippet_brain_selected_candidate_index] if args.key?(:snippet_brain_selected_candidate_index)
        end
      end
      
      # Next ID: 12
      class SnippetExtraInfoSnippetCandidateInfo
        include Google::Apis::Core::Hashable
      
        # Candidate identifier number, unique among all snippet candidates under each
        # document in each request. What does this number mean: - Muppet candidates:
        # This equals to the candidate's rank by Muppet snippets scorer. - Superroot
        # candidates: No specific meaning, this number should be larger than that of
        # Muppet candidates. This field is used to: - Verify whether snippet brain
        # chooses a different snippet from Muppet (the one chosen by Muppet is always in
        # id 0). - Print debugging information and sort candidates in debug output.
        # Corresponds to the JSON property `id`
        # @return [Fixnum]
        attr_accessor :id
      
        # If this snippet is chosen by Muppet.
        # Corresponds to the JSON property `isMuppetSelectedSnippet`
        # @return [Boolean]
        attr_accessor :is_muppet_selected_snippet
        alias_method :is_muppet_selected_snippet?, :is_muppet_selected_snippet
      
        # If SnippetsBrain bolding model triggered and a bolding span is generated.
        # Corresponds to the JSON property `isSnippetBrainBoldingTriggered`
        # @return [Boolean]
        attr_accessor :is_snippet_brain_bolding_triggered
        alias_method :is_snippet_brain_bolding_triggered?, :is_snippet_brain_bolding_triggered
      
        # Data to generate the list preview for organic list snippets.
        # Corresponds to the JSON property `listInfo`
        # @return [Google::Apis::ContentwarehouseV1::MustangReposWwwSnippetsOrganicListSnippetResponse]
        attr_accessor :list_info
      
        # Next ID: 9
        # Corresponds to the JSON property `scoringInfo`
        # @return [Google::Apis::ContentwarehouseV1::SnippetExtraInfoSnippetScoringInfo]
        attr_accessor :scoring_info
      
        # Muppet fills snippet lines in `snippet` field.
        # Corresponds to the JSON property `snippet`
        # @return [Array<String>]
        attr_accessor :snippet
      
        # 
        # Corresponds to the JSON property `snippetSource`
        # @return [String]
        attr_accessor :snippet_source
      
        # `snippet_text` will be filled by snippet brain flow in SR for model scoring
        # and debugging purpose.
        # Corresponds to the JSON property `snippetText`
        # @return [String]
        attr_accessor :snippet_text
      
        # 
        # Corresponds to the JSON property `snippetType`
        # @return [String]
        attr_accessor :snippet_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @is_muppet_selected_snippet = args[:is_muppet_selected_snippet] if args.key?(:is_muppet_selected_snippet)
          @is_snippet_brain_bolding_triggered = args[:is_snippet_brain_bolding_triggered] if args.key?(:is_snippet_brain_bolding_triggered)
          @list_info = args[:list_info] if args.key?(:list_info)
          @scoring_info = args[:scoring_info] if args.key?(:scoring_info)
          @snippet = args[:snippet] if args.key?(:snippet)
          @snippet_source = args[:snippet_source] if args.key?(:snippet_source)
          @snippet_text = args[:snippet_text] if args.key?(:snippet_text)
          @snippet_type = args[:snippet_type] if args.key?(:snippet_type)
        end
      end
      
      # Next ID: 9
      class SnippetExtraInfoSnippetScoringInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `brainNg3Score`
        # @return [Float]
        attr_accessor :brain_ng3_score
      
        # The below fields are populated by SnippetFlow in superroot. Score generated
        # from snippet brain model. go/snippets-brain
        # Corresponds to the JSON property `brainScore`
        # @return [Float]
        attr_accessor :brain_score
      
        # Snippet candidate related information and signal scores.
        # Corresponds to the JSON property `features`
        # @return [Google::Apis::ContentwarehouseV1::QualityPreviewRanklabSnippet]
        attr_accessor :features
      
        # Final snippet score by chooser.
        # Corresponds to the JSON property `finalScore`
        # @return [Float]
        attr_accessor :final_score
      
        # Final rank given by SnippetFlow.
        # Corresponds to the JSON property `rankBySnippetFlow`
        # @return [Fixnum]
        attr_accessor :rank_by_snippet_flow
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @brain_ng3_score = args[:brain_ng3_score] if args.key?(:brain_ng3_score)
          @brain_score = args[:brain_score] if args.key?(:brain_score)
          @features = args[:features] if args.key?(:features)
          @final_score = args[:final_score] if args.key?(:final_score)
          @rank_by_snippet_flow = args[:rank_by_snippet_flow] if args.key?(:rank_by_snippet_flow)
        end
      end
      
      # Leading text which may consist of multiple pieces.
      class SnippetsLeadingtextLeadingTextAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `piece`
        # @return [Array<Google::Apis::ContentwarehouseV1::SnippetsLeadingtextLeadingTextAnnotationPiece>]
        attr_accessor :piece
      
        # 
        # Corresponds to the JSON property `pieceType`
        # @return [String]
        attr_accessor :piece_type
      
        # Type of this leading text. Should be an enum of LeadingTextInfo.
        # LeadingTextType
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @piece = args[:piece] if args.key?(:piece)
          @piece_type = args[:piece_type] if args.key?(:piece_type)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class SnippetsLeadingtextLeadingTextAnnotationPiece
        include Google::Apis::Core::Hashable
      
        # A piece of leading text is text within [begin, end). For example, a document
        # is "ABCDEF". If we want to set leading text as 'CD', the value of begin is
        # byte offset of 'C', the value of end is byte offset of 'E'. end == -1 means to
        # the end of document.
        # Corresponds to the JSON property `begin`
        # @return [Fixnum]
        attr_accessor :begin
      
        # UTF8 text, for alignment when using reusableinfo. Those text are not available
        # in docjoins.
        # Corresponds to the JSON property `beginText`
        # @return [String]
        attr_accessor :begin_text
      
        # 
        # Corresponds to the JSON property `end`
        # @return [Fixnum]
        attr_accessor :end
      
        # 
        # Corresponds to the JSON property `endText`
        # @return [String]
        attr_accessor :end_text
      
        # Matched dom path string for debugging.
        # Corresponds to the JSON property `matchedPattern`
        # @return [String]
        attr_accessor :matched_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin = args[:begin] if args.key?(:begin)
          @begin_text = args[:begin_text] if args.key?(:begin_text)
          @end = args[:end] if args.key?(:end)
          @end_text = args[:end_text] if args.key?(:end_text)
          @matched_pattern = args[:matched_pattern] if args.key?(:matched_pattern)
        end
      end
      
      # 
      class SnippetsLeadingtextLeadingTextInfo
        include Google::Apis::Core::Hashable
      
        # Leading text start position, byte offset of page content. The offset is got in
        # ParseMaster. So it is the offset after the content is converted to UTF8.
        # Corresponds to the JSON property `beginPos`
        # @return [Fixnum]
        attr_accessor :begin_pos
      
        # Note: You can also use it to save multiple leading text candidates.
        # Corresponds to the JSON property `leadingtext`
        # @return [Array<Google::Apis::ContentwarehouseV1::SnippetsLeadingtextLeadingTextAnnotation>]
        attr_accessor :leadingtext
      
        # UTF8 text, for alignment when using reusableinfo. The text is not available in
        # docjoins.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Type of leading text which is optimized for this type of document.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @begin_pos = args[:begin_pos] if args.key?(:begin_pos)
          @leadingtext = args[:leadingtext] if args.key?(:leadingtext)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # An Attachment represents a linked entity associated with a piece of social
      # content. This may be a 1st-party or 3rd-party entity. In the Papyrus context,
      # an Attachment is part of a Cent, and sits alongside the main content of the
      # cent, which is represented as a sequence of Segments. Right now an Attachment
      # is just a wrapper around an Embed, but we provide the extra layer of
      # abstraction since, as Embeds move to separate storage in Briefcase, we may
      # want to add additional fields that are not part of the Embed proper, but that (
      # for example) relate to the usage of the linked content within the particular
      # post/cent.
      class SocialCommonAttachmentAttachment
        include Google::Apis::Core::Hashable
      
        # Represents an embedded object in an update. This is a wrapper class that can
        # contain a single specific item proto in an extension field. Think of it as a
        # base class like `Message` in Java. Each item proto must declare that it
        # extends this proto: message ExampleObject ` option (item_type) =
        # EXAMPLE_OBJECT; extend EmbedClientItem ` optional ExampleObject example_object
        # = ; ` ` See go/es-embeds for details.
        # Corresponds to the JSON property `embedItem`
        # @return [Google::Apis::ContentwarehouseV1::EmbedsEmbedClientItem]
        attr_accessor :embed_item
      
        # An id to uniquely identify an attachment when several attachments are in a
        # collection.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @embed_item = args[:embed_item] if args.key?(:embed_item)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # Formatting information for a segment.
      class SocialCommonFormatting
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `bold`
        # @return [Boolean]
        attr_accessor :bold
        alias_method :bold?, :bold
      
        # This indicates that the segment should be rendered as highlighted or visually
        # emphasized.
        # Corresponds to the JSON property `highlight`
        # @return [Boolean]
        attr_accessor :highlight
        alias_method :highlight?, :highlight
      
        # 
        # Corresponds to the JSON property `italics`
        # @return [Boolean]
        attr_accessor :italics
        alias_method :italics?, :italics
      
        # 
        # Corresponds to the JSON property `strikethrough`
        # @return [Boolean]
        attr_accessor :strikethrough
        alias_method :strikethrough?, :strikethrough
      
        # If set, this indicates that the segment should be rendered with the specified
        # style. The absence of an explicit style represents "no style", i.e. the
        # segment can be rendered with the default style chosen by the application.
        # Corresponds to the JSON property `style`
        # @return [String]
        attr_accessor :style
      
        # 
        # Corresponds to the JSON property `underline`
        # @return [Boolean]
        attr_accessor :underline
        alias_method :underline?, :underline
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bold = args[:bold] if args.key?(:bold)
          @highlight = args[:highlight] if args.key?(:highlight)
          @italics = args[:italics] if args.key?(:italics)
          @strikethrough = args[:strikethrough] if args.key?(:strikethrough)
          @style = args[:style] if args.key?(:style)
          @underline = args[:underline] if args.key?(:underline)
        end
      end
      
      # Hashtag metadata, for HASHTAG segments. For a hashtag, the "text" field should
      # contain the display text, and the search_text field should represent the topic
      # being referenced, without the hash symbol; for example, we might have: text = "
      # #Google" hashtag_data.search_text = "Google" Another example: text = "#pikachu"
      # hashtag_data.search_text = "Pokemon" Both strings should be considered part
      # of the searchable text. In go/sbe, both are indexed and searchable.
      class SocialCommonHashtagData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `searchText`
        # @return [String]
        attr_accessor :search_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @search_text = args[:search_text] if args.key?(:search_text)
        end
      end
      
      # Link metadata, for LINK segments. Anchor text should be stored in the "text"
      # field of the Segment, which can also serve as a fallback.
      class SocialCommonLinkData
        include Google::Apis::Core::Hashable
      
        # An Attachment represents a linked entity associated with a piece of social
        # content. This may be a 1st-party or 3rd-party entity. In the Papyrus context,
        # an Attachment is part of a Cent, and sits alongside the main content of the
        # cent, which is represented as a sequence of Segments. Right now an Attachment
        # is just a wrapper around an Embed, but we provide the extra layer of
        # abstraction since, as Embeds move to separate storage in Briefcase, we may
        # want to add additional fields that are not part of the Embed proper, but that (
        # for example) relate to the usage of the linked content within the particular
        # post/cent.
        # Corresponds to the JSON property `attachment`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonAttachmentAttachment]
        attr_accessor :attachment
      
        # The hint to use when rendering the associated attachment. Ignored if there is
        # no associated attachment.
        # Corresponds to the JSON property `attachmentRenderHint`
        # @return [String]
        attr_accessor :attachment_render_hint
      
        # If we wish to show the user a different (e.g. shortened) version of the URL
        # for display purposes, then that version should be set here. If this field isn'
        # t set, link_target will be used for both purposes.
        # Corresponds to the JSON property `displayUrl`
        # @return [String]
        attr_accessor :display_url
      
        # link_target is the URL to navigate to when clicked. This could be the original
        # URL, or a URL signed by the GWS URL signing service.
        # Corresponds to the JSON property `linkTarget`
        # @return [String]
        attr_accessor :link_target
      
        # LinkType is an optional field that provides additional information regarding
        # link target. For example, link type can be identified as the SELF_LINK when
        # the request was executed from the same link as the link target.
        # Corresponds to the JSON property `linkType`
        # @return [String]
        attr_accessor :link_type
      
        # Title is an optional field that provides a short string that describes the
        # link or its destination. User interfaces often use title as a tooltip or for
        # accessibility purposes. However, they are of course free to present this data
        # in any form. This field is plain text.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attachment = args[:attachment] if args.key?(:attachment)
          @attachment_render_hint = args[:attachment_render_hint] if args.key?(:attachment_render_hint)
          @display_url = args[:display_url] if args.key?(:display_url)
          @link_target = args[:link_target] if args.key?(:link_target)
          @link_type = args[:link_type] if args.key?(:link_type)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class SocialCommonSegment
        include Google::Apis::Core::Hashable
      
        # Formatting information for a segment.
        # Corresponds to the JSON property `formatting`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonFormatting]
        attr_accessor :formatting
      
        # Hashtag metadata, for HASHTAG segments. For a hashtag, the "text" field should
        # contain the display text, and the search_text field should represent the topic
        # being referenced, without the hash symbol; for example, we might have: text = "
        # #Google" hashtag_data.search_text = "Google" Another example: text = "#pikachu"
        # hashtag_data.search_text = "Pokemon" Both strings should be considered part
        # of the searchable text. In go/sbe, both are indexed and searchable.
        # Corresponds to the JSON property `hashtagData`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonHashtagData]
        attr_accessor :hashtag_data
      
        # Link metadata, for LINK segments. Anchor text should be stored in the "text"
        # field of the Segment, which can also serve as a fallback.
        # Corresponds to the JSON property `linkData`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonLinkData]
        attr_accessor :link_data
      
        # Text content of the Segment. As a general rule, this field should contain the
        # actual text that should be rendered in the UI. Thus, for a hashtag, it should
        # be "#Foo", and for a link, it should be the display text. Clients that do not
        # understand a particular segment type may use this text, along with the
        # Formatting info below, as a fallback for display. The field is not required --
        # if all relevant information is carried in other metadata fields and there is
        # no need for a fallback, or it is not practical for a fallback to be provided
        # for any other reason, the field may be left blank. A standard example would be
        # a user reference being transmitted between server layers, where a gaia-ID
        # representation may be sufficient and there is no need for a textual fallback.
        # In such a case, it would be valid and useful - though not required - for
        # servers to compute and populate a fallback on the serving path.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # Type of Segment.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # Person metadata, for USER_MENTION segments. Should always contain at least one
        # of user_gaia_id, user_id, email or user. The exact set of populated fields may
        # differ depending on the context and the level in the serving stack; for
        # example, emails will be elided on the viewing path. But as a general rule, a
        # proto having any one of the four is valid, subject to the standard constraints
        # of the applied annotations -- that is, communication between servers and
        # clients will ignore jspb.ignore fields, and communication between servers and
        # other servers (or between servers and storage) will ignore client_only fields.
        # For more on the annotations, see the comments in social/common/
        # segment_annotations.proto
        # Corresponds to the JSON property `userMentionData`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonUserMentionData]
        attr_accessor :user_mention_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @formatting = args[:formatting] if args.key?(:formatting)
          @hashtag_data = args[:hashtag_data] if args.key?(:hashtag_data)
          @link_data = args[:link_data] if args.key?(:link_data)
          @text = args[:text] if args.key?(:text)
          @type = args[:type] if args.key?(:type)
          @user_mention_data = args[:user_mention_data] if args.key?(:user_mention_data)
        end
      end
      
      # Segments (go/social-segments) represent structured social content, e.g. the
      # contents of a G+ stream post or chat message. A single post or message may
      # consist of a sequence of segments, each representing a type of content, e.g.
      # plain text, hash tag, mention, etc. Segments correspond approximately to units
      # of content delimited by HTML tags, so that a piece of bolded text would be a
      # distinct Segment, a link would be a distinct Segment, and so forth. A single
      # Segment may have multiple such qualifiers; e.g. it may be a bold link; in this
      # case, information about all such qualifiers will be encoded in the Segment
      # proto.
      class SocialCommonSegments
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `segments`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialCommonSegment>]
        attr_accessor :segments
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @segments = args[:segments] if args.key?(:segments)
        end
      end
      
      # Person metadata, for USER_MENTION segments. Should always contain at least one
      # of user_gaia_id, user_id, email or user. The exact set of populated fields may
      # differ depending on the context and the level in the serving stack; for
      # example, emails will be elided on the viewing path. But as a general rule, a
      # proto having any one of the four is valid, subject to the standard constraints
      # of the applied annotations -- that is, communication between servers and
      # clients will ignore jspb.ignore fields, and communication between servers and
      # other servers (or between servers and storage) will ignore client_only fields.
      # For more on the annotations, see the comments in social/common/
      # segment_annotations.proto
      class SocialCommonUserMentionData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # A Principal represents something to which permissions are assigned, often but
        # not always a user or group of some kind. It is most appropriate for use in
        # ACLs and authorization checks. Callers should prefer to use the wrapper
        # classes in google3/security/credentials/public/principal.h google3/java/com/
        # google/security/credentials/Principal.java google3/security/credentials/go/
        # principal.go unless direct proto access is essential. If you update this
        # protocol buffer, please update the wrapper classes as well.
        # Corresponds to the JSON property `user`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsPrincipalProto]
        attr_accessor :user
      
        # An unobfuscated gaia ID:
        # Corresponds to the JSON property `userGaiaId`
        # @return [Fixnum]
        attr_accessor :user_gaia_id
      
        # An obfuscated gaia ID:
        # Corresponds to the JSON property `userId`
        # @return [String]
        attr_accessor :user_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @user = args[:user] if args.key?(:user)
          @user_gaia_id = args[:user_gaia_id] if args.key?(:user_gaia_id)
          @user_id = args[:user_id] if args.key?(:user_id)
        end
      end
      
      # An entity key with an obfuscated gaia id that can be used externally.
      class SocialDiscoveryExternalEntityKey
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `email`
        # @return [String]
        attr_accessor :email
      
        # 
        # Corresponds to the JSON property `phone`
        # @return [String]
        attr_accessor :phone
      
        # Obfuscated GAIA id.
        # Corresponds to the JSON property `profileId`
        # @return [String]
        attr_accessor :profile_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @email = args[:email] if args.key?(:email)
          @phone = args[:phone] if args.key?(:phone)
          @profile_id = args[:profile_id] if args.key?(:profile_id)
        end
      end
      
      # Contains a mimetype supported by a third-party app together with additional
      # ids and other data that the apps use to complete the action for the given
      # mimetype. For example, an app_specific_endpoint_id that corresponds to a
      # WhatsApp Profile. Full Design: go/3p-contact-upload LINT.IfChange
      class SocialGraphApiAppContactData
        include Google::Apis::Core::Hashable
      
        # Set of column-name and value for the given mimetype. The semantic meaning of
        # the column values is mime-type specific. For example they may contain
        # app_specific_endpoint_ids for WhatsApp. This is uploaded from CP2 http://go/
        # cp2-data1 through http://go/cp2-data14.
        # Corresponds to the JSON property `data`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiDataColumn>]
        attr_accessor :data
      
        # The mimetype of the action defined by the third-party app.
        # Corresponds to the JSON property `mimetype`
        # @return [String]
        attr_accessor :mimetype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @mimetype = args[:mimetype] if args.key?(:mimetype)
        end
      end
      
      # LINT.IfChange
      class SocialGraphApiDataColumn
        include Google::Apis::Core::Hashable
      
        # The name of the column in CP2 for raw_contact_data.
        # Corresponds to the JSON property `columnName`
        # @return [String]
        attr_accessor :column_name
      
        # The value of the data inside column.
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @column_name = args[:column_name] if args.key?(:column_name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class SocialGraphApiProtoAndroidDeviceInfo
        include Google::Apis::Core::Hashable
      
        # This string will represent either the device make and model in the case of
        # FSA2, or the device model in the case of FSA1.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # 
      class SocialGraphApiProtoBirthdayDecoration
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `birthdayDecorationVisibility`
        # @return [String]
        attr_accessor :birthday_decoration_visibility
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @birthday_decoration_visibility = args[:birthday_decoration_visibility] if args.key?(:birthday_decoration_visibility)
        end
      end
      
      # The ContactDeletionContext message is a wrapper around the generic
      # ContactMutationContext data, and will include any needed delete specific data.
      # NOTE: Before using this message please review go/people-api-contact-deletion-
      # context
      class SocialGraphApiProtoContactDeletionContext
        include Google::Apis::Core::Hashable
      
        # This message is the generic mutation message which will encapsulate the fields
        # which are shared between the create, update, and delete actions, including
        # source of change, timestamp, and metadata messages passed in from the source
        # for any source specific data (such as phone name/model from FSA).
        # Corresponds to the JSON property `mutationContext`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoContactMutationContext]
        attr_accessor :mutation_context
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mutation_context = args[:mutation_context] if args.key?(:mutation_context)
        end
      end
      
      # This message is the generic mutation message which will encapsulate the fields
      # which are shared between the create, update, and delete actions, including
      # source of change, timestamp, and metadata messages passed in from the source
      # for any source specific data (such as phone name/model from FSA).
      class SocialGraphApiProtoContactMutationContext
        include Google::Apis::Core::Hashable
      
        # Android device info should always be set when using either ANDROID_FSA1 or
        # ANDROID_FSA2 as the source of the delete.
        # Corresponds to the JSON property `androidDeviceInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoAndroidDeviceInfo]
        attr_accessor :android_device_info
      
        # Host app info should always be set when using CONTACTS_COMPANION as the source.
        # Corresponds to the JSON property `hostAppInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoHostAppInfo]
        attr_accessor :host_app_info
      
        # The source of a mutate should provide all needed information a user should
        # know, and should be enough information for the front end to generate a proper
        # human readable string to describe the mutate to the user.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # Third party info should always be set when using THIRD_PARTY as the source.
        # Corresponds to the JSON property `thirdPartyInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoThirdPartyInfo]
        attr_accessor :third_party_info
      
        # Timestamp representing when the contact was mutated. This should not be set on
        # write, as it is the job of focus backend to determine this timestamp. This
        # field will be populated on read with the data written by FBS.
        # Corresponds to the JSON property `timestamp`
        # @return [String]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @android_device_info = args[:android_device_info] if args.key?(:android_device_info)
          @host_app_info = args[:host_app_info] if args.key?(:host_app_info)
          @source = args[:source] if args.key?(:source)
          @third_party_info = args[:third_party_info] if args.key?(:third_party_info)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # Contact state and related metadata. See go/fbs-contacts-trash.
      class SocialGraphApiProtoContactState
        include Google::Apis::Core::Hashable
      
        # The ContactDeletionContext message is a wrapper around the generic
        # ContactMutationContext data, and will include any needed delete specific data.
        # NOTE: Before using this message please review go/people-api-contact-deletion-
        # context
        # Corresponds to the JSON property `deletionContext`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoContactDeletionContext]
        attr_accessor :deletion_context
      
        # 
        # Corresponds to the JSON property `deletionState`
        # @return [String]
        attr_accessor :deletion_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @deletion_context = args[:deletion_context] if args.key?(:deletion_context)
          @deletion_state = args[:deletion_state] if args.key?(:deletion_state)
        end
      end
      
      # Represents a delegated group id, delegated groups refer to groups that are
      # owned by another gaiaId, but this user has access to.
      class SocialGraphApiProtoDelegatedGroupId
        include Google::Apis::Core::Hashable
      
        # Required. The id for a delegated group.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
        end
      end
      
      # 
      class SocialGraphApiProtoDisplayNameSource
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # 
      class SocialGraphApiProtoHostAppInfo
        include Google::Apis::Core::Hashable
      
        # This string will represent the info for the host app to the Companion sidebar
        # Corresponds to the JSON property `hostAppName`
        # @return [String]
        attr_accessor :host_app_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @host_app_name = args[:host_app_name] if args.key?(:host_app_name)
        end
      end
      
      # 
      class SocialGraphApiProtoLimitedProfileNameSettings
        include Google::Apis::Core::Hashable
      
        # Required. Describes which shortening option the user implicitly chose for
        # their limited profile. E.g., if 'John Doe' chose 'John D.', they implicitly
        # chose: partial_name_options ` given_name_spec ` show_all: true `
        # family_name_spec: ` show_initial: true truncation_indicator: PERIOD ` ` While
        # we'll in all cases serve the actual name chosen by the user for limited
        # profiles (stored below), we'll use this information to recompute the default
        # limited profile to be rendered to users when they change their core name.
        # Corresponds to the JSON property `partialNameOptions`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPartialNameOptions]
        attr_accessor :partial_name_options
      
        # The actual textual name that was chosen by the user in the UI. E.g., if 'John
        # Doe' chose 'John D.', this holds 'John D.'. While `partial_name_options`
        # allows the limited profile name to be computed from the core name, the
        # resulting shortened name might change across different versions of the name
        # shortening logic, and we want to preserve the user's choice verbatim whenever
        # possible. This field will be cleared when the two conditions below are met: (1)
        # A successful core name change is not accompanied by a limited profile
        # settings update and (2) The shortened name computed from `partial_name_options`
        # yields a different result than what is originally stored in `
        # verbatim_full_name`. When this happens, the limited profile is effectively *
        # disabled*. E.g., if 'John Doe' from the example above changes their name to '
        # Jane Doe' and no LimitedProfileSettings are provided, `Jane D.` is the
        # resulting shortened name. Therefore `verbatim_full_name` will be cleared and
        # the limited profile settings will be disabled. On the other hand, if they
        # change their name to `John Dõe`, the resulting shortened name remains `John D.`
        # , and `verbatim_full_name` is kept as is.
        # Corresponds to the JSON property `verbatimFullName`
        # @return [String]
        attr_accessor :verbatim_full_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @partial_name_options = args[:partial_name_options] if args.key?(:partial_name_options)
          @verbatim_full_name = args[:verbatim_full_name] if args.key?(:verbatim_full_name)
        end
      end
      
      # 
      class SocialGraphApiProtoLimitedProfilePictureSettings
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `profilePictureOption`
        # @return [String]
        attr_accessor :profile_picture_option
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @profile_picture_option = args[:profile_picture_option] if args.key?(:profile_picture_option)
        end
      end
      
      # Next ID: 9
      class SocialGraphApiProtoLimitedProfileSettings
        include Google::Apis::Core::Hashable
      
        # Indicates why the limited profile has been disabled. Will be set iff the
        # limited profile is disabled. This field can only be set server-side and must
        # not be used by external clients when mutating LimitedProfiles.
        # Corresponds to the JSON property `disableReason`
        # @return [String]
        attr_accessor :disable_reason
      
        # Created with user input in GPay OOBE.
        # Corresponds to the JSON property `gpayOobe`
        # @return [Boolean]
        attr_accessor :gpay_oobe
        alias_method :gpay_oobe?, :gpay_oobe
      
        # Timestamp indicating when the settings were last stored. Read-only field.
        # Corresponds to the JSON property `lastUpdateTime`
        # @return [String]
        attr_accessor :last_update_time
      
        # A user who had legacy discoverability had a Limited Profile autogenerated for
        # them, either through a healer or in the live path in FBS.
        # Corresponds to the JSON property `legacyDiscoverability`
        # @return [String]
        attr_accessor :legacy_discoverability
      
        # Created with user input in MyAccount UI.
        # Corresponds to the JSON property `myAccount`
        # @return [Boolean]
        attr_accessor :my_account
        alias_method :my_account?, :my_account
      
        # Required. Defines how the name should be formatted in the limited profile.
        # Corresponds to the JSON property `nameSettings`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoLimitedProfileNameSettings]
        attr_accessor :name_settings
      
        # DEPRECATED. Profile picture choices are controlled through the ACL of the
        # Photo field.
        # Corresponds to the JSON property `profilePictureSettings`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoLimitedProfilePictureSettings]
        attr_accessor :profile_picture_settings
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @disable_reason = args[:disable_reason] if args.key?(:disable_reason)
          @gpay_oobe = args[:gpay_oobe] if args.key?(:gpay_oobe)
          @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
          @legacy_discoverability = args[:legacy_discoverability] if args.key?(:legacy_discoverability)
          @my_account = args[:my_account] if args.key?(:my_account)
          @name_settings = args[:name_settings] if args.key?(:name_settings)
          @profile_picture_settings = args[:profile_picture_settings] if args.key?(:profile_picture_settings)
        end
      end
      
      # 
      class SocialGraphApiProtoPartialNameOptions
        include Google::Apis::Core::Hashable
      
        # IETF BCP-47 language code that should be used for localizing the name
        # computation (go/bcp-47). If not provided, we'll use the name origin detector
        # to infer it. If unable to detect, "en" will be assumed.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # These options use more sophisticated logic from a location-aware name detector
        # to parse the full name of a user into structured parts and operate on those
        # parts. For more information on how names are parsed, see the NameOccurrence
        # proto definition: http://google3/quality/peoplesearch/namedetector/detector/
        # proto/name_occurrence.proto?l=50&rcl=334484707 Next ID: 7
        # Corresponds to the JSON property `parsedDisplayNameSpec`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPartialNameOptionsParsedDisplayNameSpec]
        attr_accessor :parsed_display_name_spec
      
        # Holds the name specs for the two parts of a name, as they are structured in
        # storage (given and family).
        # Corresponds to the JSON property `twoPartNameSpec`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPartialNameOptionsTwoPartNameSpec]
        attr_accessor :two_part_name_spec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @parsed_display_name_spec = args[:parsed_display_name_spec] if args.key?(:parsed_display_name_spec)
          @two_part_name_spec = args[:two_part_name_spec] if args.key?(:two_part_name_spec)
        end
      end
      
      # Specifies how each piece of the name should be handled. Names are structured
      # into given name and family name and this allows an independent specification
      # for each of these pieces. Very limited preprocessing is done for this option (
      # leading whitespace trimming mostly). Composed names are treated as a single
      # unit and are not broken down.
      class SocialGraphApiProtoPartialNameOptionsNamePartSpec
        include Google::Apis::Core::Hashable
      
        # Completely omit that part of the name.
        # Corresponds to the JSON property `hideAll`
        # @return [Boolean]
        attr_accessor :hide_all
        alias_method :hide_all?, :hide_all
      
        # Show the complete name. Note that this does not express the same semantics as
        # show_first_n_chars=length_of_name, because when regenerating a shortened name
        # the new name could have more characters, thus yielding a different result.
        # Corresponds to the JSON property `showAll`
        # @return [Boolean]
        attr_accessor :show_all
        alias_method :show_all?, :show_all
      
        # Show first `n` characters. Same note about characters referring to "
        # grapheme_clusters" applies.
        # Corresponds to the JSON property `showFirstNChars`
        # @return [Fixnum]
        attr_accessor :show_first_n_chars
      
        # Show only the initial, i.e., a single character. Note that "character" refers
        # to "user-perceived" characters, aka a "grapheme cluster". See go/morphology
        # for more details.
        # Corresponds to the JSON property `showInitial`
        # @return [Boolean]
        attr_accessor :show_initial
        alias_method :show_initial?, :show_initial
      
        # Which truncation indicator to use after the shortened piece of the name. Will
        # be ignored for the `hide_all` or `show_all` options.
        # Corresponds to the JSON property `truncationIndicator`
        # @return [String]
        attr_accessor :truncation_indicator
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hide_all = args[:hide_all] if args.key?(:hide_all)
          @show_all = args[:show_all] if args.key?(:show_all)
          @show_first_n_chars = args[:show_first_n_chars] if args.key?(:show_first_n_chars)
          @show_initial = args[:show_initial] if args.key?(:show_initial)
          @truncation_indicator = args[:truncation_indicator] if args.key?(:truncation_indicator)
        end
      end
      
      # These options use more sophisticated logic from a location-aware name detector
      # to parse the full name of a user into structured parts and operate on those
      # parts. For more information on how names are parsed, see the NameOccurrence
      # proto definition: http://google3/quality/peoplesearch/namedetector/detector/
      # proto/name_occurrence.proto?l=50&rcl=334484707 Next ID: 7
      class SocialGraphApiProtoPartialNameOptionsParsedDisplayNameSpec
        include Google::Apis::Core::Hashable
      
        # Extract an initial from each parsed name. For example, "Niels Henrik David
        # Bohr" yields "N. H. D. B.". Other special cases are treated as follows: -
        # Hyphenated names are broken down: "Angelina Jollie-Pit" yields "A. J. P."; -
        # Prefixes are ignored: "Prof. Albus Dumbledore" yields "A. D."; - Auxiliaries
        # are ignored: "Luís de Camões" yields "L. C.".
        # Corresponds to the JSON property `allInitialsFromParsedName`
        # @return [Boolean]
        attr_accessor :all_initials_from_parsed_name
        alias_method :all_initials_from_parsed_name?, :all_initials_from_parsed_name
      
        # Show the initial of the very first name and the very last name, e.g. "Ana
        # Maria Silva" yields "A. Silva". - Hyphenated names are broken down: "Angelina
        # Jollie-Pitt" yields "A. Pitt"; - Prefixes are ignored: "Prof. Albus Dumbledore"
        # yields "A. Dumbledore"; - Auxiliaries are ignored: "Luís de Camões" yields "L.
        # Camões".
        # Corresponds to the JSON property `firstInitialAndVeryLastName`
        # @return [Boolean]
        attr_accessor :first_initial_and_very_last_name
        alias_method :first_initial_and_very_last_name?, :first_initial_and_very_last_name
      
        # Shorten the display name using the Knowledge Graph name shortener (go/short-
        # names).
        # Corresponds to the JSON property `knowledgeGraphNameShortening`
        # @return [Boolean]
        attr_accessor :knowledge_graph_name_shortening
        alias_method :knowledge_graph_name_shortening?, :knowledge_graph_name_shortening
      
        # Which truncation indicator to use after each shortened part of the name. Will
        # be ignored for the `knowledge_graph_name_shortening` option.
        # Corresponds to the JSON property `truncationIndicator`
        # @return [String]
        attr_accessor :truncation_indicator
      
        # Show the full very first name and all the other initials, e.g. "Ana Maria
        # Silva" yields "Ana M. S.". - Hyphenated names are broken down: "Angelina
        # Jollie-Pit" yields "Angelina J. P."; - Prefixes are ignored: "Prof. Albus
        # Dumbledore" yields "Albus D."; - Auxiliaries are ignored: "Luís de Camões"
        # yields "Luís C.".
        # Corresponds to the JSON property `veryFirstNameAndAllInitials`
        # @return [Boolean]
        attr_accessor :very_first_name_and_all_initials
        alias_method :very_first_name_and_all_initials?, :very_first_name_and_all_initials
      
        # Show the very first name only, e.g. "Ana Maria Silva" yields "Ana". -
        # Hyphenated names are broken down: "Mary-Kate Smith" yields "Mary"; - Prefixes
        # are ignored: "Prof. Albus Dumbledore" yields "Albus";
        # Corresponds to the JSON property `veryFirstNameOnly`
        # @return [Boolean]
        attr_accessor :very_first_name_only
        alias_method :very_first_name_only?, :very_first_name_only
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @all_initials_from_parsed_name = args[:all_initials_from_parsed_name] if args.key?(:all_initials_from_parsed_name)
          @first_initial_and_very_last_name = args[:first_initial_and_very_last_name] if args.key?(:first_initial_and_very_last_name)
          @knowledge_graph_name_shortening = args[:knowledge_graph_name_shortening] if args.key?(:knowledge_graph_name_shortening)
          @truncation_indicator = args[:truncation_indicator] if args.key?(:truncation_indicator)
          @very_first_name_and_all_initials = args[:very_first_name_and_all_initials] if args.key?(:very_first_name_and_all_initials)
          @very_first_name_only = args[:very_first_name_only] if args.key?(:very_first_name_only)
        end
      end
      
      # Holds the name specs for the two parts of a name, as they are structured in
      # storage (given and family).
      class SocialGraphApiProtoPartialNameOptionsTwoPartNameSpec
        include Google::Apis::Core::Hashable
      
        # Specifies how each piece of the name should be handled. Names are structured
        # into given name and family name and this allows an independent specification
        # for each of these pieces. Very limited preprocessing is done for this option (
        # leading whitespace trimming mostly). Composed names are treated as a single
        # unit and are not broken down.
        # Corresponds to the JSON property `familyNameSpec`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPartialNameOptionsNamePartSpec]
        attr_accessor :family_name_spec
      
        # Specifies how each piece of the name should be handled. Names are structured
        # into given name and family name and this allows an independent specification
        # for each of these pieces. Very limited preprocessing is done for this option (
        # leading whitespace trimming mostly). Composed names are treated as a single
        # unit and are not broken down.
        # Corresponds to the JSON property `givenNameSpec`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPartialNameOptionsNamePartSpec]
        attr_accessor :given_name_spec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @family_name_spec = args[:family_name_spec] if args.key?(:family_name_spec)
          @given_name_spec = args[:given_name_spec] if args.key?(:given_name_spec)
        end
      end
      
      # Design doc: go/pronouns-backend Represents a user's preferred pronouns.
      class SocialGraphApiProtoPronounData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `pronounEntry`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPronounEntry>]
        attr_accessor :pronoun_entry
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pronoun_entry = args[:pronoun_entry] if args.key?(:pronoun_entry)
        end
      end
      
      # 
      class SocialGraphApiProtoPronounEntry
        include Google::Apis::Core::Hashable
      
        # Locale option in which the pronouns were set, in the BCP-47 format. Set by the
        # client at write time.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # The pronoun entry type that the user has selected. This indicates which locale-
        # independent classification of pronoun was selected (or optionally, if it is a
        # custom field).
        # Corresponds to the JSON property `pronounType`
        # @return [String]
        attr_accessor :pronoun_type
      
        # The user's preferred pronouns. Eg. "they / them". This is a human-readable
        # string to be displayed as the user's pronoun. Set at write-time, regardless of
        # pronoun-type. Value is returned as it was set (no localization).
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language_code = args[:language_code] if args.key?(:language_code)
          @pronoun_type = args[:pronoun_type] if args.key?(:pronoun_type)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Stores the pronunciation as phoneme for the given word/text. Next ID: 8
      class SocialGraphApiProtoPronunciation
        include Google::Apis::Core::Hashable
      
        # All pronunciations with the same learning_session_id were learnt in the same
        # learning flow, e.g. multiple name segments learnt simultaneously from a
        # recording in the Your People UI.
        # Corresponds to the JSON property `learningSessionId`
        # @return [String]
        attr_accessor :learning_session_id
      
        # 
        # Corresponds to the JSON property `learningSource`
        # @return [String]
        attr_accessor :learning_source
      
        # The locale used when learning the pronunciation. BCP-47 language code, e.g. "
        # en-US".
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        # Phoneme sequence representing how the user pronounces |token|. Format is
        # specified by the phonology_type type field, e.g. go/psampa is the preferred
        # phonology type used by the TTS team.
        # Corresponds to the JSON property `phonemes`
        # @return [String]
        attr_accessor :phonemes
      
        # 
        # Corresponds to the JSON property `phonologyType`
        # @return [String]
        attr_accessor :phonology_type
      
        # An optional user-specified spelling of this token, to improve pronunciation
        # learning success rate. E.g. the token may be "Jana" and the spelling hint "jah-
        # nah".
        # Corresponds to the JSON property `spellingHint`
        # @return [String]
        attr_accessor :spelling_hint
      
        # Corresponds to a word segment of the contact name. E.g. for a contact with
        # given name "John Doe", last name "Smith" and nickname "Best Dad", |token| can
        # be any of `John, Doe, Smith, Best, Dad`.
        # Corresponds to the JSON property `token`
        # @return [String]
        attr_accessor :token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @learning_session_id = args[:learning_session_id] if args.key?(:learning_session_id)
          @learning_source = args[:learning_source] if args.key?(:learning_source)
          @locale = args[:locale] if args.key?(:locale)
          @phonemes = args[:phonemes] if args.key?(:phonemes)
          @phonology_type = args[:phonology_type] if args.key?(:phonology_type)
          @spelling_hint = args[:spelling_hint] if args.key?(:spelling_hint)
          @token = args[:token] if args.key?(:token)
        end
      end
      
      # Container proto for repeated pronunciation objects. For example, a set of
      # pronunciations that can be added to a single name field.
      class SocialGraphApiProtoPronunciations
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `pronunciation`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoPronunciation>]
        attr_accessor :pronunciation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @pronunciation = args[:pronunciation] if args.key?(:pronunciation)
        end
      end
      
      # Data contained in every search profile. go/janata-profile-in-sgbe.
      class SocialGraphApiProtoSearchProfileData
        include Google::Apis::Core::Hashable
      
        # A free-text summary that the user inputs. E.g. "Coder by day, jazz guitarist
        # by night."
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # 
        # Corresponds to the JSON property `education`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEducation>]
        attr_accessor :education
      
        # 
        # Corresponds to the JSON property `interest`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity>]
        attr_accessor :interest
      
        # Indicates the language of this search profile. Use ISO-639 2-letter language
        # code to specifying the language that this profile is created in.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `location`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileLocation>]
        attr_accessor :location
      
        # This proto represents metadata of the users SearchProfile like profile state,
        # GOG account id etc.,
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileMetadata]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `occupation`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity>]
        attr_accessor :occupation
      
        # This is the email that the user has chosen to display on their "SearchCard"
        # publicly.
        # Corresponds to the JSON property `publicEmail`
        # @return [Array<String>]
        attr_accessor :public_email
      
        # This is the phone number that the user has chosen to display on their "
        # SearchCard" publicly.
        # Corresponds to the JSON property `publicPhoneNumber`
        # @return [Array<String>]
        attr_accessor :public_phone_number
      
        # 
        # Corresponds to the JSON property `socialLink`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileSocialLink>]
        attr_accessor :social_link
      
        # 
        # Corresponds to the JSON property `website`
        # @return [Array<String>]
        attr_accessor :website
      
        # 
        # Corresponds to the JSON property `workplace`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileWorkplace>]
        attr_accessor :workplace
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @education = args[:education] if args.key?(:education)
          @interest = args[:interest] if args.key?(:interest)
          @language = args[:language] if args.key?(:language)
          @location = args[:location] if args.key?(:location)
          @metadata = args[:metadata] if args.key?(:metadata)
          @occupation = args[:occupation] if args.key?(:occupation)
          @public_email = args[:public_email] if args.key?(:public_email)
          @public_phone_number = args[:public_phone_number] if args.key?(:public_phone_number)
          @social_link = args[:social_link] if args.key?(:social_link)
          @website = args[:website] if args.key?(:website)
          @workplace = args[:workplace] if args.key?(:workplace)
        end
      end
      
      # Wraps information about a user's eductational background.
      class SocialGraphApiProtoSearchProfileEducation
        include Google::Apis::Core::Hashable
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `endTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :end_time
      
        # 
        # Corresponds to the JSON property `fieldOfStudy`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity>]
        attr_accessor :field_of_study
      
        # This proto represents either a KG-entity, as represented by it's MID, or free-
        # string text.
        # Corresponds to the JSON property `institution`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity]
        attr_accessor :institution
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `startTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :start_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_time = args[:end_time] if args.key?(:end_time)
          @field_of_study = args[:field_of_study] if args.key?(:field_of_study)
          @institution = args[:institution] if args.key?(:institution)
          @start_time = args[:start_time] if args.key?(:start_time)
        end
      end
      
      # This proto represents either a KG-entity, as represented by it's MID, or free-
      # string text.
      class SocialGraphApiProtoSearchProfileEntity
        include Google::Apis::Core::Hashable
      
        # Corresponding country code. Refer to go/people-search-dashboard for code list.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # Corresponding mid in KG.
        # Corresponds to the JSON property `entity`
        # @return [String]
        attr_accessor :entity
      
        # Custom name of entity if there is no corresponding place/entity in KG (mid)
        # Corresponds to the JSON property `name`
        # @return [Array<String>]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @country_code = args[:country_code] if args.key?(:country_code)
          @entity = args[:entity] if args.key?(:entity)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Wraps information about a user's location, if they have chosen to share it on
      # their SearchCard.
      class SocialGraphApiProtoSearchProfileLocation
        include Google::Apis::Core::Hashable
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `endTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :end_time
      
        # 
        # Corresponds to the JSON property `lengthOfStay`
        # @return [String]
        attr_accessor :length_of_stay
      
        # This proto represents either a KG-entity, as represented by it's MID, or free-
        # string text.
        # Corresponds to the JSON property `place`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity]
        attr_accessor :place
      
        # 
        # Corresponds to the JSON property `point`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileLocationInfo]
        attr_accessor :point
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `startTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :start_time
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_time = args[:end_time] if args.key?(:end_time)
          @length_of_stay = args[:length_of_stay] if args.key?(:length_of_stay)
          @place = args[:place] if args.key?(:place)
          @point = args[:point] if args.key?(:point)
          @start_time = args[:start_time] if args.key?(:start_time)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class SocialGraphApiProtoSearchProfileLocationInfo
        include Google::Apis::Core::Hashable
      
        # Degrees [-90 .. 90]
        # Corresponds to the JSON property `lat`
        # @return [Float]
        attr_accessor :lat
      
        # Degrees [-180 .. 180]
        # Corresponds to the JSON property `lon`
        # @return [Float]
        attr_accessor :lon
      
        # Meters
        # Corresponds to the JSON property `radius`
        # @return [Float]
        attr_accessor :radius
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lat = args[:lat] if args.key?(:lat)
          @lon = args[:lon] if args.key?(:lon)
          @radius = args[:radius] if args.key?(:radius)
        end
      end
      
      # This proto represents metadata of the users SearchProfile like profile state,
      # GOG account id etc.,
      class SocialGraphApiProtoSearchProfileMetadata
        include Google::Apis::Core::Hashable
      
        # Unique contributor account id allocated by presence/janata infrastructure.
        # This will be used in the frontend for various actions like reporting errors,
        # photo uploads etc., go/boba-janata, go/cleanup-contributor-creation
        # Corresponds to the JSON property `accountId`
        # @return [String]
        attr_accessor :account_id
      
        # Account KG entity mid assigned to this user required by old janata serving
        # stack. This is not required anymore for serving. But might need it for
        # historical purposes. See https://hume.google.com/edit/g/11gg6cyvch for more
        # details.
        # Corresponds to the JSON property `accountMid`
        # @return [String]
        attr_accessor :account_mid
      
        # Ares id used for tracking the auto moderation.
        # Corresponds to the JSON property `aresId`
        # @return [String]
        attr_accessor :ares_id
      
        # Current state of the Search Profile.
        # Corresponds to the JSON property `state`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileState>]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @account_id = args[:account_id] if args.key?(:account_id)
          @account_mid = args[:account_mid] if args.key?(:account_mid)
          @ares_id = args[:ares_id] if args.key?(:ares_id)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # Wraps social profile information about the user.
      class SocialGraphApiProtoSearchProfileSocialLink
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `link`
        # @return [String]
        attr_accessor :link
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @link = args[:link] if args.key?(:link)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class SocialGraphApiProtoSearchProfileState
        include Google::Apis::Core::Hashable
      
        # Timestamp of when the state was changed.
        # Corresponds to the JSON property `changeTimestamp`
        # @return [String]
        attr_accessor :change_timestamp
      
        # This will be used to display status to the user at a set time. If set to a
        # value after `change_timestamp`, the change will not be 'reflected' until this
        # time.
        # Corresponds to the JSON property `displayTimestamp`
        # @return [String]
        attr_accessor :display_timestamp
      
        # State that the UserProfile was changed to.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @change_timestamp = args[:change_timestamp] if args.key?(:change_timestamp)
          @display_timestamp = args[:display_timestamp] if args.key?(:display_timestamp)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Wraps information about a user working at a specific place.
      class SocialGraphApiProtoSearchProfileWorkplace
        include Google::Apis::Core::Hashable
      
        # This proto represents either a KG-entity, as represented by it's MID, or free-
        # string text.
        # Corresponds to the JSON property `company`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphApiProtoSearchProfileEntity]
        attr_accessor :company
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `endTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :end_time
      
        # Represents a whole or partial calendar date, such as a birthday. The time of
        # day and time zone are either specified elsewhere or are insignificant. The
        # date is relative to the Gregorian Calendar. This can represent one of the
        # following: * A full date, with non-zero year, month, and day values. * A month
        # and day, with a zero year (for example, an anniversary). * A year on its own,
        # with a zero month and a zero day. * A year and month, with a zero day (for
        # example, a credit card expiration date). Related types: * google.type.
        # TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
        # Corresponds to the JSON property `startTime`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeDate]
        attr_accessor :start_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @company = args[:company] if args.key?(:company)
          @end_time = args[:end_time] if args.key?(:end_time)
          @start_time = args[:start_time] if args.key?(:start_time)
        end
      end
      
      # LINT.IfChange
      class SocialGraphApiProtoSyncInfo
        include Google::Apis::Core::Hashable
      
        # CP2 sourceid column.
        # Corresponds to the JSON property `sourceId`
        # @return [String]
        attr_accessor :source_id
      
        # CP2 sync1 column.
        # Corresponds to the JSON property `sync1`
        # @return [String]
        attr_accessor :sync1
      
        # CP2 sync2 column.
        # Corresponds to the JSON property `sync2`
        # @return [String]
        attr_accessor :sync2
      
        # CP2 sync3 column.
        # Corresponds to the JSON property `sync3`
        # @return [String]
        attr_accessor :sync3
      
        # CP2 sync4 column.
        # Corresponds to the JSON property `sync4`
        # @return [String]
        attr_accessor :sync4
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @source_id = args[:source_id] if args.key?(:source_id)
          @sync1 = args[:sync1] if args.key?(:sync1)
          @sync2 = args[:sync2] if args.key?(:sync2)
          @sync3 = args[:sync3] if args.key?(:sync3)
          @sync4 = args[:sync4] if args.key?(:sync4)
        end
      end
      
      # 
      class SocialGraphApiProtoThirdPartyInfo
        include Google::Apis::Core::Hashable
      
        # Not to be used. We have since moved to a lookup string at read time approach
        # as opposed to storing data at write time. b/146072927
        # Corresponds to the JSON property `clientName`
        # @return [String]
        attr_accessor :client_name
      
        # Project number of the third party application performing the delete to be
        # looked up via ClientAuthConfig during display time for users to know the
        # current name of an application which has deleted contact data.
        # Corresponds to the JSON property `projectNumber`
        # @return [Fixnum]
        attr_accessor :project_number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_name = args[:client_name] if args.key?(:client_name)
          @project_number = args[:project_number] if args.key?(:project_number)
        end
      end
      
      # Usage information. This is currently used for device contacts. Next ID: 3
      class SocialGraphApiProtoUsageInfo
        include Google::Apis::Core::Hashable
      
        # Last time a contact was contacted.
        # Corresponds to the JSON property `lastTimeContacted`
        # @return [String]
        attr_accessor :last_time_contacted
      
        # Number of times a contact was contacted.
        # Corresponds to the JSON property `timesContacted`
        # @return [Fixnum]
        attr_accessor :times_contacted
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @last_time_contacted = args[:last_time_contacted] if args.key?(:last_time_contacted)
          @times_contacted = args[:times_contacted] if args.key?(:times_contacted)
        end
      end
      
      # Extra ranking info returned with affinity data. This info is returned by DAS
      # and passed to PAPI clients (Yenta), where it is used for ranking and filtering
      # device and server suggestions together.
      class SocialGraphWireProtoPeopleapiAffinityMetadata
        include Google::Apis::Core::Hashable
      
        # Information regarding client interactions.
        # Corresponds to the JSON property `clientInteractionInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiAffinityMetadataClientInteractionInfo]
        attr_accessor :client_interaction_info
      
        # Device information about the candidate available in the cloud.
        # Corresponds to the JSON property `cloudDeviceDataInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialGraphWireProtoPeopleapiAffinityMetadataCloudDeviceDataInfo]
        attr_accessor :cloud_device_data_info
      
        # Affinity score for the cloud contact.
        # Corresponds to the JSON property `cloudScore`
        # @return [Float]
        attr_accessor :cloud_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_interaction_info = args[:client_interaction_info] if args.key?(:client_interaction_info)
          @cloud_device_data_info = args[:cloud_device_data_info] if args.key?(:cloud_device_data_info)
          @cloud_score = args[:cloud_score] if args.key?(:cloud_score)
        end
      end
      
      # 
      class SocialGraphWireProtoPeopleapiAffinityMetadataClientInteractionInfo
        include Google::Apis::Core::Hashable
      
        # Whether this suggestion is an edge directly from the client. E.g., a
        # suggestion with which the user shared a photo on photos app.
        # Corresponds to the JSON property `isDirectClientInteraction`
        # @return [Boolean]
        attr_accessor :is_direct_client_interaction
        alias_method :is_direct_client_interaction?, :is_direct_client_interaction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_direct_client_interaction = args[:is_direct_client_interaction] if args.key?(:is_direct_client_interaction)
        end
      end
      
      # 
      class SocialGraphWireProtoPeopleapiAffinityMetadataCloudDeviceDataInfo
        include Google::Apis::Core::Hashable
      
        # The partial affinity score only counting device features.
        # Corresponds to the JSON property `deviceScore`
        # @return [Float]
        attr_accessor :device_score
      
        # Whether device data about this candidate were available in the cloud.
        # Corresponds to the JSON property `isDeviceDataKnown`
        # @return [Boolean]
        attr_accessor :is_device_data_known
        alias_method :is_device_data_known?, :is_device_data_known
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @device_score = args[:device_score] if args.key?(:device_score)
          @is_device_data_known = args[:is_device_data_known] if args.key?(:is_device_data_known)
        end
      end
      
      # Waldo-related extension data.
      class SocialGraphWireProtoPeopleapiExtensionAppsWaldoExtendedData
        include Google::Apis::Core::Hashable
      
        # The current and future availabilities of a user. The response contains a
        # timeline, which starts before or at the request time, and the timeline is
        # split into a set of disjoint intervals (without gaps), where the first range
        # always contains the request time. Each range represents what should be
        # displayed in the UI during this time range. The time range might be different
        # from the actual time range of the underlying status. For example, if the user
        # is OOO from 09:00 to 10:00, and a request is made at 8:00, the response might
        # contain two intervals: [08:00, 09:00) - "User is INACTIVE, but leaving the
        # office soon" [09:00, 10:00) - "User is OOO till 10:00" For intervals that don'
        # t have a clear availability signal coming from Calendar (e.g. OOO), we return
        # INACTIVE. For more details, please see https://docs.google.com/presentation/d/
        # 1ADCTxGawjF9UqMnfuVrVNxGvdyjeiV8h4D7p0a9zYgw/edit#slide=id.g3e2824ac6c_12_94
        # The service returns availabilities for some short period of time - likely one
        # day, but the client should stick to the "next_poll_time" to decide when to
        # query the server again at the latest. Below there is an example response from
        # the server. Let's assume the client calls the service at 17:59:45. The client
        # receives the message and, assuming its current time is between [17:59:45, 18:
        # 00:00), it displays "inactive". When the current time becomes 18:00:00 it
        # displays "outside working hours". At 18:00:40 the client issues another rpc
        # which will return the availabilities for the next minute. The original
        # response looks like availabilities ` time_range ` start_time: 17:59:45
        # end_time: 18:00:00 ` status ` inactive `` ` ` availabilities ` time_range `
        # start_time: 18:00:00 end_time: 18:00:45 ` status ` outside_working_hours ` ` `
        # ` next_poll_time: 18:00:40
        # Corresponds to the JSON property `availabilities`
        # @return [Google::Apis::ContentwarehouseV1::GoogleInternalAppsWaldoV1alphaUserAvailabilities]
        attr_accessor :availabilities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @availabilities = args[:availabilities] if args.key?(:availabilities)
        end
      end
      
      # Corp Deskbooking-related extension data for use with Location.
      class SocialGraphWireProtoPeopleapiExtensionCorpDeskbookingLocationExtendedData
        include Google::Apis::Core::Hashable
      
        # Represents a time interval, encoded as a Timestamp start (inclusive) and a
        # Timestamp end (exclusive). The start must be less than or equal to the end.
        # When the start equals the end, the interval is empty (matches no time). When
        # both start and end are unspecified, the interval matches any time.
        # Corresponds to the JSON property `validityInterval`
        # @return [Google::Apis::ContentwarehouseV1::GoogleTypeInterval]
        attr_accessor :validity_interval
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @validity_interval = args[:validity_interval] if args.key?(:validity_interval)
        end
      end
      
      # Dynamite-related extension data.
      class SocialGraphWireProtoPeopleapiExtensionDynamiteExtendedData
        include Google::Apis::Core::Hashable
      
        # Avatar image URL for a Google Group, based on the member count.
        # Corresponds to the JSON property `avatarUrl`
        # @return [String]
        attr_accessor :avatar_url
      
        # Short description of this bot. Only set if EntityType == BOT.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Display name of bot developer. Only set if EntityType == BOT.
        # Corresponds to the JSON property `developerName`
        # @return [String]
        attr_accessor :developer_name
      
        # 
        # Corresponds to the JSON property `dndState`
        # @return [String]
        attr_accessor :dnd_state
      
        # 
        # Corresponds to the JSON property `entityType`
        # @return [String]
        attr_accessor :entity_type
      
        # Number of members (direct or indirect) in a Google Group. Only an estimate for
        # large groups (currently > 1K direct / indirect members).
        # Corresponds to the JSON property `memberCount`
        # @return [Fixnum]
        attr_accessor :member_count
      
        # Contains info about the entity that something is, or is owned by.
        # Corresponds to the JSON property `organizationInfo`
        # @return [Google::Apis::ContentwarehouseV1::AppsDynamiteSharedOrganizationInfo]
        attr_accessor :organization_info
      
        # 
        # Corresponds to the JSON property `presence`
        # @return [String]
        attr_accessor :presence_prop
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @avatar_url = args[:avatar_url] if args.key?(:avatar_url)
          @description = args[:description] if args.key?(:description)
          @developer_name = args[:developer_name] if args.key?(:developer_name)
          @dnd_state = args[:dnd_state] if args.key?(:dnd_state)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @member_count = args[:member_count] if args.key?(:member_count)
          @organization_info = args[:organization_info] if args.key?(:organization_info)
          @presence_prop = args[:presence_prop] if args.key?(:presence_prop)
        end
      end
      
      # Next tag number: 3
      class SocialGraphWireProtoPeopleapiExtensionPaisaExtendedData
        include Google::Apis::Core::Hashable
      
        # Actor ID of the person, if available (if the person has used the Paisa app).
        # Corresponds to the JSON property `actorId`
        # @return [String]
        attr_accessor :actor_id
      
        # Display subtitle, which may be used in suggestion/autocompletion results.
        # Generally, this will be the Actor's registered Paisa phone number, in unmasked
        # or masked form (e.g. +1 ***-***-1234) depending on visibility rules.
        # Corresponds to the JSON property `subtitle`
        # @return [String]
        attr_accessor :subtitle
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @actor_id = args[:actor_id] if args.key?(:actor_id)
          @subtitle = args[:subtitle] if args.key?(:subtitle)
        end
      end
      
      # 
      class SocialGraphWireProtoPeopleapiExtensionPeopleStackExtendedData
        include Google::Apis::Core::Hashable
      
        # Whether the person is in the same family as the requesting user. Family here
        # refers to https://families.google.com/families. This information is read from
        # SuperGlue, and can be consumed by clients, e.g. Assistant and Photos. If this
        # field is not set, the person is not in the user's family.
        # Corresponds to the JSON property `familyStatus`
        # @return [String]
        attr_accessor :family_status
      
        # The full list of hidden keys associated with this person. These are the
        # external equivalent to the keys stored by the ConnectionLabelService, and they
        # can be passed to the MutateConnectionLabel endpoint to unhide this person.
        # This field will only be set if hide_type is HIDDEN.
        # Corresponds to the JSON property `hiddenKeys`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialDiscoveryExternalEntityKey>]
        attr_accessor :hidden_keys
      
        # If this field is not set, the person is visible (implicit).
        # Corresponds to the JSON property `hideType`
        # @return [String]
        attr_accessor :hide_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @family_status = args[:family_status] if args.key?(:family_status)
          @hidden_keys = args[:hidden_keys] if args.key?(:hidden_keys)
          @hide_type = args[:hide_type] if args.key?(:hide_type)
        end
      end
      
      # NEXT_ID: 5
      class SocialGraphWireProtoPeopleapiExtensionPeopleStackPersonExtendedData
        include Google::Apis::Core::Hashable
      
        # Whether the person has birthday field populated.
        # Corresponds to the JSON property `birthdayStatus`
        # @return [String]
        attr_accessor :birthday_status
      
        # Whether the person is in the same family as the requesting user. Family here
        # refers to https://families.google.com/families. This information is read from
        # SuperGlue, and can be consumed by clients, e.g. Assistant and Photos. If this
        # field is not set, the person is not in the user's family.
        # Corresponds to the JSON property `familyStatus`
        # @return [String]
        attr_accessor :family_status
      
        # The full list of hidden keys associated with this person. These are the
        # external equivalent to the keys stored by the ConnectionLabelService, and they
        # can be passed to the MutateConnectionLabel endpoint to unhide this person.
        # This field will only be set if hide_type is HIDDEN.
        # Corresponds to the JSON property `hiddenKeys`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialDiscoveryExternalEntityKey>]
        attr_accessor :hidden_keys
      
        # If this field is not set, the person is visible (implicit).
        # Corresponds to the JSON property `hideType`
        # @return [String]
        attr_accessor :hide_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @birthday_status = args[:birthday_status] if args.key?(:birthday_status)
          @family_status = args[:family_status] if args.key?(:family_status)
          @hidden_keys = args[:hidden_keys] if args.key?(:hidden_keys)
          @hide_type = args[:hide_type] if args.key?(:hide_type)
        end
      end
      
      # 
      class SocialPersonalizationKnexAnnotation
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `item`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialPersonalizationKnexAnnotationItem>]
        attr_accessor :item
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @item = args[:item] if args.key?(:item)
        end
      end
      
      # Next Tag: 8
      class SocialPersonalizationKnexAnnotationItem
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Description of the item for debugging. Note that this field is populated only
        # in a few select places.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # If this field exists, then there exists a commonly used MID (typically a
        # public MID, i.e., one in /m/) that approximates the meaning for this
        # particular k'nex topic. For example, the value of this field for k'nex topic
        # Tennis (/t/236) is /m/07bs0. The difference between k'nex /m/07bs0 and webref /
        # m/07bs0 is as follows. If a content is annotated with webref /m/07bs0, then
        # the content has to explicitly mention "Tennis" in some way, whereas if a
        # content is annotated with k'nex /m/07bs0, then the content simply needs to
        # talk about stuff related to tennis. Note that this field is not populated for
        # all queries. For example, the compound concept "Tennis in California" does not
        # have an associated mid. This field is intended to help external clients
        # transit to k'nex.
        # Corresponds to the JSON property `equivalentMid`
        # @return [Fixnum]
        attr_accessor :equivalent_mid
      
        # A score that measures how broad / narrow a topic is, independent of the
        # document and/or user profile. This is an experimental score and is not
        # populated by default. Currently, it is in the range of [0, 1], where the
        # higher the score is, the more general a topic is. Please talk to sherlock-dev@
        # before using this score. Populated when debug_level > 0.
        # Corresponds to the JSON property `generality`
        # @return [Float]
        attr_accessor :generality
      
        # This is an MID in the /t/ namespace. We will migrate them to /g/ in Q3'15.
        # Corresponds to the JSON property `mid`
        # @return [Fixnum]
        attr_accessor :mid
      
        # 
        # Corresponds to the JSON property `relatedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialPersonalizationKnexAnnotationItemTopic>]
        attr_accessor :related_entity
      
        # 
        # Corresponds to the JSON property `topicality`
        # @return [Float]
        attr_accessor :topicality
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @description = args[:description] if args.key?(:description)
          @equivalent_mid = args[:equivalent_mid] if args.key?(:equivalent_mid)
          @generality = args[:generality] if args.key?(:generality)
          @mid = args[:mid] if args.key?(:mid)
          @related_entity = args[:related_entity] if args.key?(:related_entity)
          @topicality = args[:topicality] if args.key?(:topicality)
        end
      end
      
      # 
      class SocialPersonalizationKnexAnnotationItemTopic
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `mid`
        # @return [Fixnum]
        attr_accessor :mid
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @mid = args[:mid] if args.key?(:mid)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Restrictions that affect the delivery of the stanza. By default, Stanzas are
      # publishable, which means that they are eligible for indexing, aggregation, and
      # other delivery options (Goops, Moonshine, notifications). A stanza can be
      # created in a "do not publish" state; the stanza will not be published anywhere.
      # The restriction can subsequently be removed with an UpdateStanza call, at
      # which point the post will be treated as if it were newly created. A few notes/
      # limitations about this option: 1. Client should keep a stanza unpublishable
      # for a small period of time (if possible to) so that our ranking system does
      # not consider this as a stale post (thus downranking the post). 2. Client
      # should keep the number of unpublishable stanzas to a minimum, to reduce under-
      # serving. 3. Updating a stanza from publishable to unpublishable after creation
      # is not supported 4. At this time, publishing options are only supported on
      # root stanzas; let us know if you require this for child stanzas. 5. Similarly,
      # this is only supported as a global restriction. It may not be set as a per-
      # destination-stream restriction.
      class SocialStanzaDeliveryRestriction
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `doNotPublish`
        # @return [Boolean]
        attr_accessor :do_not_publish
        alias_method :do_not_publish?, :do_not_publish
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @do_not_publish = args[:do_not_publish] if args.key?(:do_not_publish)
        end
      end
      
      # ModerationInfo stores the information of moderation for a stanza in a specific
      # destination stream. Including who moderated and why.
      class SocialStanzaModerationInfo
        include Google::Apis::Core::Hashable
      
        # The reason why this stanza was moderated provided by client.
        # Corresponds to the JSON property `moderationReason`
        # @return [String]
        attr_accessor :moderation_reason
      
        # A Principal represents something to which permissions are assigned, often but
        # not always a user or group of some kind. It is most appropriate for use in
        # ACLs and authorization checks. Callers should prefer to use the wrapper
        # classes in google3/security/credentials/public/principal.h google3/java/com/
        # google/security/credentials/Principal.java google3/security/credentials/go/
        # principal.go unless direct proto access is essential. If you update this
        # protocol buffer, please update the wrapper classes as well.
        # Corresponds to the JSON property `moderator`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsPrincipalProto]
        attr_accessor :moderator
      
        # Type of moderation. Semantically REQUIRED, http://go/required At write time,
        # only ModeratorType.AUTO_MODERATOR is allowed. For all other cases, this
        # information is inferred from the request at write time.
        # Corresponds to the JSON property `moderatorType`
        # @return [String]
        attr_accessor :moderator_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @moderation_reason = args[:moderation_reason] if args.key?(:moderation_reason)
          @moderator = args[:moderator] if args.key?(:moderator)
          @moderator_type = args[:moderator_type] if args.key?(:moderator_type)
        end
      end
      
      # Contains various restriction information about a stanza, derived from
      # properties of the stanza, the viewer and the creator. Restrictions stored in
      # this message are not related to direct/indirect relationship between the
      # viewer and the creator of stanza. Some examples are: - Abusive - Legal - Racy -
      # Content not suitable for age - Porn - Blocked by country/geo of viewer. -
      # Restricted by stanza creator (not the user specific block). - etc... Please
      # see go/stanza-abuse-flow for more details.
      class SocialStanzaStanzaRestriction
        include Google::Apis::Core::Hashable
      
        # The abuses.
        # Corresponds to the JSON property `abuseTypes`
        # @return [Array<Google::Apis::ContentwarehouseV1::AbuseiamAbuseType>]
        attr_accessor :abuse_types
      
        # The appeal state.
        # Corresponds to the JSON property `appealState`
        # @return [String]
        attr_accessor :appeal_state
      
        # Pair of Verdicts used for ProjectR age/geo gating. See http://go/projectr for
        # more information.
        # Corresponds to the JSON property `contentRestriction`
        # @return [Google::Apis::ContentwarehouseV1::AbuseiamContentRestriction]
        attr_accessor :content_restriction
      
        # Delete reasons. This is a repeated field because an stanza can be deleted
        # multiple times due to different reasons such as user_delete, admin_delete.
        # Corresponds to the JSON property `deleteReason`
        # @return [Array<String>]
        attr_accessor :delete_reason
      
        # Restrictions that affect the delivery of the stanza. By default, Stanzas are
        # publishable, which means that they are eligible for indexing, aggregation, and
        # other delivery options (Goops, Moonshine, notifications). A stanza can be
        # created in a "do not publish" state; the stanza will not be published anywhere.
        # The restriction can subsequently be removed with an UpdateStanza call, at
        # which point the post will be treated as if it were newly created. A few notes/
        # limitations about this option: 1. Client should keep a stanza unpublishable
        # for a small period of time (if possible to) so that our ranking system does
        # not consider this as a stale post (thus downranking the post). 2. Client
        # should keep the number of unpublishable stanzas to a minimum, to reduce under-
        # serving. 3. Updating a stanza from publishable to unpublishable after creation
        # is not supported 4. At this time, publishing options are only supported on
        # root stanzas; let us know if you require this for child stanzas. 5. Similarly,
        # this is only supported as a global restriction. It may not be set as a per-
        # destination-stream restriction.
        # Corresponds to the JSON property `deliveryRestriction`
        # @return [Google::Apis::ContentwarehouseV1::SocialStanzaDeliveryRestriction]
        attr_accessor :delivery_restriction
      
        # A DestinationStream is a /namespace/id[0]/id[1]/.../id[n] that represents a
        # collection of Activities. Example destinations: -The Profile Stream on http://
        # plus.google.com/+JohnDoe/posts -A Square Stream on http://plus.google.com/
        # squares/123 -A "comment Stream" (Fountain) on http://www.youtube.com/watch?id=
        # 123 It's possible for a single Activity to show in each of these destinations -
        # and it might behave/look slightly differently for each one. Destinations can
        # have their own business logic associated with them at both write-time and read-
        # time server-side (these are documented below). Each DestinationStream is
        # indexed and can be retrieved using the GetDestinationStreamRequest. For the
        # repeated ID space indexing happens at all levels, e.g. if you have: /square/
        # 123/abc /square/123/efd /square/456 You can fetch /square/123/abc directly or /
        # square/123 (which includes all Activities in both /square/123/abc and /square/
        # 123/efd), or even /square which retrieves all Activities in the Square
        # namespace (visible for that user). On the storage layer, we represent
        # DestinationStream as Channel (http://cs/#google3/social/common/channel/channel.
        # proto), since the storage does not have the concept of a Stream. Both terms
        # are used interchangeably within the service layer, but client of Social
        # Infrastructure should use the term DestinationStream. Next ID: 3
        # Corresponds to the JSON property `destinationStream`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleActivityBackendDestinationStream]
        attr_accessor :destination_stream
      
        # ModerationInfo stores the information of moderation for a stanza in a specific
        # destination stream. Including who moderated and why.
        # Corresponds to the JSON property `moderationInfo`
        # @return [Google::Apis::ContentwarehouseV1::SocialStanzaModerationInfo]
        attr_accessor :moderation_info
      
        # The moderation state.
        # Corresponds to the JSON property `moderationState`
        # @return [String]
        attr_accessor :moderation_state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @abuse_types = args[:abuse_types] if args.key?(:abuse_types)
          @appeal_state = args[:appeal_state] if args.key?(:appeal_state)
          @content_restriction = args[:content_restriction] if args.key?(:content_restriction)
          @delete_reason = args[:delete_reason] if args.key?(:delete_reason)
          @delivery_restriction = args[:delivery_restriction] if args.key?(:delivery_restriction)
          @destination_stream = args[:destination_stream] if args.key?(:destination_stream)
          @moderation_info = args[:moderation_info] if args.key?(:moderation_info)
          @moderation_state = args[:moderation_state] if args.key?(:moderation_state)
        end
      end
      
      # This protocol buffer indicates actions that we take based on Cookbook recipes (
      # see http://cookbook/) matching a particular document.
      class SpamCookbookAction
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `dropInServing`
        # @return [Boolean]
        attr_accessor :drop_in_serving
        alias_method :drop_in_serving?, :drop_in_serving
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @drop_in_serving = args[:drop_in_serving] if args.key?(:drop_in_serving)
        end
      end
      
      # 
      class SpamMuppetjoinsMuppetSignals
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `hackedDateNautilus`
        # @return [Fixnum]
        attr_accessor :hacked_date_nautilus
      
        # 
        # Corresponds to the JSON property `hackedDateRaiden`
        # @return [Fixnum]
        attr_accessor :hacked_date_raiden
      
        # 
        # Corresponds to the JSON property `raidenScore`
        # @return [Float]
        attr_accessor :raiden_score
      
        # 
        # Corresponds to the JSON property `site`
        # @return [String]
        attr_accessor :site
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hacked_date_nautilus = args[:hacked_date_nautilus] if args.key?(:hacked_date_nautilus)
          @hacked_date_raiden = args[:hacked_date_raiden] if args.key?(:hacked_date_raiden)
          @raiden_score = args[:raiden_score] if args.key?(:raiden_score)
          @site = args[:site] if args.key?(:site)
        end
      end
      
      # Response proto for the LangId service running on a Greco server in prod. Next
      # Tag: 6
      class SpeechS3LanguageIdentificationResult
        include Google::Apis::Core::Hashable
      
        # The end time of the input audio that this result refers to. This value should
        # increase across LanguageIdentificationResult emitted by the Greco server
        # running LangId, and reflects the server having processed more of the input
        # audio.
        # Corresponds to the JSON property `endTimeUsec`
        # @return [Fixnum]
        attr_accessor :end_time_usec
      
        # Ranked list of top-N language codes. Ranking is based on ConfidenceIntervals
        # of supported languages, and N is defined in the LanguageIdentificationConfig.
        # Corresponds to the JSON property `rankedTopSupportedLanguages`
        # @return [Array<Google::Apis::ContentwarehouseV1::SpeechS3Locale>]
        attr_accessor :ranked_top_supported_languages
      
        # Global start time. This value should be fixed across all
        # LanguageIdentificationResults for a given utterance.
        # Corresponds to the JSON property `startTimeUsec`
        # @return [Fixnum]
        attr_accessor :start_time_usec
      
        # Confidence interval of the top recognized language.
        # Corresponds to the JSON property `topLanguageConfidence`
        # @return [String]
        attr_accessor :top_language_confidence
      
        # Identifies when the provided audio sample does or doesn't contain voiced
        # samples. E.g. an unvoice utterance happens when the EOS signal is received
        # before any frame because all frames were filtered by the endpointer. For
        # events where voiced_utterance is false, ranked_top_supported_languages is
        # defined but scores are not to be trusted. All LanguageIdentificationResults
        # contains a valid value of voiced_utterance.
        # Corresponds to the JSON property `voicedUtterance`
        # @return [Boolean]
        attr_accessor :voiced_utterance
        alias_method :voiced_utterance?, :voiced_utterance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_time_usec = args[:end_time_usec] if args.key?(:end_time_usec)
          @ranked_top_supported_languages = args[:ranked_top_supported_languages] if args.key?(:ranked_top_supported_languages)
          @start_time_usec = args[:start_time_usec] if args.key?(:start_time_usec)
          @top_language_confidence = args[:top_language_confidence] if args.key?(:top_language_confidence)
          @voiced_utterance = args[:voiced_utterance] if args.key?(:voiced_utterance)
        end
      end
      
      # 
      class SpeechS3Locale
        include Google::Apis::Core::Hashable
      
        # The format of the string in "locale". Should be one of LocaleFormat.
        # Corresponds to the JSON property `format`
        # @return [Fixnum]
        attr_accessor :format
      
        # 
        # Corresponds to the JSON property `locale`
        # @return [String]
        attr_accessor :locale
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @format = args[:format] if args.key?(:format)
          @locale = args[:locale] if args.key?(:locale)
        end
      end
      
      # go/entity-authority NB: currently all facts associated with Authority Feedback
      # are externally traceable to the requests from which they originate.
      class StorageGraphBfgAuthorityFeedbackMetadata
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # 
      class StorageGraphBfgLegalRequestMetadata
        include Google::Apis::Core::Hashable
      
        # The buganizer ID associated with this legal request. This is required.
        # Corresponds to the JSON property `bugId`
        # @return [Fixnum]
        attr_accessor :bug_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bug_id = args[:bug_id] if args.key?(:bug_id)
        end
      end
      
      # Metadata on source assertions that isn't part of the user-visible Triple
      # payload, and that doesn't really represent data provenance, but that's used to
      # affect the way Livegraph and possibly other horizontal KG infra systems *
      # process* the triple. Read: fields below really shouldn't be part of the cross-
      # system Triple proto at all. But because Triple is used both as an internal and
      # an external KG API, we at least want to "hide" those fields that ought to be
      # purely part of the internal source <-> LG contract. Next id: 5
      class StorageGraphBfgLivegraphProvenanceMetadata
        include Google::Apis::Core::Hashable
      
        # Identifies the LG internal writers that asserted the triple. This is the same
        # as 'origin_id' in LG. This will only be populated by the LG writers to
        # FactStore
        # Corresponds to the JSON property `lgInternalWriterId`
        # @return [Fixnum]
        attr_accessor :lg_internal_writer_id
      
        # Whether this provenance is a provenance only addition or not. A provenance is
        # considered an "addition" if it belongs to a triple that we expect FactStore to
        # contain on its own (i.e through some inference), and thus we will *not*
        # attempt to write it explicitly. This is a composer only populated field.
        # Clients are not expected to populate this field.
        # Corresponds to the JSON property `provenanceOnlyAddition`
        # @return [Boolean]
        attr_accessor :provenance_only_addition
        alias_method :provenance_only_addition?, :provenance_only_addition
      
        # Triples typically have a single triangulation key. This field supports > 1
        # keys to allow staged transition to a different key scheme. To successfully
        # triangulate in the Livegraph Composer, the triple must have >=3 instances and
        # each triple instance having a pairwise disjoint set of triangulation keys. The
        # triangulation keys supplied for a single input triple are treated part of the
        # same set, so a single triple cannot self-triangulate, regardless of how many
        # triangulation keys it has. Note2: If a triple has multiple provenances, each
        # one is expected to set the same triangulation_keys.
        # Corresponds to the JSON property `triangulationKey`
        # @return [Array<String>]
        attr_accessor :triangulation_key
      
        # WARNING! The feature is still under active development and the exact semantics
        # may be subject to change pending KE Design Review. Data marked as weak will be
        # less preferred to regular data which does not have the marker. This allows
        # ingesting data with a lower chance of negatively affecting existing features
        # and products, at the cost of potentially not showing the data when competing
        # data is available. Specifically, weak data is less preferred by conflict
        # resolution inside of Livegraph composition. Additionally, RefX triggering will
        # prefer to trigger based on signals computed from regular data. Aside from data
        # providers choosing to mark their data as weak, Livegraph and RefX are the only
        # horizontal systems expected to use this information. Please contact livegraph-
        # team@ if you see a need for this to change. See go/weak-data for more
        # information.
        # Corresponds to the JSON property `weakData`
        # @return [Boolean]
        attr_accessor :weak_data
        alias_method :weak_data?, :weak_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lg_internal_writer_id = args[:lg_internal_writer_id] if args.key?(:lg_internal_writer_id)
          @provenance_only_addition = args[:provenance_only_addition] if args.key?(:provenance_only_addition)
          @triangulation_key = args[:triangulation_key] if args.key?(:triangulation_key)
          @weak_data = args[:weak_data] if args.key?(:weak_data)
        end
      end
      
      # Metadata about data governance policies. For more context, see go/ke-triple-dg-
      # policy-and-metadata. If any attribute is not set, then there's no specific
      # restrictions associated with the missing attribute. For example, if `
      # availability_start_timestamp` is not set, the data won't be embargoed
      # automatically; if `availability_end_timestamp` is not set, they won't expire
      # automatically. Next ID: 8 LINT.IfChange
      class StorageGraphBfgPolicyMetadata
        include Google::Apis::Core::Hashable
      
        # Timestamp after which data with this policy cannot be used. This value must be
        # strictly larger/later than availability_start_time, if both are set. WARNING:
        # This field is WIP and please do not populate it without reading go/ke-dg-tape
        # and consulting ke-data-governance@.
        # Corresponds to the JSON property `availabilityEndTimestamp`
        # @return [String]
        attr_accessor :availability_end_timestamp
      
        # Timestamp before which data with this policy cannot be used. This value must
        # be strictly smaller/earlier than availability_end_time, if both are set.
        # WARNING: This field is WIP and please do not populate it without reading go/ke-
        # dg-tape and consulting ke-data-governance@.
        # Corresponds to the JSON property `availabilityStartTimestamp`
        # @return [String]
        attr_accessor :availability_start_timestamp
      
        # List of regions in which the data with this policy is allowed to be used,
        # while the data need to be removed in all regions outside this list according
        # to legal request. This field should be used when the data is only allowed in a
        # few regions and it is inconvenient to enumerate all of the regions in `
        # legal_removal_regions` field. `legal_allowed_regions` and `
        # legal_removal_region` together should include all possible regions, setting
        # one field implies the other. Please set only one of them so the other field's
        # values are implied. See details: http://go/ke-allowed-countries-policy-1p
        # WARNING: This field is for legal purposes only. Please do not populate it
        # without consulting ke-data-governance@.
        # Corresponds to the JSON property `legalAllowedRegions`
        # @return [Array<Google::Apis::ContentwarehouseV1::KeGovernanceTypedRegions>]
        attr_accessor :legal_allowed_regions
      
        # List of regions in which the data with this policy need to be removed
        # according to legal request. WARNING: This field is for legal purposes only.
        # Please do not populate it without consulting ke-data-governance@.
        # Corresponds to the JSON property `legalRemovalRegions`
        # @return [Array<Google::Apis::ContentwarehouseV1::KeGovernanceTypedRegions>]
        attr_accessor :legal_removal_regions
      
        # Policy metadata are VERTICAL by default. Vertical policy makers / providers
        # does not need to set this field explicitly.
        # Corresponds to the JSON property `policySourceType`
        # @return [String]
        attr_accessor :policy_source_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @availability_end_timestamp = args[:availability_end_timestamp] if args.key?(:availability_end_timestamp)
          @availability_start_timestamp = args[:availability_start_timestamp] if args.key?(:availability_start_timestamp)
          @legal_allowed_regions = args[:legal_allowed_regions] if args.key?(:legal_allowed_regions)
          @legal_removal_regions = args[:legal_removal_regions] if args.key?(:legal_removal_regions)
          @policy_source_type = args[:policy_source_type] if args.key?(:policy_source_type)
        end
      end
      
      # 
      class StorageGraphBfgPublicInformationMetadata
        include Google::Apis::Core::Hashable
      
        # Publicly-visible URLs claiming this fact. Can not be empty -- at least one URL
        # must be provided.
        # Corresponds to the JSON property `attributionUrl`
        # @return [Array<String>]
        attr_accessor :attribution_url
      
        # Most recent date at which 'attribution_url's were verified, as UNIX epoch time
        # in milliseconds. This is required.
        # Corresponds to the JSON property `lastVerifiedDate`
        # @return [Fixnum]
        attr_accessor :last_verified_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attribution_url = args[:attribution_url] if args.key?(:attribution_url)
          @last_verified_date = args[:last_verified_date] if args.key?(:last_verified_date)
        end
      end
      
      # A fact about potentially sensitive personal info (http://what/SPII) can be "
      # certified" iff it meets specific requirements. See go/kg-spii-certification
      # for details.
      class StorageGraphBfgSpiiCertification
        include Google::Apis::Core::Hashable
      
        # go/entity-authority NB: currently all facts associated with Authority Feedback
        # are externally traceable to the requests from which they originate.
        # Corresponds to the JSON property `authorityFeedback`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgAuthorityFeedbackMetadata]
        attr_accessor :authority_feedback
      
        # This fact was provided via a legal request.
        # Corresponds to the JSON property `legalRequest`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgLegalRequestMetadata]
        attr_accessor :legal_request
      
        # This fact is public information. (See go/kg-spii-certification for a
        # description of what qualifies as public information -- simply finding a fact
        # online is not sufficient to certify a fact as public.)
        # Corresponds to the JSON property `publicInformation`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgPublicInformationMetadata]
        attr_accessor :public_information
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @authority_feedback = args[:authority_feedback] if args.key?(:authority_feedback)
          @legal_request = args[:legal_request] if args.key?(:legal_request)
          @public_information = args[:public_information] if args.key?(:public_information)
        end
      end
      
      # a message containing information about the source of this triple. Note for
      # freebase data: that this is an unpacking of the creator/attribution chain. The
      # creator below is the actual creator of the attribution node, and the rest of
      # the attribution data sits along side. Next id: 22
      class StorageGraphBfgTripleProvenance
        include Google::Apis::Core::Hashable
      
        # Data providers shall use this to specify access requirement.
        # Corresponds to the JSON property `accessRequired`
        # @return [String]
        attr_accessor :access_required
      
        # For KE internal use only. Data providers shall *not* set this. At ingress, LG
        # Record service will read access_required and properly translate it to
        # access_required_int. KE horizontal systems shall use this field instead of
        # access_required; so that binaries would not depend on the release of a newly
        # introduced AccessRequirement enum. (go/easy-ar-onboarding)
        # Corresponds to the JSON property `accessRequiredInt`
        # @return [Fixnum]
        attr_accessor :access_required_int
      
        # 
        # Corresponds to the JSON property `authoringTimestamp`
        # @return [Fixnum]
        attr_accessor :authoring_timestamp
      
        # Freebase: the freebase user id in the form '/user/userid' KG: the Google LDAP
        # of the developer or MDB group that set up the triplification and import
        # pipeline for this data source.
        # Corresponds to the JSON property `creator`
        # @return [String]
        attr_accessor :creator
      
        # Freebase & KG: the dataset the assertion was loaded from
        # Corresponds to the JSON property `dataset`
        # @return [String]
        attr_accessor :dataset
      
        # 
        # Corresponds to the JSON property `extractionPattern`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :extraction_pattern
      
        # 
        # Corresponds to the JSON property `extractionTimestamp`
        # @return [Fixnum]
        attr_accessor :extraction_timestamp
      
        # Below are deprecated Provenance fields. They are not indexed or served in KE
        # infrastructure (they are stripped at ingress in Livegraph).
        # Corresponds to the JSON property `freebaseAttribution`
        # @return [String]
        attr_accessor :freebase_attribution
      
        # Indicates that the corresponding data is supporting evidence for
        # reconciliation only, and is *not* an assertion that should be visible to other
        # systems or to external users. Note that this also means that no provenances
        # indicating supporting data will be visible in the composed graph. Please see
        # go/supporting-kg-triples-design-doc for additional details and background. If
        # a triple is sent to Livegraph with multiple provenances each of them must have
        # is_supporting_data bit set for it to be considered valid supporting evidence
        # triple.
        # Corresponds to the JSON property `isSupportingData`
        # @return [Boolean]
        attr_accessor :is_supporting_data
        alias_method :is_supporting_data?, :is_supporting_data
      
        # Metadata on source assertions that isn't part of the user-visible Triple
        # payload, and that doesn't really represent data provenance, but that's used to
        # affect the way Livegraph and possibly other horizontal KG infra systems *
        # process* the triple. Read: fields below really shouldn't be part of the cross-
        # system Triple proto at all. But because Triple is used both as an internal and
        # an external KG API, we at least want to "hide" those fields that ought to be
        # purely part of the internal source <-> LG contract. Next id: 5
        # Corresponds to the JSON property `lgMetadata`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgLivegraphProvenanceMetadata]
        attr_accessor :lg_metadata
      
        # Metadata about data governance policies. For more context, see go/ke-triple-dg-
        # policy-and-metadata. If any attribute is not set, then there's no specific
        # restrictions associated with the missing attribute. For example, if `
        # availability_start_timestamp` is not set, the data won't be embargoed
        # automatically; if `availability_end_timestamp` is not set, they won't expire
        # automatically. Next ID: 8 LINT.IfChange
        # Corresponds to the JSON property `policyMetadata`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgPolicyMetadata]
        attr_accessor :policy_metadata
      
        # Used to uniquely identify data sources. Freebase: the OAuth application KG:
        # the name of the source directory the triple was loaded from (eg, "amg", "tms ",
        # "collections"). KV: identifier of an extraction system, e.g., SAFT or
        # Tractzor.
        # Corresponds to the JSON property `process`
        # @return [String]
        attr_accessor :process
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `provenanceExtension`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :provenance_extension
      
        # 'ranking_token' (which must be accompanied by the 'process' field above or
        # will be ignored) is used to distinguish subsets of data within a single
        # process, solely for the purposes of composition in Livegraph. This field is
        # useful when partitioning of data is needed, but using a separate process is
        # intractable due to organizational or infrastructure limitations. For example,
        # if a process such as "geo" wishes to distinguish some of their /type/object/
        # name triples as higher priority in Composer's conflict resolution rules, then
        # they can add a config entry with a dedicated ranking_token and tag the
        # relevant triples with that ranking_token. This field should only be used in
        # conjunction with a Composer-side configuration to use it for value selection.
        # It is not appropriate to use this field as free-form metadata. This value must
        # match [[:alnum:]][[:alnum:]_-]`0,127` (i.e., [a-zA-Z0-9]+[a-zA-Z0-9_-]* and
        # must be less than 128 characters in length) , or else its containing triple
        # will be considered malformed and will be rejected by Livegraph at ingress. As
        # of 2018-02-14, this field is used within Livegraph's Composer and is exposed
        # in Livegraph's Lookup APIs to aid debugging, but it is not indexed or served
        # by TopicServer.
        # Corresponds to the JSON property `rankingToken`
        # @return [String]
        attr_accessor :ranking_token
      
        # When specified as part of triples input to Livegraph (go/livegraph), this
        # indicates that the triple needs to be triangulated by 3 different sources
        # before it can be served in production. A triple's source is identified by its
        # URL(provenance.source).host(). Please see go/baike-triangulation for more
        # background on this. WARNING: If you're a new client trying to enable
        # triangulation for your feed, please contact lg-composition@/kashk@ before
        # using this feature.
        # Corresponds to the JSON property `requiresTriangulation`
        # @return [Boolean]
        attr_accessor :requires_triangulation
        alias_method :requires_triangulation?, :requires_triangulation
      
        # 
        # Corresponds to the JSON property `restrictions`
        # @return [Array<String>]
        attr_accessor :restrictions
      
        # Freebase & KG: if the triples were extracted from the web, the source URL
        # where the assertion was found. (generally empty in freebase-sourced triples)
        # TopicServer will serve/populate/retain if REQUIRES_CITATION is also set, or if
        # the process is explicitly allowed. http://g/topic-server/vn9PBWtVKqI/
        # arQEDqKTAgAJ
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # 
        # Corresponds to the JSON property `sourceCategory`
        # @return [Array<String>]
        attr_accessor :source_category
      
        # 
        # Corresponds to the JSON property `sourceDocId`
        # @return [Array<Fixnum>]
        attr_accessor :source_doc_id
      
        # A fact about potentially sensitive personal info (http://what/SPII) can be "
        # certified" iff it meets specific requirements. See go/kg-spii-certification
        # for details.
        # Corresponds to the JSON property `spiiCertification`
        # @return [Google::Apis::ContentwarehouseV1::StorageGraphBfgSpiiCertification]
        attr_accessor :spii_certification
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @access_required = args[:access_required] if args.key?(:access_required)
          @access_required_int = args[:access_required_int] if args.key?(:access_required_int)
          @authoring_timestamp = args[:authoring_timestamp] if args.key?(:authoring_timestamp)
          @creator = args[:creator] if args.key?(:creator)
          @dataset = args[:dataset] if args.key?(:dataset)
          @extraction_pattern = args[:extraction_pattern] if args.key?(:extraction_pattern)
          @extraction_timestamp = args[:extraction_timestamp] if args.key?(:extraction_timestamp)
          @freebase_attribution = args[:freebase_attribution] if args.key?(:freebase_attribution)
          @is_supporting_data = args[:is_supporting_data] if args.key?(:is_supporting_data)
          @lg_metadata = args[:lg_metadata] if args.key?(:lg_metadata)
          @policy_metadata = args[:policy_metadata] if args.key?(:policy_metadata)
          @process = args[:process] if args.key?(:process)
          @provenance_extension = args[:provenance_extension] if args.key?(:provenance_extension)
          @ranking_token = args[:ranking_token] if args.key?(:ranking_token)
          @requires_triangulation = args[:requires_triangulation] if args.key?(:requires_triangulation)
          @restrictions = args[:restrictions] if args.key?(:restrictions)
          @source = args[:source] if args.key?(:source)
          @source_category = args[:source_category] if args.key?(:source_category)
          @source_doc_id = args[:source_doc_id] if args.key?(:source_doc_id)
          @spii_certification = args[:spii_certification] if args.key?(:spii_certification)
        end
      end
      
      # LINT.IfChange Next ID: 101
      class SuperrootPodcastsRecommendationsPodcastRecsFeatures
        include Google::Apis::Core::Hashable
      
        # Average duration listened per episode. Ignores duration < 10s. Computed
        # offline
        # Corresponds to the JSON property `averageDurationSecondsEpisode`
        # @return [Fixnum]
        attr_accessor :average_duration_seconds_episode
      
        # Average duration listened per show. Ignores duration < 10s. Computed offline
        # Corresponds to the JSON property `averageDurationSecondsShow`
        # @return [Fixnum]
        attr_accessor :average_duration_seconds_show
      
        # Average fraction of podcast listened per episode. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `averageFractionEpisode`
        # @return [Float]
        attr_accessor :average_fraction_episode
      
        # Average fraction of podcast listened per show. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `averageFractionShow`
        # @return [Float]
        attr_accessor :average_fraction_show
      
        # Per cluster lift where the lift_squashing_factor is set to 0.4
        # Corresponds to the JSON property `balancedLift`
        # @return [Float]
        attr_accessor :balanced_lift
      
        # category_match is a 0 to 1 score depicting how much of the user's listening
        # history matches the categories of this podcast recommendation.
        # Corresponds to the JSON property `categoryMatch`
        # @return [Float]
        attr_accessor :category_match
      
        # The total minutes listened to this podcast show by users in this cluster
        # Corresponds to the JSON property `clusterFeedMinutes`
        # @return [Fixnum]
        attr_accessor :cluster_feed_minutes
      
        # This captures the probability that this show could have been listened by the
        # user in lieu of what they have subscribed or listened to.
        # Corresponds to the JSON property `colistenedShowColistenAffinity`
        # @return [Float]
        attr_accessor :colistened_show_colisten_affinity
      
        # This captures the rank of the podcast show in the colisten candidate generator.
        # Corresponds to the JSON property `colistenedShowLevelRank`
        # @return [Fixnum]
        attr_accessor :colistened_show_level_rank
      
        # 
        # Corresponds to the JSON property `convAiToxicitySevereScore`
        # @return [Float]
        attr_accessor :conv_ai_toxicity_severe_score
      
        # Score of csai safe search score go/safesearch
        # Corresponds to the JSON property `csaiScore`
        # @return [Float]
        attr_accessor :csai_score
      
        # Ordinal rank features like this have been found to be useful in Hermione
        # Recipes, where the top ranked items from a candidate generator is always
        # retained. Ranks are integral values starting with 1 for the highest affinity
        # show.
        # Corresponds to the JSON property `dnnShowLevelRank`
        # @return [Fixnum]
        attr_accessor :dnn_show_level_rank
      
        # Dot product of user embedding and podcast show embedding from the two tower
        # model v2a
        # Corresponds to the JSON property `dnnV2aScore`
        # @return [Float]
        attr_accessor :dnn_v2a_score
      
        # Sigmoid of the score obtained by dot product of user embedding and show
        # embedding. See https://b.corp.google.com/issues/158602034#comment2 for
        # intuition.
        # Corresponds to the JSON property `dnnV2aScoreSigmoid`
        # @return [Float]
        attr_accessor :dnn_v2a_score_sigmoid
      
        # Total duration listened for this episode by all users. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `durationTotalSecondsEpisode`
        # @return [Fixnum]
        attr_accessor :duration_total_seconds_episode
      
        # Total duration listened for this show by all users. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `durationTotalSecondsShow`
        # @return [Fixnum]
        attr_accessor :duration_total_seconds_show
      
        # The duration of a single episode, in seconds. - For show documents, this is a
        # duration of a typical recent episode, or an approximation thereof. - For
        # episode documents, this is the duration of the episode itself.
        # Corresponds to the JSON property `episodeDurationSec`
        # @return [Fixnum]
        attr_accessor :episode_duration_sec
      
        # Number of all episode impressions.
        # Corresponds to the JSON property `episodeImpressions`
        # @return [Fixnum]
        attr_accessor :episode_impressions
      
        # Number of episode impressions during the past week.
        # Corresponds to the JSON property `episodeImpressionsPastWeek`
        # @return [Fixnum]
        attr_accessor :episode_impressions_past_week
      
        # How frequently are podcasts published by this show. To see publishing
        # frequency calculation go here: http://shortn/_6zzfyEpBRq
        # Corresponds to the JSON property `episodesPublishedPerMonth`
        # @return [Fixnum]
        attr_accessor :episodes_published_per_month
      
        # Whether the show is marked as explicit by the authors
        # Corresponds to the JSON property `explicitShow`
        # @return [String]
        attr_accessor :explicit_show
      
        # Scaled pagerank score for the feed url in [0..1]. Not to be confused with
        # pagerank above, which measures the pagerank for the feed's homepage.
        # Corresponds to the JSON property `feedPagerank`
        # @return [Float]
        attr_accessor :feed_pagerank
      
        # final reaction boost score computed from positive_reaction_boost_score and
        # negative_reaction_boost_score. The score will be applied as a multiplier on
        # the ranking score to adjust the ranking.
        # Corresponds to the JSON property `finalReactionBoostScore`
        # @return [Float]
        attr_accessor :final_reaction_boost_score
      
        # Some of all fraction of this listened by users. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `fractionTotalEpisode`
        # @return [Float]
        attr_accessor :fraction_total_episode
      
        # Some of all fraction of this show listened by users. Ignores duration < 10s.
        # Computed offline
        # Corresponds to the JSON property `fractionTotalShow`
        # @return [Float]
        attr_accessor :fraction_total_show
      
        # Score of fringe safe search score go/safesearch
        # Corresponds to the JSON property `fringeScore`
        # @return [Float]
        attr_accessor :fringe_score
      
        # Probability of a random user listening to this podcast randomly
        # Corresponds to the JSON property `globalProb`
        # @return [Float]
        attr_accessor :global_prob
      
        # Probability of a random user from this cluster listening to this podcast
        # randomly (K-means specific feature)
        # Corresponds to the JSON property `inClusterProb`
        # @return [Float]
        attr_accessor :in_cluster_prob
      
        # A binary value based on whether this is a canonical source for a cluster.
        # Corresponds to the JSON property `isCanonical`
        # @return [Boolean]
        attr_accessor :is_canonical
        alias_method :is_canonical?, :is_canonical
      
        # Ranks are integral values starting with 1 for the highest affinity show.
        # Corresponds to the JSON property `kmeansShowLevelRank`
        # @return [Fixnum]
        attr_accessor :kmeans_show_level_rank
      
        # How much of user listening history match the language of this episode
        # Corresponds to the JSON property `languageMatch`
        # @return [Float]
        attr_accessor :language_match
      
        # Ownership verification status for the episode page URL.
        # Corresponds to the JSON property `linkOwnershipVerified`
        # @return [Boolean]
        attr_accessor :link_ownership_verified
        alias_method :link_ownership_verified?, :link_ownership_verified
      
        # Number of minutes of podcasts listened by the user
        # Corresponds to the JSON property `listenTimeMin`
        # @return [Fixnum]
        attr_accessor :listen_time_min
      
        # The rank of the show in the top listened shows candidate generator. Ranks are
        # integral values starting with 1 for the highest affinity show.
        # Corresponds to the JSON property `listenedShowLevelRank`
        # @return [Fixnum]
        attr_accessor :listened_show_level_rank
      
        # This captures the fraction of total listening time accounted for by this show.
        # Corresponds to the JSON property `listenedShowListeningAffinity`
        # @return [Float]
        attr_accessor :listened_show_listening_affinity
      
        # Feature ID of a location. For more info, see go/feature-id.
        # Corresponds to the JSON property `locationFeatureId`
        # @return [String]
        attr_accessor :location_feature_id
      
        # Match score between user listening mids and episode webref entities, where the
        # listening can have happened at any time in the past. Values are in a 0.0 to 1.
        # 0 range.
        # Corresponds to the JSON property `longUserListeningWebrefSimilarity`
        # @return [Float]
        attr_accessor :long_user_listening_webref_similarity
      
        # Score of medical safe search score go/safesearch
        # Corresponds to the JSON property `medicalScore`
        # @return [Float]
        attr_accessor :medical_score
      
        # Match score between user listening mids and episode webref entities, where the
        # listening is limited to last two mohths activity. Values are in a 0.0 to 1.0
        # range.
        # Corresponds to the JSON property `mediumUserListeningWebrefSimilarity`
        # @return [Float]
        attr_accessor :medium_user_listening_webref_similarity
      
        # boost score from the similarity between the candidate and the shows with user
        # negative feedback, currently the score will be applied directly to the final
        # ranking score: go/podcast-reaction-reranking-v1, but can be used as reranker
        # model feature in the future.
        # Corresponds to the JSON property `negativeReactionBoostScore`
        # @return [Float]
        attr_accessor :negative_reaction_boost_score
      
        # Per cluster lift where the lift_squashing_factor is set to +2
        # Corresponds to the JSON property `nicheLift`
        # @return [Float]
        attr_accessor :niche_lift
      
        # The number of users in this k-means cluster.
        # Corresponds to the JSON property `numListenersInKmeansCluster`
        # @return [Fixnum]
        attr_accessor :num_listeners_in_kmeans_cluster
      
        # The number of users in the k-means cluster who have listened to this feed.
        # Corresponds to the JSON property `numListenersToShowInKmeansCluster`
        # @return [Fixnum]
        attr_accessor :num_listeners_to_show_in_kmeans_cluster
      
        # Number of podcasts listened by the user
        # Corresponds to the JSON property `numListens`
        # @return [Fixnum]
        attr_accessor :num_listens
      
        # From: indexing/speech/proto/colisten-matrix.proto The number of subscribers
        # for this podcast series.
        # Corresponds to the JSON property `numSubscribersShow`
        # @return [Fixnum]
        attr_accessor :num_subscribers_show
      
        # From: indexing/speech/proto/colisten-matrix.proto Absolute number of unique
        # listeners during the past month.
        # Corresponds to the JSON property `numUniqueListenersShow`
        # @return [Fixnum]
        attr_accessor :num_unique_listeners_show
      
        # Score of offensive safe search score go/safesearch
        # Corresponds to the JSON property `offensiveScore`
        # @return [Float]
        attr_accessor :offensive_score
      
        # 
        # Corresponds to the JSON property `peDurationScoreEpisode`
        # @return [Float]
        attr_accessor :pe_duration_score_episode
      
        # 
        # Corresponds to the JSON property `peDurationScoreShow`
        # @return [Float]
        attr_accessor :pe_duration_score_show
      
        # 
        # Corresponds to the JSON property `peDurationTotalScoreEpisode`
        # @return [Float]
        attr_accessor :pe_duration_total_score_episode
      
        # 
        # Corresponds to the JSON property `peDurationTotalScoreShow`
        # @return [Float]
        attr_accessor :pe_duration_total_score_show
      
        # 
        # Corresponds to the JSON property `peFractionScoreEpisode`
        # @return [Float]
        attr_accessor :pe_fraction_score_episode
      
        # 
        # Corresponds to the JSON property `peFractionScoreShow`
        # @return [Float]
        attr_accessor :pe_fraction_score_show
      
        # 
        # Corresponds to the JSON property `peFractionTotalScoreEpisode`
        # @return [Float]
        attr_accessor :pe_fraction_total_score_episode
      
        # 
        # Corresponds to the JSON property `peFractionTotalScoreShow`
        # @return [Float]
        attr_accessor :pe_fraction_total_score_show
      
        # 
        # Corresponds to the JSON property `peListenScoreEpisode`
        # @return [Float]
        attr_accessor :pe_listen_score_episode
      
        # Anima User Embedding based features. Dot product of Anima User Embedding and
        # podcast embeddings from UserEmbeddingBasedSignals (podcasts/quality/proto/
        # ranking_signals.proto)
        # Corresponds to the JSON property `peListenScoreShow`
        # @return [Float]
        attr_accessor :pe_listen_score_show
      
        # 
        # Corresponds to the JSON property `peListenTotalScoreEpisode`
        # @return [Float]
        attr_accessor :pe_listen_total_score_episode
      
        # 
        # Corresponds to the JSON property `peListenTotalScoreShow`
        # @return [Float]
        attr_accessor :pe_listen_total_score_show
      
        # Per cluster lift where the lift_squashing_factor is set to -3
        # Corresponds to the JSON property `popularLift`
        # @return [Float]
        attr_accessor :popular_lift
      
        # Score of porn safe search score go/safesearch
        # Corresponds to the JSON property `pornScore`
        # @return [Float]
        attr_accessor :porn_score
      
        # boost score from the similarity between the candidate and the shows with user
        # positive feedback, currently the score will be applied directly to the final
        # ranking score: go/podcast-reaction-reranking-v1, but can be used as reranker
        # model feature in the future.
        # Corresponds to the JSON property `positiveReactionBoostScore`
        # @return [Float]
        attr_accessor :positive_reaction_boost_score
      
        # This is the language extracted from the query_language.
        # Corresponds to the JSON property `queryLanguage`
        # @return [String]
        attr_accessor :query_language
      
        # The index in the list of most popular podcasts.
        # Corresponds to the JSON property `rank`
        # @return [Fixnum]
        attr_accessor :rank
      
        # rank_percent_contrib = 100 / ( 1 + rank_percent ) Here rank_percent was
        # derived from show level data in Wernicke corpus So if rank_percent of a feed
        # was 3, then the feature value would be: 100 / (1 + 3) = 25. This indicator
        # falls off quickly from 100 to almost 1 as we go from rank_percent 0 to 100.
        # Corresponds to the JSON property `rankPercentContrib`
        # @return [Float]
        attr_accessor :rank_percent_contrib
      
        # Match score between user listening mids and episode webref entities, where the
        # listening is limited to recent activity. Values are in a 0.0 to 1.0 range.
        # Corresponds to the JSON property `recentUserListeningWebrefSimilarity`
        # @return [Float]
        attr_accessor :recent_user_listening_webref_similarity
      
        # A reranking feature showing the age of the episode that is being recommended.
        # This is computed as (current time - publication_time) publication_time of the
        # episode is defined: (http://shortn/_S46Ouk5ZWW) publication_time is specified
        # as seconds since Unix Epoch.
        # Corresponds to the JSON property `secondsSincePublication`
        # @return [Fixnum]
        attr_accessor :seconds_since_publication
      
        # Base quality of the document, used as a multiplier for the query-specific
        # score. Should be in [0, 1] range. See: http://g3doc/indexing/moonshine/generic/
        # g3doc/doc/scoring
        # Corresponds to the JSON property `showBaseQuality`
        # @return [Float]
        attr_accessor :show_base_quality
      
        # Number of show episode impressions.
        # Corresponds to the JSON property `showImpressions`
        # @return [Fixnum]
        attr_accessor :show_impressions
      
        # Number of show impressions during the past week.
        # Corresponds to the JSON property `showImpressionsPastWeek`
        # @return [Fixnum]
        attr_accessor :show_impressions_past_week
      
        # Language of the show from show data.
        # Corresponds to the JSON property `showLanguage`
        # @return [String]
        attr_accessor :show_language
      
        # Show only impressions. Doesn't include shows of episode impressions.
        # Corresponds to the JSON property `showOnlyImpressions`
        # @return [Fixnum]
        attr_accessor :show_only_impressions
      
        # 
        # Corresponds to the JSON property `showOnlyImpressionsPastWeek`
        # @return [Fixnum]
        attr_accessor :show_only_impressions_past_week
      
        # Expresses the absolute popularity rank within all documents.
        # Corresponds to the JSON property `showPopularRank`
        # @return [Fixnum]
        attr_accessor :show_popular_rank
      
        # Score of spoof safe search score go/safesearch
        # Corresponds to the JSON property `spoofScore`
        # @return [Float]
        attr_accessor :spoof_score
      
        # This captures the fraction of total listening time accounted for by this
        # subscribed show.
        # Corresponds to the JSON property `subscribedShowListeningAffinity`
        # @return [Float]
        attr_accessor :subscribed_show_listening_affinity
      
        # The rank of the show in the subscription candidate generator. Ranks are
        # integral values starting with 1 for the highest subscribed affinity show.
        # Corresponds to the JSON property `subscriptionShowLevelRank`
        # @return [Fixnum]
        attr_accessor :subscription_show_level_rank
      
        # 
        # Corresponds to the JSON property `surface`
        # @return [String]
        attr_accessor :surface
      
        # Show level trending score percent from Wernicke corpus.
        # Corresponds to the JSON property `trendingScorePercent`
        # @return [Fixnum]
        attr_accessor :trending_score_percent
      
        # Inferred language preferences of the user with their probabilities.
        # Corresponds to the JSON property `ulpLanguage`
        # @return [Array<Google::Apis::ContentwarehouseV1::SuperrootPodcastsRecommendationsPodcastRecsFeaturesUserLanguage>]
        attr_accessor :ulp_language
      
        # How much of ulp match the language of this episode
        # Corresponds to the JSON property `ulpLanguageMatch`
        # @return [Float]
        attr_accessor :ulp_language_match
      
        # The distance between user's Anima embedding and the centroid of the cluster in
        # k-means.
        # Corresponds to the JSON property `userClusterDistance`
        # @return [Float]
        attr_accessor :user_cluster_distance
      
        # Match score between user interest mids and episode salient entities. in a 0.0
        # to 1.0 range.
        # Corresponds to the JSON property `userInterestsSalientSimilarity`
        # @return [Float]
        attr_accessor :user_interests_salient_similarity
      
        # Match score between user interest mids and episode webref entities. in a 0.0
        # to 1.0 range.
        # Corresponds to the JSON property `userInterestsWebrefSimilarity`
        # @return [Float]
        attr_accessor :user_interests_webref_similarity
      
        # Language of shows in user history and how much they listened to each.
        # Corresponds to the JSON property `userLanguage`
        # @return [Array<Google::Apis::ContentwarehouseV1::SuperrootPodcastsRecommendationsPodcastRecsFeaturesUserLanguage>]
        attr_accessor :user_language
      
        # Score of violence safe search score go/safesearch
        # Corresponds to the JSON property `violenceScore`
        # @return [Float]
        attr_accessor :violence_score
      
        # Score of vulgar safe search score go/safesearch
        # Corresponds to the JSON property `vulgarScore`
        # @return [Float]
        attr_accessor :vulgar_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_duration_seconds_episode = args[:average_duration_seconds_episode] if args.key?(:average_duration_seconds_episode)
          @average_duration_seconds_show = args[:average_duration_seconds_show] if args.key?(:average_duration_seconds_show)
          @average_fraction_episode = args[:average_fraction_episode] if args.key?(:average_fraction_episode)
          @average_fraction_show = args[:average_fraction_show] if args.key?(:average_fraction_show)
          @balanced_lift = args[:balanced_lift] if args.key?(:balanced_lift)
          @category_match = args[:category_match] if args.key?(:category_match)
          @cluster_feed_minutes = args[:cluster_feed_minutes] if args.key?(:cluster_feed_minutes)
          @colistened_show_colisten_affinity = args[:colistened_show_colisten_affinity] if args.key?(:colistened_show_colisten_affinity)
          @colistened_show_level_rank = args[:colistened_show_level_rank] if args.key?(:colistened_show_level_rank)
          @conv_ai_toxicity_severe_score = args[:conv_ai_toxicity_severe_score] if args.key?(:conv_ai_toxicity_severe_score)
          @csai_score = args[:csai_score] if args.key?(:csai_score)
          @dnn_show_level_rank = args[:dnn_show_level_rank] if args.key?(:dnn_show_level_rank)
          @dnn_v2a_score = args[:dnn_v2a_score] if args.key?(:dnn_v2a_score)
          @dnn_v2a_score_sigmoid = args[:dnn_v2a_score_sigmoid] if args.key?(:dnn_v2a_score_sigmoid)
          @duration_total_seconds_episode = args[:duration_total_seconds_episode] if args.key?(:duration_total_seconds_episode)
          @duration_total_seconds_show = args[:duration_total_seconds_show] if args.key?(:duration_total_seconds_show)
          @episode_duration_sec = args[:episode_duration_sec] if args.key?(:episode_duration_sec)
          @episode_impressions = args[:episode_impressions] if args.key?(:episode_impressions)
          @episode_impressions_past_week = args[:episode_impressions_past_week] if args.key?(:episode_impressions_past_week)
          @episodes_published_per_month = args[:episodes_published_per_month] if args.key?(:episodes_published_per_month)
          @explicit_show = args[:explicit_show] if args.key?(:explicit_show)
          @feed_pagerank = args[:feed_pagerank] if args.key?(:feed_pagerank)
          @final_reaction_boost_score = args[:final_reaction_boost_score] if args.key?(:final_reaction_boost_score)
          @fraction_total_episode = args[:fraction_total_episode] if args.key?(:fraction_total_episode)
          @fraction_total_show = args[:fraction_total_show] if args.key?(:fraction_total_show)
          @fringe_score = args[:fringe_score] if args.key?(:fringe_score)
          @global_prob = args[:global_prob] if args.key?(:global_prob)
          @in_cluster_prob = args[:in_cluster_prob] if args.key?(:in_cluster_prob)
          @is_canonical = args[:is_canonical] if args.key?(:is_canonical)
          @kmeans_show_level_rank = args[:kmeans_show_level_rank] if args.key?(:kmeans_show_level_rank)
          @language_match = args[:language_match] if args.key?(:language_match)
          @link_ownership_verified = args[:link_ownership_verified] if args.key?(:link_ownership_verified)
          @listen_time_min = args[:listen_time_min] if args.key?(:listen_time_min)
          @listened_show_level_rank = args[:listened_show_level_rank] if args.key?(:listened_show_level_rank)
          @listened_show_listening_affinity = args[:listened_show_listening_affinity] if args.key?(:listened_show_listening_affinity)
          @location_feature_id = args[:location_feature_id] if args.key?(:location_feature_id)
          @long_user_listening_webref_similarity = args[:long_user_listening_webref_similarity] if args.key?(:long_user_listening_webref_similarity)
          @medical_score = args[:medical_score] if args.key?(:medical_score)
          @medium_user_listening_webref_similarity = args[:medium_user_listening_webref_similarity] if args.key?(:medium_user_listening_webref_similarity)
          @negative_reaction_boost_score = args[:negative_reaction_boost_score] if args.key?(:negative_reaction_boost_score)
          @niche_lift = args[:niche_lift] if args.key?(:niche_lift)
          @num_listeners_in_kmeans_cluster = args[:num_listeners_in_kmeans_cluster] if args.key?(:num_listeners_in_kmeans_cluster)
          @num_listeners_to_show_in_kmeans_cluster = args[:num_listeners_to_show_in_kmeans_cluster] if args.key?(:num_listeners_to_show_in_kmeans_cluster)
          @num_listens = args[:num_listens] if args.key?(:num_listens)
          @num_subscribers_show = args[:num_subscribers_show] if args.key?(:num_subscribers_show)
          @num_unique_listeners_show = args[:num_unique_listeners_show] if args.key?(:num_unique_listeners_show)
          @offensive_score = args[:offensive_score] if args.key?(:offensive_score)
          @pe_duration_score_episode = args[:pe_duration_score_episode] if args.key?(:pe_duration_score_episode)
          @pe_duration_score_show = args[:pe_duration_score_show] if args.key?(:pe_duration_score_show)
          @pe_duration_total_score_episode = args[:pe_duration_total_score_episode] if args.key?(:pe_duration_total_score_episode)
          @pe_duration_total_score_show = args[:pe_duration_total_score_show] if args.key?(:pe_duration_total_score_show)
          @pe_fraction_score_episode = args[:pe_fraction_score_episode] if args.key?(:pe_fraction_score_episode)
          @pe_fraction_score_show = args[:pe_fraction_score_show] if args.key?(:pe_fraction_score_show)
          @pe_fraction_total_score_episode = args[:pe_fraction_total_score_episode] if args.key?(:pe_fraction_total_score_episode)
          @pe_fraction_total_score_show = args[:pe_fraction_total_score_show] if args.key?(:pe_fraction_total_score_show)
          @pe_listen_score_episode = args[:pe_listen_score_episode] if args.key?(:pe_listen_score_episode)
          @pe_listen_score_show = args[:pe_listen_score_show] if args.key?(:pe_listen_score_show)
          @pe_listen_total_score_episode = args[:pe_listen_total_score_episode] if args.key?(:pe_listen_total_score_episode)
          @pe_listen_total_score_show = args[:pe_listen_total_score_show] if args.key?(:pe_listen_total_score_show)
          @popular_lift = args[:popular_lift] if args.key?(:popular_lift)
          @porn_score = args[:porn_score] if args.key?(:porn_score)
          @positive_reaction_boost_score = args[:positive_reaction_boost_score] if args.key?(:positive_reaction_boost_score)
          @query_language = args[:query_language] if args.key?(:query_language)
          @rank = args[:rank] if args.key?(:rank)
          @rank_percent_contrib = args[:rank_percent_contrib] if args.key?(:rank_percent_contrib)
          @recent_user_listening_webref_similarity = args[:recent_user_listening_webref_similarity] if args.key?(:recent_user_listening_webref_similarity)
          @seconds_since_publication = args[:seconds_since_publication] if args.key?(:seconds_since_publication)
          @show_base_quality = args[:show_base_quality] if args.key?(:show_base_quality)
          @show_impressions = args[:show_impressions] if args.key?(:show_impressions)
          @show_impressions_past_week = args[:show_impressions_past_week] if args.key?(:show_impressions_past_week)
          @show_language = args[:show_language] if args.key?(:show_language)
          @show_only_impressions = args[:show_only_impressions] if args.key?(:show_only_impressions)
          @show_only_impressions_past_week = args[:show_only_impressions_past_week] if args.key?(:show_only_impressions_past_week)
          @show_popular_rank = args[:show_popular_rank] if args.key?(:show_popular_rank)
          @spoof_score = args[:spoof_score] if args.key?(:spoof_score)
          @subscribed_show_listening_affinity = args[:subscribed_show_listening_affinity] if args.key?(:subscribed_show_listening_affinity)
          @subscription_show_level_rank = args[:subscription_show_level_rank] if args.key?(:subscription_show_level_rank)
          @surface = args[:surface] if args.key?(:surface)
          @trending_score_percent = args[:trending_score_percent] if args.key?(:trending_score_percent)
          @ulp_language = args[:ulp_language] if args.key?(:ulp_language)
          @ulp_language_match = args[:ulp_language_match] if args.key?(:ulp_language_match)
          @user_cluster_distance = args[:user_cluster_distance] if args.key?(:user_cluster_distance)
          @user_interests_salient_similarity = args[:user_interests_salient_similarity] if args.key?(:user_interests_salient_similarity)
          @user_interests_webref_similarity = args[:user_interests_webref_similarity] if args.key?(:user_interests_webref_similarity)
          @user_language = args[:user_language] if args.key?(:user_language)
          @violence_score = args[:violence_score] if args.key?(:violence_score)
          @vulgar_score = args[:vulgar_score] if args.key?(:vulgar_score)
        end
      end
      
      # 
      class SuperrootPodcastsRecommendationsPodcastRecsFeaturesUserLanguage
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lang`
        # @return [String]
        attr_accessor :lang
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lang = args[:lang] if args.key?(:lang)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # 
      class TelephoneNumber
        include Google::Apis::Core::Hashable
      
        # The local "area code", if there is such a concept.
        # Corresponds to the JSON property `areaCode`
        # @return [String]
        attr_accessor :area_code
      
        # The international direct dialing code for the country, as per ITU E.164: http:/
        # /www.itu.int/itudoc/itu-t/ob-lists/icc/e164_763.html
        # Corresponds to the JSON property `countryCode`
        # @return [Fixnum]
        attr_accessor :country_code
      
        # Extension (to be dialed after connection).
        # Corresponds to the JSON property `extension`
        # @return [String]
        attr_accessor :extension
      
        # To call this number from within the same country, the national call prefix may
        # be necessary. This is 1 in the US, 0 in the UK, etc. In the US, it's
        # reasonable to omit the leading 1 when writing the number, but in other
        # countries it is less optional.
        # Corresponds to the JSON property `nationalPrefix`
        # @return [String]
        attr_accessor :national_prefix
      
        # The actual number, broken down into sections as per local convention. Note
        # that the actual formatting of these sections (hyphen vs space, usage of
        # parentheses) will vary according to local custom.
        # Corresponds to the JSON property `number`
        # @return [Array<String>]
        attr_accessor :number
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @area_code = args[:area_code] if args.key?(:area_code)
          @country_code = args[:country_code] if args.key?(:country_code)
          @extension = args[:extension] if args.key?(:extension)
          @national_prefix = args[:national_prefix] if args.key?(:national_prefix)
          @number = args[:number] if args.key?(:number)
        end
      end
      
      # The docshards are a FlatSSTable from (64-bit) urlfp to data containing the
      # information found in this protocol buffer. (It's not actually one of these PBs
      # for various performance reasons; instead, the DocumentFormat class handles
      # serialization and deserialization in our own way) Next available ID: 37
      class TeragoogleDocumentInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `attachment`
        # @return [Array<Google::Apis::ContentwarehouseV1::TeragoogleDocumentInfoAttachment>]
        attr_accessor :attachment
      
        # The average weight of terms in the document. If not available, there will be
        # no term weight averaging: font sizes will be taken literally from the document
        # HTML.
        # Corresponds to the JSON property `averageTermWeight`
        # @return [Fixnum]
        attr_accessor :average_term_weight
      
        # Next id: 127
        # Corresponds to the JSON property `doc`
        # @return [Google::Apis::ContentwarehouseV1::GDocumentBase]
        attr_accessor :doc
      
        # The serialized ExtendedDocId, needed to construct a proper docinfo response if
        # the docinfo request is missing it and it's present.
        # Corresponds to the JSON property `extendedDocid`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :extended_docid
      
        # the global docid, we need it in the docservers (Continuum mode) to construct
        # proper docinfo response when the docinfo request does not contain a valid
        # global docid
        # Corresponds to the JSON property `globalDocid`
        # @return [Fixnum]
        attr_accessor :global_docid
      
        # If the original encoding isn't UTF8
        # Corresponds to the JSON property `originalEncoding`
        # @return [Fixnum]
        attr_accessor :original_encoding
      
        # 
        # Corresponds to the JSON property `section`
        # @return [Array<Google::Apis::ContentwarehouseV1::TeragoogleDocumentInfoSection>]
        attr_accessor :section
      
        # Indicates format of 'tokens' field in all Section entries.
        # Corresponds to the JSON property `sectionType`
        # @return [String]
        attr_accessor :section_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @attachment = args[:attachment] if args.key?(:attachment)
          @average_term_weight = args[:average_term_weight] if args.key?(:average_term_weight)
          @doc = args[:doc] if args.key?(:doc)
          @extended_docid = args[:extended_docid] if args.key?(:extended_docid)
          @global_docid = args[:global_docid] if args.key?(:global_docid)
          @original_encoding = args[:original_encoding] if args.key?(:original_encoding)
          @section = args[:section] if args.key?(:section)
          @section_type = args[:section_type] if args.key?(:section_type)
        end
      end
      
      # Misc. attachments to be added to the dynamic repository the docservers build.
      # These override any attachments created by parsing the GDocumentBase.
      class TeragoogleDocumentInfoAttachment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # Compression type to be applied to section/attachment.
        # Corresponds to the JSON property `options`
        # @return [Google::Apis::ContentwarehouseV1::TeragoogleRepositoryAttachmentOptions]
        attr_accessor :options
      
        # 
        # Corresponds to the JSON property `value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @options = args[:options] if args.key?(:options)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Sections to be added to the dynamic repository the docservers build. 'tokens'
      # is either a sequence of tokens encoded using the TokenSequenceEncoder (MDU),
      # or a TokenspaceRepository (depends on what's set in section_type. If 'doc' is
      # present, then the contents of these sections override what was created by
      # parsing 'doc'.
      class TeragoogleDocumentInfoSection
        include Google::Apis::Core::Hashable
      
        # List of field repository (subsection) names within the section.
        # Corresponds to the JSON property `fieldName`
        # @return [Array<String>]
        attr_accessor :field_name
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `tokens`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @field_name = args[:field_name] if args.key?(:field_name)
          @name = args[:name] if args.key?(:name)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # Compression type to be applied to section/attachment.
      class TeragoogleRepositoryAttachmentOptions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `compression`
        # @return [String]
        attr_accessor :compression
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compression = args[:compression] if args.key?(:compression)
        end
      end
      
      # Data related to title sizing calculations in Muppet.
      class TitleSizeParams
        include Google::Apis::Core::Hashable
      
        # Total max length of title in deciems
        # Corresponds to the JSON property `muppetTitleLengthInDeciems`
        # @return [Fixnum]
        attr_accessor :muppet_title_length_in_deciems
      
        # Number of lines for title
        # Corresponds to the JSON property `muppetTitleNumLines`
        # @return [Fixnum]
        attr_accessor :muppet_title_num_lines
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @muppet_title_length_in_deciems = args[:muppet_title_length_in_deciems] if args.key?(:muppet_title_length_in_deciems)
          @muppet_title_num_lines = args[:muppet_title_num_lines] if args.key?(:muppet_title_num_lines)
        end
      end
      
      # DO NOT USE THIS FOR ANYTHING LIVE WITHOUT PERMISSION! If you want to use this
      # for anything user-facing file a logs-access ticket describing what you want to
      # do. This data is currently only available in the freshdocs pipeline, so it
      # will only be present in instant mustang and certain librarian shards. Email
      # freshdocs-indexing with questions.
      class ToolBarPerDocData
        include Google::Apis::Core::Hashable
      
        # Indicates how many distinct toolbar visitors this page had in the past day.
        # Will only be present if the number is reasonably large.
        # Corresponds to the JSON property `VisitorsPastDay`
        # @return [Fixnum]
        attr_accessor :visitors_past_day
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @visitors_past_day = args[:visitors_past_day] if args.key?(:visitors_past_day)
        end
      end
      
      # Next ID: 26
      class TravelFlightsAirlineConfig
        include Google::Apis::Core::Hashable
      
        # Populated using airlines_company_ids.csv for AdWords company map
        # Corresponds to the JSON property `adwordsCid`
        # @return [Fixnum]
        attr_accessor :adwords_cid
      
        # STAR_ALLIANCE
        # Corresponds to the JSON property `alliance`
        # @return [String]
        attr_accessor :alliance
      
        # Default url for baggage fee information.
        # Corresponds to the JSON property `baggageCarryonLimitationsUrls`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :baggage_carryon_limitations_urls
      
        # Default url for baggage fee information.
        # Corresponds to the JSON property `baggageFeeUrls`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :baggage_fee_urls
      
        # ISO 3166-1 alpha-2 country code in which this airline is domestic.
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        # LocalizedContactInfo allows localization by country and language. Once the
        # data is ready, we will start filling both fields. After that the old field
        # will be deprecated and deleted at some point.
        # Corresponds to the JSON property `countryContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::TravelFlightsAirlineConfigCountryContactInfo>]
        attr_accessor :country_contact_info
      
        # true, if this carrier's IATA code is a "controlled duplicate" (goto/controlled-
        # duplicate).
        # Corresponds to the JSON property `dupFlag`
        # @return [Boolean]
        attr_accessor :dup_flag
        alias_method :dup_flag?, :dup_flag
      
        # 
        # Corresponds to the JSON property `fareFamilyUrls`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :fare_family_urls
      
        # IATA codes of airlines who this airline's travel can be credited to for
        # mileage accrual.
        # Corresponds to the JSON property `fqtvPartnerCode`
        # @return [Array<String>]
        attr_accessor :fqtv_partner_code
      
        # Note that some iata_codes are reused (`dup_flag` field). For details,
        # including how to resolve collisions for airlines shown in Google Flights, see:
        # go/controlled-duplicate go/flights-data/airlines#resolving-iata-code-
        # collisions cs/go/controlled-duplicate U2 - some have no IATA code
        # Corresponds to the JSON property `iataCode`
        # @return [String]
        attr_accessor :iata_code
      
        # EZY - some have no ICAO code
        # Corresponds to the JSON property `icaoCode`
        # @return [String]
        attr_accessor :icao_code
      
        # U2! - with optional dedup sign ('!')
        # Corresponds to the JSON property `innovataCode`
        # @return [String]
        attr_accessor :innovata_code
      
        # 
        # Corresponds to the JSON property `localizedContactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::TravelFlightsAirlineConfigLocalizedContactInfo>]
        attr_accessor :localized_contact_info
      
        # Note: fields #16 and #17 are ununused. The identifier of the airline, e.g. /m/
        # 07y2s for United Populated using airlines_mids.csv.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # EasyJet/イージージェット
        # Corresponds to the JSON property `names`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :names
      
        # Number of flights with this airline over the next 180 days.
        # Corresponds to the JSON property `popularity`
        # @return [Fixnum]
        attr_accessor :popularity
      
        # KLM - instead of 'KLM Royal Dutch Airlines'
        # Corresponds to the JSON property `shortNames`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :short_names
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # http://www.airfrance.us/
        # Corresponds to the JSON property `urls`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :urls
      
        # Default url for waiver information.
        # Corresponds to the JSON property `waiverSummaryUrls`
        # @return [Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogProto]
        attr_accessor :waiver_summary_urls
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @adwords_cid = args[:adwords_cid] if args.key?(:adwords_cid)
          @alliance = args[:alliance] if args.key?(:alliance)
          @baggage_carryon_limitations_urls = args[:baggage_carryon_limitations_urls] if args.key?(:baggage_carryon_limitations_urls)
          @baggage_fee_urls = args[:baggage_fee_urls] if args.key?(:baggage_fee_urls)
          @country_code = args[:country_code] if args.key?(:country_code)
          @country_contact_info = args[:country_contact_info] if args.key?(:country_contact_info)
          @dup_flag = args[:dup_flag] if args.key?(:dup_flag)
          @fare_family_urls = args[:fare_family_urls] if args.key?(:fare_family_urls)
          @fqtv_partner_code = args[:fqtv_partner_code] if args.key?(:fqtv_partner_code)
          @iata_code = args[:iata_code] if args.key?(:iata_code)
          @icao_code = args[:icao_code] if args.key?(:icao_code)
          @innovata_code = args[:innovata_code] if args.key?(:innovata_code)
          @localized_contact_info = args[:localized_contact_info] if args.key?(:localized_contact_info)
          @mid = args[:mid] if args.key?(:mid)
          @names = args[:names] if args.key?(:names)
          @popularity = args[:popularity] if args.key?(:popularity)
          @short_names = args[:short_names] if args.key?(:short_names)
          @type = args[:type] if args.key?(:type)
          @urls = args[:urls] if args.key?(:urls)
          @waiver_summary_urls = args[:waiver_summary_urls] if args.key?(:waiver_summary_urls)
        end
      end
      
      # 
      class TravelFlightsAirlineConfigContactInfo
        include Google::Apis::Core::Hashable
      
        # Typically, formatted phone number.
        # Corresponds to the JSON property `data`
        # @return [String]
        attr_accessor :data
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Airline contact info grouped by country.
      class TravelFlightsAirlineConfigCountryContactInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::TravelFlightsAirlineConfigContactInfo>]
        attr_accessor :contact_info
      
        # Two char country code, e.g. "US"
        # Corresponds to the JSON property `countryCode`
        # @return [String]
        attr_accessor :country_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_info = args[:contact_info] if args.key?(:contact_info)
          @country_code = args[:country_code] if args.key?(:country_code)
        end
      end
      
      # Airline contact info grouped by language. The language locale subcode will
      # determine the country.
      class TravelFlightsAirlineConfigLocalizedContactInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `contactInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::TravelFlightsAirlineConfigContactInfo>]
        attr_accessor :contact_info
      
        # IETF BCP-47, e.g. "en" or "zh-HK-Hant"
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @contact_info = args[:contact_info] if args.key?(:contact_info)
          @language = args[:language] if args.key?(:language)
        end
      end
      
      # 
      class TravelFlightsNameCatalogEntry
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @language = args[:language] if args.key?(:language)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # 
      class TravelFlightsNameCatalogProto
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [Array<Google::Apis::ContentwarehouseV1::TravelFlightsNameCatalogEntry>]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # ClientServiceInfo is meant for trawler/harpoon clients which are in turn
      # services to store some data specific to their clients. E.g., Kodachrome may
      # serve multiple other clients. In this case they can store their client name
      # here. Webmirror may also store the feed name here even though a feed is
      # technically not a service client. ClientServiceInfo is in nature similar to
      # ClientInfo, except it's stored in FetchReplyData (i.e., trawler logs), whereas
      # ClientInfo is copied to FetchReply (outside FetchReplyData), thus it's not
      # stored in trawler logs.
      class TrawlerClientServiceInfo
        include Google::Apis::Core::Hashable
      
        # Project delegation name to support bandwidth enforcement. Harpoon will call
        # SetDelegatedUser() with the specified DelegatedProjectName and a domain
        # associated with the RequestorID provided in the client capatibility file.
        # Corresponds to the JSON property `DelegatedProjectName`
        # @return [String]
        attr_accessor :delegated_project_name
      
        # 
        # Corresponds to the JSON property `ServiceClientID`
        # @return [String]
        attr_accessor :service_client_id
      
        # 
        # Corresponds to the JSON property `clientLabels`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerClientServiceInfoClientLabels>]
        attr_accessor :client_labels
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @delegated_project_name = args[:delegated_project_name] if args.key?(:delegated_project_name)
          @service_client_id = args[:service_client_id] if args.key?(:service_client_id)
          @client_labels = args[:client_labels] if args.key?(:client_labels)
        end
      end
      
      # ClientLabels contains client-specified key/value pairs, used to annotate
      # individual FetchRequests and FetchReplies. This is primarily useful when the
      # Multiverse Nexus performs postprocessing of fetchreplies. ClientLabels
      # essentially allow clients to use the Nexus UI to slice statistics computed on
      # fetchreplies by the specified key/value pairs. Note: we don't use "map" type
      # here delibrately in order to avoid the non-deterministric serialization of the
      # "map" field. See b/69064361 for more details.
      class TrawlerClientServiceInfoClientLabels
        include Google::Apis::Core::Hashable
      
        # ======================== End of Deprecated Part ========================
        # Corresponds to the JSON property `labelsDeprecated`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::TrawlerClientServiceInfoClientLabelsClientLabelValues>]
        attr_accessor :labels_deprecated
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `values`
        # @return [Array<String>]
        attr_accessor :values
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @labels_deprecated = args[:labels_deprecated] if args.key?(:labels_deprecated)
          @name = args[:name] if args.key?(:name)
          @values = args[:values] if args.key?(:values)
        end
      end
      
      # ===================== Beginning of Deprecated Part ======================
      class TrawlerClientServiceInfoClientLabelsClientLabelValues
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `value`
        # @return [Array<String>]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # Parsed version of a Content-Range field, which in http might look like:
      # Content-Range: bytes 500-999/3156
      class TrawlerContentRangeInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `EndPos`
        # @return [Fixnum]
        attr_accessor :end_pos
      
        # In ContentRange, the first byte is 0 (rather than 1), and the positions are
        # inclusive. Thus, length is EndPos+1-StartPos
        # Corresponds to the JSON property `StartPos`
        # @return [Fixnum]
        attr_accessor :start_pos
      
        # 
        # Corresponds to the JSON property `TotalLength`
        # @return [Fixnum]
        attr_accessor :total_length
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_pos = args[:end_pos] if args.key?(:end_pos)
          @start_pos = args[:start_pos] if args.key?(:start_pos)
          @total_length = args[:total_length] if args.key?(:total_length)
        end
      end
      
      # This is similar to CrawlDates group in FetchReplyData, except that 1) it's a
      # message; 2) it's filled in each Redirects hop; and 3) the timestamps are in ms
      # rather than seconds since Unix Epoch.
      class TrawlerCrawlTimes
        include Google::Apis::Core::Hashable
      
        # fetched from the web. Time when the page was last
        # Corresponds to the JSON property `NotChangedTimeMs`
        # @return [Fixnum]
        attr_accessor :not_changed_time_ms
      
        # Time when the page was
        # Corresponds to the JSON property `OriginalCrawlTimeMs`
        # @return [Fixnum]
        attr_accessor :original_crawl_time_ms
      
        # checked but found to be the same as before. If set, timestamp to indicate
        # Corresponds to the JSON property `ReuseTimeMs`
        # @return [Fixnum]
        attr_accessor :reuse_time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @not_changed_time_ms = args[:not_changed_time_ms] if args.key?(:not_changed_time_ms)
          @original_crawl_time_ms = args[:original_crawl_time_ms] if args.key?(:original_crawl_time_ms)
          @reuse_time_ms = args[:reuse_time_ms] if args.key?(:reuse_time_ms)
        end
      end
      
      # Event is for logging interesting events that happen during a url fetch.
      # Interesting events include "fetch start", "url rejected", etc. The events are
      # written to binary logs together with the request and reply messages. If the
      # same event occurs multiple times consecutively, We record the time of the
      # first three instances in EarliestTimeStamp but omit the rest. We keep track
      # the total number of occurrences in NumOccurrences and the timestamp of the
      # last occurrence is kept in TimeStamp field.
      class TrawlerEvent
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `ID`
        # @return [Fixnum]
        attr_accessor :id
      
        # 
        # Corresponds to the JSON property `Msg`
        # @return [String]
        attr_accessor :msg
      
        # 
        # Corresponds to the JSON property `NumOccurrences`
        # @return [Fixnum]
        attr_accessor :num_occurrences
      
        # Limited to 3.
        # Corresponds to the JSON property `OldestTimeStampInUS`
        # @return [Array<Fixnum>]
        attr_accessor :oldest_time_stamp_in_us
      
        # 
        # Corresponds to the JSON property `TimeStampInUS`
        # @return [Fixnum]
        attr_accessor :time_stamp_in_us
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @msg = args[:msg] if args.key?(:msg)
          @num_occurrences = args[:num_occurrences] if args.key?(:num_occurrences)
          @oldest_time_stamp_in_us = args[:oldest_time_stamp_in_us] if args.key?(:oldest_time_stamp_in_us)
          @time_stamp_in_us = args[:time_stamp_in_us] if args.key?(:time_stamp_in_us)
        end
      end
      
      # 
      class TrawlerFetchBodyData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `compression`
        # @return [String]
        attr_accessor :compression
      
        # 
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # Size hint. Set if compression != NO_COMPRESSION
        # Corresponds to the JSON property `uncompressedSize`
        # @return [Fixnum]
        attr_accessor :uncompressed_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @compression = args[:compression] if args.key?(:compression)
          @content = args[:content] if args.key?(:content)
          @uncompressed_size = args[:uncompressed_size] if args.key?(:uncompressed_size)
        end
      end
      
      # Fetcher -> FetchClient FetchReplyData is the metadata for a reply from a
      # FetchRequest. For metadata + document body, FetchReply is further below. NOTE:
      # FetchReplyData (and FetchReply) is the output interface from Multiverse. Teams
      # outside Multiverse/Trawler should not create fake FetchReplies. Trawler: When
      # adding new fields here, it is recommended that at least the following be
      # rebuilt and pushed: - cron_fetcher_index mapreduces: so that UrlReplyIndex,
      # etc. retain the new fields - tlookup, tlookup_server: want to be able to
      # return the new fields - logviewer, fetchutil: annoying to get back 'tag88:' in
      # results -------------------------- Next Tag: 124 -----------------------
      class TrawlerFetchReplyData
        include Google::Apis::Core::Hashable
      
        # This field, if non-empty, contains the SSL certificate chain from the server.
        # The filed should be serialized SSLCertificateInfo protobuf, although it used
        # to be text format. Hence, one should ideally use trawler::CertificateUtil to
        # check this field and understand in more detail. This field is populated in two
        # cases: (1) something is wrong with the server certificate and we cannot verify
        # the server's identity. In this case the URL most likely won't display in a
        # browser; (2) if you turned on WantSSLCertificateChain in the FetchRequest. In
        # this case the server certificate may be perfectly fine (despite the field name)
        # . This is for the initial hop; additional hops are in Redirects group.
        # Corresponds to the JSON property `BadSSLCertificate`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :bad_ssl_certificate
      
        # ClientServiceInfo is meant for trawler/harpoon clients which are in turn
        # services to store some data specific to their clients. E.g., Kodachrome may
        # serve multiple other clients. In this case they can store their client name
        # here. Webmirror may also store the feed name here even though a feed is
        # technically not a service client. ClientServiceInfo is in nature similar to
        # ClientInfo, except it's stored in FetchReplyData (i.e., trawler logs), whereas
        # ClientInfo is copied to FetchReply (outside FetchReplyData), thus it's not
        # stored in trawler logs.
        # Corresponds to the JSON property `ClientServiceInfo`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerClientServiceInfo]
        attr_accessor :client_service_info
      
        # Is the associated body compressed ?
        # Corresponds to the JSON property `CompressedBody`
        # @return [Boolean]
        attr_accessor :compressed_body
        alias_method :compressed_body?, :compressed_body
      
        # This is similar to CrawlDates group in FetchReplyData, except that 1) it's a
        # message; 2) it's filled in each Redirects hop; and 3) the timestamps are in ms
        # rather than seconds since Unix Epoch.
        # Corresponds to the JSON property `CrawlTimes`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerCrawlTimes]
        attr_accessor :crawl_times
      
        # Sometimes the hostid and destination IP in the FetchReplyData are not for the
        # hostname in the url. If that's the case DNSHost will be the host that we have
        # used when resolving hostid and DNS. Right now there are two cases: (1) malware
        # team provides a proxy IP:Port to us, so DNSHost will be the proxy IP; and (2)
        # PSS team provides a reference DNS host; so DNSHost will be the reference DNS
        # host.
        # Corresponds to the JSON property `DNSHost`
        # @return [String]
        attr_accessor :dns_host
      
        # The download time for this fetch (ms). This is the RTT time between fetcher
        # and HOPE, note it does not include time from redirects, just initial hop. If
        # you want the sum of the DownloadTime values for all fetches in the redirect
        # chain, then use the DownLoadTime value in the FetchStats.
        # Corresponds to the JSON property `DownloadTime`
        # @return [Fixnum]
        attr_accessor :download_time
      
        # If present, the edge region that we have used.
        # Corresponds to the JSON property `EgressRegion`
        # @return [String]
        attr_accessor :egress_region
      
        # If present, it means this host might be eligible for geo crawl. However, this
        # does not mean we enable geo-crawl for this request. Check "
        # GeoCrawlEgressRegion" instead to see if this fetch is conducted via geo crawl.
        # Corresponds to the JSON property `EligibleGeoCrawlEgressRegion`
        # @return [String]
        attr_accessor :eligible_geo_crawl_egress_region
      
        # To keep track of fetch connection endpoints. Note: You can use trawler::
        # SourceIP(info) or trawler::DestinationIP(info) (as well as HasSourceIP/
        # HasDestinationIP) in basictypes.h instead of accessing the packed strings
        # directly. This will return a proper IPAddress. Never use the fixed32 based
        # Source/Destination-IP in new code as they will go away (only IPv4).
        # Corresponds to the JSON property `Endpoints`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerTcpipInfo]
        attr_accessor :endpoints
      
        # 
        # Corresponds to the JSON property `Events`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerEvent>]
        attr_accessor :events
      
        # With the introduction of fetch pattern based hostload exceptions, one hostid
        # may have multiple hostload buckets, each with its own hostload. In this case,
        # FetchPatternFp will be set to identify the hostload bucket within the hostid.
        # Note this field is only meaningful for the HostBucketData which is recorded
        # only when the client requests to have as part of reply. However, this field is
        # useful for certain stats gathering, so we choose to always record it if its
        # value is available during the fetch.
        # Corresponds to the JSON property `FetchPatternFp`
        # @return [Fixnum]
        attr_accessor :fetch_pattern_fp
      
        # If present, fetch was conducted using floonet and this is the location of
        # floonet egress point we used.
        # Corresponds to the JSON property `FlooEgressRegion`
        # @return [String]
        attr_accessor :floo_egress_region
      
        # If present, the last hop of the fetch was conducted using floonet and this is
        # the location of floonet egress point. It is different from EgressRegion and
        # FlooEgressREgion because it is a Trawler transparent routing configured in the
        # geo crawl rules(go/da-geo-crawl).
        # Corresponds to the JSON property `GeoCrawlEgressRegion`
        # @return [String]
        attr_accessor :geo_crawl_egress_region
      
        # Whether we fallback from geo crawl to local crawl during fetch. The fallback
        # could happen in any hops and there can be at most one fallback because once
        # fallback happens, we will not try geo-crawl anymore.
        # Corresponds to the JSON property `GeoCrawlFallback`
        # @return [Boolean]
        attr_accessor :geo_crawl_fallback
        alias_method :geo_crawl_fallback?, :geo_crawl_fallback
      
        # Set only when GeoCrawlFallback is true. Logs the geo crawl location we
        # attempted but failed for this request.
        # Corresponds to the JSON property `GeoCrawlLocationAttempted`
        # @return [String]
        attr_accessor :geo_crawl_location_attempted
      
        # Set to: o HSTS_STATUS_NONE if there was no HSTS policy match for the URL's
        # host. o HSTS_STATUS_AVAILABLE if there was an HSTS policy, but the URL was not
        # rewritten from HTTP to HTTPS because enable_hsts was not set in client
        # capability config. o HSTS_STATUS_REWRITTEN if the HSTS policy was followed and
        # url was rewritten from HTTP to HTTPS. This field only pertains to the current
        # URL fetch and does not explain a redirect's HSTS status. However,
        # FetchReplyData.Redirects have their own HSTSInfo.
        # Corresponds to the JSON property `HSTSInfo`
        # @return [String]
        attr_accessor :hsts_info
      
        # The received HTTP trailers if available.
        # Corresponds to the JSON property `HTTPTrailers`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataHttpHeader>]
        attr_accessor :http_trailers
      
        # Returns the cache key used when doing cache lookup/update, on a per-hop basis (
        # initial hop) Note this field will not be set if cache lookup/update is
        # disabled/skipped.
        # Corresponds to the JSON property `HopCacheKeyForLookup`
        # @return [Fixnum]
        attr_accessor :hop_cache_key_for_lookup
      
        # 
        # Corresponds to the JSON property `HopCacheKeyForUpdate`
        # @return [Fixnum]
        attr_accessor :hop_cache_key_for_update
      
        # Returns trawler::ReuseInfo with status of IMS/IMF/cache query, on a per-hop
        # basis (initial hop) For example, if the URL redirect chain is [URL A] --> [URL
        # B] --> [URL C], this field stores the reuse info of [URL A].
        # Corresponds to the JSON property `HopReuseInfo`
        # @return [String]
        attr_accessor :hop_reuse_info
      
        # Extra information in robots.txt for this page (integer: or'ed together of type
        # trawler::RobotsInfo) on a per-hop basis (initial hop)
        # Corresponds to the JSON property `HopRobotsInfo`
        # @return [Fixnum]
        attr_accessor :hop_robots_info
      
        # ============================ Next Tag: 21 ============================ Data
        # about the scheduling host bucket a URL was in (if the client wants to use this,
        # e.g. for more intelligent scheduling, etc).
        # Corresponds to the JSON property `HostBucketData`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerHostBucketData]
        attr_accessor :host_bucket_data
      
        # If known, the trawler::HostId that identifies the host (initial hop).
        # Corresponds to the JSON property `HostId`
        # @return [Fixnum]
        attr_accessor :host_id
      
        # The http protocol we send to fetch this URL. This will only be set if the
        # request is using http
        # Corresponds to the JSON property `HttpProtocol`
        # @return [String]
        attr_accessor :http_protocol
      
        # The HTTP headers we sent to fetch this URL (initial hop). Not normally filled
        # in, unless FetchParams.WantSentHeaders is set.
        # Corresponds to the JSON property `HttpRequestHeaders`
        # @return [String]
        attr_accessor :http_request_headers
      
        # HTTP headers from the response (initial hop). Trawler does not fill this in;
        # this is intended as a placeholder for crawls like webmirror that fill in and
        # want to track this across redirect hops.
        # Corresponds to the JSON property `HttpResponseHeaders`
        # @return [String]
        attr_accessor :http_response_headers
      
        # Stores the HTTP version we used in the final hop.
        # Corresponds to the JSON property `HttpVersion`
        # @return [String]
        attr_accessor :http_version
      
        # Same as the ID of the matching request (used for matching internal fetchclient
        # data in request/reply)
        # Corresponds to the JSON property `ID`
        # @return [Fixnum]
        attr_accessor :id
      
        # Crawl status of the last url on chain
        # Corresponds to the JSON property `LastUrlStatus`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchStatus]
        attr_accessor :last_url_status
      
        # Trawler can optionally add a policy label to a FetchReply. Some uses: - "spam"
        # label via trawler_site_info - "roboted:googlebot" label as a signal to crawls
        # supporting multiple useragents that it's not safe to share the fetch replies
        # with googlebot crawls.
        # Corresponds to the JSON property `PolicyData`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerPolicyData>]
        attr_accessor :policy_data
      
        # If the fetch uses HTTP POST, PUT, or PATCH protocol, and WantPostData is true,
        # the POST data will be copied here. This is only for initial hop. If there are
        # redirects, HTTP POST will be changed to GET on subsequent hops, and the
        # PostData will be cleared. There is only one exception, if the HTTP response
        # code to the POST request is 307 (a new code introduced in RFC7321, sec. 6.4.7),
        # we will preserve the request method and the PostData for the next hop.
        # Corresponds to the JSON property `PostData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :post_data
      
        # This is available only if a fetch results in TIMEOUT_WEB, and we were able to
        # predict, based on content length and bandwidth we were using, how much time (
        # in ms) would be needed to download the entire content.
        # Corresponds to the JSON property `PredictedDownloadTimeMs`
        # @return [Fixnum]
        attr_accessor :predicted_download_time_ms
      
        # Whether we fallback from HTTP/2 to HTTP/1.1 during fetch. The fallback could
        # happen in any hops and there can be at most one fallback because once fallback
        # happens, we will not try HTTP/2 anymore.
        # Corresponds to the JSON property `ProtocolVersionFallback`
        # @return [Boolean]
        attr_accessor :protocol_version_fallback
        alias_method :protocol_version_fallback?, :protocol_version_fallback
      
        # If this fetch was a result of a redirect, we populate the parent ID here.
        # Corresponds to the JSON property `RedirectSourceFetchId`
        # @return [Fixnum]
        attr_accessor :redirect_source_fetch_id
      
        # RequestorId is the same on as in the request that triggers this reply --
        # mainly for diagnostics purpose
        # Corresponds to the JSON property `RequestorID`
        # @return [String]
        attr_accessor :requestor_id
      
        # Machine that sent Trawler this request, for logging. An IPAddress object,
        # packed as a string.
        # Corresponds to the JSON property `RequestorIPAddressPacked`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :requestor_ip_address_packed
      
        # -------- Returns trawler::ReuseInfo with status of IMS/IMF/cache query.
        # Consider using HopReuseInfo instead, which has per-redirect hop detail. If
        # there's URL redirection, this field stores the reuse info of the last hop. For
        # example, if the and URL redirect chain is [URL A] --> [URL B] --> [URL C],
        # this field stores the reuse info of [URL C].
        # Corresponds to the JSON property `ReuseInfo`
        # @return [String]
        attr_accessor :reuse_info
      
        # Extra information in robots.txt for this page (ORed together bits from trawler:
        # :RobotsInfo). e.g. nosnippet vs. noarchive vs nofollow vs noindex vs disallow
        # Consider using HopRobotsInfo instead, which has per-redirect hop detail.
        # Corresponds to the JSON property `RobotsInfo`
        # @return [Fixnum]
        attr_accessor :robots_info
      
        # Status of the robots.txt fetch. Currently, this is present if: - Certain
        # robots error cases, such as URL_TIMEOUT-TIMEOUT_ROBOTS or URL_UNREACHABLE-
        # UNREACHABLE_ROBOTS_ERROR. - If WantRobotsBody is set in the FetchParams.
        # Corresponds to the JSON property `RobotsStatus`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchStatus]
        attr_accessor :robots_status
      
        # The robots.txt we used for this URL (initial hop). Not normally filled in
        # unless WantRobotsBody is set. This is mostly for debugging purposes and should
        # not be used for large volumes of traffic.
        # Corresponds to the JSON property `RobotsTxt`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :robots_txt
      
        # Status of the fetch - refers to the final status at the end of the redirect
        # chain.
        # Corresponds to the JSON property `Status`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchStatus]
        attr_accessor :status
      
        # If present, Client API will enforce the contained constraints
        # Corresponds to the JSON property `ThrottleClient`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerThrottleClientData]
        attr_accessor :throttle_client
      
        # Sometimes we throw away content because we cannot store it in the internal
        # buffers. These is how many bytes we have thrown away for this factor.
        # Corresponds to the JSON property `ThrownAwayBytes`
        # @return [Fixnum]
        attr_accessor :thrown_away_bytes
      
        # When this reply came back from fetcher NOTE: TimestampInMS is used for
        # internal debugging. To see when a document was crawled, check CrawlDates.
        # Corresponds to the JSON property `TimestampInMS`
        # @return [Fixnum]
        attr_accessor :timestamp_in_ms
      
        # How many raw bytes we read from the connection to the server when we fetched
        # the page. Includes everything: HTTP headers, overhead for HTTP chunked
        # encoding, whatever compressed/uncompressed form (i.e. gzip/deflate accept-
        # encoding) the content was sent in, etc. This is NOT the same as the size of
        # the uncompressed FetchReply::Body - if the webserver used gzip encoding, this
        # value might be much smaller, since it only counts the compressed wire size. To
        # illustrate, think of 3 sizes: 1) TotalFetchedSize - amount Trawler read over
        # the wire from the server. If they used gzip/deflate, this might be 4-5x
        # smaller than the body. 2) UnTruncatedSize/CutoffSize - how big is the full
        # document, after uncompressing any gzip/deflate encoding? If truncated, this is
        # reflected in CutoffSize. 3) FetchReply::Body size - most crawls enable Trawler
        # compression to save storage space (gzip + a google html dictionary). The body
        # size that the end Trawler client sees is post-compression.
        # Corresponds to the JSON property `TotalFetchedSize`
        # @return [Fixnum]
        attr_accessor :total_fetched_size
      
        # If the url got rewriten by transparent rewrites, here it is the series of
        # rewrites it got through. The fetched one is the last
        # Corresponds to the JSON property `TransparentRewrites`
        # @return [Array<String>]
        attr_accessor :transparent_rewrites
      
        # This is an optional container of arbitrary data that can be added to a
        # FetchReplyData. This data is meant to be logged, but not sent back in a fetch
        # reply (it should be added *after* the reply is prepared). Use
        # FetchResponsePreparatorImpl::AddTrawlerPrivateDataToFetchReplyData to add. See
        # also the comment in fetch_response_preparator_impl.cc. Next Tag: 43
        # Corresponds to the JSON property `TrawlerPrivate`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerTrawlerPrivateFetchReplyData]
        attr_accessor :trawler_private
      
        # The original url in the request we are answering. Even though "optional," url
        # must be filled in on all well-formed replies. Trawler guarantees that it is
        # filled in, and basically every client expects it (CHECKs in some cases). ->
        # Not filling this field in is a bug, if you share this data with other crawls/
        # pipelines. You should expect everybody else to require a url.
        # Corresponds to the JSON property `Url`
        # @return [String]
        attr_accessor :url
      
        # Encoding info for the original url itself. Bitfield encoding; see UrlEncoding::
        # `Set,Get`Value in webutil/urlencoding.
        # Corresponds to the JSON property `UrlEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        # Use the special compression dictionary for uncompressing this. (trawler::
        # kHtmlCompressionDict. Use trawler::FetchReplyUncompressor to uncompress;
        # crawler/trawler/public/fetchreply-util.h)
        # Corresponds to the JSON property `UseHtmlCompressDictionary`
        # @return [Boolean]
        attr_accessor :use_html_compress_dictionary
        alias_method :use_html_compress_dictionary?, :use_html_compress_dictionary
      
        # Reuse information returned if UrlState == CRAWLED, specifying when we may have
        # reused from cache. See also ReuseInfo below. NOTE: Please use the CrawlTimes
        # below. CrawlDates is deprecated. use CrawlTimes instead!
        # Corresponds to the JSON property `crawldates`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataCrawlDates]
        attr_accessor :crawldates
      
        # Depending on which Data Acquisition API the client uses, the fetched content
        # can be delivered to the client in the RPC, via Goops, or copied to the client'
        # s storage system (possibly after transformation). In the latter case,
        # DeliveryReport will contain info about the delivery status, such as whether we
        # have permission error, whether the destination storage is out of quota, etc).
        # Corresponds to the JSON property `deliveryReport`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataDeliveryReport]
        attr_accessor :delivery_report
      
        # The fetcher keeps track of various time intervals spent in the states of the
        # fetcher url control flow. Sometimes flows branch out into more than one flow (
        # next flow), and we aggregate all the time intervals spent in a specific state
        # for all the flows to get the time interval for the state. The time interval
        # for a state is therefore not the time interval of an individual flow, if the
        # WaitNextFlow time is non zero. The WaitNextFlow interval included here is the
        # time spent by one flow waiting for another flow. Although the WaitNextFlow
        # time is the time spent by a flow in the WaitNextFlow state, its also
        # equivalent to the entire timeline of another flow. It is the time spent in the
        # various states of another flow. In computing the total time spent in the
        # primary flow, one must omit the WaitNextFlow time, since it is already
        # included in the form of slices of individual state time intervals in the
        # aggregated time intervals for other states, and will result in double counting.
        # Corresponds to the JSON property `fetchstats`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataFetchStats]
        attr_accessor :fetchstats
      
        # If the input url in FetchRequest is Amazon S3 protocol or Apple Itunes
        # protocol, we will translate it into https url and log it as https url. In the
        # meantime we will store the original s3/itunes url in this field. Before
        # sending back to client, the Url will be translated back to s3 and this field
        # will be cleard.
        # Corresponds to the JSON property `originalProtocolUrl`
        # @return [String]
        attr_accessor :original_protocol_url
      
        # ----------------------------------------------------------------------
        # PartialResponse is used with streaming responses in LargeFileFetchAdapter.
        # Rather than fitting entirely in a single FetchReply, there is a series of
        # FetchReplies until IsFinalResponse. Each group of responses will have a unique
        # FetchID to link them.
        # Corresponds to the JSON property `partialresponse`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataPartialResponse]
        attr_accessor :partialresponse
      
        # Group with protocol specific response (determined by the protocol of the url
        # that generated the content we return).
        # Corresponds to the JSON property `protocolresponse`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataProtocolResponse]
        attr_accessor :protocolresponse
      
        # 
        # Corresponds to the JSON property `redirects`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataRedirects>]
        attr_accessor :redirects
      
        # Traffic type of this fetch.
        # Corresponds to the JSON property `trafficType`
        # @return [String]
        attr_accessor :traffic_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bad_ssl_certificate = args[:bad_ssl_certificate] if args.key?(:bad_ssl_certificate)
          @client_service_info = args[:client_service_info] if args.key?(:client_service_info)
          @compressed_body = args[:compressed_body] if args.key?(:compressed_body)
          @crawl_times = args[:crawl_times] if args.key?(:crawl_times)
          @dns_host = args[:dns_host] if args.key?(:dns_host)
          @download_time = args[:download_time] if args.key?(:download_time)
          @egress_region = args[:egress_region] if args.key?(:egress_region)
          @eligible_geo_crawl_egress_region = args[:eligible_geo_crawl_egress_region] if args.key?(:eligible_geo_crawl_egress_region)
          @endpoints = args[:endpoints] if args.key?(:endpoints)
          @events = args[:events] if args.key?(:events)
          @fetch_pattern_fp = args[:fetch_pattern_fp] if args.key?(:fetch_pattern_fp)
          @floo_egress_region = args[:floo_egress_region] if args.key?(:floo_egress_region)
          @geo_crawl_egress_region = args[:geo_crawl_egress_region] if args.key?(:geo_crawl_egress_region)
          @geo_crawl_fallback = args[:geo_crawl_fallback] if args.key?(:geo_crawl_fallback)
          @geo_crawl_location_attempted = args[:geo_crawl_location_attempted] if args.key?(:geo_crawl_location_attempted)
          @hsts_info = args[:hsts_info] if args.key?(:hsts_info)
          @http_trailers = args[:http_trailers] if args.key?(:http_trailers)
          @hop_cache_key_for_lookup = args[:hop_cache_key_for_lookup] if args.key?(:hop_cache_key_for_lookup)
          @hop_cache_key_for_update = args[:hop_cache_key_for_update] if args.key?(:hop_cache_key_for_update)
          @hop_reuse_info = args[:hop_reuse_info] if args.key?(:hop_reuse_info)
          @hop_robots_info = args[:hop_robots_info] if args.key?(:hop_robots_info)
          @host_bucket_data = args[:host_bucket_data] if args.key?(:host_bucket_data)
          @host_id = args[:host_id] if args.key?(:host_id)
          @http_protocol = args[:http_protocol] if args.key?(:http_protocol)
          @http_request_headers = args[:http_request_headers] if args.key?(:http_request_headers)
          @http_response_headers = args[:http_response_headers] if args.key?(:http_response_headers)
          @http_version = args[:http_version] if args.key?(:http_version)
          @id = args[:id] if args.key?(:id)
          @last_url_status = args[:last_url_status] if args.key?(:last_url_status)
          @policy_data = args[:policy_data] if args.key?(:policy_data)
          @post_data = args[:post_data] if args.key?(:post_data)
          @predicted_download_time_ms = args[:predicted_download_time_ms] if args.key?(:predicted_download_time_ms)
          @protocol_version_fallback = args[:protocol_version_fallback] if args.key?(:protocol_version_fallback)
          @redirect_source_fetch_id = args[:redirect_source_fetch_id] if args.key?(:redirect_source_fetch_id)
          @requestor_id = args[:requestor_id] if args.key?(:requestor_id)
          @requestor_ip_address_packed = args[:requestor_ip_address_packed] if args.key?(:requestor_ip_address_packed)
          @reuse_info = args[:reuse_info] if args.key?(:reuse_info)
          @robots_info = args[:robots_info] if args.key?(:robots_info)
          @robots_status = args[:robots_status] if args.key?(:robots_status)
          @robots_txt = args[:robots_txt] if args.key?(:robots_txt)
          @status = args[:status] if args.key?(:status)
          @throttle_client = args[:throttle_client] if args.key?(:throttle_client)
          @thrown_away_bytes = args[:thrown_away_bytes] if args.key?(:thrown_away_bytes)
          @timestamp_in_ms = args[:timestamp_in_ms] if args.key?(:timestamp_in_ms)
          @total_fetched_size = args[:total_fetched_size] if args.key?(:total_fetched_size)
          @transparent_rewrites = args[:transparent_rewrites] if args.key?(:transparent_rewrites)
          @trawler_private = args[:trawler_private] if args.key?(:trawler_private)
          @url = args[:url] if args.key?(:url)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
          @use_html_compress_dictionary = args[:use_html_compress_dictionary] if args.key?(:use_html_compress_dictionary)
          @crawldates = args[:crawldates] if args.key?(:crawldates)
          @delivery_report = args[:delivery_report] if args.key?(:delivery_report)
          @fetchstats = args[:fetchstats] if args.key?(:fetchstats)
          @original_protocol_url = args[:original_protocol_url] if args.key?(:original_protocol_url)
          @partialresponse = args[:partialresponse] if args.key?(:partialresponse)
          @protocolresponse = args[:protocolresponse] if args.key?(:protocolresponse)
          @redirects = args[:redirects] if args.key?(:redirects)
          @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
        end
      end
      
      # Reuse information returned if UrlState == CRAWLED, specifying when we may have
      # reused from cache. See also ReuseInfo below. NOTE: Please use the CrawlTimes
      # below. CrawlDates is deprecated. use CrawlTimes instead!
      class TrawlerFetchReplyDataCrawlDates
        include Google::Apis::Core::Hashable
      
        # fetched from the web. Timestamp indicates when
        # Corresponds to the JSON property `NotChangedDate`
        # @return [Fixnum]
        attr_accessor :not_changed_date
      
        # Timestamp when the page was
        # Corresponds to the JSON property `OriginalCrawlDate`
        # @return [Fixnum]
        attr_accessor :original_crawl_date
      
        # the page was last checked but found to be the same as before. If set,
        # timestamp to indicate
        # Corresponds to the JSON property `ReuseDate`
        # @return [Fixnum]
        attr_accessor :reuse_date
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @not_changed_date = args[:not_changed_date] if args.key?(:not_changed_date)
          @original_crawl_date = args[:original_crawl_date] if args.key?(:original_crawl_date)
          @reuse_date = args[:reuse_date] if args.key?(:reuse_date)
        end
      end
      
      # Depending on which Data Acquisition API the client uses, the fetched content
      # can be delivered to the client in the RPC, via Goops, or copied to the client'
      # s storage system (possibly after transformation). In the latter case,
      # DeliveryReport will contain info about the delivery status, such as whether we
      # have permission error, whether the destination storage is out of quota, etc).
      class TrawlerFetchReplyDataDeliveryReport
        include Google::Apis::Core::Hashable
      
        # The events store the detail of messages (usually error).
        # Corresponds to the JSON property `events`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerEvent>]
        attr_accessor :events
      
        # The complete path (include the file name) of the file downloaded. For requests
        # that require delivery, this path will be the user specified location. For
        # requests that use Multiverse default storage, this path will be the managed by
        # Multiverse.
        # Corresponds to the JSON property `filePath`
        # @return [String]
        attr_accessor :file_path
      
        # Status of the transfer action.
        # Corresponds to the JSON property `status`
        # @return [String]
        attr_accessor :status
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @events = args[:events] if args.key?(:events)
          @file_path = args[:file_path] if args.key?(:file_path)
          @status = args[:status] if args.key?(:status)
        end
      end
      
      # The fetcher keeps track of various time intervals spent in the states of the
      # fetcher url control flow. Sometimes flows branch out into more than one flow (
      # next flow), and we aggregate all the time intervals spent in a specific state
      # for all the flows to get the time interval for the state. The time interval
      # for a state is therefore not the time interval of an individual flow, if the
      # WaitNextFlow time is non zero. The WaitNextFlow interval included here is the
      # time spent by one flow waiting for another flow. Although the WaitNextFlow
      # time is the time spent by a flow in the WaitNextFlow state, its also
      # equivalent to the entire timeline of another flow. It is the time spent in the
      # various states of another flow. In computing the total time spent in the
      # primary flow, one must omit the WaitNextFlow time, since it is already
      # included in the form of slices of individual state time intervals in the
      # aggregated time intervals for other states, and will result in double counting.
      class TrawlerFetchReplyDataFetchStats
        include Google::Apis::Core::Hashable
      
        # Overhead spent RPCing with the Bot/proxy.
        # Corresponds to the JSON property `BotOverheadMS`
        # @return [Fixnum]
        attr_accessor :bot_overhead_ms
      
        # Records stats about state changes on the client side if there're any. For
        # example, there's a state of cache lookup when using private-cache client
        # library.
        # Corresponds to the JSON property `ClientControlflowStats`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataFetchStatsClientStateStats]
        attr_accessor :client_controlflow_stats
      
        # Report only with first request on connection, so that we keep track of the
        # connect time with a host. Sometimes a connection is initiated by a prior
        # request that times out before the connection is established. Another request
        # can get scheduled on a connection that is already in the process of being
        # established but has no request scheduled onto it. We want to keep track of the
        # entire connect time even if a request didn't need to wait for the entire
        # connection establishment time. Sometimes a connection may get established
        # before the first request uses it. We tag along the connect time with the first
        # request using the connection. ConnectTimeMs also includes SSL negotiation time.
        # Corresponds to the JSON property `ConnectTimeMs`
        # @return [Fixnum]
        attr_accessor :connect_time_ms
      
        # The following are only populated if Params.WantStateStats is true.
        # Corresponds to the JSON property `ControlflowStats`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchReplyDataFetchStatsStateStats]
        attr_accessor :controlflow_stats
      
        # DownLoadTime = Share of connect time + ServerResponseTimeMs + TransferTimeMs (
        # see below) in ms
        # Corresponds to the JSON property `DownLoadTime`
        # @return [Fixnum]
        attr_accessor :down_load_time
      
        # Overhead spent routing the request from HOPE to edge egress nodes, which open
        # connection to webservers. This is only set for edge fetches (e.g., through
        # Floonet egress nodes).
        # Corresponds to the JSON property `EdgeEgressOverheadMs`
        # @return [Fixnum]
        attr_accessor :edge_egress_overhead_ms
      
        # ConnectTimeMs includes TCP connect time + SSL time, whereas SSLConnectTimeMs
        # includes only the latter.
        # Corresponds to the JSON property `SSLConnectTimeMs`
        # @return [Fixnum]
        attr_accessor :ssl_connect_time_ms
      
        # Time between the request send and the receipt of the first fragment of the
        # response. For HTTP responses the first fragment is the first fragment of the
        # response payload (the headers are ignored).
        # Corresponds to the JSON property `ServerResponseTimeMs`
        # @return [Fixnum]
        attr_accessor :server_response_time_ms
      
        # Time to receive the entire response payload starting the clock on receiving
        # the first fragment.
        # Corresponds to the JSON property `TransferTimeMs`
        # @return [Fixnum]
        attr_accessor :transfer_time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bot_overhead_ms = args[:bot_overhead_ms] if args.key?(:bot_overhead_ms)
          @client_controlflow_stats = args[:client_controlflow_stats] if args.key?(:client_controlflow_stats)
          @connect_time_ms = args[:connect_time_ms] if args.key?(:connect_time_ms)
          @controlflow_stats = args[:controlflow_stats] if args.key?(:controlflow_stats)
          @down_load_time = args[:down_load_time] if args.key?(:down_load_time)
          @edge_egress_overhead_ms = args[:edge_egress_overhead_ms] if args.key?(:edge_egress_overhead_ms)
          @ssl_connect_time_ms = args[:ssl_connect_time_ms] if args.key?(:ssl_connect_time_ms)
          @server_response_time_ms = args[:server_response_time_ms] if args.key?(:server_response_time_ms)
          @transfer_time_ms = args[:transfer_time_ms] if args.key?(:transfer_time_ms)
        end
      end
      
      # Records stats about state changes on the client side if there're any. For
      # example, there's a state of cache lookup when using private-cache client
      # library.
      class TrawlerFetchReplyDataFetchStatsClientStateStats
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `WaitContentCacheUsec`
        # @return [Fixnum]
        attr_accessor :wait_content_cache_usec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @wait_content_cache_usec = args[:wait_content_cache_usec] if args.key?(:wait_content_cache_usec)
        end
      end
      
      # The following are only populated if Params.WantStateStats is true.
      class TrawlerFetchReplyDataFetchStatsStateStats
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `EndTrackingTimeUsec`
        # @return [Fixnum]
        attr_accessor :end_tracking_time_usec
      
        # Start and end timestamp tracking the delays for this request.
        # Corresponds to the JSON property `StartTrackingTimeUsec`
        # @return [Fixnum]
        attr_accessor :start_tracking_time_usec
      
        # 
        # Corresponds to the JSON property `WaitCompressTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_compress_time_usec
      
        # 
        # Corresponds to the JSON property `WaitContentCacheUsec`
        # @return [Fixnum]
        attr_accessor :wait_content_cache_usec
      
        # 
        # Corresponds to the JSON property `WaitCredentialTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_credential_time_usec
      
        # 
        # Corresponds to the JSON property `WaitDNSTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_dns_time_usec
      
        # 
        # Corresponds to the JSON property `WaitFetchClientUsec`
        # @return [Fixnum]
        attr_accessor :wait_fetch_client_usec
      
        # 
        # Corresponds to the JSON property `WaitForCachedContentStreamingUsec`
        # @return [Fixnum]
        attr_accessor :wait_for_cached_content_streaming_usec
      
        # 
        # Corresponds to the JSON property `WaitForFetchUsec`
        # @return [Fixnum]
        attr_accessor :wait_for_fetch_usec
      
        # 
        # Corresponds to the JSON property `WaitHostIdTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_host_id_time_usec
      
        # 
        # Corresponds to the JSON property `WaitNextFlowUsec`
        # @return [Fixnum]
        attr_accessor :wait_next_flow_usec
      
        # obsolete. Not set.
        # Corresponds to the JSON property `WaitRobotsCacheTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_robots_cache_time_usec
      
        # obsolete. Not set.
        # Corresponds to the JSON property `WaitRobotsFetchTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_robots_fetch_time_usec
      
        # 
        # Corresponds to the JSON property `WaitRobotsTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_robots_time_usec
      
        # 
        # Corresponds to the JSON property `WaitScheduleTimeUsec`
        # @return [Fixnum]
        attr_accessor :wait_schedule_time_usec
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_tracking_time_usec = args[:end_tracking_time_usec] if args.key?(:end_tracking_time_usec)
          @start_tracking_time_usec = args[:start_tracking_time_usec] if args.key?(:start_tracking_time_usec)
          @wait_compress_time_usec = args[:wait_compress_time_usec] if args.key?(:wait_compress_time_usec)
          @wait_content_cache_usec = args[:wait_content_cache_usec] if args.key?(:wait_content_cache_usec)
          @wait_credential_time_usec = args[:wait_credential_time_usec] if args.key?(:wait_credential_time_usec)
          @wait_dns_time_usec = args[:wait_dns_time_usec] if args.key?(:wait_dns_time_usec)
          @wait_fetch_client_usec = args[:wait_fetch_client_usec] if args.key?(:wait_fetch_client_usec)
          @wait_for_cached_content_streaming_usec = args[:wait_for_cached_content_streaming_usec] if args.key?(:wait_for_cached_content_streaming_usec)
          @wait_for_fetch_usec = args[:wait_for_fetch_usec] if args.key?(:wait_for_fetch_usec)
          @wait_host_id_time_usec = args[:wait_host_id_time_usec] if args.key?(:wait_host_id_time_usec)
          @wait_next_flow_usec = args[:wait_next_flow_usec] if args.key?(:wait_next_flow_usec)
          @wait_robots_cache_time_usec = args[:wait_robots_cache_time_usec] if args.key?(:wait_robots_cache_time_usec)
          @wait_robots_fetch_time_usec = args[:wait_robots_fetch_time_usec] if args.key?(:wait_robots_fetch_time_usec)
          @wait_robots_time_usec = args[:wait_robots_time_usec] if args.key?(:wait_robots_time_usec)
          @wait_schedule_time_usec = args[:wait_schedule_time_usec] if args.key?(:wait_schedule_time_usec)
        end
      end
      
      # header : value
      class TrawlerFetchReplyDataHttpHeader
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `key`
        # @return [String]
        attr_accessor :key
      
        # 
        # Corresponds to the JSON property `value`
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # ----------------------------------------------------------------------
      # PartialResponse is used with streaming responses in LargeFileFetchAdapter.
      # Rather than fitting entirely in a single FetchReply, there is a series of
      # FetchReplies until IsFinalResponse. Each group of responses will have a unique
      # FetchID to link them.
      class TrawlerFetchReplyDataPartialResponse
        include Google::Apis::Core::Hashable
      
        # If set, indicates where the fetched body is, e.g. a CNS file path. FetchReply.
        # Body should be empty in this case. In the case where client does not support
        # streaming but the content is too large to be accumulated in memory, we keep
        # writing the streaming chunks to some storage unit and notify client when it is
        # done.
        # Corresponds to the JSON property `BodyLocation`
        # @return [String]
        attr_accessor :body_location
      
        # Fetch number in this series of fetches
        # Corresponds to the JSON property `ChunkNumber`
        # @return [Fixnum]
        attr_accessor :chunk_number
      
        # Parsed version of a Content-Range field, which in http might look like:
        # Content-Range: bytes 500-999/3156
        # Corresponds to the JSON property `ContentRange`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerContentRangeInfo]
        attr_accessor :content_range
      
        # Any ETag seen in the headers
        # Corresponds to the JSON property `ETag`
        # @return [String]
        attr_accessor :e_tag
      
        # ID which links all partial fetches for this url
        # Corresponds to the JSON property `FetchID`
        # @return [Fixnum]
        attr_accessor :fetch_id
      
        # Is this the final response for this fetch?
        # Corresponds to the JSON property `IsFinalResponse`
        # @return [Boolean]
        attr_accessor :is_final_response
        alias_method :is_final_response?, :is_final_response
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @body_location = args[:body_location] if args.key?(:body_location)
          @chunk_number = args[:chunk_number] if args.key?(:chunk_number)
          @content_range = args[:content_range] if args.key?(:content_range)
          @e_tag = args[:e_tag] if args.key?(:e_tag)
          @fetch_id = args[:fetch_id] if args.key?(:fetch_id)
          @is_final_response = args[:is_final_response] if args.key?(:is_final_response)
        end
      end
      
      # Group with protocol specific response (determined by the protocol of the url
      # that generated the content we return).
      class TrawlerFetchReplyDataProtocolResponse
        include Google::Apis::Core::Hashable
      
        # Response code. We emulate the HTTP response codes for all protocols that we
        # know. -- HTTP: response code for the downloaded page. -- FTP: similar with
        # HTTP: 200 - OK, 40X - errors (not found, etc), 500 - server unavailable
        # Corresponds to the JSON property `Code`
        # @return [Fixnum]
        attr_accessor :code
      
        # Content type as inferred by the fetcher (webutil/http/content-type.proto)
        # Corresponds to the JSON property `ContentType`
        # @return [String]
        attr_accessor :content_type
      
        # Where did we cut off? Includes headers plus truncated but uncompressed content.
        # Present if and only if we truncated the document.
        # Corresponds to the JSON property `CutoffSize`
        # @return [Fixnum]
        attr_accessor :cutoff_size
      
        # DEPRECATED, see field 113. Stores the HTTP version we used in the final hop.
        # Corresponds to the JSON property `HttpVersion`
        # @return [String]
        attr_accessor :http_version
      
        # DEPRECATED, see field 114. Whether we fallback from HTTP/2 to HTTP/1.1 during
        # fetch. The fallback could happen in any hops and there can be at most one
        # fallback because once fallback happens, we will not try HTTP/2 anymore.
        # Corresponds to the JSON property `ProtocolVersionFallback`
        # @return [Boolean]
        attr_accessor :protocol_version_fallback
        alias_method :protocol_version_fallback?, :protocol_version_fallback
      
        # The amount of data we got from the webserver before any truncation, but after
        # undoing any HTTP gzip/deflate encoding. For HTTP, this includes headers and
        # uncompressed content. Content size is excluded if content was not successfully
        # fetched. See description above TotalFetchedSize for comparison.
        # Corresponds to the JSON property `UnTruncatedSize`
        # @return [Fixnum]
        attr_accessor :un_truncated_size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @code = args[:code] if args.key?(:code)
          @content_type = args[:content_type] if args.key?(:content_type)
          @cutoff_size = args[:cutoff_size] if args.key?(:cutoff_size)
          @http_version = args[:http_version] if args.key?(:http_version)
          @protocol_version_fallback = args[:protocol_version_fallback] if args.key?(:protocol_version_fallback)
          @un_truncated_size = args[:un_truncated_size] if args.key?(:un_truncated_size)
        end
      end
      
      # The sequence of redirects fetched, if applicable. This includes url plus stats
      # for each hop after the first hop. NOTE: This can be one redirect longer than
      # the chain of redirects *followed*, in the case where there was a redirect at
      # the end of the chain that the fetcher detected but did not follow.
      class TrawlerFetchReplyDataRedirects
        include Google::Apis::Core::Hashable
      
        # The server SSL certificate chain in SSLCertificateInfo protobuf format. See
        # this field in FetchReplyData (i.e., the initial hop) for more description on
        # when it will be populated.
        # Corresponds to the JSON property `BadSSLCertificate`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :bad_ssl_certificate
      
        # This is similar to CrawlDates group in FetchReplyData, except that 1) it's a
        # message; 2) it's filled in each Redirects hop; and 3) the timestamps are in ms
        # rather than seconds since Unix Epoch.
        # Corresponds to the JSON property `CrawlTimes`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerCrawlTimes]
        attr_accessor :crawl_times
      
        # Download time of this fetch (ms)
        # Corresponds to the JSON property `DownloadTime`
        # @return [Fixnum]
        attr_accessor :download_time
      
        # To keep track of fetch connection endpoints. Note: You can use trawler::
        # SourceIP(info) or trawler::DestinationIP(info) (as well as HasSourceIP/
        # HasDestinationIP) in basictypes.h instead of accessing the packed strings
        # directly. This will return a proper IPAddress. Never use the fixed32 based
        # Source/Destination-IP in new code as they will go away (only IPv4).
        # Corresponds to the JSON property `Endpoints`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerTcpipInfo]
        attr_accessor :endpoints
      
        # This specifies if the url in a redirect was rewritten to HTTPS because of an
        # HSTS policy for the domain. See comments on FetchReplyData.HSTSInfo for how
        # this field's values. A redirect that was rewritten with HSTS will have
        # HSTS_STATUS_REWRITTEN ## here.
        # Corresponds to the JSON property `HSTSInfo`
        # @return [String]
        attr_accessor :hsts_info
      
        # The HTTP response code for this hop. We need this since multiple response
        # codes may have the same redirect type (e.g., 302 and 307 are both
        # REDIRECT_TEMPORARILY), but clients may want to know which one was received.
        # Note this is set only for the hops that are followed (i.e., TargetUrl is
        # present). If the last redirect hop was not followed the fetch status will be
        # URL_NOT_FOLLOWED, and the response code will be in the top level
        # ProtocolResponse field.
        # Corresponds to the JSON property `HTTPResponseCode`
        # @return [Fixnum]
        attr_accessor :http_response_code
      
        # Extra trawler::PageNoIndexInfo for this hop. Integer: ORed together bits from
        # trawler::PageNoIndexInfo. The information specified by this field comes from
        # the http header or content of the source url, not the "TargetUrl" in this
        # Redirects group.
        # Corresponds to the JSON property `HopPageNoIndexInfo`
        # @return [Fixnum]
        attr_accessor :hop_page_no_index_info
      
        # trawler::ReuseInfo with status of IMS/IMF/cache query, for this hop.
        # Corresponds to the JSON property `HopReuseInfo`
        # @return [String]
        attr_accessor :hop_reuse_info
      
        # Extra trawler::RobotsInfo for this hop. Integer: ORed together bits from
        # trawler::RobotsInfo
        # Corresponds to the JSON property `HopRobotsInfo`
        # @return [Fixnum]
        attr_accessor :hop_robots_info
      
        # If known, the hostid for this hop
        # Corresponds to the JSON property `HostId`
        # @return [Fixnum]
        attr_accessor :host_id
      
        # The http headers we sent for fetching this redirect hop. Not normally filled
        # in, unless FetchParams.WantSentHeaders is set.
        # Corresponds to the JSON property `HttpRequestHeaders`
        # @return [String]
        attr_accessor :http_request_headers
      
        # The http headers we received from this redirect hop. Trawler does not fill
        # this in; this is intended as a placeholder for crawls like webmirror that fill
        # in and want to track this across redirect hops.
        # Corresponds to the JSON property `HttpResponseHeaders`
        # @return [String]
        attr_accessor :http_response_headers
      
        # bytes: can contain bad encoding.
        # Corresponds to the JSON property `RawTargetUrl`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :raw_target_url
      
        # Refresh time in meta redirect tag
        # Corresponds to the JSON property `RefreshTime`
        # @return [Fixnum]
        attr_accessor :refresh_time
      
        # The robots.txt we used for this fetch. Not normally filled in unless
        # WantRobotsBody is set.
        # Corresponds to the JSON property `RobotsTxt`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :robots_txt
      
        # For meta-redirects, this field may contain the body of the source document.
        # Currently only filled client side and not implemented (yet) for server-side
        # redirects.
        # Corresponds to the JSON property `SourceBody`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerFetchBodyData]
        attr_accessor :source_body
      
        # Difference between the following two fields: TargetUrl is set when we have
        # followed the redirect target, and the url is canonicalized. RawTargetUrl is
        # set in either of the following two cases: (1) The url has not be been followed.
        # For example, the redirect is intended to be handled by the client. In the
        # fetch reply response, you will see the url's status as URL_NOT_FOLLOWED-
        # NOT_FOLLOWED*. (2) The extracted redirect url is different from its *
        # canonicalized* form. For example, if the target url contains fragments, then
        # this RawTargetUrl will have the fragments. Redirect target
        # Corresponds to the JSON property `TargetUrl`
        # @return [String]
        attr_accessor :target_url
      
        # URL and redirect type
        # Corresponds to the JSON property `Type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bad_ssl_certificate = args[:bad_ssl_certificate] if args.key?(:bad_ssl_certificate)
          @crawl_times = args[:crawl_times] if args.key?(:crawl_times)
          @download_time = args[:download_time] if args.key?(:download_time)
          @endpoints = args[:endpoints] if args.key?(:endpoints)
          @hsts_info = args[:hsts_info] if args.key?(:hsts_info)
          @http_response_code = args[:http_response_code] if args.key?(:http_response_code)
          @hop_page_no_index_info = args[:hop_page_no_index_info] if args.key?(:hop_page_no_index_info)
          @hop_reuse_info = args[:hop_reuse_info] if args.key?(:hop_reuse_info)
          @hop_robots_info = args[:hop_robots_info] if args.key?(:hop_robots_info)
          @host_id = args[:host_id] if args.key?(:host_id)
          @http_request_headers = args[:http_request_headers] if args.key?(:http_request_headers)
          @http_response_headers = args[:http_response_headers] if args.key?(:http_response_headers)
          @raw_target_url = args[:raw_target_url] if args.key?(:raw_target_url)
          @refresh_time = args[:refresh_time] if args.key?(:refresh_time)
          @robots_txt = args[:robots_txt] if args.key?(:robots_txt)
          @source_body = args[:source_body] if args.key?(:source_body)
          @target_url = args[:target_url] if args.key?(:target_url)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class TrawlerFetchStatus
        include Google::Apis::Core::Hashable
      
        # The Reason field gives further clarifying details about why or how the fetch
        # had the given outcome. For instance, if State is URL_ERROR - was it a 404/
        # NotFound or a DNS error? The Reason field is present iff State != URL_CRAWLED.
        # For a given crawl status of URL_FOO, the Reason value will be one of the
        # various FetchFooReason enum values from crawler/trawler/trawler_enums.proto
        # Corresponds to the JSON property `Reason`
        # @return [Fixnum]
        attr_accessor :reason
      
        # The State field describes the basic outcome of a fetch (URL_CRAWLED,
        # URL_ROBOTED, URL_ERROR, etc). The value is one of the UrlStatusType enum
        # values from crawler/trawler/trawler_enums.proto Note, there are several
        # combinations of this Status/Reason tuple that could mean that your content is
        # crawled or can be bucketed in a particular type of error. So instead of
        # comparing the enumeration values manually, we suggest to use the predicate
        # functions such as IsContentCrawled() provided in crawler/trawler/public/
        # basictypes.h (see details there).
        # Corresponds to the JSON property `State`
        # @return [String]
        attr_accessor :state
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @reason = args[:reason] if args.key?(:reason)
          @state = args[:state] if args.key?(:state)
        end
      end
      
      # ============================ Next Tag: 21 ============================ Data
      # about the scheduling host bucket a URL was in (if the client wants to use this,
      # e.g. for more intelligent scheduling, etc).
      class TrawlerHostBucketData
        include Google::Apis::Core::Hashable
      
        # How much existing traffic
        # Corresponds to the JSON property `ClientTrafficFraction`
        # @return [Float]
        attr_accessor :client_traffic_fraction
      
        # belong to the client How much weight the client
        # Corresponds to the JSON property `ClientWeightFraction`
        # @return [Float]
        attr_accessor :client_weight_fraction
      
        # How many connections are actively used for downloading ?
        # Corresponds to the JSON property `CurrentActiveConnections`
        # @return [Fixnum]
        attr_accessor :current_active_connections
      
        # Is this bucket currently full ?
        # Corresponds to the JSON property `IsFull`
        # @return [Boolean]
        attr_accessor :is_full
        alias_method :is_full?, :is_full
      
        # How many ms ago we last scheduled a url
        # Corresponds to the JSON property `LastScheduleIntervalMs`
        # @return [Fixnum]
        attr_accessor :last_schedule_interval_ms
      
        # The current hostload value (# of connections) - if negative does not apply
        # Corresponds to the JSON property `MaxActiveConnections`
        # @return [Float]
        attr_accessor :max_active_connections
      
        # The load the recent times (the actual hostload that we apply is
        # MaxActiveConnections / MediumTermLoad) - a hostload of 1.00 is normal, while
        # over 1.0 is higher than normal load
        # Corresponds to the JSON property `MediumTermLoad`
        # @return [Float]
        attr_accessor :medium_term_load
      
        # The min delay between requests (in secs) - if negative does not apply
        # Corresponds to the JSON property `MinInterRequestSecs`
        # @return [Float]
        attr_accessor :min_inter_request_secs
      
        # If is full, when is becoming non-full (in ms)
        # Corresponds to the JSON property `NonFullIntervalMs`
        # @return [Fixnum]
        attr_accessor :non_full_interval_ms
      
        # The following four fields attempt to make things simpler for clients to
        # estimate available capacity. They are not populated yet as of 2013/08/21. Even
        # after they are populated, they may change. So talk to trawler-dev@ before you
        # use the fields. Total qps for this hostid
        # Corresponds to the JSON property `TotalCapacityQps`
        # @return [Float]
        attr_accessor :total_capacity_qps
      
        # Currently used qps
        # Corresponds to the JSON property `TotalUsedQps`
        # @return [Float]
        attr_accessor :total_used_qps
      
        # 
        # Corresponds to the JSON property `urllist`
        # @return [Array<Google::Apis::ContentwarehouseV1::TrawlerHostBucketDataUrlList>]
        attr_accessor :urllist
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_traffic_fraction = args[:client_traffic_fraction] if args.key?(:client_traffic_fraction)
          @client_weight_fraction = args[:client_weight_fraction] if args.key?(:client_weight_fraction)
          @current_active_connections = args[:current_active_connections] if args.key?(:current_active_connections)
          @is_full = args[:is_full] if args.key?(:is_full)
          @last_schedule_interval_ms = args[:last_schedule_interval_ms] if args.key?(:last_schedule_interval_ms)
          @max_active_connections = args[:max_active_connections] if args.key?(:max_active_connections)
          @medium_term_load = args[:medium_term_load] if args.key?(:medium_term_load)
          @min_inter_request_secs = args[:min_inter_request_secs] if args.key?(:min_inter_request_secs)
          @non_full_interval_ms = args[:non_full_interval_ms] if args.key?(:non_full_interval_ms)
          @total_capacity_qps = args[:total_capacity_qps] if args.key?(:total_capacity_qps)
          @total_used_qps = args[:total_used_qps] if args.key?(:total_used_qps)
          @urllist = args[:urllist] if args.key?(:urllist)
        end
      end
      
      # Per each list that wishes to schedule url we return one of these:
      class TrawlerHostBucketDataUrlList
        include Google::Apis::Core::Hashable
      
        # Is this client/requestorid allowed to crawl now? (based on resource use)
        # Corresponds to the JSON property `ClientCanCrawl`
        # @return [Boolean]
        attr_accessor :client_can_crawl
        alias_method :client_can_crawl?, :client_can_crawl
      
        # Is this the 'default' user's list
        # Corresponds to the JSON property `IsDefaultNode`
        # @return [Boolean]
        attr_accessor :is_default_node
        alias_method :is_default_node?, :is_default_node
      
        # Was this the list that a given request landed in?
        # Corresponds to the JSON property `IsListForUrl`
        # @return [Boolean]
        attr_accessor :is_list_for_url
        alias_method :is_list_for_url?, :is_list_for_url
      
        # # of current active fetches
        # Corresponds to the JSON property `NumCurrentFetches`
        # @return [Fixnum]
        attr_accessor :num_current_fetches
      
        # # of urls currently in the queue
        # Corresponds to the JSON property `NumUrls`
        # @return [Fixnum]
        attr_accessor :num_urls
      
        # The type of the request (low latency vs. high throughput)
        # Corresponds to the JSON property `RequestType`
        # @return [String]
        attr_accessor :request_type
      
        # The fp64 of the requestor string
        # Corresponds to the JSON property `RequestorFp`
        # @return [Fixnum]
        attr_accessor :requestor_fp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_can_crawl = args[:client_can_crawl] if args.key?(:client_can_crawl)
          @is_default_node = args[:is_default_node] if args.key?(:is_default_node)
          @is_list_for_url = args[:is_list_for_url] if args.key?(:is_list_for_url)
          @num_current_fetches = args[:num_current_fetches] if args.key?(:num_current_fetches)
          @num_urls = args[:num_urls] if args.key?(:num_urls)
          @request_type = args[:request_type] if args.key?(:request_type)
          @requestor_fp = args[:requestor_fp] if args.key?(:requestor_fp)
        end
      end
      
      # Information about VPC fetches tracked for logging purposes.
      class TrawlerLoggedVpcDestination
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `cloudRegion`
        # @return [String]
        attr_accessor :cloud_region
      
        # Globally unique identifier for a virtual network.
        # Corresponds to the JSON property `vnid`
        # @return [Google::Apis::ContentwarehouseV1::NetFabricRpcVirtualNetworkId]
        attr_accessor :vnid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @cloud_region = args[:cloud_region] if args.key?(:cloud_region)
          @vnid = args[:vnid] if args.key?(:vnid)
        end
      end
      
      # Contain Multiverse client information, such as topic name. Can include other
      # information such as crawl policy id in the future.
      class TrawlerMultiverseClientIdentifier
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `topicName`
        # @return [String]
        attr_accessor :topic_name
      
        # 
        # Corresponds to the JSON property `trafficType`
        # @return [String]
        attr_accessor :traffic_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @topic_name = args[:topic_name] if args.key?(:topic_name)
          @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
        end
      end
      
      # The information about the original client who starts the request.
      class TrawlerOriginalClientParams
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `clientCell`
        # @return [String]
        attr_accessor :client_cell
      
        # 
        # Corresponds to the JSON property `clientIp`
        # @return [String]
        attr_accessor :client_ip
      
        # through which RPC request
        # Corresponds to the JSON property `clientRpcType`
        # @return [String]
        attr_accessor :client_rpc_type
      
        # 
        # Corresponds to the JSON property `clientUsername`
        # @return [String]
        attr_accessor :client_username
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @client_cell = args[:client_cell] if args.key?(:client_cell)
          @client_ip = args[:client_ip] if args.key?(:client_ip)
          @client_rpc_type = args[:client_rpc_type] if args.key?(:client_rpc_type)
          @client_username = args[:client_username] if args.key?(:client_username)
        end
      end
      
      # Trawler can add a policy label to a FetchReply. The two main cases are: - "
      # spam" label added for specific spammer IPs listed in trawler_site_info, which
      # most crawls auto-reject. - "roboted:useragent" (e.g. "roboted:googlebot") if
      # InfoOnlyUserAgents field is set in FetchParams
      class TrawlerPolicyData
        include Google::Apis::Core::Hashable
      
        # in roboted case, the RobotsInfo
        # Corresponds to the JSON property `ExtraData`
        # @return [Fixnum]
        attr_accessor :extra_data
      
        # "spam" or "roboted:googlebot"
        # Corresponds to the JSON property `Label`
        # @return [String]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @extra_data = args[:extra_data] if args.key?(:extra_data)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # This protobuf specifies the results of https certificate validation, typically
      # used for the BadSSLCertificate field in FetchReplyData. -----------------------
      # --- Next Tag: 13 -------------------------------
      class TrawlerSslCertificateInfo
        include Google::Apis::Core::Hashable
      
        # ALPN negotiated protocol, see https://tools.ietf.org/html/rfc7301 The value
        # will either be empty, or one of the protocol names sent by the client that the
        # server accepted. Examples include "h2" and "acme-tls/1".
        # Corresponds to the JSON property `ALPNNegotiatedProtocol`
        # @return [String]
        attr_accessor :alpn_negotiated_protocol
      
        # If present, this consists of the remote webserver's X.509 certificate chain in
        # DER format. The chain stored here is the *reversed* result of
        # SSL_get_peer_cert_chain(). That is to say, it is the chain presented by the
        # peer (which may differ from the chain that was built and verified), but in
        # leaf-last order. Typically the root cert will not be included. But do not
        # assume anything, because servers do all manner of weird things. (For example
        # on the beginning of the chain, there might be also some irrelevant
        # certificates besides the root certificate.) Certificates may be the empty
        # string, indicating an encoding failure. See also |IsTruncated|. Certs can be
        # loaded with util/sig/cert.h Cert::LoadBinaryCert(), converted to ASCII PEM
        # format (CertificateUtil::CertificateToPEM()) or shown as text at the
        # commandline by piping them into 'openssl x509 -text -inform DER'.
        # Corresponds to the JSON property `CertificateChain`
        # @return [Array<String>]
        attr_accessor :certificate_chain
      
        # ErrorMessages contains errors from HTTPS validation. Examples of such errors
        # include invalid certificates, failure to build a certificate chain,
        # certificates that do not match the expected hostname, and internal errors. If
        # ErrorMessages is empty, HTTPS validation succeeded. Otherwise, it failed. This
        # is the only guarantee about the contents of this field, though legacy code
        # exists that embeds invalid assumptions, b/70904498. New code should not do
        # anything with this field other than test whether it is empty and display its
        # value to humans. If you need to know more about the details of a particular
        # HTTPS validation, you can revalidate |CertificateChain| independently.
        # Corresponds to the JSON property `ErrorMessages`
        # @return [Array<String>]
        attr_accessor :error_messages
      
        # This SSLCertificateInfo had its fields truncated because it was too large. It
        # is no longer set (cl/205356251) but may be true in old records.
        # Corresponds to the JSON property `IsTruncated`
        # @return [Boolean]
        attr_accessor :is_truncated
        alias_method :is_truncated?, :is_truncated
      
        # Stapled OCSP response obtained during the TLS handshake, if any. An OCSP (
        # Online Certificate Status Protocol) response is an indication, signed by the
        # issuing CA, that the certificate has not been revoked. A TLS handshake
        # extension allows servers to "staple" a response to the certificate served in
        # the handshake, saving the need for the client to fetch it itself from the CA.
        # This field contain the stapled OCSP response if the server served one. See
        # RFC6066, Section 8 for the data format: https://tools.ietf.org/html/rfc6066#
        # section-8
        # Corresponds to the JSON property `OCSPResponse`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ocsp_response
      
        # SCTList obtained during the TLS handshake, if any. See RFC6962, Section 3.3
        # for the data format: https://tools.ietf.org/html/rfc6962#section-3.3
        # Corresponds to the JSON property `SCTList`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :sct_list
      
        # 
        # Corresponds to the JSON property `SSLCipherSuite`
        # @return [Fixnum]
        attr_accessor :ssl_cipher_suite
      
        # 
        # Corresponds to the JSON property `SSLCipherSuiteName`
        # @return [String]
        attr_accessor :ssl_cipher_suite_name
      
        # Details about the SSL/TLS protocol and cipher. See RFC5246 and google3/crawler/
        # trawler/hope/proto/ssl.proto for more details.
        # Corresponds to the JSON property `SSLProtocolVersion`
        # @return [Fixnum]
        attr_accessor :ssl_protocol_version
      
        # The names of the SSL protocol version and cipher suite. These strings are
        # implementation defined and may be subject to change.
        # Corresponds to the JSON property `SSLProtocolVersionName`
        # @return [String]
        attr_accessor :ssl_protocol_version_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alpn_negotiated_protocol = args[:alpn_negotiated_protocol] if args.key?(:alpn_negotiated_protocol)
          @certificate_chain = args[:certificate_chain] if args.key?(:certificate_chain)
          @error_messages = args[:error_messages] if args.key?(:error_messages)
          @is_truncated = args[:is_truncated] if args.key?(:is_truncated)
          @ocsp_response = args[:ocsp_response] if args.key?(:ocsp_response)
          @sct_list = args[:sct_list] if args.key?(:sct_list)
          @ssl_cipher_suite = args[:ssl_cipher_suite] if args.key?(:ssl_cipher_suite)
          @ssl_cipher_suite_name = args[:ssl_cipher_suite_name] if args.key?(:ssl_cipher_suite_name)
          @ssl_protocol_version = args[:ssl_protocol_version] if args.key?(:ssl_protocol_version)
          @ssl_protocol_version_name = args[:ssl_protocol_version_name] if args.key?(:ssl_protocol_version_name)
        end
      end
      
      # To keep track of fetch connection endpoints. Note: You can use trawler::
      # SourceIP(info) or trawler::DestinationIP(info) (as well as HasSourceIP/
      # HasDestinationIP) in basictypes.h instead of accessing the packed strings
      # directly. This will return a proper IPAddress. Never use the fixed32 based
      # Source/Destination-IP in new code as they will go away (only IPv4).
      class TrawlerTcpipInfo
        include Google::Apis::Core::Hashable
      
        # Address of the destination host. Extract with trawler::DestinationIP() or
        # decode with PackedStringToIPAddress().
        # Corresponds to the JSON property `DestinationIPAddressPacked`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :destination_ip_address_packed
      
        # 
        # Corresponds to the JSON property `DestinationPort`
        # @return [Fixnum]
        attr_accessor :destination_port
      
        # Source address of the crawl machine we originated the fetch from. Extract with
        # trawler::SourceIP() or decode with PackedStringToIPAddress().
        # Corresponds to the JSON property `SourceIPAddressPacked`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :source_ip_address_packed
      
        # 
        # Corresponds to the JSON property `SourcePort`
        # @return [Fixnum]
        attr_accessor :source_port
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @destination_ip_address_packed = args[:destination_ip_address_packed] if args.key?(:destination_ip_address_packed)
          @destination_port = args[:destination_port] if args.key?(:destination_port)
          @source_ip_address_packed = args[:source_ip_address_packed] if args.key?(:source_ip_address_packed)
          @source_port = args[:source_port] if args.key?(:source_port)
        end
      end
      
      # 
      class TrawlerThrottleClientData
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `IsBandwidthThrottle`
        # @return [Boolean]
        attr_accessor :is_bandwidth_throttle
        alias_method :is_bandwidth_throttle?, :is_bandwidth_throttle
      
        # Max doc_requestor urls/second allowed from this client to this fetcher.
        # Corresponds to the JSON property `MaxAllowedRate`
        # @return [Float]
        attr_accessor :max_allowed_rate
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_bandwidth_throttle = args[:is_bandwidth_throttle] if args.key?(:is_bandwidth_throttle)
          @max_allowed_rate = args[:max_allowed_rate] if args.key?(:max_allowed_rate)
        end
      end
      
      # This is an optional container of arbitrary data that can be added to a
      # FetchReplyData. This data is meant to be logged, but not sent back in a fetch
      # reply (it should be added *after* the reply is prepared). Use
      # FetchResponsePreparatorImpl::AddTrawlerPrivateDataToFetchReplyData to add. See
      # also the comment in fetch_response_preparator_impl.cc. Next Tag: 43
      class TrawlerTrawlerPrivateFetchReplyData
        include Google::Apis::Core::Hashable
      
        # If we fetched using BotFetchAgent, what is the BotGroupName?
        # Corresponds to the JSON property `BotGroupName`
        # @return [String]
        attr_accessor :bot_group_name
      
        # This is the HOPE server that we sent the url to. We log the HOPE backend cell
        # and hope server shard number (e.g., 'qf:6'). This allows us to understand how
        # we are balancing our load to the HOPE servers.
        # Corresponds to the JSON property `BotHostname`
        # @return [String]
        attr_accessor :bot_hostname
      
        # Present if the reply is from the trawler cache. This is the requestorid of the
        # trawler client that populated the cache with the data we are reusing.
        # Corresponds to the JSON property `CacheRequestorID`
        # @return [String]
        attr_accessor :cache_requestor_id
      
        # Which Trawler fetcher task fetched this URL.
        # Corresponds to the JSON property `FetcherTaskNumber`
        # @return [Fixnum]
        attr_accessor :fetcher_task_number
      
        # HTTP Strict-Transport-Security (RFC6797) header value. We log this so we can
        # generate a list of hosts that prefer HTTPS over HTTP.
        # Corresponds to the JSON property `HSTSHeaderValue`
        # @return [String]
        attr_accessor :hsts_header_value
      
        # 
        # Corresponds to the JSON property `HadInMemCacheHit`
        # @return [Boolean]
        attr_accessor :had_in_mem_cache_hit
        alias_method :had_in_mem_cache_hit?, :had_in_mem_cache_hit
      
        # If we do not have Endpoints in FetchReplyData (e.g., url rejected due to
        # hostload limit), do we have a guess of the server IPAddress (e.g., from robots
        # fetch)? This helps us classify URLs based on country code, etc. The field is
        # filled with IPAddress::ToPackedString().
        # Corresponds to the JSON property `HintIPAddress`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :hint_ip_address
      
        # Represents if the HostId belongs to HostId set in 5xx url patterns, it can
        # work as a tag when emitting requestor minute summary, this helps us to
        # aggregate traffic affected by 5xx patterns, and test if there are any fetching
        # changes.
        # Corresponds to the JSON property `Is5xxHostId`
        # @return [Boolean]
        attr_accessor :is5xx_host_id
        alias_method :is5xx_host_id?, :is5xx_host_id
      
        # Was this an internally-initiated robots.txt fetch?
        # Corresponds to the JSON property `IsRobotsFetch`
        # @return [Boolean]
        attr_accessor :is_robots_fetch
        alias_method :is_robots_fetch?, :is_robots_fetch
      
        # What's the post data size (in bytes) if it's a post request.
        # Corresponds to the JSON property `PostDataSize`
        # @return [Fixnum]
        attr_accessor :post_data_size
      
        # Note TrawlerPrivateFetchReplyData is never sent back to clients. The following
        # field is just for Trawler and Multiverse internal tracking, and clients should
        # not look at this field at all.
        # Corresponds to the JSON property `Producer`
        # @return [String]
        attr_accessor :producer
      
        # If set, this fetch was done through a proxy (e.g., fetchproxy).
        # Corresponds to the JSON property `ProxyInstance`
        # @return [String]
        attr_accessor :proxy_instance
      
        # Log the loas username in trawler private to help with debugging. Store the
        # username in trawler private so clients won't see it from FetchReply. To reduce
        # disk usage, we only log the loas username if the requestorid being used does
        # not have ClientUsernameRestrictions.
        # Corresponds to the JSON property `RequestUserName`
        # @return [String]
        attr_accessor :request_user_name
      
        # The number of bytes we sent back to the client.
        # Corresponds to the JSON property `ResponseBytes`
        # @return [Fixnum]
        attr_accessor :response_bytes
      
        # If this was a robots.txt fetch (IsRobotsFetch above), this may contain the
        # robots.txt body. (It may not, for instance, 404s are omitted; current policy
        # is URL_CRAWLED + partially crawled) This includes http headers + body.
        # Corresponds to the JSON property `RobotsBody`
        # @return [String]
        attr_accessor :robots_body
      
        # RPC deadline left at the end of url control flow. Can be useful for debugging
        # rpc deadline exceeded error received by clients, this field is only recorded
        # if it's small enough.
        # Corresponds to the JSON property `RpcEndDeadlineLeftMs`
        # @return [Fixnum]
        attr_accessor :rpc_end_deadline_left_ms
      
        # RPC deadline left at the start of url control flow. Can be useful for
        # debugging rpc deadline exceeded error received by clients, this field is only
        # recorded if RpcEndDeadlineLeftMs is small enough.
        # Corresponds to the JSON property `RpcStartDeadlineLeftMs`
        # @return [Fixnum]
        attr_accessor :rpc_start_deadline_left_ms
      
        # An arbitrary string signature identifying the remote server type/version. In
        # the case of HTTP, this would be the contents of the "Server:" header.
        # Corresponds to the JSON property `ServerSignature`
        # @return [String]
        attr_accessor :server_signature
      
        # Which Trawler cell was this response fetched in? (e.g. "HR" or "YQ")
        # Corresponds to the JSON property `TrawlerInstance`
        # @return [String]
        attr_accessor :trawler_instance
      
        # The useragent string sent to the remote webserver. It corresponds to
        # UserAgentToSend field in FetchParams.
        # Corresponds to the JSON property `UserAgentSent`
        # @return [String]
        attr_accessor :user_agent_sent
      
        # The fp2011 of useragent sent to the remote webserver, note it corresponds to
        # UserAgentToSend field in FetchParams
        # Corresponds to the JSON property `UserAgentSentFp`
        # @return [Fixnum]
        attr_accessor :user_agent_sent_fp
      
        # Stores the OAuth authentication method.
        # Corresponds to the JSON property `authenticationInfo`
        # @return [String]
        attr_accessor :authentication_info
      
        # Corresponds to AcceptableAfterDate field in FetchParams.
        # Corresponds to the JSON property `cacheAcceptableAfterDate`
        # @return [Fixnum]
        attr_accessor :cache_acceptable_after_date
      
        # Corresponds to AcceptableAge field in FetchParams.
        # Corresponds to the JSON property `cacheAcceptableAge`
        # @return [Fixnum]
        attr_accessor :cache_acceptable_age
      
        # Only set if the fetch uses cache content (is_cache_fetch is true).
        # Corresponds to the JSON property `cacheHitType`
        # @return [String]
        attr_accessor :cache_hit_type
      
        # 
        # Corresponds to the JSON property `cdnProvider`
        # @return [String]
        attr_accessor :cdn_provider
      
        # How many concurrent streams are on the connection when the request finishes (
        # including this request). Export this value to monitor the stream multiplexing
        # for HTTP/2.
        # Corresponds to the JSON property `concurrentStreamNum`
        # @return [Fixnum]
        attr_accessor :concurrent_stream_num
      
        # Dependent fetch type
        # Corresponds to the JSON property `dependentFetchType`
        # @return [String]
        attr_accessor :dependent_fetch_type
      
        # If the response header contains Content-Disposition header "attachment;
        # filename="google.zip": the download_file_name would be "google.zip"
        # Corresponds to the JSON property `downloadFileName`
        # @return [String]
        attr_accessor :download_file_name
      
        # Stores the HTTP version we used in the last hop.
        # Corresponds to the JSON property `httpVersion`
        # @return [String]
        attr_accessor :http_version
      
        # Whether this is a bidirectional streaming fetch.
        # Corresponds to the JSON property `isBidiStreamingFetch`
        # @return [Boolean]
        attr_accessor :is_bidi_streaming_fetch
        alias_method :is_bidi_streaming_fetch?, :is_bidi_streaming_fetch
      
        # Whether or not this is a Floonet fetch request. Floonet requests have inherent
        # lower availability (due to HOPE rejections when HOPE is in degraded mode, and
        # other Floonet specific reasons). Therefore, it is important for debugging and
        # for our availability SLO to know whether of not it is a floonet fetch.
        # IMPORTANT NOTE: This field is only currently set for traffic that explicitly
        # requires Floonet and can not failover to use Googlebot (i.e. "transparent" or "
        # implicit" Floonet fetches).
        # Corresponds to the JSON property `isFloonetFetch`
        # @return [Boolean]
        attr_accessor :is_floonet_fetch
        alias_method :is_floonet_fetch?, :is_floonet_fetch
      
        # Whether or not this response is sent from gRPC proxy service.
        # Corresponds to the JSON property `isFromGrpcProxy`
        # @return [Boolean]
        attr_accessor :is_from_grpc_proxy
        alias_method :is_from_grpc_proxy?, :is_from_grpc_proxy
      
        # Set if the fetch goes through the virtual private cloud path so we can track
        # the VPC traffic.
        # Corresponds to the JSON property `isVpcTraffic`
        # @return [Boolean]
        attr_accessor :is_vpc_traffic
        alias_method :is_vpc_traffic?, :is_vpc_traffic
      
        # Set to the hit location (CNS filename) if cache comes from large store.
        # Corresponds to the JSON property `largeStoreHitLocation`
        # @return [String]
        attr_accessor :large_store_hit_location
      
        # Contain Multiverse client information, such as topic name. Can include other
        # information such as crawl policy id in the future.
        # Corresponds to the JSON property `multiverseClientIdentifier`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerMultiverseClientIdentifier]
        attr_accessor :multiverse_client_identifier
      
        # Number of times we drop the content of a stream reply or the final reply,
        # which can only be caused by REJECTED_NO_RPC_BUFFERS now.
        # Corresponds to the JSON property `numDroppedReplies`
        # @return [Fixnum]
        attr_accessor :num_dropped_replies
      
        # The information about the original client who starts the request.
        # Corresponds to the JSON property `originalClientParams`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerOriginalClientParams]
        attr_accessor :original_client_params
      
        # If the requestor shares resource bucket with other requestorids, we will store
        # the resource bucket name in these fields.
        # Corresponds to the JSON property `resourceBucket`
        # @return [String]
        attr_accessor :resource_bucket
      
        # 
        # Corresponds to the JSON property `subResourceBucket`
        # @return [String]
        attr_accessor :sub_resource_bucket
      
        # Service tier info will be used in traffic grapher for ploting per tier graph.
        # Corresponds to the JSON property `tier`
        # @return [String]
        attr_accessor :tier
      
        # Information about VPC fetches tracked for logging purposes.
        # Corresponds to the JSON property `vpcDestination`
        # @return [Google::Apis::ContentwarehouseV1::TrawlerLoggedVpcDestination]
        attr_accessor :vpc_destination
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bot_group_name = args[:bot_group_name] if args.key?(:bot_group_name)
          @bot_hostname = args[:bot_hostname] if args.key?(:bot_hostname)
          @cache_requestor_id = args[:cache_requestor_id] if args.key?(:cache_requestor_id)
          @fetcher_task_number = args[:fetcher_task_number] if args.key?(:fetcher_task_number)
          @hsts_header_value = args[:hsts_header_value] if args.key?(:hsts_header_value)
          @had_in_mem_cache_hit = args[:had_in_mem_cache_hit] if args.key?(:had_in_mem_cache_hit)
          @hint_ip_address = args[:hint_ip_address] if args.key?(:hint_ip_address)
          @is5xx_host_id = args[:is5xx_host_id] if args.key?(:is5xx_host_id)
          @is_robots_fetch = args[:is_robots_fetch] if args.key?(:is_robots_fetch)
          @post_data_size = args[:post_data_size] if args.key?(:post_data_size)
          @producer = args[:producer] if args.key?(:producer)
          @proxy_instance = args[:proxy_instance] if args.key?(:proxy_instance)
          @request_user_name = args[:request_user_name] if args.key?(:request_user_name)
          @response_bytes = args[:response_bytes] if args.key?(:response_bytes)
          @robots_body = args[:robots_body] if args.key?(:robots_body)
          @rpc_end_deadline_left_ms = args[:rpc_end_deadline_left_ms] if args.key?(:rpc_end_deadline_left_ms)
          @rpc_start_deadline_left_ms = args[:rpc_start_deadline_left_ms] if args.key?(:rpc_start_deadline_left_ms)
          @server_signature = args[:server_signature] if args.key?(:server_signature)
          @trawler_instance = args[:trawler_instance] if args.key?(:trawler_instance)
          @user_agent_sent = args[:user_agent_sent] if args.key?(:user_agent_sent)
          @user_agent_sent_fp = args[:user_agent_sent_fp] if args.key?(:user_agent_sent_fp)
          @authentication_info = args[:authentication_info] if args.key?(:authentication_info)
          @cache_acceptable_after_date = args[:cache_acceptable_after_date] if args.key?(:cache_acceptable_after_date)
          @cache_acceptable_age = args[:cache_acceptable_age] if args.key?(:cache_acceptable_age)
          @cache_hit_type = args[:cache_hit_type] if args.key?(:cache_hit_type)
          @cdn_provider = args[:cdn_provider] if args.key?(:cdn_provider)
          @concurrent_stream_num = args[:concurrent_stream_num] if args.key?(:concurrent_stream_num)
          @dependent_fetch_type = args[:dependent_fetch_type] if args.key?(:dependent_fetch_type)
          @download_file_name = args[:download_file_name] if args.key?(:download_file_name)
          @http_version = args[:http_version] if args.key?(:http_version)
          @is_bidi_streaming_fetch = args[:is_bidi_streaming_fetch] if args.key?(:is_bidi_streaming_fetch)
          @is_floonet_fetch = args[:is_floonet_fetch] if args.key?(:is_floonet_fetch)
          @is_from_grpc_proxy = args[:is_from_grpc_proxy] if args.key?(:is_from_grpc_proxy)
          @is_vpc_traffic = args[:is_vpc_traffic] if args.key?(:is_vpc_traffic)
          @large_store_hit_location = args[:large_store_hit_location] if args.key?(:large_store_hit_location)
          @multiverse_client_identifier = args[:multiverse_client_identifier] if args.key?(:multiverse_client_identifier)
          @num_dropped_replies = args[:num_dropped_replies] if args.key?(:num_dropped_replies)
          @original_client_params = args[:original_client_params] if args.key?(:original_client_params)
          @resource_bucket = args[:resource_bucket] if args.key?(:resource_bucket)
          @sub_resource_bucket = args[:sub_resource_bucket] if args.key?(:sub_resource_bucket)
          @tier = args[:tier] if args.key?(:tier)
          @vpc_destination = args[:vpc_destination] if args.key?(:vpc_destination)
        end
      end
      
      # Information about the result support for a given interpretation.
      class UniversalsearchNewPackerKnowledgeResultSupport
        include Google::Apis::Core::Hashable
      
        # A debug message that summarizes how the score was computed. Populated if
        # result was matched and in debug mode.
        # Corresponds to the JSON property `debug`
        # @return [String]
        attr_accessor :debug
      
        # The docid of the result, if available.
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # The naviness for this result. Each matcher can determine the naviness to use
        # for the result. This can be copied directly from the result, or estimated
        # based on clicks or some other heuristic. The value should be between 0 and 1
        # and should indicate the probability that the user will click on that result.
        # The estimated_naviness is used to break ties when between results with the
        # same rank.
        # Corresponds to the JSON property `estimatedNaviness`
        # @return [Float]
        attr_accessor :estimated_naviness
      
        # All provenances of this result support.
        # Corresponds to the JSON property `provenance`
        # @return [Array<Google::Apis::ContentwarehouseV1::UniversalsearchNewPackerKnowledgeResultSupportProvenance>]
        attr_accessor :provenance
      
        # The 0 based rank for this result. When the source is MAIN_GSR this corresponds
        # to the index of the result in the generic search response specific in
        # AddKnowledgePackerPreprocessors. Otherwise, the rank should be estimated so
        # the result is closest in importance to the web result at the same rank.
        # Corresponds to the JSON property `rank`
        # @return [Fixnum]
        attr_accessor :rank
      
        # A score from 0 to 1 inclusive that represents the strength of the result
        # support. A score of one indicates this result is entirely about this
        # interpretation.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # The source of the result support.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The result url when available.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug = args[:debug] if args.key?(:debug)
          @docid = args[:docid] if args.key?(:docid)
          @estimated_naviness = args[:estimated_naviness] if args.key?(:estimated_naviness)
          @provenance = args[:provenance] if args.key?(:provenance)
          @rank = args[:rank] if args.key?(:rank)
          @score = args[:score] if args.key?(:score)
          @source = args[:source] if args.key?(:source)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Information about provenance of a result support.
      class UniversalsearchNewPackerKnowledgeResultSupportProvenance
        include Google::Apis::Core::Hashable
      
        # Entity group type of the supported entity. This field should only be set for
        # support on entities.
        # Corresponds to the JSON property `entityGroupType`
        # @return [String]
        attr_accessor :entity_group_type
      
        # ===== Deprecated Fields ===== The bool flag indicating whether the
        # ResultSupport comes from answer entities.
        # Corresponds to the JSON property `fromAnswer`
        # @return [Boolean]
        attr_accessor :from_answer
        alias_method :from_answer?, :from_answer
      
        # The provenance provider name.
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_group_type = args[:entity_group_type] if args.key?(:entity_group_type)
          @from_answer = args[:from_answer] if args.key?(:from_answer)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # Url poisoning information. This information is sparse: if num_spam_siblings is
      # not populated, none of the following fields will be populated. Next tag: 6
      class UrlPoisoningData
        include Google::Apis::Core::Hashable
      
        # fetched from the web. Time when the page was last
        # Corresponds to the JSON property `NotChangedTimeMs`
        # @return [Fixnum]
        attr_accessor :not_changed_time_ms
      
        # Time when the page was
        # Corresponds to the JSON property `OriginalCrawlTimeMs`
        # @return [Fixnum]
        attr_accessor :original_crawl_time_ms
      
        # checked but found to be the same as before. If set, timestamp to indicate
        # Corresponds to the JSON property `ReuseTimeMs`
        # @return [Fixnum]
        attr_accessor :reuse_time_ms
      
        # 
        # Corresponds to the JSON property `numSpamSiblings`
        # @return [Fixnum]
        attr_accessor :num_spam_siblings
      
        # when it is fetched from the repository. URL of the document for debugging
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @not_changed_time_ms = args[:not_changed_time_ms] if args.key?(:not_changed_time_ms)
          @original_crawl_time_ms = args[:original_crawl_time_ms] if args.key?(:original_crawl_time_ms)
          @reuse_time_ms = args[:reuse_time_ms] if args.key?(:reuse_time_ms)
          @num_spam_siblings = args[:num_spam_siblings] if args.key?(:num_spam_siblings)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # Wire-format for a Status object
      class UtilStatusProto
        include Google::Apis::Core::Hashable
      
        # The canonical error code (see codes.proto) that most closely corresponds to
        # this status. May be missing.
        # Corresponds to the JSON property `canonicalCode`
        # @return [Fixnum]
        attr_accessor :canonical_code
      
        # Numeric code drawn from the space specified below. Often, this is the
        # canonical error space, and code is drawn from google3/util/task/codes.proto
        # Corresponds to the JSON property `code`
        # @return [Fixnum]
        attr_accessor :code
      
        # Detail message
        # Corresponds to the JSON property `message`
        # @return [String]
        attr_accessor :message
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `messageSet`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :message_set
      
        # The following are usually only present when code != 0 Space to which this
        # status belongs
        # Corresponds to the JSON property `space`
        # @return [String]
        attr_accessor :space
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
          @code = args[:code] if args.key?(:code)
          @message = args[:message] if args.key?(:message)
          @message_set = args[:message_set] if args.key?(:message_set)
          @space = args[:space] if args.key?(:space)
        end
      end
      
      # ------------------------------------------------------------------------------
      # Proto message containing the trusted genome entities that belong to an app.
      # Document type: ANDROID_APP See go/gd-server-design for more info. ## Next tag:
      # 4
      class VendingConsumerProtoTrustedGenomeAnnotation
        include Google::Apis::Core::Hashable
      
        # Proto message containing policy related information.
        # Corresponds to the JSON property `policy`
        # @return [Google::Apis::ContentwarehouseV1::VendingConsumerProtoTrustedGenomePolicy]
        attr_accessor :policy
      
        # The list of test code, used to log when serving. The test code is set in both
        # control and experiment annotations when they are different.
        # Corresponds to the JSON property `testCode`
        # @return [Array<String>]
        attr_accessor :test_code
      
        # The list of trusted genome hierarchy. One trusted_genome_hierarchy may contain
        # one or multiple entities. This is required for TG 2.0 tags.
        # Corresponds to the JSON property `trustedGenomeHierarchy`
        # @return [Array<Google::Apis::ContentwarehouseV1::VendingConsumerProtoTrustedGenomeHierarchy>]
        attr_accessor :trusted_genome_hierarchy
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @policy = args[:policy] if args.key?(:policy)
          @test_code = args[:test_code] if args.key?(:test_code)
          @trusted_genome_hierarchy = args[:trusted_genome_hierarchy] if args.key?(:trusted_genome_hierarchy)
        end
      end
      
      # Proto message containing the id, localized title, score, and hierarchy level
      # of a trusted genome entity.
      class VendingConsumerProtoTrustedGenomeEntity
        include Google::Apis::Core::Hashable
      
        # The category id matching this trusted genome entity. e.g. Action tag with id /
        # m/025zzc matches category of id GAME_ACTION
        # Corresponds to the JSON property `categoryId`
        # @return [String]
        attr_accessor :category_id
      
        # The identifier of a play trusted genome entity. Required.
        # Corresponds to the JSON property `id`
        # @return [String]
        attr_accessor :id
      
        # The level of the entity. E.g. in hierarchy like Action -> Platformer > Endless
        # Runner. Action is level 1, Platformer is level 2 and Endless Runner is level 3.
        # Currently, only APP_TAXONOMY and GAME_TAXONOMY type may have the levels. For
        # entity that does not have hierarchy, its level is 1. Required.
        # Corresponds to the JSON property `level`
        # @return [Fixnum]
        attr_accessor :level
      
        # The localized query string for this trusted genome entity. This query will be
        # used when we want to bring users to SERP on click.
        # Corresponds to the JSON property `queryText`
        # @return [String]
        attr_accessor :query_text
      
        # The confidence score of the entity to the app.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # The localized title. Required.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # This boolean is used to decide whether this entity will be shown on user-
        # facing features in the Store or not.
        # Corresponds to the JSON property `userVisible`
        # @return [Boolean]
        attr_accessor :user_visible
        alias_method :user_visible?, :user_visible
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category_id = args[:category_id] if args.key?(:category_id)
          @id = args[:id] if args.key?(:id)
          @level = args[:level] if args.key?(:level)
          @query_text = args[:query_text] if args.key?(:query_text)
          @score = args[:score] if args.key?(:score)
          @title = args[:title] if args.key?(:title)
          @user_visible = args[:user_visible] if args.key?(:user_visible)
        end
      end
      
      # Proto message containing one or multiple trusted genome entity. This is used
      # to capture entities that belong to the same type and have parent-children
      # relationship in the taxonomy. e.g. One hierarchy may include 3 entities with
      # Game_Taxonomy Type: (1) Action (Level 1) (2) Platformer (Level 2 under Action)
      # (3) Endless Runner (Level 3 under Platformer) e.g. One hierarchy may also
      # include only 1 entity with Game_Graphic_Style: (1) Anime (No level information)
      # Next ID: 5
      class VendingConsumerProtoTrustedGenomeHierarchy
        include Google::Apis::Core::Hashable
      
        # List of entities (one or multiple) that belong in the same hierarchy. The
        # entries will be ordered such that the first entry will be of level 1, and the
        # second entry will be of level 2, and so on. Required
        # Corresponds to the JSON property `entity`
        # @return [Array<Google::Apis::ContentwarehouseV1::VendingConsumerProtoTrustedGenomeEntity>]
        attr_accessor :entity
      
        # The (hierarchy-level) type of this Trusted Genome hierarchy. Will only be
        # populated when meeting certain criteria, e.g. 'GD2_Game_Main' means this
        # hierarchy of entities can serve as the main game genre for Game Discovery 2.0.
        # Corresponds to the JSON property `hierarchyType`
        # @return [String]
        attr_accessor :hierarchy_type
      
        # The source of this Trusted Genome hierarchy.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        # The (entity-level) type of trusted genome entities in this hierarchy. Required.
        # Corresponds to the JSON property `trustedGenomeType`
        # @return [String]
        attr_accessor :trusted_genome_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity = args[:entity] if args.key?(:entity)
          @hierarchy_type = args[:hierarchy_type] if args.key?(:hierarchy_type)
          @source = args[:source] if args.key?(:source)
          @trusted_genome_type = args[:trusted_genome_type] if args.key?(:trusted_genome_type)
        end
      end
      
      # Proto message containing policy related information.
      class VendingConsumerProtoTrustedGenomePolicy
        include Google::Apis::Core::Hashable
      
        # Override text for region for special treatment. Override will be used in
        # special cases for example regions are too long to show in UI, the override
        # will be "CA/NV/..." to cut it short. By keeping a region override string we'll
        # have more flexibility to adjust what we show on UI. Optional.
        # Corresponds to the JSON property `localizedRegionOverride`
        # @return [String]
        attr_accessor :localized_region_override
      
        # Policy type. e.g. Government Endorsed, Apollo Required.
        # Corresponds to the JSON property `policyType`
        # @return [Array<String>]
        attr_accessor :policy_type
      
        # Contains target region for the current policy. Optional
        # Corresponds to the JSON property `targetRegion`
        # @return [Array<Google::Apis::ContentwarehouseV1::VendingConsumerProtoTrustedGenomePolicyTargetRegion>]
        attr_accessor :target_region
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @localized_region_override = args[:localized_region_override] if args.key?(:localized_region_override)
          @policy_type = args[:policy_type] if args.key?(:policy_type)
          @target_region = args[:target_region] if args.key?(:target_region)
        end
      end
      
      # 
      class VendingConsumerProtoTrustedGenomePolicyTargetRegion
        include Google::Apis::Core::Hashable
      
        # Localized name for targeted regions. e.g. San Francisco Bay Area Required.
        # Corresponds to the JSON property `localizedRegion`
        # @return [String]
        attr_accessor :localized_region
      
        # Associated KG entity mid for region. e.g. /m/06pvr
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @localized_region = args[:localized_region] if args.key?(:localized_region)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # 
      class VideoAmbisonicsAmbisonicsMetadata
        include Google::Apis::Core::Hashable
      
        # Maps channel indexes of an audio stream to indexes corresponding to the
        # specified ambisonics channel ordering scheme. For example: A 1st order
        # pheriphonic ambisonics format is configured with 4 audio channels
        # corresponding to ambisonic components W, X, Y, Z respectively. The
        # channel_ordering scheme is specified as CHANNEL_ORDERING_ACN (which implies a
        # W, Y, Z, X ordering). Therefore the channel_map is [0, 3, 1, 2].
        # Corresponds to the JSON property `channelMap`
        # @return [Array<Fixnum>]
        attr_accessor :channel_map
      
        # 
        # Corresponds to the JSON property `channelOrdering`
        # @return [String]
        attr_accessor :channel_ordering
      
        # 
        # Corresponds to the JSON property `nonDiegeticStereo`
        # @return [Boolean]
        attr_accessor :non_diegetic_stereo
        alias_method :non_diegetic_stereo?, :non_diegetic_stereo
      
        # 
        # Corresponds to the JSON property `normalization`
        # @return [String]
        attr_accessor :normalization
      
        # 
        # Corresponds to the JSON property `numChannels`
        # @return [Fixnum]
        attr_accessor :num_channels
      
        # 
        # Corresponds to the JSON property `order`
        # @return [Fixnum]
        attr_accessor :order
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `version`
        # @return [Fixnum]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channel_map = args[:channel_map] if args.key?(:channel_map)
          @channel_ordering = args[:channel_ordering] if args.key?(:channel_ordering)
          @non_diegetic_stereo = args[:non_diegetic_stereo] if args.key?(:non_diegetic_stereo)
          @normalization = args[:normalization] if args.key?(:normalization)
          @num_channels = args[:num_channels] if args.key?(:num_channels)
          @order = args[:order] if args.key?(:order)
          @type = args[:type] if args.key?(:type)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Valid fields in ACL are "mdb/groupname", or "user/username", e.g., "mdb/
      # youtube-prod", or "user/alice".
      class VideoAssetsVenomAcl
        include Google::Apis::Core::Hashable
      
        # REQUIRED: the current owner of this video. Please note that owner does not get
        # implicit reader/writer access. You must set them explicitly.
        # Corresponds to the JSON property `owner`
        # @return [String]
        attr_accessor :owner
      
        # Allowed readers of this video.
        # Corresponds to the JSON property `reader`
        # @return [Array<String>]
        attr_accessor :reader
      
        # Allowed writers of this video.
        # Corresponds to the JSON property `writer`
        # @return [Array<String>]
        attr_accessor :writer
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @owner = args[:owner] if args.key?(:owner)
          @reader = args[:reader] if args.key?(:reader)
          @writer = args[:writer] if args.key?(:writer)
        end
      end
      
      # Describes ingredient level settings. Clients are authoritative in defining
      # Settings. See go/venom-trustme for how Settings and ProcessingCharacteristics
      # work together. If your Settings extension contains PII fields, please 1)
      # Annotate them appropriately with DataPol, and 2) Add your BUILD target to
      # google3/video/assets/venom/proto/settings/BUILD:pii See google3/video/assets/
      # venom/proto/settings/ for extension messages.
      class VideoAssetsVenomSettings
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # As video mutations are reconciled by Venom, we can tell if the ingredient did
      # or did not reach certain objectives. When processing has completed, all
      # objectives will have a corresponding transition. All transitions are reset for
      # every mutation, but will take into account assets outside of that mutation.
      # For example, if Asset X fails, and was part of "OBJECTIVE_PRIMARY_ASSETS_DONE",
      # a rerun of Asset Y is destined to result in OUTCOME_FAILED, regardless of the
      # fate of Asset Y. Some phenonema have effects on most or all Objectives. For
      # example, a bad input file will result on OUTCOME_INFEASIBLE across the board (
      # eventually, for now it's just GO_LIVE and DO_ALL, work in progress), and a
      # failure to produce Format 18 will cause OUTCOME_FAILED across most Objectives.
      class VideoAssetsVenomTransition
        include Google::Apis::Core::Hashable
      
        # The objective this transition is about. REQUIRED.
        # Corresponds to the JSON property `objective`
        # @return [String]
        attr_accessor :objective
      
        # Whether the objective is reached or not. REQUIRED.
        # Corresponds to the JSON property `outcome`
        # @return [String]
        attr_accessor :outcome
      
        # An optional debug string indicating the reason for this transition. This is
        # typically omitted for OUTCOME_SUCCESS. e.g. "The video's content is invalid
        # due to failed blobstore cloning."
        # Corresponds to the JSON property `reason`
        # @return [String]
        attr_accessor :reason
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @objective = args[:objective] if args.key?(:objective)
          @outcome = args[:outcome] if args.key?(:outcome)
          @reason = args[:reason] if args.key?(:reason)
        end
      end
      
      # A VideoId is the unique identifier of a video. Privacy: VideoIds are visible
      # in logs, notifications, etc and must not contain PII.
      class VideoAssetsVenomVideoId
        include Google::Apis::Core::Hashable
      
        # REQUIRED. IDs have some constraints: - 32 bytes max: this is enforced by the
        # server - for the time being, must be parseable as a youtube ID (basically a
        # base64-encoded string which maps to a 64-bit integer). This restriction will
        # eventually be lifted.
        # Corresponds to the JSON property `id`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :id
      
        # LINT.ThenChange( //depot/google3/googledata/production/playbooks/video-assets/
        # clients.md ) REQUIRED.
        # Corresponds to the JSON property `ns`
        # @return [String]
        attr_accessor :ns
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @id = args[:id] if args.key?(:id)
          @ns = args[:ns] if args.key?(:ns)
        end
      end
      
      # Next tag: 10
      class VideoAudioStream
        include Google::Apis::Core::Hashable
      
        # Audio bitrate in bits/s.
        # Corresponds to the JSON property `bitrate`
        # @return [Fixnum]
        attr_accessor :bitrate
      
        # Number of audio channels.
        # Corresponds to the JSON property `channels`
        # @return [Fixnum]
        attr_accessor :channels
      
        # Audio codec ID. Uses the numeric value corresponding to the CodecId enum
        # object, in order to avoid the dependency on vsi/videostreaminfo.proto. http://
        # cs/symbol:CodecId%20f:google3/video/vidproc/vsi/videostreaminfo.proto
        # Corresponds to the JSON property `codecId`
        # @return [Fixnum]
        attr_accessor :codec_id
      
        # Content type of the stream. Only populated with valid "acont" xtag values at
        # the moment. Supported acont xtag values can be found in google3/video/storage/
        # common/xtag_validation.cc. Examples: "original", "dubbed", "descriptive", "
        # commentary", etc.
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # Language, examples: "eng", "en", "enG", etc.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # Audio length, in seconds. This value is derived from metadata in the source
        # video, and often differs from the actual duration of any given transcode. In
        # videos without valid timestamps, this value is not calculable, and is reported
        # as zero.
        # Corresponds to the JSON property `lengthSec`
        # @return [Float]
        attr_accessor :length_sec
      
        # 
        # Corresponds to the JSON property `loudness1770Lkfs`
        # @return [Float]
        attr_accessor :loudness1770_lkfs
      
        # Audio sample rate.
        # Corresponds to the JSON property `sampleRate`
        # @return [Fixnum]
        attr_accessor :sample_rate
      
        # Index of the stream in the file, 0-based.
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bitrate = args[:bitrate] if args.key?(:bitrate)
          @channels = args[:channels] if args.key?(:channels)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @content_type = args[:content_type] if args.key?(:content_type)
          @language = args[:language] if args.key?(:language)
          @length_sec = args[:length_sec] if args.key?(:length_sec)
          @loudness1770_lkfs = args[:loudness1770_lkfs] if args.key?(:loudness1770_lkfs)
          @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
        end
      end
      
      # Generic clip information contains a key string and a value string.
      class VideoClipInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `key`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :key
      
        # 
        # Corresponds to the JSON property `value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @key = args[:key] if args.key?(:key)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # 
      class VideoClosedCaptions
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `videoHasClosedCaptions`
        # @return [Boolean]
        attr_accessor :video_has_closed_captions
        alias_method :video_has_closed_captions?, :video_has_closed_captions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @video_has_closed_captions = args[:video_has_closed_captions] if args.key?(:video_has_closed_captions)
        end
      end
      
      # Contains anchor level features that apply to all anchor types. Next id: 18.
      class VideoContentSearchAnchorCommonFeatureSet
        include Google::Apis::Core::Hashable
      
        # QBST distance between the anchor and the top navboost query of the video if
        # exists, or the video title otherwise.
        # Corresponds to the JSON property `anchorQbstDistance`
        # @return [Float]
        attr_accessor :anchor_qbst_distance
      
        # Contains features needed for Bleurt inference.
        # Corresponds to the JSON property `bleurtFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchBleurtFeatures]
        attr_accessor :bleurt_features
      
        # The Bleurt inference score generated using the bleurt_features.
        # Corresponds to the JSON property `bleurtScore`
        # @return [Float]
        attr_accessor :bleurt_score
      
        # Descartes similarity score between video title and anchor label.
        # Corresponds to the JSON property `descartesScoreWithTitle`
        # @return [Float]
        attr_accessor :descartes_score_with_title
      
        # The predicted descriptiveness and usefulness rating scores generated by the
        # Unified Dolphin model. Rating template: experimental/video/
        # video_anchors_oneside_without_thumbnail/template.jhtml
        # Corresponds to the JSON property `dolphinDescriptivenessScore`
        # @return [Float]
        attr_accessor :dolphin_descriptiveness_score
      
        # If the dolphin model is an ensemble model, this contains the scores associated
        # to each individual ensemble model.
        # Corresponds to the JSON property `dolphinEnsembleScore`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchDolphinEnsembleScore>]
        attr_accessor :dolphin_ensemble_score
      
        # The features used to generate the Dolphin score.
        # Corresponds to the JSON property `dolphinFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchDolphinFeatures]
        attr_accessor :dolphin_features
      
        # The score generated by the Dolphin callout model.
        # Corresponds to the JSON property `dolphinScore`
        # @return [Float]
        attr_accessor :dolphin_score
      
        # 
        # Corresponds to the JSON property `dolphinUsefulnessScore`
        # @return [Float]
        attr_accessor :dolphin_usefulness_score
      
        # A phrase embedding for the anchor label. The model used to generate the
        # embedding can be found in VideoAnchorSets: video_score_info.common_features.
        # label_phrase_embedding_model
        # Corresponds to the JSON property `labelPhraseEmbedding`
        # @return [Array<Float>]
        attr_accessor :label_phrase_embedding
      
        # The predicted descriptiveness of the anchor using the MUM unified scoring
        # model.
        # Corresponds to the JSON property `mumDescriptivenessScore`
        # @return [Float]
        attr_accessor :mum_descriptiveness_score
      
        # The predicted usefulness of the anchor using the MUM unified scoring model.
        # Corresponds to the JSON property `mumUsefulnessScore`
        # @return [Float]
        attr_accessor :mum_usefulness_score
      
        # A score that is correlated with retention probability of the interval
        # associated with this anchor (start time to end time). Retention probability of
        # an interval is 1 - (probability the user does not watch the interval all the
        # way through, given they started watching it). This score may be predicted by a
        # model, or calculated from actual retention data.
        # Corresponds to the JSON property `retentionScore`
        # @return [Float]
        attr_accessor :retention_score
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `saftDocument`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :saft_document
      
        # For annotating labels and their timing and context info. For example, this is
        # used for anchor labels within a passage.
        # Corresponds to the JSON property `timedLabelFeatures`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionLabelFeatures>]
        attr_accessor :timed_label_features
      
        # 
        # Corresponds to the JSON property `timestamp`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorCommonFeatureSetLabelSpanTimestamp>]
        attr_accessor :timestamp
      
        # Babel similarity between the anchor and the video title.
        # Corresponds to the JSON property `titleAnchorBabelMatchScore`
        # @return [Float]
        attr_accessor :title_anchor_babel_match_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_qbst_distance = args[:anchor_qbst_distance] if args.key?(:anchor_qbst_distance)
          @bleurt_features = args[:bleurt_features] if args.key?(:bleurt_features)
          @bleurt_score = args[:bleurt_score] if args.key?(:bleurt_score)
          @descartes_score_with_title = args[:descartes_score_with_title] if args.key?(:descartes_score_with_title)
          @dolphin_descriptiveness_score = args[:dolphin_descriptiveness_score] if args.key?(:dolphin_descriptiveness_score)
          @dolphin_ensemble_score = args[:dolphin_ensemble_score] if args.key?(:dolphin_ensemble_score)
          @dolphin_features = args[:dolphin_features] if args.key?(:dolphin_features)
          @dolphin_score = args[:dolphin_score] if args.key?(:dolphin_score)
          @dolphin_usefulness_score = args[:dolphin_usefulness_score] if args.key?(:dolphin_usefulness_score)
          @label_phrase_embedding = args[:label_phrase_embedding] if args.key?(:label_phrase_embedding)
          @mum_descriptiveness_score = args[:mum_descriptiveness_score] if args.key?(:mum_descriptiveness_score)
          @mum_usefulness_score = args[:mum_usefulness_score] if args.key?(:mum_usefulness_score)
          @retention_score = args[:retention_score] if args.key?(:retention_score)
          @saft_document = args[:saft_document] if args.key?(:saft_document)
          @timed_label_features = args[:timed_label_features] if args.key?(:timed_label_features)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
          @title_anchor_babel_match_score = args[:title_anchor_babel_match_score] if args.key?(:title_anchor_babel_match_score)
        end
      end
      
      # When an anchor label has a long duration (for example, labels that contain
      # multiple sentences), this field stores the mapping between label segments and
      # the start time.
      class VideoContentSearchAnchorCommonFeatureSetLabelSpanTimestamp
        include Google::Apis::Core::Hashable
      
        # The ASR confidence for the label span, if available.
        # Corresponds to the JSON property `asrConfidence`
        # @return [Float]
        attr_accessor :asr_confidence
      
        # Whether or not this token is the first token in a sentence.
        # Corresponds to the JSON property `isSentenceStart`
        # @return [Boolean]
        attr_accessor :is_sentence_start
        alias_method :is_sentence_start?, :is_sentence_start
      
        # The character index range for the span. The end index is exclusive.
        # Corresponds to the JSON property `labelBeginCharIndex`
        # @return [Fixnum]
        attr_accessor :label_begin_char_index
      
        # 
        # Corresponds to the JSON property `labelEndCharIndex`
        # @return [Fixnum]
        attr_accessor :label_end_char_index
      
        # The time of the span.
        # Corresponds to the JSON property `timeMs`
        # @return [Fixnum]
        attr_accessor :time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_confidence = args[:asr_confidence] if args.key?(:asr_confidence)
          @is_sentence_start = args[:is_sentence_start] if args.key?(:is_sentence_start)
          @label_begin_char_index = args[:label_begin_char_index] if args.key?(:label_begin_char_index)
          @label_end_char_index = args[:label_end_char_index] if args.key?(:label_end_char_index)
          @time_ms = args[:time_ms] if args.key?(:time_ms)
        end
      end
      
      # Properties of the thumbnail image to show for an anchor.
      class VideoContentSearchAnchorThumbnail
        include Google::Apis::Core::Hashable
      
        # Serving docid for the thumbnail in the images-tbn tables.
        # Corresponds to the JSON property `imagesearchDocid`
        # @return [Fixnum]
        attr_accessor :imagesearch_docid
      
        # Set to true when no thumbnail could be generated for this anchor.
        # Corresponds to the JSON property `isThumbnailMissing`
        # @return [Boolean]
        attr_accessor :is_thumbnail_missing
        alias_method :is_thumbnail_missing?, :is_thumbnail_missing
      
        # Next ID: 15
        # Corresponds to the JSON property `servingMetadata`
        # @return [Google::Apis::ContentwarehouseV1::ImageBaseThumbnailMetadata]
        attr_accessor :serving_metadata
      
        # Information about the thumbnail anchor.
        # Corresponds to the JSON property `thumbnailInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorThumbnailInfo]
        attr_accessor :thumbnail_info
      
        # Millisecond timestamp of the frame used for the thumbnail.
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @imagesearch_docid = args[:imagesearch_docid] if args.key?(:imagesearch_docid)
          @is_thumbnail_missing = args[:is_thumbnail_missing] if args.key?(:is_thumbnail_missing)
          @serving_metadata = args[:serving_metadata] if args.key?(:serving_metadata)
          @thumbnail_info = args[:thumbnail_info] if args.key?(:thumbnail_info)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
        end
      end
      
      # 
      class VideoContentSearchAnchorThumbnailInfo
        include Google::Apis::Core::Hashable
      
        # Entropy of the clustered color distribution.
        # Corresponds to the JSON property `colorEntropy`
        # @return [Float]
        attr_accessor :color_entropy
      
        # This defines the per-doc data which is extracted from thumbnails and
        # propagated over to indexing. It contains all information that can be used for
        # restricts. Next tag id: 127
        # Corresponds to the JSON property `imageData`
        # @return [Google::Apis::ContentwarehouseV1::ImageData]
        attr_accessor :image_data
      
        # Convenience field that consolidates signals for whether this thumbnail is safe.
        # Corresponds to the JSON property `isUnsafe`
        # @return [Boolean]
        attr_accessor :is_unsafe
        alias_method :is_unsafe?, :is_unsafe
      
        # 64d float vector of starburst v4 embedings.
        # Corresponds to the JSON property `starburstV4Embedding`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiDenseFeatureData]
        attr_accessor :starburst_v4_embedding
      
        # The raw data for a thumbnail.
        # Corresponds to the JSON property `thumbnailBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :thumbnail_bytes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @color_entropy = args[:color_entropy] if args.key?(:color_entropy)
          @image_data = args[:image_data] if args.key?(:image_data)
          @is_unsafe = args[:is_unsafe] if args.key?(:is_unsafe)
          @starburst_v4_embedding = args[:starburst_v4_embedding] if args.key?(:starburst_v4_embedding)
          @thumbnail_bytes = args[:thumbnail_bytes] if args.key?(:thumbnail_bytes)
        end
      end
      
      # Contains anchor set level features that apply to all anchor types.
      class VideoContentSearchAnchorsCommonFeatureSet
        include Google::Apis::Core::Hashable
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `dolphinDescriptivenessStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :dolphin_descriptiveness_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `dolphinUsefulnessStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :dolphin_usefulness_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `mumDescriptivenessStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :mum_descriptiveness_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `mumUsefulnessStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :mum_usefulness_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dolphin_descriptiveness_stats = args[:dolphin_descriptiveness_stats] if args.key?(:dolphin_descriptiveness_stats)
          @dolphin_usefulness_stats = args[:dolphin_usefulness_stats] if args.key?(:dolphin_usefulness_stats)
          @mum_descriptiveness_stats = args[:mum_descriptiveness_stats] if args.key?(:mum_descriptiveness_stats)
          @mum_usefulness_stats = args[:mum_usefulness_stats] if args.key?(:mum_usefulness_stats)
        end
      end
      
      # 
      class VideoContentSearchAnchorsThumbnailInfo
        include Google::Apis::Core::Hashable
      
        # Whether or not any of the anchor thumbnails have missing Starburst embeddings.
        # Corresponds to the JSON property `hasMissingStarburst`
        # @return [Boolean]
        attr_accessor :has_missing_starburst
        alias_method :has_missing_starburst?, :has_missing_starburst
      
        # Whether or not any of the anchors have missing thumbnails.
        # Corresponds to the JSON property `hasMissingThumbnails`
        # @return [Boolean]
        attr_accessor :has_missing_thumbnails
        alias_method :has_missing_thumbnails?, :has_missing_thumbnails
      
        # A score representing how diverse a set of thumbnails is. This is currently
        # defined as one minus the median pairwise cosine similarity between thumbnail
        # Starburst embeddings.
        # Corresponds to the JSON property `thumbnailDiversity`
        # @return [Float]
        attr_accessor :thumbnail_diversity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_missing_starburst = args[:has_missing_starburst] if args.key?(:has_missing_starburst)
          @has_missing_thumbnails = args[:has_missing_thumbnails] if args.key?(:has_missing_thumbnails)
          @thumbnail_diversity = args[:thumbnail_diversity] if args.key?(:thumbnail_diversity)
        end
      end
      
      # Product aspect.
      class VideoContentSearchAspect
        include Google::Apis::Core::Hashable
      
        # Product aspect to be used if non of the other aspects exist.
        # Corresponds to the JSON property `fallbackAspect`
        # @return [String]
        attr_accessor :fallback_aspect
      
        # Product aspect produced by running SAFT annotation.
        # Corresponds to the JSON property `saftAspect`
        # @return [String]
        attr_accessor :saft_aspect
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @fallback_aspect = args[:fallback_aspect] if args.key?(:fallback_aspect)
          @saft_aspect = args[:saft_aspect] if args.key?(:saft_aspect)
        end
      end
      
      # Contains token-level information about ASR captions.
      class VideoContentSearchAsrCaption
        include Google::Apis::Core::Hashable
      
        # The confidence score of the token: between 0 and 1.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # The duration that the token is spoken for.
        # Corresponds to the JSON property `durationMs`
        # @return [Float]
        attr_accessor :duration_ms
      
        # The time in the video at which the token starts being spoken.
        # Corresponds to the JSON property `startTimeMs`
        # @return [Fixnum]
        attr_accessor :start_time_ms
      
        # The speech token.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Contains features needed for Bleurt inference.
      class VideoContentSearchBleurtFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `candidate`
        # @return [String]
        attr_accessor :candidate
      
        # 
        # Corresponds to the JSON property `reference`
        # @return [String]
        attr_accessor :reference
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @candidate = args[:candidate] if args.key?(:candidate)
          @reference = args[:reference] if args.key?(:reference)
        end
      end
      
      # Features and debug info for individual caption entity video anchors.
      class VideoContentSearchCaptionEntityAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # If the description anchor has been recognized as an entity and that entity has
        # also been mention in the ASR, this is the mention text from the ASR.
        # Corresponds to the JSON property `asrMentionText`
        # @return [String]
        attr_accessor :asr_mention_text
      
        # The start index of the ASR entity mention from the beginning of the ASR
        # transcript. The index is included so that individual mentions that share the
        # same mid and time can be distinguished which happens when an entity is
        # mentioned multiple times in an ASR sentence. Each mid/
        # asr_mention_transcript_offset will be unique.
        # Corresponds to the JSON property `asrMentionTranscriptOffset`
        # @return [Fixnum]
        attr_accessor :asr_mention_transcript_offset
      
        # The nearest ASR sentence.
        # Corresponds to the JSON property `asrSentence`
        # @return [String]
        attr_accessor :asr_sentence
      
        # The begin time in ms of the ASR sentence.
        # Corresponds to the JSON property `asrStartTime`
        # @return [Fixnum]
        attr_accessor :asr_start_time
      
        # The result of the BERT inference using the title, ASR sentence and entity
        # mention text.
        # Corresponds to the JSON property `bertScores`
        # @return [Array<Float>]
        attr_accessor :bert_scores
      
        # A score to help determine how specific this entity is.
        # Corresponds to the JSON property `broadness`
        # @return [Float]
        attr_accessor :broadness
      
        # The percentage of the video covered by the span of the first mention to the
        # last mention.
        # Corresponds to the JSON property `durationCoverage`
        # @return [Float]
        attr_accessor :duration_coverage
      
        # The webref connectedness score of the entity.
        # Corresponds to the JSON property `entityConnectedness`
        # @return [Float]
        attr_accessor :entity_connectedness
      
        # A short text describing the entity.
        # Corresponds to the JSON property `entityDescription`
        # @return [String]
        attr_accessor :entity_description
      
        # Contains information about document appearances of an entity.
        # Corresponds to the JSON property `entityInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionEntityDocInfo]
        attr_accessor :entity_info
      
        # Whether or not the entity mention text appears in the description of the video.
        # Corresponds to the JSON property `entityMentionInDescription`
        # @return [Boolean]
        attr_accessor :entity_mention_in_description
        alias_method :entity_mention_in_description?, :entity_mention_in_description
      
        # The estimated begin time in ms of the entity mention using the text offset
        # divided by the ASR duration.
        # Corresponds to the JSON property `estimatedMentionTime`
        # @return [Fixnum]
        attr_accessor :estimated_mention_time
      
        # Average similarity between this anchor and other anchors in the set.
        # Corresponds to the JSON property `groupCohesion`
        # @return [Float]
        attr_accessor :group_cohesion
      
        # The confidence of the hypernym used as the set label.
        # Corresponds to the JSON property `hypernymConfidence`
        # @return [Float]
        attr_accessor :hypernym_confidence
      
        # Number of hypernyms used for calculating similarity.
        # Corresponds to the JSON property `hypernymCount`
        # @return [Float]
        attr_accessor :hypernym_count
      
        # The cosine similarity between the document salient terms and the hyperpedia
        # hypernyms for a given entity.
        # Corresponds to the JSON property `hyperpediaSalientTermsSimilarity`
        # @return [Float]
        attr_accessor :hyperpedia_salient_terms_similarity
      
        # Whether or not this entity is in the webref entities.
        # Corresponds to the JSON property `inWebrefEntities`
        # @return [Boolean]
        attr_accessor :in_webref_entities
        alias_method :in_webref_entities?, :in_webref_entities
      
        # True if the given entity appears as an Oracle followup query.
        # Corresponds to the JSON property `isOracleEntity`
        # @return [Boolean]
        attr_accessor :is_oracle_entity
        alias_method :is_oracle_entity?, :is_oracle_entity
      
        # Whether this entity counts as a 'product' for the purpose of dividing entities
        # between the 'related topics' and 'products in this video' features.
        # Corresponds to the JSON property `isProduct`
        # @return [Boolean]
        attr_accessor :is_product
        alias_method :is_product?, :is_product
      
        # The maximum confidence of all of the entity mentions in the transcript.
        # Corresponds to the JSON property `maxMentionConfidence`
        # @return [Float]
        attr_accessor :max_mention_confidence
      
        # The confidence that the ASR mention matches the given mid.
        # Corresponds to the JSON property `mentionConfidence`
        # @return [Float]
        attr_accessor :mention_confidence
      
        # Number of times an entity is mentioned in the ASR transcript.
        # Corresponds to the JSON property `mentions`
        # @return [Fixnum]
        attr_accessor :mentions
      
        # The duration in ms between this anchor and the previous anchor or the
        # beginning of the video if this is the first anchor.
        # Corresponds to the JSON property `msFromLastAnchor`
        # @return [Fixnum]
        attr_accessor :ms_from_last_anchor
      
        # The ASR sentence after asr_sentence or "" if it is the last sentence.
        # Corresponds to the JSON property `nextAsrSentence`
        # @return [String]
        attr_accessor :next_asr_sentence
      
        # The ASR text of each mention of the entity.
        # Corresponds to the JSON property `otherAsrMentionText`
        # @return [Array<String>]
        attr_accessor :other_asr_mention_text
      
        # Each time the entity was mentioned.
        # Corresponds to the JSON property `otherEstimatedMentionTimes`
        # @return [Array<Fixnum>]
        attr_accessor :other_estimated_mention_times
      
        # The ASR sentence before asr_sentence or "" if it is the first sentence.
        # Corresponds to the JSON property `previousAsrSentence`
        # @return [String]
        attr_accessor :previous_asr_sentence
      
        # The confidence that the ASR mention is a trusted name.
        # Corresponds to the JSON property `trustedNameConfidence`
        # @return [Float]
        attr_accessor :trusted_name_confidence
      
        # The webref entity topicality score if the entity is a webref entity and 0 if
        # not.
        # Corresponds to the JSON property `webrefEntityTopicality`
        # @return [Float]
        attr_accessor :webref_entity_topicality
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_mention_text = args[:asr_mention_text] if args.key?(:asr_mention_text)
          @asr_mention_transcript_offset = args[:asr_mention_transcript_offset] if args.key?(:asr_mention_transcript_offset)
          @asr_sentence = args[:asr_sentence] if args.key?(:asr_sentence)
          @asr_start_time = args[:asr_start_time] if args.key?(:asr_start_time)
          @bert_scores = args[:bert_scores] if args.key?(:bert_scores)
          @broadness = args[:broadness] if args.key?(:broadness)
          @duration_coverage = args[:duration_coverage] if args.key?(:duration_coverage)
          @entity_connectedness = args[:entity_connectedness] if args.key?(:entity_connectedness)
          @entity_description = args[:entity_description] if args.key?(:entity_description)
          @entity_info = args[:entity_info] if args.key?(:entity_info)
          @entity_mention_in_description = args[:entity_mention_in_description] if args.key?(:entity_mention_in_description)
          @estimated_mention_time = args[:estimated_mention_time] if args.key?(:estimated_mention_time)
          @group_cohesion = args[:group_cohesion] if args.key?(:group_cohesion)
          @hypernym_confidence = args[:hypernym_confidence] if args.key?(:hypernym_confidence)
          @hypernym_count = args[:hypernym_count] if args.key?(:hypernym_count)
          @hyperpedia_salient_terms_similarity = args[:hyperpedia_salient_terms_similarity] if args.key?(:hyperpedia_salient_terms_similarity)
          @in_webref_entities = args[:in_webref_entities] if args.key?(:in_webref_entities)
          @is_oracle_entity = args[:is_oracle_entity] if args.key?(:is_oracle_entity)
          @is_product = args[:is_product] if args.key?(:is_product)
          @max_mention_confidence = args[:max_mention_confidence] if args.key?(:max_mention_confidence)
          @mention_confidence = args[:mention_confidence] if args.key?(:mention_confidence)
          @mentions = args[:mentions] if args.key?(:mentions)
          @ms_from_last_anchor = args[:ms_from_last_anchor] if args.key?(:ms_from_last_anchor)
          @next_asr_sentence = args[:next_asr_sentence] if args.key?(:next_asr_sentence)
          @other_asr_mention_text = args[:other_asr_mention_text] if args.key?(:other_asr_mention_text)
          @other_estimated_mention_times = args[:other_estimated_mention_times] if args.key?(:other_estimated_mention_times)
          @previous_asr_sentence = args[:previous_asr_sentence] if args.key?(:previous_asr_sentence)
          @trusted_name_confidence = args[:trusted_name_confidence] if args.key?(:trusted_name_confidence)
          @webref_entity_topicality = args[:webref_entity_topicality] if args.key?(:webref_entity_topicality)
        end
      end
      
      # Features and debug info for clusters of caption entity video anchors.
      class VideoContentSearchCaptionEntityAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # The total score used for filtering and selecting entity sets.
        # Corresponds to the JSON property `aggregateScore`
        # @return [Float]
        attr_accessor :aggregate_score
      
        # The prefiltered size of the entity set.
        # Corresponds to the JSON property `clusterSize`
        # @return [Fixnum]
        attr_accessor :cluster_size
      
        # The number of entities in the anchor set that are in the webref entities.
        # Corresponds to the JSON property `entitiesInWebrefEntities`
        # @return [Fixnum]
        attr_accessor :entities_in_webref_entities
      
        # The number of anchors where the entity mention text appears in the description
        # of the video.
        # Corresponds to the JSON property `entityMentionInDescriptionCount`
        # @return [Boolean]
        attr_accessor :entity_mention_in_description_count
        alias_method :entity_mention_in_description_count?, :entity_mention_in_description_count
      
        # The average cosine similarity between hypernyms of members of the set.
        # Corresponds to the JSON property `groupCohesion`
        # @return [Float]
        attr_accessor :group_cohesion
      
        # The most prominent hypernym across the entities in the set.
        # Corresponds to the JSON property `hypernym`
        # @return [String]
        attr_accessor :hypernym
      
        # The salience of the best hypernym for the set.
        # Corresponds to the JSON property `hypernymSalience`
        # @return [Float]
        attr_accessor :hypernym_salience
      
        # Median number of times any member of the set was mentioned in the ASR
        # transcript.
        # Corresponds to the JSON property `medianMentions`
        # @return [Fixnum]
        attr_accessor :median_mentions
      
        # Mentions divided by the total number of entity mentions in the video.
        # Corresponds to the JSON property `mentionSalience`
        # @return [Float]
        attr_accessor :mention_salience
      
        # Salience of the set computed by aggregating the hypernyms from each member and
        # calculating the cosine similarity with the salient terms.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        # The top N hypernyms for the entities in the set.
        # Corresponds to the JSON property `topHypernym`
        # @return [Array<String>]
        attr_accessor :top_hypernym
      
        # Number of times any member of the group was mentioned in the ASR transcript.
        # Corresponds to the JSON property `totalMentions`
        # @return [Fixnum]
        attr_accessor :total_mentions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregate_score = args[:aggregate_score] if args.key?(:aggregate_score)
          @cluster_size = args[:cluster_size] if args.key?(:cluster_size)
          @entities_in_webref_entities = args[:entities_in_webref_entities] if args.key?(:entities_in_webref_entities)
          @entity_mention_in_description_count = args[:entity_mention_in_description_count] if args.key?(:entity_mention_in_description_count)
          @group_cohesion = args[:group_cohesion] if args.key?(:group_cohesion)
          @hypernym = args[:hypernym] if args.key?(:hypernym)
          @hypernym_salience = args[:hypernym_salience] if args.key?(:hypernym_salience)
          @median_mentions = args[:median_mentions] if args.key?(:median_mentions)
          @mention_salience = args[:mention_salience] if args.key?(:mention_salience)
          @salience = args[:salience] if args.key?(:salience)
          @top_hypernym = args[:top_hypernym] if args.key?(:top_hypernym)
          @total_mentions = args[:total_mentions] if args.key?(:total_mentions)
        end
      end
      
      # Contains information about document appearances of an entity.
      class VideoContentSearchCaptionEntityDocInfo
        include Google::Apis::Core::Hashable
      
        # The number of documents where this entity was mentioned at least once.
        # Corresponds to the JSON property `entityDocCount`
        # @return [Fixnum]
        attr_accessor :entity_doc_count
      
        # The number of times the entity was mentioned across the entire corpus.
        # Corresponds to the JSON property `entityMentionCount`
        # @return [Fixnum]
        attr_accessor :entity_mention_count
      
        # The entity id.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The number of documents in the corpus.
        # Corresponds to the JSON property `totalDocCount`
        # @return [Fixnum]
        attr_accessor :total_doc_count
      
        # The number of mentions of any entity across the entire corpus.
        # Corresponds to the JSON property `totalMentionCount`
        # @return [Fixnum]
        attr_accessor :total_mention_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_doc_count = args[:entity_doc_count] if args.key?(:entity_doc_count)
          @entity_mention_count = args[:entity_mention_count] if args.key?(:entity_mention_count)
          @mid = args[:mid] if args.key?(:mid)
          @total_doc_count = args[:total_doc_count] if args.key?(:total_doc_count)
          @total_mention_count = args[:total_mention_count] if args.key?(:total_mention_count)
        end
      end
      
      # Contains transcript-level data about a video whether it comes from ASR or
      # closed captions.
      class VideoContentSearchCaptionInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `asrCaption`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchAsrCaption>]
        attr_accessor :asr_caption
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `saftDocument`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :saft_document
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_caption = args[:asr_caption] if args.key?(:asr_caption)
          @saft_document = args[:saft_document] if args.key?(:saft_document)
        end
      end
      
      # Contains timing and text for a given label.
      class VideoContentSearchCaptionLabelFeatures
        include Google::Apis::Core::Hashable
      
        # OCR anchors with overlapping time-window with this anchor
        # Corresponds to the JSON property `alignedOcrTexts`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchOcrText>]
        attr_accessor :aligned_ocr_texts
      
        # The time stamp in milliseconds for the reference text (e.g. description anchor
        # time).
        # Corresponds to the JSON property `alignedTime`
        # @return [Fixnum]
        attr_accessor :aligned_time
      
        # Text around the aligned_time of a long duration, say [-15 minutes, +15 minutes]
        # Corresponds to the JSON property `contextText`
        # @return [String]
        attr_accessor :context_text
      
        # The main label text for the feature.
        # Corresponds to the JSON property `labelText`
        # @return [String]
        attr_accessor :label_text
      
        # Identified matching text by similarity.
        # Corresponds to the JSON property `textSimilarityFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchTextSimilarityFeatures]
        attr_accessor :text_similarity_features
      
        # The text span in the passage starting from the aligned time.
        # Corresponds to the JSON property `textSpanAtAlignedTime`
        # @return [String]
        attr_accessor :text_span_at_aligned_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aligned_ocr_texts = args[:aligned_ocr_texts] if args.key?(:aligned_ocr_texts)
          @aligned_time = args[:aligned_time] if args.key?(:aligned_time)
          @context_text = args[:context_text] if args.key?(:context_text)
          @label_text = args[:label_text] if args.key?(:label_text)
          @text_similarity_features = args[:text_similarity_features] if args.key?(:text_similarity_features)
          @text_span_at_aligned_time = args[:text_span_at_aligned_time] if args.key?(:text_span_at_aligned_time)
        end
      end
      
      # 
      class VideoContentSearchCaptionSpanAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The features used to construct the inference example.
        # Corresponds to the JSON property `dolphinFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchSpanDolphinFeatures]
        attr_accessor :dolphin_features
      
        # The inference result from the Dolphin span model.
        # Corresponds to the JSON property `dolphinScores`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchSpanDolphinScores]
        attr_accessor :dolphin_scores
      
        # Embedding distances (e.g. cosine distance) to the other anchors of the same
        # video.
        # Corresponds to the JSON property `embeddingDistance`
        # @return [Array<Float>]
        attr_accessor :embedding_distance
      
        # Time gap in ms to the next anchor. Always positive number.
        # Corresponds to the JSON property `postGapInMs`
        # @return [Fixnum]
        attr_accessor :post_gap_in_ms
      
        # Time gap in ms to the previous anchor. Always a positive number.
        # Corresponds to the JSON property `preGapInMs`
        # @return [Fixnum]
        attr_accessor :pre_gap_in_ms
      
        # The range of tokens in video_info.saft_doc for the anchor label.
        # Corresponds to the JSON property `saftBeginTokenIndex`
        # @return [Fixnum]
        attr_accessor :saft_begin_token_index
      
        # 
        # Corresponds to the JSON property `saftEndTokenIndex`
        # @return [Fixnum]
        attr_accessor :saft_end_token_index
      
        # 
        # Corresponds to the JSON property `saftTranscriptEndCharOffset`
        # @return [Fixnum]
        attr_accessor :saft_transcript_end_char_offset
      
        # The range of characters in video_info.saft_transcript for the anchor label.
        # Corresponds to the JSON property `saftTranscriptStartCharOffset`
        # @return [Fixnum]
        attr_accessor :saft_transcript_start_char_offset
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `spanAsrConfidenceStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :span_asr_confidence_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `spanDolphinScore`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :span_dolphin_score
      
        # Word count of the span text, tokenized with SAFT.
        # Corresponds to the JSON property `wordCount`
        # @return [Fixnum]
        attr_accessor :word_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dolphin_features = args[:dolphin_features] if args.key?(:dolphin_features)
          @dolphin_scores = args[:dolphin_scores] if args.key?(:dolphin_scores)
          @embedding_distance = args[:embedding_distance] if args.key?(:embedding_distance)
          @post_gap_in_ms = args[:post_gap_in_ms] if args.key?(:post_gap_in_ms)
          @pre_gap_in_ms = args[:pre_gap_in_ms] if args.key?(:pre_gap_in_ms)
          @saft_begin_token_index = args[:saft_begin_token_index] if args.key?(:saft_begin_token_index)
          @saft_end_token_index = args[:saft_end_token_index] if args.key?(:saft_end_token_index)
          @saft_transcript_end_char_offset = args[:saft_transcript_end_char_offset] if args.key?(:saft_transcript_end_char_offset)
          @saft_transcript_start_char_offset = args[:saft_transcript_start_char_offset] if args.key?(:saft_transcript_start_char_offset)
          @span_asr_confidence_stats = args[:span_asr_confidence_stats] if args.key?(:span_asr_confidence_stats)
          @span_dolphin_score = args[:span_dolphin_score] if args.key?(:span_dolphin_score)
          @word_count = args[:word_count] if args.key?(:word_count)
        end
      end
      
      # 
      class VideoContentSearchCaptionSpanAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `anchorSetDolphinScoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :anchor_set_dolphin_score_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_set_dolphin_score_stats = args[:anchor_set_dolphin_score_stats] if args.key?(:anchor_set_dolphin_score_stats)
        end
      end
      
      # A message containing set-level comment anchor features. Next ID: 3
      class VideoContentSearchCommentAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `replies`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchCommentAnchorSetFeaturesComment>]
        attr_accessor :replies
      
        # A structure that represents a comment. Fields 1 through 6 are designed to
        # store responses from the 3P YouTube Data API (see https://developers.google.
        # com/youtube/v3/docs/comments). Field 7 is used to store the Google-internal
        # representation of the comment; if it is populated, then all other fields may
        # be empty. Next ID: 8
        # Corresponds to the JSON property `rootComment`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCommentAnchorSetFeaturesComment]
        attr_accessor :root_comment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @replies = args[:replies] if args.key?(:replies)
          @root_comment = args[:root_comment] if args.key?(:root_comment)
        end
      end
      
      # A structure that represents a comment. Fields 1 through 6 are designed to
      # store responses from the 3P YouTube Data API (see https://developers.google.
      # com/youtube/v3/docs/comments). Field 7 is used to store the Google-internal
      # representation of the comment; if it is populated, then all other fields may
      # be empty. Next ID: 8
      class VideoContentSearchCommentAnchorSetFeaturesComment
        include Google::Apis::Core::Hashable
      
        # The ID that YouTube uses to uniquely identify the comment.
        # Corresponds to the JSON property `commentId`
        # @return [String]
        attr_accessor :comment_id
      
        # The total number of likes (positive ratings) the comment has received.
        # Corresponds to the JSON property `likeCount`
        # @return [Fixnum]
        attr_accessor :like_count
      
        # Intended to be simpler to work with than the ExportedStanza it's derived from
        # See documentation: https://g3doc.corp.google.com/company/teams/youtube/
        # community_intelligence/eng_resources/data_sources.md#ministanza Next available:
        # 74
        # Corresponds to the JSON property `miniStanza`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeCommentsClusteringMiniStanza]
        attr_accessor :mini_stanza
      
        # The date and time when the comment was orignally published, specified in ISO
        # 8601 format.
        # Corresponds to the JSON property `publishedAt`
        # @return [String]
        attr_accessor :published_at
      
        # The comment's text, in HTML.
        # Corresponds to the JSON property `textDisplay`
        # @return [String]
        attr_accessor :text_display
      
        # The original, raw text of the comment.
        # Corresponds to the JSON property `textOriginal`
        # @return [String]
        attr_accessor :text_original
      
        # The date and time when the comment was last updated, specified in ISO 8601
        # format.
        # Corresponds to the JSON property `updatedAt`
        # @return [String]
        attr_accessor :updated_at
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @comment_id = args[:comment_id] if args.key?(:comment_id)
          @like_count = args[:like_count] if args.key?(:like_count)
          @mini_stanza = args[:mini_stanza] if args.key?(:mini_stanza)
          @published_at = args[:published_at] if args.key?(:published_at)
          @text_display = args[:text_display] if args.key?(:text_display)
          @text_original = args[:text_original] if args.key?(:text_original)
          @updated_at = args[:updated_at] if args.key?(:updated_at)
        end
      end
      
      # 
      class VideoContentSearchDescriptionAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # When the description anchor text has been recognized as an entity, how much of
        # the description anchor text is covered by the entity mention.
        # Corresponds to the JSON property `entityTextCoverage`
        # @return [Float]
        attr_accessor :entity_text_coverage
      
        # Whether or not a mention of the description anchor exists in the ASR.
        # Corresponds to the JSON property `inAsr`
        # @return [Boolean]
        attr_accessor :in_asr
        alias_method :in_asr?, :in_asr
      
        # Whether or not the anchor was created from the description for use in training
        # data. This will be set to true for positive examples and false for negative
        # examples.
        # Corresponds to the JSON property `isDescriptionAnchor`
        # @return [Boolean]
        attr_accessor :is_description_anchor
        alias_method :is_description_anchor?, :is_description_anchor
      
        # The distance from the ASR sentence to the description anchor time in ms.
        # Corresponds to the JSON property `spanToAsrTime`
        # @return [Fixnum]
        attr_accessor :span_to_asr_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_text_coverage = args[:entity_text_coverage] if args.key?(:entity_text_coverage)
          @in_asr = args[:in_asr] if args.key?(:in_asr)
          @is_description_anchor = args[:is_description_anchor] if args.key?(:is_description_anchor)
          @span_to_asr_time = args[:span_to_asr_time] if args.key?(:span_to_asr_time)
        end
      end
      
      # 
      class VideoContentSearchDescriptionAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # The number of description anchors that were matched to captions in the ASR.
        # Corresponds to the JSON property `asrAnchorCount`
        # @return [Fixnum]
        attr_accessor :asr_anchor_count
      
        # The fraction of anchors that were matched to captions in the ASR.
        # Corresponds to the JSON property `asrAnchorFraction`
        # @return [Float]
        attr_accessor :asr_anchor_fraction
      
        # The number of unique mids which where matched to description anchors.
        # Corresponds to the JSON property `uniqueAsrMidCount`
        # @return [Fixnum]
        attr_accessor :unique_asr_mid_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_anchor_count = args[:asr_anchor_count] if args.key?(:asr_anchor_count)
          @asr_anchor_fraction = args[:asr_anchor_fraction] if args.key?(:asr_anchor_fraction)
          @unique_asr_mid_count = args[:unique_asr_mid_count] if args.key?(:unique_asr_mid_count)
        end
      end
      
      # Metadata about the span when the anchor source is description span.
      class VideoContentSearchDescriptionSpanInfo
        include Google::Apis::Core::Hashable
      
        # The number of tokens in the context (sentence) where the description span is
        # extracted from.
        # Corresponds to the JSON property `contextTokenCount`
        # @return [Fixnum]
        attr_accessor :context_token_count
      
        # The inference result from the Dolphin span model if the anchor's source is
        # description span.
        # Corresponds to the JSON property `dolphinScores`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchSpanDolphinScores]
        attr_accessor :dolphin_scores
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `spanDolphinScoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :span_dolphin_score_stats
      
        # The number of tokens in the description span. The description span is formed
        # from non-contiguous segment spans of a sentence (context), where each segment
        # span's score satifsies the min span thresholds.
        # Corresponds to the JSON property `spanTokenCount`
        # @return [Fixnum]
        attr_accessor :span_token_count
      
        # The ratio of span_token_count / context_token_count.
        # Corresponds to the JSON property `spanTokenCountRatio`
        # @return [Float]
        attr_accessor :span_token_count_ratio
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @context_token_count = args[:context_token_count] if args.key?(:context_token_count)
          @dolphin_scores = args[:dolphin_scores] if args.key?(:dolphin_scores)
          @span_dolphin_score_stats = args[:span_dolphin_score_stats] if args.key?(:span_dolphin_score_stats)
          @span_token_count = args[:span_token_count] if args.key?(:span_token_count)
          @span_token_count_ratio = args[:span_token_count_ratio] if args.key?(:span_token_count_ratio)
        end
      end
      
      # Contains information about the scores from each individual dolphin ensemble
      # model.
      class VideoContentSearchDolphinEnsembleScore
        include Google::Apis::Core::Hashable
      
        # The score generated by the Dolphin callout model.
        # Corresponds to the JSON property `dolphinScore`
        # @return [Float]
        attr_accessor :dolphin_score
      
        # 
        # Corresponds to the JSON property `modelName`
        # @return [String]
        attr_accessor :model_name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dolphin_score = args[:dolphin_score] if args.key?(:dolphin_score)
          @model_name = args[:model_name] if args.key?(:model_name)
        end
      end
      
      # 
      class VideoContentSearchDolphinFeatures
        include Google::Apis::Core::Hashable
      
        # The alt query used for building the Dolphin example.
        # Corresponds to the JSON property `altQuery`
        # @return [String]
        attr_accessor :alt_query
      
        # The answer used for building the Dolphin example.
        # Corresponds to the JSON property `answer`
        # @return [String]
        attr_accessor :answer
      
        # The query used for building the Dolphin example.
        # Corresponds to the JSON property `query`
        # @return [String]
        attr_accessor :query
      
        # The time stamp of the video anchor in milliseconds.
        # Corresponds to the JSON property `timeMs`
        # @return [Fixnum]
        attr_accessor :time_ms
      
        # The title used for building the Dolphin example.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # The url of the video.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @alt_query = args[:alt_query] if args.key?(:alt_query)
          @answer = args[:answer] if args.key?(:answer)
          @query = args[:query] if args.key?(:query)
          @time_ms = args[:time_ms] if args.key?(:time_ms)
          @title = args[:title] if args.key?(:title)
          @url = args[:url] if args.key?(:url)
        end
      end
      
      # 
      class VideoContentSearchDolphinScoringConfig
        include Google::Apis::Core::Hashable
      
        # The output put keys for Dolphin PredictResponse
        # Corresponds to the JSON property `descriptivenessOutputKey`
        # @return [String]
        attr_accessor :descriptiveness_output_key
      
        # If the dolphin model is an ensemble model (e.g. Video QnA model which consists
        # of 4 teacher models), stores each individual model name.
        # Corresponds to the JSON property `ensembleModelNames`
        # @return [Array<String>]
        attr_accessor :ensemble_model_names
      
        # The inference batch size to use for inference methods that handle batching.
        # Corresponds to the JSON property `inferenceBatchSize`
        # @return [Fixnum]
        attr_accessor :inference_batch_size
      
        # The method to use for inference. This must be set or inference will fail.
        # Corresponds to the JSON property `inferenceMethod`
        # @return [String]
        attr_accessor :inference_method
      
        # Holds value of flag --max_rpc_retries.
        # Corresponds to the JSON property `maxRpcRetries`
        # @return [Fixnum]
        attr_accessor :max_rpc_retries
      
        # Model name used for ModelSpec in PredictRequest used in the PredictionService
        # API.
        # Corresponds to the JSON property `modelName`
        # @return [String]
        attr_accessor :model_name
      
        # Only used when using the bulk_inference API. See go/dolphin-models to learn
        # about the different dolphin models.
        # Corresponds to the JSON property `modelPath`
        # @return [String]
        attr_accessor :model_path
      
        # TODO(alexiaxu) To deprecate this field in the future Output key for Dolphin
        # PredictResponse.
        # Corresponds to the JSON property `outputKey`
        # @return [String]
        attr_accessor :output_key
      
        # Holds value of flag --rpc_deadline (converted to seconds).
        # Corresponds to the JSON property `rpcDeadlineSeconds`
        # @return [Float]
        attr_accessor :rpc_deadline_seconds
      
        # Tensorflow inference BNS address when using PredictionService API.
        # Corresponds to the JSON property `serviceBns`
        # @return [String]
        attr_accessor :service_bns
      
        # 
        # Corresponds to the JSON property `usefulnessOutputKey`
        # @return [String]
        attr_accessor :usefulness_output_key
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @descriptiveness_output_key = args[:descriptiveness_output_key] if args.key?(:descriptiveness_output_key)
          @ensemble_model_names = args[:ensemble_model_names] if args.key?(:ensemble_model_names)
          @inference_batch_size = args[:inference_batch_size] if args.key?(:inference_batch_size)
          @inference_method = args[:inference_method] if args.key?(:inference_method)
          @max_rpc_retries = args[:max_rpc_retries] if args.key?(:max_rpc_retries)
          @model_name = args[:model_name] if args.key?(:model_name)
          @model_path = args[:model_path] if args.key?(:model_path)
          @output_key = args[:output_key] if args.key?(:output_key)
          @rpc_deadline_seconds = args[:rpc_deadline_seconds] if args.key?(:rpc_deadline_seconds)
          @service_bns = args[:service_bns] if args.key?(:service_bns)
          @usefulness_output_key = args[:usefulness_output_key] if args.key?(:usefulness_output_key)
        end
      end
      
      # Entity annotations for one of the mids representing an anchor label or a query
      # text.
      class VideoContentSearchEntityAnnotations
        include Google::Apis::Core::Hashable
      
        # The Webref category that this entity belongs to e.g. "/moka/software".
        # Corresponds to the JSON property `category`
        # @return [String]
        attr_accessor :category
      
        # The overall confidence that this entity is annotated somewhere in the label.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # Whether or not this entity belongs to a set of blocklisted categories.
        # Corresponds to the JSON property `isRestricted`
        # @return [Boolean]
        attr_accessor :is_restricted
        alias_method :is_restricted?, :is_restricted
      
        # The Webref entity mid.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @category = args[:category] if args.key?(:category)
          @confidence = args[:confidence] if args.key?(:confidence)
          @is_restricted = args[:is_restricted] if args.key?(:is_restricted)
          @mid = args[:mid] if args.key?(:mid)
        end
      end
      
      # 
      class VideoContentSearchEntityGroupInfo
        include Google::Apis::Core::Hashable
      
        # Collection id.
        # Corresponds to the JSON property `collectionId`
        # @return [String]
        attr_accessor :collection_id
      
        # Label for this anchor group.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @collection_id = args[:collection_id] if args.key?(:collection_id)
          @label = args[:label] if args.key?(:label)
        end
      end
      
      # Frame-level similarities info for each topic for an interval of frames.
      class VideoContentSearchFrameSimilarityInterval
        include Google::Apis::Core::Hashable
      
        # The similarity between this topic and starburst features for frames in [frames[
        # frame_level_starburst_start_index], frames[frame_level_starburst_start_index +
        # len(frame_similarity)].
        # Corresponds to the JSON property `frameSimilarity`
        # @return [Array<Float>]
        attr_accessor :frame_similarity
      
        # Timestamp in milliseconds for the last frame in this frame interval.
        # Corresponds to the JSON property `framesEndTimestampMs`
        # @return [Fixnum]
        attr_accessor :frames_end_timestamp_ms
      
        # The index of the first frame within this interval of similar frames.
        # VideoMultimodalTopicFeatures.frame_starburst_data.
        # Corresponds to the JSON property `framesStarburstStartIndex`
        # @return [Fixnum]
        attr_accessor :frames_starburst_start_index
      
        # Timestamp in milliseconds for the first frame in this frame interval.
        # Corresponds to the JSON property `framesStartTimestampMs`
        # @return [Fixnum]
        attr_accessor :frames_start_timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_similarity = args[:frame_similarity] if args.key?(:frame_similarity)
          @frames_end_timestamp_ms = args[:frames_end_timestamp_ms] if args.key?(:frames_end_timestamp_ms)
          @frames_starburst_start_index = args[:frames_starburst_start_index] if args.key?(:frames_starburst_start_index)
          @frames_start_timestamp_ms = args[:frames_start_timestamp_ms] if args.key?(:frames_start_timestamp_ms)
        end
      end
      
      # Starburst frame-level dense data.
      class VideoContentSearchFrameStarburstData
        include Google::Apis::Core::Hashable
      
        # Raw float feature vector of the starburst representation.
        # Corresponds to the JSON property `denseVector`
        # @return [Array<Float>]
        attr_accessor :dense_vector
      
        # Starburst version. Possible values are: STARBURST_TEXT_V4 STARBURST_TEXT_V4_5
        # STARBURST_TEXT_V4_PLC STARBURST_TEXT_V5
        # Corresponds to the JSON property `sbVersion`
        # @return [String]
        attr_accessor :sb_version
      
        # Timestamp in milliseconds for this frame.
        # Corresponds to the JSON property `timestampMs`
        # @return [Fixnum]
        attr_accessor :timestamp_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @dense_vector = args[:dense_vector] if args.key?(:dense_vector)
          @sb_version = args[:sb_version] if args.key?(:sb_version)
          @timestamp_ms = args[:timestamp_ms] if args.key?(:timestamp_ms)
        end
      end
      
      # 
      class VideoContentSearchGenerativePredictionFeatures
        include Google::Apis::Core::Hashable
      
        # Features for inferences from generative models.
        # Corresponds to the JSON property `passage`
        # @return [String]
        attr_accessor :passage
      
        # Inference results.
        # Corresponds to the JSON property `predictions`
        # @return [Array<String>]
        attr_accessor :predictions
      
        # 
        # Corresponds to the JSON property `target`
        # @return [String]
        attr_accessor :target
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @passage = args[:passage] if args.key?(:passage)
          @predictions = args[:predictions] if args.key?(:predictions)
          @target = args[:target] if args.key?(:target)
        end
      end
      
      # The inference result features coming from the prediction service that
      # generates the topics.
      class VideoContentSearchGenerativeTopicPredictionFeatures
        include Google::Apis::Core::Hashable
      
        # This field is present if we already have a ground truth topic from the
        # training data.
        # Corresponds to the JSON property `groundTruthTopic`
        # @return [String]
        attr_accessor :ground_truth_topic
      
        # The name of the model where the predictions come from.
        # Corresponds to the JSON property `modelName`
        # @return [String]
        attr_accessor :model_name
      
        # Inference results from the prediction service. Since we generally use beam
        # search with beam_size > 1, this field is repeated to capture all the generated
        # topic beams.
        # Corresponds to the JSON property `predictions`
        # @return [Array<String>]
        attr_accessor :predictions
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ground_truth_topic = args[:ground_truth_topic] if args.key?(:ground_truth_topic)
          @model_name = args[:model_name] if args.key?(:model_name)
          @predictions = args[:predictions] if args.key?(:predictions)
        end
      end
      
      # Anchor-level Metadata about Instruction anchors. TODO(keyvana) Update this
      # proto.
      class VideoContentSearchInstructionAnchorFeatures
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Anchor-level metadata about the instruction anchors. Each instruction passage
      # anchor can contain multiple instruction steps and multiple description anchors
      # and thus the following fields are defined as repeated.
      class VideoContentSearchInstructionTrainingDataAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The match info about the description anchor matches with the ASR n-grams in
        # the instruction passage. Each element represents the best match between a
        # given description anchor and all qualified n-grams within the passage.
        # Corresponds to the JSON property `bestAsrAndDescriptionAnchorsMatchInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchSimilarityMatchInfo>]
        attr_accessor :best_asr_and_description_anchors_match_info
      
        # The match info about the description anchor matches with the instruction
        # anchors in a instruction passage. Each element represents the best match
        # between a given description anchor and all the instruction anchors in the
        # passage.
        # Corresponds to the JSON property `bestDescriptionAndInstructionAnchorsMatchInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchSimilarityMatchInfo>]
        attr_accessor :best_description_and_instruction_anchors_match_info
      
        # The match info about the instruction steps matches with the ASR. Each
        # instruction step corresponds to a step extracted from a web doc. Each
        # instruction passage can contain multiple instruction step matches thus the
        # repeated field.
        # Corresponds to the JSON property `instructionAnchorsMatchInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchSimilarityMatchInfo>]
        attr_accessor :instruction_anchors_match_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @best_asr_and_description_anchors_match_info = args[:best_asr_and_description_anchors_match_info] if args.key?(:best_asr_and_description_anchors_match_info)
          @best_description_and_instruction_anchors_match_info = args[:best_description_and_instruction_anchors_match_info] if args.key?(:best_description_and_instruction_anchors_match_info)
          @instruction_anchors_match_info = args[:instruction_anchors_match_info] if args.key?(:instruction_anchors_match_info)
        end
      end
      
      # Anchor-level Metadata about list description anchors.
      class VideoContentSearchListAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The babel match info of the list anchor with its matched ASR text.
        # Corresponds to the JSON property `babelMatch`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchTextMatchInfo]
        attr_accessor :babel_match
      
        # Metadata about the span when the anchor source is description span.
        # Corresponds to the JSON property `descriptionSpanInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchDescriptionSpanInfo]
        attr_accessor :description_span_info
      
        # The list item index of this anchor in the video description.
        # Corresponds to the JSON property `listItemIndex`
        # @return [Fixnum]
        attr_accessor :list_item_index
      
        # The metadata about this list item's matches with different ASR snippets. This
        # is currently used in the base model (DTW) to generate candidate anchors.
        # Corresponds to the JSON property `matchScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchMatchScores>]
        attr_accessor :match_scores
      
        # The score from the pretrigger model.
        # Corresponds to the JSON property `pretriggerScore`
        # @return [Float]
        attr_accessor :pretrigger_score
      
        # Babel similarity between the anchor and the video title.
        # Corresponds to the JSON property `titleAnchorBabelMatchScore`
        # @return [Float]
        attr_accessor :title_anchor_babel_match_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @babel_match = args[:babel_match] if args.key?(:babel_match)
          @description_span_info = args[:description_span_info] if args.key?(:description_span_info)
          @list_item_index = args[:list_item_index] if args.key?(:list_item_index)
          @match_scores = args[:match_scores] if args.key?(:match_scores)
          @pretrigger_score = args[:pretrigger_score] if args.key?(:pretrigger_score)
          @title_anchor_babel_match_score = args[:title_anchor_babel_match_score] if args.key?(:title_anchor_babel_match_score)
        end
      end
      
      # Cluster-level Metadata about list anchors. Next id: 15.
      class VideoContentSearchListAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # The following fields are used for description span anchors, The aggregated
        # span token texts over all the span candidates of the anchor set.
        # Corresponds to the JSON property `aggregatedSpanText`
        # @return [String]
        attr_accessor :aggregated_span_text
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `anchorSetSpanScoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :anchor_set_span_score_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `babelMatchScoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :babel_match_score_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `contextTokenCountStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :context_token_count_stats
      
        # The ratio of anchors timespan duration over the total duration of the video.
        # Anchors timespan duration is defined as the time span from the first anchor to
        # the last anchor in VideoAnchors.
        # Corresponds to the JSON property `durationSpanRatio`
        # @return [Float]
        attr_accessor :duration_span_ratio
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `durationToPredictedTimeMsStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :duration_to_predicted_time_ms_stats
      
        # The source of anchors extracted from the video descriptions.
        # Corresponds to the JSON property `listAnchorSource`
        # @return [String]
        attr_accessor :list_anchor_source
      
        # The total number of list items mentioned in the video description. Not all
        # these list items are necessarily found as list anchors.
        # Corresponds to the JSON property `listDescriptionItemsSize`
        # @return [Fixnum]
        attr_accessor :list_description_items_size
      
        # The number of matched anchors in the list anchors over the total number of
        # post-filtering list items in the video description, i.e.
        # matched_list_description_anchors_ratio = matched_list_description_anchors_size
        # / post_filtering_list_description_items_size.
        # Corresponds to the JSON property `matchedListDescriptionAnchorsRatio`
        # @return [Float]
        attr_accessor :matched_list_description_anchors_ratio
      
        # The number of matched list anchors found in the ASR. The matched list anchors
        # are a subset of the post-filtering list items in the video description, and as
        # such matched_list_description_anchors_size <=
        # post_filtering_list_description_items_size.
        # Corresponds to the JSON property `matchedListDescriptionAnchorsSize`
        # @return [Fixnum]
        attr_accessor :matched_list_description_anchors_size
      
        # The total number of list items in the video description that are actually
        # considered for matching. This is a subset of list items in the video
        # description that passed filterings such as language filtering, i.e.
        # post_filtering_list_description_items_size <= list_description_items_size
        # Corresponds to the JSON property `postFilteringListDescriptionItemsSize`
        # @return [Fixnum]
        attr_accessor :post_filtering_list_description_items_size
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `pretriggerScoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :pretrigger_score_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `spanTokenCountRatioStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :span_token_count_ratio_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `spanTokenCountStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :span_token_count_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aggregated_span_text = args[:aggregated_span_text] if args.key?(:aggregated_span_text)
          @anchor_set_span_score_stats = args[:anchor_set_span_score_stats] if args.key?(:anchor_set_span_score_stats)
          @babel_match_score_stats = args[:babel_match_score_stats] if args.key?(:babel_match_score_stats)
          @context_token_count_stats = args[:context_token_count_stats] if args.key?(:context_token_count_stats)
          @duration_span_ratio = args[:duration_span_ratio] if args.key?(:duration_span_ratio)
          @duration_to_predicted_time_ms_stats = args[:duration_to_predicted_time_ms_stats] if args.key?(:duration_to_predicted_time_ms_stats)
          @list_anchor_source = args[:list_anchor_source] if args.key?(:list_anchor_source)
          @list_description_items_size = args[:list_description_items_size] if args.key?(:list_description_items_size)
          @matched_list_description_anchors_ratio = args[:matched_list_description_anchors_ratio] if args.key?(:matched_list_description_anchors_ratio)
          @matched_list_description_anchors_size = args[:matched_list_description_anchors_size] if args.key?(:matched_list_description_anchors_size)
          @post_filtering_list_description_items_size = args[:post_filtering_list_description_items_size] if args.key?(:post_filtering_list_description_items_size)
          @pretrigger_score_stats = args[:pretrigger_score_stats] if args.key?(:pretrigger_score_stats)
          @span_token_count_ratio_stats = args[:span_token_count_ratio_stats] if args.key?(:span_token_count_ratio_stats)
          @span_token_count_stats = args[:span_token_count_stats] if args.key?(:span_token_count_stats)
        end
      end
      
      # Anchor-level metadata about the description anchors used as list items to
      # build training data for list anchors.
      class VideoContentSearchListTrainingDataAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The timestamp of when the description anchor is annotated to appear in the
        # video in ms.
        # Corresponds to the JSON property `descriptionAnchorTimeMs`
        # @return [Fixnum]
        attr_accessor :description_anchor_time_ms
      
        # The time gap of when the description anchor is annotated to appear in the
        # video (description_anchor_time_ms) from when it's matched in the ASR as the
        # list anchor.
        # Corresponds to the JSON property `descriptionAnchorTimeToMatchedTimeMs`
        # @return [Fixnum]
        attr_accessor :description_anchor_time_to_matched_time_ms
      
        # Closest edit distance between the anchor generated by description span and the
        # description anchor where the span anchor must be within small threshold time
        # difference of the description anchor timestamp.
        # Corresponds to the JSON property `editDistance`
        # @return [Fixnum]
        attr_accessor :edit_distance
      
        # edit_distance over the description anchor's label length.
        # Corresponds to the JSON property `editDistanceRatio`
        # @return [Float]
        attr_accessor :edit_distance_ratio
      
        # The description anchor text used for matching to Span anchor text.
        # Corresponds to the JSON property `matchedDescriptionText`
        # @return [String]
        attr_accessor :matched_description_text
      
        # The description span anchor text that was the best match for the nearby
        # description anchor.
        # Corresponds to the JSON property `matchedSpanText`
        # @return [String]
        attr_accessor :matched_span_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description_anchor_time_ms = args[:description_anchor_time_ms] if args.key?(:description_anchor_time_ms)
          @description_anchor_time_to_matched_time_ms = args[:description_anchor_time_to_matched_time_ms] if args.key?(:description_anchor_time_to_matched_time_ms)
          @edit_distance = args[:edit_distance] if args.key?(:edit_distance)
          @edit_distance_ratio = args[:edit_distance_ratio] if args.key?(:edit_distance_ratio)
          @matched_description_text = args[:matched_description_text] if args.key?(:matched_description_text)
          @matched_span_text = args[:matched_span_text] if args.key?(:matched_span_text)
        end
      end
      
      # Cluster-level metadata about the description anchors used as list items to
      # build training data for list anchors.
      class VideoContentSearchListTrainingDataSetFeatures
        include Google::Apis::Core::Hashable
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `editDistanceRatioStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :edit_distance_ratio_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `editDistanceStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :edit_distance_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `matchedDescriptionAnchorsTimegapStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :matched_description_anchors_timegap_stats
      
        # Number of description anchors in the description of this video.
        # Corresponds to the JSON property `numDescriptionAnchors`
        # @return [Fixnum]
        attr_accessor :num_description_anchors
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @edit_distance_ratio_stats = args[:edit_distance_ratio_stats] if args.key?(:edit_distance_ratio_stats)
          @edit_distance_stats = args[:edit_distance_stats] if args.key?(:edit_distance_stats)
          @matched_description_anchors_timegap_stats = args[:matched_description_anchors_timegap_stats] if args.key?(:matched_description_anchors_timegap_stats)
          @num_description_anchors = args[:num_description_anchors] if args.key?(:num_description_anchors)
        end
      end
      
      # 
      class VideoContentSearchMatchScores
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matchInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchTextMatchInfo>]
        attr_accessor :match_info
      
        # The method used for matching, e.g. 'babel', 'nlp', 'neon', ßß'phonetic'.
        # Corresponds to the JSON property `method`
        # @return [String]
        attr_accessor :method_prop
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @match_info = args[:match_info] if args.key?(:match_info)
          @method_prop = args[:method_prop] if args.key?(:method_prop)
        end
      end
      
      # Median, mean and standard deviation of a feature value.
      class VideoContentSearchMetricStats
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `max`
        # @return [Float]
        attr_accessor :max
      
        # 
        # Corresponds to the JSON property `mean`
        # @return [Float]
        attr_accessor :mean
      
        # 
        # Corresponds to the JSON property `median`
        # @return [Float]
        attr_accessor :median
      
        # 
        # Corresponds to the JSON property `min`
        # @return [Float]
        attr_accessor :min
      
        # 
        # Corresponds to the JSON property `stddev`
        # @return [Float]
        attr_accessor :stddev
      
        # 
        # Corresponds to the JSON property `sum`
        # @return [Float]
        attr_accessor :sum
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max = args[:max] if args.key?(:max)
          @mean = args[:mean] if args.key?(:mean)
          @median = args[:median] if args.key?(:median)
          @min = args[:min] if args.key?(:min)
          @stddev = args[:stddev] if args.key?(:stddev)
          @sum = args[:sum] if args.key?(:sum)
        end
      end
      
      # Multimodal features for a single generated topic. Next ID: 8
      class VideoContentSearchMultimodalTopicFeatures
        include Google::Apis::Core::Hashable
      
        # The list of frame sequence similarities to this topic. The list of frames are
        # picked to be around the topic timestamp. The set of frames selected are
        # thresholded at a value to ensure the selected frame intervals are similar to
        # the query.
        # Corresponds to the JSON property `frameSimilarityInterval`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchFrameSimilarityInterval>]
        attr_accessor :frame_similarity_interval
      
        # The inference results from the prediction services that generate the topics.
        # Corresponds to the JSON property `generativeTopicPredictionFeatures`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchGenerativeTopicPredictionFeatures>]
        attr_accessor :generative_topic_prediction_features
      
        # Features for queries generated using document navboost data with timed anchors.
        # Corresponds to the JSON property `navboostAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchNavboostAnchorFeatures]
        attr_accessor :navboost_anchor_features
      
        # The text of the generated topic.
        # Corresponds to the JSON property `topic`
        # @return [String]
        attr_accessor :topic
      
        # End time of the topic.
        # Corresponds to the JSON property `topicEndMs`
        # @return [Fixnum]
        attr_accessor :topic_end_ms
      
        # Start time of the topic.
        # Corresponds to the JSON property `topicStartMs`
        # @return [Fixnum]
        attr_accessor :topic_start_ms
      
        # How the query was generated.
        # Corresponds to the JSON property `videoQuerySource`
        # @return [String]
        attr_accessor :video_query_source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_similarity_interval = args[:frame_similarity_interval] if args.key?(:frame_similarity_interval)
          @generative_topic_prediction_features = args[:generative_topic_prediction_features] if args.key?(:generative_topic_prediction_features)
          @navboost_anchor_features = args[:navboost_anchor_features] if args.key?(:navboost_anchor_features)
          @topic = args[:topic] if args.key?(:topic)
          @topic_end_ms = args[:topic_end_ms] if args.key?(:topic_end_ms)
          @topic_start_ms = args[:topic_start_ms] if args.key?(:topic_start_ms)
          @video_query_source = args[:video_query_source] if args.key?(:video_query_source)
        end
      end
      
      # Multimodal features for a single generated topic used to build training data.
      class VideoContentSearchMultimodalTopicTrainingFeatures
        include Google::Apis::Core::Hashable
      
        # Frame-level similarities info for each topic for an interval of frames.
        # Corresponds to the JSON property `maxFrameSimilarityInterval`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchFrameSimilarityInterval]
        attr_accessor :max_frame_similarity_interval
      
        # The topic/query normalized for Navboost and QBST lookups as well as fetching
        # of the Rankembed nearest neighbors.
        # Corresponds to the JSON property `normalizedTopic`
        # @return [String]
        attr_accessor :normalized_topic
      
        # QBST terms overlap features for the candidate query.
        # Corresponds to the JSON property `qbstTermsOverlapFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchQbstTermsOverlapFeatures]
        attr_accessor :qbst_terms_overlap_features
      
        # Rankembed neighbor neighbor features for the candidate query.
        # Corresponds to the JSON property `rankembedNearestNeighborsFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchRankEmbedNearestNeighborsFeatures]
        attr_accessor :rankembed_nearest_neighbors_features
      
        # Saft named-entities info for a given topic.
        # Corresponds to the JSON property `saftEntityInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchSaftEntityInfo]
        attr_accessor :saft_entity_info
      
        # Raw float feature vector of the topic's co-text embedding representation in
        # the Starburst space.
        # Corresponds to the JSON property `topicDenseVector`
        # @return [Array<Float>]
        attr_accessor :topic_dense_vector
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_frame_similarity_interval = args[:max_frame_similarity_interval] if args.key?(:max_frame_similarity_interval)
          @normalized_topic = args[:normalized_topic] if args.key?(:normalized_topic)
          @qbst_terms_overlap_features = args[:qbst_terms_overlap_features] if args.key?(:qbst_terms_overlap_features)
          @rankembed_nearest_neighbors_features = args[:rankembed_nearest_neighbors_features] if args.key?(:rankembed_nearest_neighbors_features)
          @saft_entity_info = args[:saft_entity_info] if args.key?(:saft_entity_info)
          @topic_dense_vector = args[:topic_dense_vector] if args.key?(:topic_dense_vector)
        end
      end
      
      # Message for SAFT named entities.
      class VideoContentSearchNamedEntity
        include Google::Apis::Core::Hashable
      
        # Type name: e.g. /saft/person for a person's name.
        # Corresponds to the JSON property `entityType`
        # @return [String]
        attr_accessor :entity_type
      
        # Text referring to an entity of type entity_type;
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_type = args[:entity_type] if args.key?(:entity_type)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Features for queries generated using document navboost data with timed anchors.
      class VideoContentSearchNavboostAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The anchor text used in the generated query.
        # Corresponds to the JSON property `anchorText`
        # @return [String]
        attr_accessor :anchor_text
      
        # The navboost query used in the generated query.
        # Corresponds to the JSON property `navboostText`
        # @return [String]
        attr_accessor :navboost_text
      
        # How the navboost-anchor query was constructed.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_text = args[:anchor_text] if args.key?(:anchor_text)
          @navboost_text = args[:navboost_text] if args.key?(:navboost_text)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Contains OCR text, its start time and additional details about position/fonts
      class VideoContentSearchOcrText
        include Google::Apis::Core::Hashable
      
        # Keep feature values which are useful to filter titles, labels.
        # Corresponds to the JSON property `ocrFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOnScreenTextFeature]
        attr_accessor :ocr_feature
      
        # The OCR recognized text label
        # Corresponds to the JSON property `ocrText`
        # @return [String]
        attr_accessor :ocr_text
      
        # The time in ms at which the OCR text appears on the frame
        # Corresponds to the JSON property `timeMs`
        # @return [Fixnum]
        attr_accessor :time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ocr_feature = args[:ocr_feature] if args.key?(:ocr_feature)
          @ocr_text = args[:ocr_text] if args.key?(:ocr_text)
          @time_ms = args[:time_ms] if args.key?(:time_ms)
        end
      end
      
      # 
      class VideoContentSearchOcrAsrFeature
        include Google::Apis::Core::Hashable
      
        # The minimum char edit distance between the normalized OCR text and candidate
        # word strings taken from a time window around the OCR appearance.
        # Corresponds to the JSON property `minCharEditDistance`
        # @return [Fixnum]
        attr_accessor :min_char_edit_distance
      
        # The matched ASR candidate for minimum char edit distance.
        # Corresponds to the JSON property `minCharEditDistanceAsrText`
        # @return [String]
        attr_accessor :min_char_edit_distance_asr_text
      
        # The min_char_edit_distance divided by the length of the OCR string.
        # Corresponds to the JSON property `minCharEditDistancePercent`
        # @return [Float]
        attr_accessor :min_char_edit_distance_percent
      
        # The normalized OCR text which was used to match the candidate.
        # Corresponds to the JSON property `ocrTextNormalizedForCharMatch`
        # @return [String]
        attr_accessor :ocr_text_normalized_for_char_match
      
        # The length of the normalized OCR text.
        # Corresponds to the JSON property `ocrTextNormalizedForCharMatchLength`
        # @return [Fixnum]
        attr_accessor :ocr_text_normalized_for_char_match_length
      
        # The score from the pretrigger model.
        # Corresponds to the JSON property `pretriggerScore`
        # @return [Float]
        attr_accessor :pretrigger_score
      
        # The ASR text that was used for the word overlap calculation.
        # Corresponds to the JSON property `wordOverlapAsrText`
        # @return [String]
        attr_accessor :word_overlap_asr_text
      
        # The number of words found both in the OCR text and the ASR in a time window
        # around OCR appearance.
        # Corresponds to the JSON property `wordOverlapCount`
        # @return [Fixnum]
        attr_accessor :word_overlap_count
      
        # The word_overlap_count divided by the number of words in the OCR text.
        # Corresponds to the JSON property `wordOverlapPercent`
        # @return [Float]
        attr_accessor :word_overlap_percent
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @min_char_edit_distance = args[:min_char_edit_distance] if args.key?(:min_char_edit_distance)
          @min_char_edit_distance_asr_text = args[:min_char_edit_distance_asr_text] if args.key?(:min_char_edit_distance_asr_text)
          @min_char_edit_distance_percent = args[:min_char_edit_distance_percent] if args.key?(:min_char_edit_distance_percent)
          @ocr_text_normalized_for_char_match = args[:ocr_text_normalized_for_char_match] if args.key?(:ocr_text_normalized_for_char_match)
          @ocr_text_normalized_for_char_match_length = args[:ocr_text_normalized_for_char_match_length] if args.key?(:ocr_text_normalized_for_char_match_length)
          @pretrigger_score = args[:pretrigger_score] if args.key?(:pretrigger_score)
          @word_overlap_asr_text = args[:word_overlap_asr_text] if args.key?(:word_overlap_asr_text)
          @word_overlap_count = args[:word_overlap_count] if args.key?(:word_overlap_count)
          @word_overlap_percent = args[:word_overlap_percent] if args.key?(:word_overlap_percent)
        end
      end
      
      # 
      class VideoContentSearchOcrAsrSetFeature
        include Google::Apis::Core::Hashable
      
        # The word_overlap_score divided by the greatest word_overlap_score for any
        # cluster in the VideoAnchorSets.
        # Corresponds to the JSON property `normalizedWordOverlapScore`
        # @return [Float]
        attr_accessor :normalized_word_overlap_score
      
        # A score based on the number of overlapped words between the OCR and ASR for
        # anchors in the cluster.
        # Corresponds to the JSON property `wordOverlapScore`
        # @return [Float]
        attr_accessor :word_overlap_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @normalized_word_overlap_score = args[:normalized_word_overlap_score] if args.key?(:normalized_word_overlap_score)
          @word_overlap_score = args[:word_overlap_score] if args.key?(:word_overlap_score)
        end
      end
      
      # Metadata about the join of description anchors and OCR data which is used to
      # build training data.
      class VideoContentSearchOcrDescriptionTrainingDataAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The string edit distance from the anchor label to the nearest OCR text.
        # Corresponds to the JSON property `editDistance`
        # @return [Fixnum]
        attr_accessor :edit_distance
      
        # edit_distance over the description anchor's label length.
        # Corresponds to the JSON property `editDistanceRatio`
        # @return [Float]
        attr_accessor :edit_distance_ratio
      
        # The description anchor text used for matching to OCR text.
        # Corresponds to the JSON property `matchedDescriptionText`
        # @return [String]
        attr_accessor :matched_description_text
      
        # The time of the selected OCR frame in ms. The best frame in a window around
        # the target description anchor will be selected.
        # Corresponds to the JSON property `matchedFrameTimeMs`
        # @return [Fixnum]
        attr_accessor :matched_frame_time_ms
      
        # The OCR text that was the best match for the nearby description anchor.
        # Corresponds to the JSON property `matchedOcrText`
        # @return [String]
        attr_accessor :matched_ocr_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @edit_distance = args[:edit_distance] if args.key?(:edit_distance)
          @edit_distance_ratio = args[:edit_distance_ratio] if args.key?(:edit_distance_ratio)
          @matched_description_text = args[:matched_description_text] if args.key?(:matched_description_text)
          @matched_frame_time_ms = args[:matched_frame_time_ms] if args.key?(:matched_frame_time_ms)
          @matched_ocr_text = args[:matched_ocr_text] if args.key?(:matched_ocr_text)
        end
      end
      
      # Metadata about the join of description anchors and OCR data for a set of
      # description anchors.
      class VideoContentSearchOcrDescriptionTrainingDataSetFeatures
        include Google::Apis::Core::Hashable
      
        # The max edit distance of any description anchor to its closest OCR text.
        # Corresponds to the JSON property `maxEditDistance`
        # @return [Fixnum]
        attr_accessor :max_edit_distance
      
        # The maximum of (edit distance of any description anchor to its closest OCR
        # text over description anchor label length).
        # Corresponds to the JSON property `maxEditDistanceRatio`
        # @return [Float]
        attr_accessor :max_edit_distance_ratio
      
        # The median edit distance of any description anchor to its closest OCR text.
        # Corresponds to the JSON property `medianEditDistance`
        # @return [Fixnum]
        attr_accessor :median_edit_distance
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_edit_distance = args[:max_edit_distance] if args.key?(:max_edit_distance)
          @max_edit_distance_ratio = args[:max_edit_distance_ratio] if args.key?(:max_edit_distance_ratio)
          @median_edit_distance = args[:median_edit_distance] if args.key?(:median_edit_distance)
        end
      end
      
      # Features for video level info.
      class VideoContentSearchOcrVideoFeature
        include Google::Apis::Core::Hashable
      
        # Average text area ratio throughout video frames. Text area ratio for a frame
        # is defined by sum(text area) / image area.
        # Corresponds to the JSON property `averageTextAreaRatio`
        # @return [Float]
        attr_accessor :average_text_area_ratio
      
        # Cluster id to the num of frames in each cluster.
        # Corresponds to the JSON property `clusterIdToFrameSize`
        # @return [Hash<String,Fixnum>]
        attr_accessor :cluster_id_to_frame_size
      
        # Total time of this video in milliseconds.
        # Corresponds to the JSON property `durationInMs`
        # @return [Fixnum]
        attr_accessor :duration_in_ms
      
        # Video level detected language by lang id, aggregated from each frame.
        # Corresponds to the JSON property `langIdDetectedLanguage`
        # @return [String]
        attr_accessor :lang_id_detected_language
      
        # The number of ShotInfo clusters.
        # Corresponds to the JSON property `numClusters`
        # @return [Fixnum]
        attr_accessor :num_clusters
      
        # The number of video frames contained in ShotInfo cluster.
        # Corresponds to the JSON property `numFrames`
        # @return [Fixnum]
        attr_accessor :num_frames
      
        # Video level detected language, aggregated from each frame.
        # Corresponds to the JSON property `ocrDetectedLanguage`
        # @return [String]
        attr_accessor :ocr_detected_language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_text_area_ratio = args[:average_text_area_ratio] if args.key?(:average_text_area_ratio)
          @cluster_id_to_frame_size = args[:cluster_id_to_frame_size] if args.key?(:cluster_id_to_frame_size)
          @duration_in_ms = args[:duration_in_ms] if args.key?(:duration_in_ms)
          @lang_id_detected_language = args[:lang_id_detected_language] if args.key?(:lang_id_detected_language)
          @num_clusters = args[:num_clusters] if args.key?(:num_clusters)
          @num_frames = args[:num_frames] if args.key?(:num_frames)
          @ocr_detected_language = args[:ocr_detected_language] if args.key?(:ocr_detected_language)
        end
      end
      
      # Features for the set of OnScreenText.
      class VideoContentSearchOnScreenTextClusterFeature
        include Google::Apis::Core::Hashable
      
        # Average confidence.
        # Corresponds to the JSON property `averageConfidence`
        # @return [Float]
        attr_accessor :average_confidence
      
        # 
        # Corresponds to the JSON property `averageDurationRatio`
        # @return [Float]
        attr_accessor :average_duration_ratio
      
        # 
        # Corresponds to the JSON property `averageHorizontalPosition`
        # @return [Float]
        attr_accessor :average_horizontal_position
      
        # Deprecated. Please use ocr_text_length_stats.median instead. The average
        # length of anchor labels. average_ocr_text_length is deprecated, because now
        # ocr_text_length_stats has a field for holding the same value.
        # Corresponds to the JSON property `averageOcrTextLength`
        # @return [Float]
        attr_accessor :average_ocr_text_length
      
        # Deprecated. Please use text_height_ratio_stats.mean instead. Average value of
        # text height ratio (over image height), which is taken average over the same
        # text. average_of_average_text_height_ratio is deprecated, because now
        # text_height_ratio_stats has a field for keeping the same value.
        # Corresponds to the JSON property `averageOfAverageTextHeightRatio`
        # @return [Float]
        attr_accessor :average_of_average_text_height_ratio
      
        # Average of label center position.
        # Corresponds to the JSON property `averageVerticalPosition`
        # @return [Float]
        attr_accessor :average_vertical_position
      
        # The number of anchors in the cluster over the number of anchors in the video.
        # Corresponds to the JSON property `clusterRatio`
        # @return [Float]
        attr_accessor :cluster_ratio
      
        # The number of anchors in the cluster.
        # Corresponds to the JSON property `clusterSize`
        # @return [Fixnum]
        attr_accessor :cluster_size
      
        # The number of anchors that had a counting number over the number of anchors in
        # total.
        # Corresponds to the JSON property `countingNumberRatio`
        # @return [Float]
        attr_accessor :counting_number_ratio
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `durationMsStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :duration_ms_stats
      
        # Frame size ratio over total frames in video.
        # Corresponds to the JSON property `frameSizeRatio`
        # @return [Float]
        attr_accessor :frame_size_ratio
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `logOcrTextLengthStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :log_ocr_text_length_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `logTextHeightRatioStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :log_text_height_ratio_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `logp1000DurationMsStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :logp1000_duration_ms_stats
      
        # The maximum ratio of duration between two consecutive anchors to video
        # duration. This is calculated after all anchor filtering has been completed.
        # Corresponds to the JSON property `maxVideoDurationRatioBetweenAnchors`
        # @return [Float]
        attr_accessor :max_video_duration_ratio_between_anchors
      
        # Stats for ratio of frame time intervals, over total video time.
        # Corresponds to the JSON property `maximumDurationRatio`
        # @return [Float]
        attr_accessor :maximum_duration_ratio
      
        # The median cluster distance for the anchors in the cluster. The way the
        # distance is calculated will vary depending on the clustering method.
        # Corresponds to the JSON property `medianClusteringDistance`
        # @return [Float]
        attr_accessor :median_clustering_distance
      
        # 
        # Corresponds to the JSON property `medianDurationRatio`
        # @return [Float]
        attr_accessor :median_duration_ratio
      
        # Deprecated. Please use text_height_ratio_stats.median instead. Median value of
        # text height ratio (over image height), which is taken average over the same
        # text. median_of_average_text_height_ratio is deprecated, because now
        # text_height_ratio_stats has a field for keeping the same value.
        # Corresponds to the JSON property `medianOfAverageTextHeightRatio`
        # @return [Float]
        attr_accessor :median_of_average_text_height_ratio
      
        # Features for the overlap between OCR and ASR.
        # Corresponds to the JSON property `ocrAsrFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOcrAsrSetFeature]
        attr_accessor :ocr_asr_feature
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `ocrTextLengthStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :ocr_text_length_stats
      
        # 
        # Corresponds to the JSON property `stddevDurationRatio`
        # @return [Float]
        attr_accessor :stddev_duration_ratio
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `textHeightRatioStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :text_height_ratio_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_confidence = args[:average_confidence] if args.key?(:average_confidence)
          @average_duration_ratio = args[:average_duration_ratio] if args.key?(:average_duration_ratio)
          @average_horizontal_position = args[:average_horizontal_position] if args.key?(:average_horizontal_position)
          @average_ocr_text_length = args[:average_ocr_text_length] if args.key?(:average_ocr_text_length)
          @average_of_average_text_height_ratio = args[:average_of_average_text_height_ratio] if args.key?(:average_of_average_text_height_ratio)
          @average_vertical_position = args[:average_vertical_position] if args.key?(:average_vertical_position)
          @cluster_ratio = args[:cluster_ratio] if args.key?(:cluster_ratio)
          @cluster_size = args[:cluster_size] if args.key?(:cluster_size)
          @counting_number_ratio = args[:counting_number_ratio] if args.key?(:counting_number_ratio)
          @duration_ms_stats = args[:duration_ms_stats] if args.key?(:duration_ms_stats)
          @frame_size_ratio = args[:frame_size_ratio] if args.key?(:frame_size_ratio)
          @log_ocr_text_length_stats = args[:log_ocr_text_length_stats] if args.key?(:log_ocr_text_length_stats)
          @log_text_height_ratio_stats = args[:log_text_height_ratio_stats] if args.key?(:log_text_height_ratio_stats)
          @logp1000_duration_ms_stats = args[:logp1000_duration_ms_stats] if args.key?(:logp1000_duration_ms_stats)
          @max_video_duration_ratio_between_anchors = args[:max_video_duration_ratio_between_anchors] if args.key?(:max_video_duration_ratio_between_anchors)
          @maximum_duration_ratio = args[:maximum_duration_ratio] if args.key?(:maximum_duration_ratio)
          @median_clustering_distance = args[:median_clustering_distance] if args.key?(:median_clustering_distance)
          @median_duration_ratio = args[:median_duration_ratio] if args.key?(:median_duration_ratio)
          @median_of_average_text_height_ratio = args[:median_of_average_text_height_ratio] if args.key?(:median_of_average_text_height_ratio)
          @ocr_asr_feature = args[:ocr_asr_feature] if args.key?(:ocr_asr_feature)
          @ocr_text_length_stats = args[:ocr_text_length_stats] if args.key?(:ocr_text_length_stats)
          @stddev_duration_ratio = args[:stddev_duration_ratio] if args.key?(:stddev_duration_ratio)
          @text_height_ratio_stats = args[:text_height_ratio_stats] if args.key?(:text_height_ratio_stats)
        end
      end
      
      # Keep feature values which are useful to filter titles, labels.
      class VideoContentSearchOnScreenTextFeature
        include Google::Apis::Core::Hashable
      
        # The average of rotation angles (degree) of texts.
        # Corresponds to the JSON property `averageAngle`
        # @return [Float]
        attr_accessor :average_angle
      
        # Average value of confidence.
        # Corresponds to the JSON property `averageConfidence`
        # @return [Float]
        attr_accessor :average_confidence
      
        # Font size or weight information. This is extracted from internal message, so
        # may not be available in future.
        # Corresponds to the JSON property `averageFontsize`
        # @return [Float]
        attr_accessor :average_fontsize
      
        # 
        # Corresponds to the JSON property `averageFontweight`
        # @return [Float]
        attr_accessor :average_fontweight
      
        # 
        # Corresponds to the JSON property `averageHeightRatio`
        # @return [Float]
        attr_accessor :average_height_ratio
      
        # 
        # Corresponds to the JSON property `backgroundBlue`
        # @return [Float]
        attr_accessor :background_blue
      
        # 
        # Corresponds to the JSON property `backgroundGray`
        # @return [Float]
        attr_accessor :background_gray
      
        # 
        # Corresponds to the JSON property `backgroundGreen`
        # @return [Float]
        attr_accessor :background_green
      
        # 
        # Corresponds to the JSON property `backgroundRed`
        # @return [Float]
        attr_accessor :background_red
      
        # 
        # Corresponds to the JSON property `boxHeightRatio`
        # @return [Float]
        attr_accessor :box_height_ratio
      
        # Box width and height ratio, against to the frame size, so the value range is [
        # 0, 1]. If this text feature consists of multiple text boxes, the box width /
        # height is a union of each text box.
        # Corresponds to the JSON property `boxWidthRatio`
        # @return [Float]
        attr_accessor :box_width_ratio
      
        # Horizontal position of the center of this text, by ratio [0.0, 1.0].
        # Corresponds to the JSON property `centerHorizontalPositionRatio`
        # @return [Float]
        attr_accessor :center_horizontal_position_ratio
      
        # Vertical position of the center of this text, by ratio [0.0, 1.0].
        # Corresponds to the JSON property `centerVerticalPositionRatio`
        # @return [Float]
        attr_accessor :center_vertical_position_ratio
      
        # Counting number in this anchor's original label.
        # Corresponds to the JSON property `countingNumber`
        # @return [Fixnum]
        attr_accessor :counting_number
      
        # # of numbered anchors that are not out-of-order / # of all the numbered
        # anchors. If no counting number is detected, this will be empty.
        # Corresponds to the JSON property `countingNumberOooRatio`
        # @return [Float]
        attr_accessor :counting_number_ooo_ratio
      
        # Prefix for counting number in this anchor's label. If no counting number is
        # detected, this will be empty.
        # Corresponds to the JSON property `countingNumberPrefix`
        # @return [String]
        attr_accessor :counting_number_prefix
      
        # Suffix for counting number in this anchor's label. If no counting number is
        # detected, this will be empty.
        # Corresponds to the JSON property `countingNumberSuffix`
        # @return [String]
        attr_accessor :counting_number_suffix
      
        # Duration time in millisec.
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        # 
        # Corresponds to the JSON property `foregroundBlue`
        # @return [Float]
        attr_accessor :foreground_blue
      
        # Color information, normalized to [0-1]. This color information is extracted
        # from the largest word in the line entities of PageLayout message. See goodoc::
        # PageLayoutEntity::Colors for details.
        # Corresponds to the JSON property `foregroundGray`
        # @return [Float]
        attr_accessor :foreground_gray
      
        # 
        # Corresponds to the JSON property `foregroundGreen`
        # @return [Float]
        attr_accessor :foreground_green
      
        # 
        # Corresponds to the JSON property `foregroundRed`
        # @return [Float]
        attr_accessor :foreground_red
      
        # Whether or not this anchor had URL in its label before the label fixing step.
        # Corresponds to the JSON property `hadUrlInLabel`
        # @return [Boolean]
        attr_accessor :had_url_in_label
        alias_method :had_url_in_label?, :had_url_in_label
      
        # # of LINE entities that are recognized as handwritten texts over # of merged
        # LINE entities.
        # Corresponds to the JSON property `handwrittenTextRatio`
        # @return [Float]
        attr_accessor :handwritten_text_ratio
      
        # Whether or not the counting number in this anchor's label is out-of-order. If
        # no counting number is detected, this will be empty.
        # Corresponds to the JSON property `isCountingNumberOoo`
        # @return [Boolean]
        attr_accessor :is_counting_number_ooo
        alias_method :is_counting_number_ooo?, :is_counting_number_ooo
      
        # Languages predicted by OCR. "repeated" is employed for this field because LINE
        # entities of PageLayout message are sometimes annotated with multiple languages,
        # and also two VideoAnchor that are annotated with different languages can be
        # merged into one VideoAnchor. When two VideoAnchor are merged into one, the
        # weight field values of the new VideoAnchor will be the average of weight field
        # values weighted by merged_line_count.
        # Corresponds to the JSON property `languages`
        # @return [Array<Google::Apis::ContentwarehouseV1::GoodocLanguageCombinationLanguage>]
        attr_accessor :languages
      
        # Left position of this text, by ratio [0, 1].
        # Corresponds to the JSON property `leftPositionRatio`
        # @return [Float]
        attr_accessor :left_position_ratio
      
        # The median distance between this anchor and other anchors in the cluster. The
        # way the distance is calculated will vary depending on the clustering method.
        # Corresponds to the JSON property `medianClusteringDistance`
        # @return [Float]
        attr_accessor :median_clustering_distance
      
        # The number of LINE entities used for this text.
        # Corresponds to the JSON property `mergedLineCount`
        # @return [Fixnum]
        attr_accessor :merged_line_count
      
        # The number of OCR texts that have the same text among temporally-merged OCR
        # texts.
        # Corresponds to the JSON property `occurrenceCount`
        # @return [Float]
        attr_accessor :occurrence_count
      
        # occurrence_count over the number of anchors merged to this anchor.
        # Corresponds to the JSON property `occurrenceRatio`
        # @return [Float]
        attr_accessor :occurrence_ratio
      
        # Features for the overlap between OCR and ASR.
        # Corresponds to the JSON property `ocrAsrFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOcrAsrFeature]
        attr_accessor :ocr_asr_feature
      
        # The label this VideoAnchor originally had before label clearning steps.
        # Corresponds to the JSON property `originalLabel`
        # @return [String]
        attr_accessor :original_label
      
        # 
        # Corresponds to the JSON property `relativeShotTimeMsPosteriorToEndTime`
        # @return [Fixnum]
        attr_accessor :relative_shot_time_ms_posterior_to_end_time
      
        # 
        # Corresponds to the JSON property `relativeShotTimeMsPosteriorToStartTime`
        # @return [Fixnum]
        attr_accessor :relative_shot_time_ms_posterior_to_start_time
      
        # 
        # Corresponds to the JSON property `relativeShotTimeMsPriorToEndTime`
        # @return [Fixnum]
        attr_accessor :relative_shot_time_ms_prior_to_end_time
      
        # Shot boundary time nearest to OnScreenText's start and end time. The time is
        # relative to each OnScreenText's start / end time (ex. -1 means shot time
        # exists prior to the start / end time). If shot time and start/end time is the
        # same, 0 is set in 'prior' field. If no shot info is available, the below
        # fields are not set.
        # Corresponds to the JSON property `relativeShotTimeMsPriorToStartTime`
        # @return [Fixnum]
        attr_accessor :relative_shot_time_ms_prior_to_start_time
      
        # 
        # Corresponds to the JSON property `shotInfoCountDuringText`
        # @return [Fixnum]
        attr_accessor :shot_info_count_during_text
      
        # OCR language that has the highest weight.
        # Corresponds to the JSON property `topOcrLanguage`
        # @return [String]
        attr_accessor :top_ocr_language
      
        # Note that top-left position is (0, 0) for position values. Top position of
        # this text, by ratio [0, 1].
        # Corresponds to the JSON property `topPositionRatio`
        # @return [Float]
        attr_accessor :top_position_ratio
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_angle = args[:average_angle] if args.key?(:average_angle)
          @average_confidence = args[:average_confidence] if args.key?(:average_confidence)
          @average_fontsize = args[:average_fontsize] if args.key?(:average_fontsize)
          @average_fontweight = args[:average_fontweight] if args.key?(:average_fontweight)
          @average_height_ratio = args[:average_height_ratio] if args.key?(:average_height_ratio)
          @background_blue = args[:background_blue] if args.key?(:background_blue)
          @background_gray = args[:background_gray] if args.key?(:background_gray)
          @background_green = args[:background_green] if args.key?(:background_green)
          @background_red = args[:background_red] if args.key?(:background_red)
          @box_height_ratio = args[:box_height_ratio] if args.key?(:box_height_ratio)
          @box_width_ratio = args[:box_width_ratio] if args.key?(:box_width_ratio)
          @center_horizontal_position_ratio = args[:center_horizontal_position_ratio] if args.key?(:center_horizontal_position_ratio)
          @center_vertical_position_ratio = args[:center_vertical_position_ratio] if args.key?(:center_vertical_position_ratio)
          @counting_number = args[:counting_number] if args.key?(:counting_number)
          @counting_number_ooo_ratio = args[:counting_number_ooo_ratio] if args.key?(:counting_number_ooo_ratio)
          @counting_number_prefix = args[:counting_number_prefix] if args.key?(:counting_number_prefix)
          @counting_number_suffix = args[:counting_number_suffix] if args.key?(:counting_number_suffix)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @foreground_blue = args[:foreground_blue] if args.key?(:foreground_blue)
          @foreground_gray = args[:foreground_gray] if args.key?(:foreground_gray)
          @foreground_green = args[:foreground_green] if args.key?(:foreground_green)
          @foreground_red = args[:foreground_red] if args.key?(:foreground_red)
          @had_url_in_label = args[:had_url_in_label] if args.key?(:had_url_in_label)
          @handwritten_text_ratio = args[:handwritten_text_ratio] if args.key?(:handwritten_text_ratio)
          @is_counting_number_ooo = args[:is_counting_number_ooo] if args.key?(:is_counting_number_ooo)
          @languages = args[:languages] if args.key?(:languages)
          @left_position_ratio = args[:left_position_ratio] if args.key?(:left_position_ratio)
          @median_clustering_distance = args[:median_clustering_distance] if args.key?(:median_clustering_distance)
          @merged_line_count = args[:merged_line_count] if args.key?(:merged_line_count)
          @occurrence_count = args[:occurrence_count] if args.key?(:occurrence_count)
          @occurrence_ratio = args[:occurrence_ratio] if args.key?(:occurrence_ratio)
          @ocr_asr_feature = args[:ocr_asr_feature] if args.key?(:ocr_asr_feature)
          @original_label = args[:original_label] if args.key?(:original_label)
          @relative_shot_time_ms_posterior_to_end_time = args[:relative_shot_time_ms_posterior_to_end_time] if args.key?(:relative_shot_time_ms_posterior_to_end_time)
          @relative_shot_time_ms_posterior_to_start_time = args[:relative_shot_time_ms_posterior_to_start_time] if args.key?(:relative_shot_time_ms_posterior_to_start_time)
          @relative_shot_time_ms_prior_to_end_time = args[:relative_shot_time_ms_prior_to_end_time] if args.key?(:relative_shot_time_ms_prior_to_end_time)
          @relative_shot_time_ms_prior_to_start_time = args[:relative_shot_time_ms_prior_to_start_time] if args.key?(:relative_shot_time_ms_prior_to_start_time)
          @shot_info_count_during_text = args[:shot_info_count_during_text] if args.key?(:shot_info_count_during_text)
          @top_ocr_language = args[:top_ocr_language] if args.key?(:top_ocr_language)
          @top_position_ratio = args[:top_position_ratio] if args.key?(:top_position_ratio)
        end
      end
      
      # QBST terms overlap features for the candidate query.
      class VideoContentSearchQbstTermsOverlapFeatures
        include Google::Apis::Core::Hashable
      
        # Fraction of salient terms of original query covered by anchor text.
        # Corresponds to the JSON property `qbstAnchorOverlap`
        # @return [Float]
        attr_accessor :qbst_anchor_overlap
      
        # Fraction of salient terms of original query covered by top navboost query of
        # the video.
        # Corresponds to the JSON property `qbstNavboostOverlap`
        # @return [Float]
        attr_accessor :qbst_navboost_overlap
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @qbst_anchor_overlap = args[:qbst_anchor_overlap] if args.key?(:qbst_anchor_overlap)
          @qbst_navboost_overlap = args[:qbst_navboost_overlap] if args.key?(:qbst_navboost_overlap)
        end
      end
      
      # Features for individual Q&A anchors. Next ID: 23
      class VideoContentSearchQnaAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # Segment of text from the ASR.
        # Corresponds to the JSON property `answer`
        # @return [String]
        attr_accessor :answer
      
        # 
        # Corresponds to the JSON property `descartesDotScore`
        # @return [Float]
        attr_accessor :descartes_dot_score
      
        # 
        # Corresponds to the JSON property `descartesRankingScore`
        # @return [Float]
        attr_accessor :descartes_ranking_score
      
        # 
        # Corresponds to the JSON property `dolphinModelType`
        # @return [String]
        attr_accessor :dolphin_model_type
      
        # Dolphin score calculated using the question as the query, the ASR passage as
        # the answer. See go/dolphin-models to learn more.
        # Corresponds to the JSON property `dolphinScore`
        # @return [Float]
        attr_accessor :dolphin_score
      
        # Edit distance of the question and the title from 0 to 1 where 1 is most
        # similar.
        # Corresponds to the JSON property `editDistance`
        # @return [Float]
        attr_accessor :edit_distance
      
        # End time in milliseconds relative to the beginning of the video.
        # Corresponds to the JSON property `endMs`
        # @return [Fixnum]
        attr_accessor :end_ms
      
        # 
        # Corresponds to the JSON property `ensembleScore`
        # @return [Float]
        attr_accessor :ensemble_score
      
        # True if question_title_similarity is less than 0.2.
        # Corresponds to the JSON property `isDuplicateOfTitle`
        # @return [Boolean]
        attr_accessor :is_duplicate_of_title
        alias_method :is_duplicate_of_title?, :is_duplicate_of_title
      
        # Neon similarity of question and title.
        # Corresponds to the JSON property `neonScore`
        # @return [Float]
        attr_accessor :neon_score
      
        # Pointwise GAP normalized score. Score ranges from 0 to 1 and corresponds to
        # GAP precision. See go/wa-cgap-to-pgap-migration to learn more.
        # Corresponds to the JSON property `pointwiseNormalizedGapScore`
        # @return [Float]
        attr_accessor :pointwise_normalized_gap_score
      
        # QBST similarity of question and title.
        # Corresponds to the JSON property `qbstScore`
        # @return [Float]
        attr_accessor :qbst_score
      
        # NavBoostFeature f_query_count for questions that are NavBoost queries.
        # Corresponds to the JSON property `queryCount`
        # @return [Float]
        attr_accessor :query_count
      
        # NavBoostFeature f_query_doc_count for questions that are NavBoost queries.
        # Corresponds to the JSON property `queryDocCount`
        # @return [Float]
        attr_accessor :query_doc_count
      
        # Question from Related Questions SSTable or NavBoost.
        # Corresponds to the JSON property `question`
        # @return [String]
        attr_accessor :question
      
        # 
        # Corresponds to the JSON property `questionTitleSimilarity`
        # @return [Float]
        attr_accessor :question_title_similarity
      
        # 
        # Corresponds to the JSON property `questionType`
        # @return [String]
        attr_accessor :question_type
      
        # Start time in milliseconds relative to the beginning of the video.
        # Corresponds to the JSON property `startMs`
        # @return [Fixnum]
        attr_accessor :start_ms
      
        # Duration of the video.
        # Corresponds to the JSON property `videoDurationMs`
        # @return [Fixnum]
        attr_accessor :video_duration_ms
      
        # Video title.
        # Corresponds to the JSON property `videoTitle`
        # @return [String]
        attr_accessor :video_title
      
        # Mid corresponding to the WebRef entity from the CDoc that was used to source
        # the question.
        # Corresponds to the JSON property `webrefMid`
        # @return [String]
        attr_accessor :webref_mid
      
        # The WebRef entity topicality score. Learn more about this score at: http://go/
        # topicality-score
        # Corresponds to the JSON property `webrefTopicalityScore`
        # @return [Float]
        attr_accessor :webref_topicality_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @answer = args[:answer] if args.key?(:answer)
          @descartes_dot_score = args[:descartes_dot_score] if args.key?(:descartes_dot_score)
          @descartes_ranking_score = args[:descartes_ranking_score] if args.key?(:descartes_ranking_score)
          @dolphin_model_type = args[:dolphin_model_type] if args.key?(:dolphin_model_type)
          @dolphin_score = args[:dolphin_score] if args.key?(:dolphin_score)
          @edit_distance = args[:edit_distance] if args.key?(:edit_distance)
          @end_ms = args[:end_ms] if args.key?(:end_ms)
          @ensemble_score = args[:ensemble_score] if args.key?(:ensemble_score)
          @is_duplicate_of_title = args[:is_duplicate_of_title] if args.key?(:is_duplicate_of_title)
          @neon_score = args[:neon_score] if args.key?(:neon_score)
          @pointwise_normalized_gap_score = args[:pointwise_normalized_gap_score] if args.key?(:pointwise_normalized_gap_score)
          @qbst_score = args[:qbst_score] if args.key?(:qbst_score)
          @query_count = args[:query_count] if args.key?(:query_count)
          @query_doc_count = args[:query_doc_count] if args.key?(:query_doc_count)
          @question = args[:question] if args.key?(:question)
          @question_title_similarity = args[:question_title_similarity] if args.key?(:question_title_similarity)
          @question_type = args[:question_type] if args.key?(:question_type)
          @start_ms = args[:start_ms] if args.key?(:start_ms)
          @video_duration_ms = args[:video_duration_ms] if args.key?(:video_duration_ms)
          @video_title = args[:video_title] if args.key?(:video_title)
          @webref_mid = args[:webref_mid] if args.key?(:webref_mid)
          @webref_topicality_score = args[:webref_topicality_score] if args.key?(:webref_topicality_score)
        end
      end
      
      # Debug info for Q&A anchors. Next ID: 15
      class VideoContentSearchQnaAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # Path to Descartes background encoding in the form of a serialized drishti.
        # DenseFeatureData proto. This is generated by the
        # flume_generate_background_encoding binary.
        # Corresponds to the JSON property `backgroundEncodingPath`
        # @return [String]
        attr_accessor :background_encoding_path
      
        # This field is used for debugging which model the decartes_model_score is
        # generated from. You can learn more about the Descartes model at go/descartes-
        # qa.
        # Corresponds to the JSON property `descartesModelVersion`
        # @return [String]
        attr_accessor :descartes_model_version
      
        # Descartes score threshold for determining whether to output a QA pair as an
        # anchor. This currently effects only the Descartes ranking score.
        # Corresponds to the JSON property `descartesScoreThreshold`
        # @return [Float]
        attr_accessor :descartes_score_threshold
      
        # The configuration used for fetching Dolphin scores.
        # Corresponds to the JSON property `dolphinConfig`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchDolphinScoringConfig]
        attr_accessor :dolphin_config
      
        # Path to Ranklab ensemble model used in post-trigger step.
        # Corresponds to the JSON property `ensembleModelPath`
        # @return [String]
        attr_accessor :ensemble_model_path
      
        # Minimum score for video anchor to pass the post-trigger step. Calculated by
        # training a logisitic regression model with 95% precision. Training colab can
        # be found at go/video-qa-ensemble.
        # Corresponds to the JSON property `ensembleModelScoreThreshold`
        # @return [Float]
        attr_accessor :ensemble_model_score_threshold
      
        # Threshold for determining whether to consider an entity from a CDoc for
        # sourcing questions on that topic. Learn more about this score at: http://go/
        # topicality-score
        # Corresponds to the JSON property `minEntityTopicalityScore`
        # @return [Float]
        attr_accessor :min_entity_topicality_score
      
        # Threshold for determining whether questions belong in the same cluster.
        # Corresponds to the JSON property `minQuestionDistance`
        # @return [Float]
        attr_accessor :min_question_distance
      
        # Path to the Related Questions SSTable that maps entities to questions.
        # Corresponds to the JSON property `relatedQuestionsSstablePath`
        # @return [String]
        attr_accessor :related_questions_sstable_path
      
        # The duration threshold for merging captions.
        # Corresponds to the JSON property `spanDurationSecs`
        # @return [Fixnum]
        attr_accessor :span_duration_secs
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @background_encoding_path = args[:background_encoding_path] if args.key?(:background_encoding_path)
          @descartes_model_version = args[:descartes_model_version] if args.key?(:descartes_model_version)
          @descartes_score_threshold = args[:descartes_score_threshold] if args.key?(:descartes_score_threshold)
          @dolphin_config = args[:dolphin_config] if args.key?(:dolphin_config)
          @ensemble_model_path = args[:ensemble_model_path] if args.key?(:ensemble_model_path)
          @ensemble_model_score_threshold = args[:ensemble_model_score_threshold] if args.key?(:ensemble_model_score_threshold)
          @min_entity_topicality_score = args[:min_entity_topicality_score] if args.key?(:min_entity_topicality_score)
          @min_question_distance = args[:min_question_distance] if args.key?(:min_question_distance)
          @related_questions_sstable_path = args[:related_questions_sstable_path] if args.key?(:related_questions_sstable_path)
          @span_duration_secs = args[:span_duration_secs] if args.key?(:span_duration_secs)
        end
      end
      
      # Rankembed neighbor neighbor features for the candidate query.
      class VideoContentSearchRankEmbedNearestNeighborsFeatures
        include Google::Apis::Core::Hashable
      
        # Rankembed similarity between the rankembed neighbor and the video anchor.
        # Corresponds to the JSON property `anchorReSimilarity`
        # @return [Float]
        attr_accessor :anchor_re_similarity
      
        # Rankembed similarity between the rankembed neighbor and the top navboost query
        # of the video.
        # Corresponds to the JSON property `navQueryReSimilarity`
        # @return [Float]
        attr_accessor :nav_query_re_similarity
      
        # Rankembed similarity between the rankembed neighbor and the original query
        # candidate.
        # Corresponds to the JSON property `reSimilarity`
        # @return [Float]
        attr_accessor :re_similarity
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_re_similarity = args[:anchor_re_similarity] if args.key?(:anchor_re_similarity)
          @nav_query_re_similarity = args[:nav_query_re_similarity] if args.key?(:nav_query_re_similarity)
          @re_similarity = args[:re_similarity] if args.key?(:re_similarity)
        end
      end
      
      # Saft named-entities info for a given topic.
      class VideoContentSearchSaftEntityInfo
        include Google::Apis::Core::Hashable
      
        # Representative canonical name for the entity.
        # Corresponds to the JSON property `canonicalEntityName`
        # @return [String]
        attr_accessor :canonical_entity_name
      
        # Score indicating the saliency (centrality) of this entity to the original_text.
        # Corresponds to the JSON property `entitySalience`
        # @return [Float]
        attr_accessor :entity_salience
      
        # The type name, like "/saft/person", "/saft/art". See README.entity-types for
        # the inventory of SAFT type tags.
        # Corresponds to the JSON property `entityTypeName`
        # @return [String]
        attr_accessor :entity_type_name
      
        # Representative entity name mention extracted from original_text.
        # Corresponds to the JSON property `mentionText`
        # @return [String]
        attr_accessor :mention_text
      
        # SAFT Mention type.
        # Corresponds to the JSON property `mentionType`
        # @return [String]
        attr_accessor :mention_type
      
        # Freebase MID for entity if this the saft entity corresponds to a Webref KG mid.
        # This field is not always populated and is taken from FREEBASE_MID mid in
        # EntityProfile in the saft entity annotation.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # The original input text (e.g. the anchor text) where the saft entity
        # annotation was run on.
        # Corresponds to the JSON property `originalText`
        # @return [String]
        attr_accessor :original_text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @canonical_entity_name = args[:canonical_entity_name] if args.key?(:canonical_entity_name)
          @entity_salience = args[:entity_salience] if args.key?(:entity_salience)
          @entity_type_name = args[:entity_type_name] if args.key?(:entity_type_name)
          @mention_text = args[:mention_text] if args.key?(:mention_text)
          @mention_type = args[:mention_type] if args.key?(:mention_type)
          @mid = args[:mid] if args.key?(:mid)
          @original_text = args[:original_text] if args.key?(:original_text)
        end
      end
      
      # Features for an individual Shopping Opinions Anchor. This file is used for
      # video anchor use case. Next Id: 34
      class VideoContentSearchShoppingOpinionsAnchorFeatures
        include Google::Apis::Core::Hashable
      
        # The anchor label.
        # Corresponds to the JSON property `anchorLabel`
        # @return [String]
        attr_accessor :anchor_label
      
        # The first anchor_label mention position (word index, 0-based). It is computed
        # from the snippet_sub_segment if exists. Otherwise it is computed from the
        # snippet. It is not populated if there is no such mention.
        # Corresponds to the JSON property `anchorLabelFirstMentionPos`
        # @return [Fixnum]
        attr_accessor :anchor_label_first_mention_pos
      
        # The sentiment score of the anchor label, with range: [-1, 1]. If using Lumin
        # Pro/Con tags as the anchor labels, the "Pro" Lumin tag will have a score of 1
        # and Con Lumin tag will have a score of -1.
        # Corresponds to the JSON property `anchorLabelSentiment`
        # @return [Float]
        attr_accessor :anchor_label_sentiment
      
        # The number of times words in anchor label (that is not a stopword) being
        # mentioned in the snippet.
        # Corresponds to the JSON property `anchorLabelWordsMentions`
        # @return [Fixnum]
        attr_accessor :anchor_label_words_mentions
      
        # The smaller number of anchor_label_first_mention_pos and
        # lumin_aspect_first_mention_pos.
        # Corresponds to the JSON property `anchorOrAspectFirstMentionPos`
        # @return [Fixnum]
        attr_accessor :anchor_or_aspect_first_mention_pos
      
        # The number of times words in anchor label or Lumin aspect (that is not a
        # stopword) being mentioned in the snippet. If a word exists in both anchor
        # label and Lumin aspect, it shall be only counted once for a mention in the
        # snippet.
        # Corresponds to the JSON property `anchorOrAspectWordsMentions`
        # @return [Fixnum]
        attr_accessor :anchor_or_aspect_words_mentions
      
        # Product aspect.
        # Corresponds to the JSON property `aspect`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAspect]
        attr_accessor :aspect
      
        # The asr with sentence break that was used for pro/con extraction.
        # Corresponds to the JSON property `asrForProConExtraction`
        # @return [String]
        attr_accessor :asr_for_pro_con_extraction
      
        # The Babel similarity score between the snippet and the anchor label.
        # Corresponds to the JSON property `babelSimilarityScore`
        # @return [Float]
        attr_accessor :babel_similarity_score
      
        # The classification score of the anchor being a con opinion.
        # Corresponds to the JSON property `conScore`
        # @return [Float]
        attr_accessor :con_score
      
        # The score from the Grampus model if the pro/con is extracted by Grampus.
        # Corresponds to the JSON property `grampusScore`
        # @return [Float]
        attr_accessor :grampus_score
      
        # Whether the anchor is classified as a con opinion.
        # Corresponds to the JSON property `isCon`
        # @return [Boolean]
        attr_accessor :is_con
        alias_method :is_con?, :is_con
      
        # Whether the anchor is classified as a pro opinion.
        # Corresponds to the JSON property `isPro`
        # @return [Boolean]
        attr_accessor :is_pro
        alias_method :is_pro?, :is_pro
      
        # True if the anchor is considered as pro or con when extracted from MUM.
        # Corresponds to the JSON property `isProConWhenExtractedFromMum`
        # @return [Boolean]
        attr_accessor :is_pro_con_when_extracted_from_mum
        alias_method :is_pro_con_when_extracted_from_mum?, :is_pro_con_when_extracted_from_mum
      
        # The lumin aspect of the Pro/Con Lumin tag. e.g. "weight".
        # Corresponds to the JSON property `luminAspect`
        # @return [String]
        attr_accessor :lumin_aspect
      
        # The first Lumin aspect mention position (word index, 0-based). It is computed
        # from the snippet_sub_segment if exists. Otherwise it is computed from the
        # snippet. It is not populated if there is no such mention.
        # Corresponds to the JSON property `luminAspectFirstMentionPos`
        # @return [Fixnum]
        attr_accessor :lumin_aspect_first_mention_pos
      
        # The number of times words in Lumin aspect (that is not a stopword) being
        # mentioned in the snippet.
        # Corresponds to the JSON property `luminAspectWordsMentions`
        # @return [Fixnum]
        attr_accessor :lumin_aspect_words_mentions
      
        # The Lumin model score for the anchor label against the segment.
        # Corresponds to the JSON property `luminScore`
        # @return [Float]
        attr_accessor :lumin_score
      
        # The product aspect of the pro/con generated using the MUM model.
        # Corresponds to the JSON property `mumProductAspect`
        # @return [String]
        attr_accessor :mum_product_aspect
      
        # The score from the MUM model if the pro/con anchor is extracted by MUM.
        # Corresponds to the JSON property `mumScore`
        # @return [Float]
        attr_accessor :mum_score
      
        # Scores from Opinions Dolphin scorer. Opinions Dolphin scorer is built by
        # finetuning the Dolphin-based Video Anchor Unified Scorer V2 on the Opinions
        # anchors ratings. It outputs two scores, which are optimized for
        # descriptiveness and usefulness ratings respectively. 'descriptiveness_score'
        # measures how well the anchor label describes the video section. '
        # usefulness_score' measures how useful the anchor label is for jumping to an
        # important section in the video. go/vs-opinions-migration-report
        # Corresponds to the JSON property `opinionsDolphinDescriptivenessScore`
        # @return [Float]
        attr_accessor :opinions_dolphin_descriptiveness_score
      
        # 
        # Corresponds to the JSON property `opinionsDolphinUsefulnessScore`
        # @return [Float]
        attr_accessor :opinions_dolphin_usefulness_score
      
        # The classification score of the anchor being a pro opinion.
        # Corresponds to the JSON property `proScore`
        # @return [Float]
        attr_accessor :pro_score
      
        # The product name from title extracted by the grampus model.
        # Corresponds to the JSON property `productNameFromTitle`
        # @return [String]
        attr_accessor :product_name_from_title
      
        # The question used to score this video segment.
        # Corresponds to the JSON property `question`
        # @return [String]
        attr_accessor :question
      
        # The ASR for the selected segment window.
        # Corresponds to the JSON property `snippet`
        # @return [String]
        attr_accessor :snippet
      
        # The QA model score for the selected segment window against the question.
        # Corresponds to the JSON property `snippetQaScore`
        # @return [Float]
        attr_accessor :snippet_qa_score
      
        # The go/scarlett sentiment score of the selected segment window. Positive score
        # represents positive sentiment. Negative score represents negative sentiment.
        # Corresponds to the JSON property `snippetSentimentScore`
        # @return [Float]
        attr_accessor :snippet_sentiment_score
      
        # The ASR for the best matched sub segment inside the selected segment.
        # Corresponds to the JSON property `snippetSubSegment`
        # @return [String]
        attr_accessor :snippet_sub_segment
      
        # The QA model score for the best sub segment against the question.
        # Corresponds to the JSON property `snippetSubSegmentQaScore`
        # @return [Float]
        attr_accessor :snippet_sub_segment_qa_score
      
        # The go/scarlett sentiment score of the best matched sub segment. Positive
        # score represents positive sentiment. Negative score represents negative
        # sentiment.
        # Corresponds to the JSON property `snippetSubSegmentSentimentScore`
        # @return [Float]
        attr_accessor :snippet_sub_segment_sentiment_score
      
        # The number of words in the ASR for the best matched sub segment.
        # Corresponds to the JSON property `snippetSubSegmentWordCount`
        # @return [Fixnum]
        attr_accessor :snippet_sub_segment_word_count
      
        # The number of words in the ASR for the selected segment window.
        # Corresponds to the JSON property `snippetWordCount`
        # @return [Fixnum]
        attr_accessor :snippet_word_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_label = args[:anchor_label] if args.key?(:anchor_label)
          @anchor_label_first_mention_pos = args[:anchor_label_first_mention_pos] if args.key?(:anchor_label_first_mention_pos)
          @anchor_label_sentiment = args[:anchor_label_sentiment] if args.key?(:anchor_label_sentiment)
          @anchor_label_words_mentions = args[:anchor_label_words_mentions] if args.key?(:anchor_label_words_mentions)
          @anchor_or_aspect_first_mention_pos = args[:anchor_or_aspect_first_mention_pos] if args.key?(:anchor_or_aspect_first_mention_pos)
          @anchor_or_aspect_words_mentions = args[:anchor_or_aspect_words_mentions] if args.key?(:anchor_or_aspect_words_mentions)
          @aspect = args[:aspect] if args.key?(:aspect)
          @asr_for_pro_con_extraction = args[:asr_for_pro_con_extraction] if args.key?(:asr_for_pro_con_extraction)
          @babel_similarity_score = args[:babel_similarity_score] if args.key?(:babel_similarity_score)
          @con_score = args[:con_score] if args.key?(:con_score)
          @grampus_score = args[:grampus_score] if args.key?(:grampus_score)
          @is_con = args[:is_con] if args.key?(:is_con)
          @is_pro = args[:is_pro] if args.key?(:is_pro)
          @is_pro_con_when_extracted_from_mum = args[:is_pro_con_when_extracted_from_mum] if args.key?(:is_pro_con_when_extracted_from_mum)
          @lumin_aspect = args[:lumin_aspect] if args.key?(:lumin_aspect)
          @lumin_aspect_first_mention_pos = args[:lumin_aspect_first_mention_pos] if args.key?(:lumin_aspect_first_mention_pos)
          @lumin_aspect_words_mentions = args[:lumin_aspect_words_mentions] if args.key?(:lumin_aspect_words_mentions)
          @lumin_score = args[:lumin_score] if args.key?(:lumin_score)
          @mum_product_aspect = args[:mum_product_aspect] if args.key?(:mum_product_aspect)
          @mum_score = args[:mum_score] if args.key?(:mum_score)
          @opinions_dolphin_descriptiveness_score = args[:opinions_dolphin_descriptiveness_score] if args.key?(:opinions_dolphin_descriptiveness_score)
          @opinions_dolphin_usefulness_score = args[:opinions_dolphin_usefulness_score] if args.key?(:opinions_dolphin_usefulness_score)
          @pro_score = args[:pro_score] if args.key?(:pro_score)
          @product_name_from_title = args[:product_name_from_title] if args.key?(:product_name_from_title)
          @question = args[:question] if args.key?(:question)
          @snippet = args[:snippet] if args.key?(:snippet)
          @snippet_qa_score = args[:snippet_qa_score] if args.key?(:snippet_qa_score)
          @snippet_sentiment_score = args[:snippet_sentiment_score] if args.key?(:snippet_sentiment_score)
          @snippet_sub_segment = args[:snippet_sub_segment] if args.key?(:snippet_sub_segment)
          @snippet_sub_segment_qa_score = args[:snippet_sub_segment_qa_score] if args.key?(:snippet_sub_segment_qa_score)
          @snippet_sub_segment_sentiment_score = args[:snippet_sub_segment_sentiment_score] if args.key?(:snippet_sub_segment_sentiment_score)
          @snippet_sub_segment_word_count = args[:snippet_sub_segment_word_count] if args.key?(:snippet_sub_segment_word_count)
          @snippet_word_count = args[:snippet_word_count] if args.key?(:snippet_word_count)
        end
      end
      
      # 
      class VideoContentSearchSimilarityMatchInfo
        include Google::Apis::Core::Hashable
      
        # The timestamp of when the first token in the token sequence is spoken in the
        # video.
        # Corresponds to the JSON property `instructionStartMs`
        # @return [Fixnum]
        attr_accessor :instruction_start_ms
      
        # The instruction step text coming from the web document. Currently only
        # populated for best_description_and_instruction_anchors_match_info.
        # Corresponds to the JSON property `instructionText`
        # @return [String]
        attr_accessor :instruction_text
      
        # The reference text used for matching against token_sequence (e.g. description
        # anchor text or instruction step text).
        # Corresponds to the JSON property `referenceText`
        # @return [String]
        attr_accessor :reference_text
      
        # The timestamp of when the reference text is pointing in the video (e.g. this
        # is the description anchor timestamp when reference_text is description anchor.
        # For instruction step used as the reference, no timestamps exists and thus this
        # field is not populated).
        # Corresponds to the JSON property `referenceTextTimeMs`
        # @return [Fixnum]
        attr_accessor :reference_text_time_ms
      
        # Similarity scorer name.
        # Corresponds to the JSON property `scoringMethodName`
        # @return [String]
        attr_accessor :scoring_method_name
      
        # The similarity score given by the scoring method specified by the message
        # scoring_method_name.
        # Corresponds to the JSON property `similarityScore`
        # @return [Float]
        attr_accessor :similarity_score
      
        # The index of the step in HowToInstructions that this token_sequence
        # corresponds to.
        # Corresponds to the JSON property `stepIndex`
        # @return [Fixnum]
        attr_accessor :step_index
      
        # The matched token sequence text in ASR.
        # Corresponds to the JSON property `tokenSequence`
        # @return [String]
        attr_accessor :token_sequence
      
        # The length of the tokens in the token sequence.
        # Corresponds to the JSON property `tokenSequenceLength`
        # @return [Fixnum]
        attr_accessor :token_sequence_length
      
        # The token offset of the matched token sequence from the beginning of the
        # document.
        # Corresponds to the JSON property `tokenStartPos`
        # @return [Fixnum]
        attr_accessor :token_start_pos
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @instruction_start_ms = args[:instruction_start_ms] if args.key?(:instruction_start_ms)
          @instruction_text = args[:instruction_text] if args.key?(:instruction_text)
          @reference_text = args[:reference_text] if args.key?(:reference_text)
          @reference_text_time_ms = args[:reference_text_time_ms] if args.key?(:reference_text_time_ms)
          @scoring_method_name = args[:scoring_method_name] if args.key?(:scoring_method_name)
          @similarity_score = args[:similarity_score] if args.key?(:similarity_score)
          @step_index = args[:step_index] if args.key?(:step_index)
          @token_sequence = args[:token_sequence] if args.key?(:token_sequence)
          @token_sequence_length = args[:token_sequence_length] if args.key?(:token_sequence_length)
          @token_start_pos = args[:token_start_pos] if args.key?(:token_start_pos)
        end
      end
      
      # 
      class VideoContentSearchSpanDolphinFeatures
        include Google::Apis::Core::Hashable
      
        # The text passage from ASR.
        # Corresponds to the JSON property `passage`
        # @return [String]
        attr_accessor :passage
      
        # The title of the video.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @passage = args[:passage] if args.key?(:passage)
          @title = args[:title] if args.key?(:title)
        end
      end
      
      # 
      class VideoContentSearchSpanDolphinScores
        include Google::Apis::Core::Hashable
      
        # The span candidates extracted from the list of span tokens. Each token is
        # added to a span if its score is above a certain threshold.
        # Corresponds to the JSON property `spanCandidate`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchSpanDolphinScoresSpanCandidate>]
        attr_accessor :span_candidate
      
        # The token-score pairs for the passage.
        # Corresponds to the JSON property `spanToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchSpanDolphinScoresSpanToken>]
        attr_accessor :span_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @span_candidate = args[:span_candidate] if args.key?(:span_candidate)
          @span_token = args[:span_token] if args.key?(:span_token)
        end
      end
      
      # 
      class VideoContentSearchSpanDolphinScoresSpanCandidate
        include Google::Apis::Core::Hashable
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `asrConfidenceStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :asr_confidence_stats
      
        # Median, mean and standard deviation of a feature value.
        # Corresponds to the JSON property `scoreStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMetricStats]
        attr_accessor :score_stats
      
        # The passage text from which this span candidate belongs to. In case of
        # description spans, this field stores the sentence containing the span
        # candidate where the sentence is a subset of the passage used for generating
        # the span candidate.
        # Corresponds to the JSON property `sourcePassage`
        # @return [String]
        attr_accessor :source_passage
      
        # The span candidate text.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # The start time for the span candidate.
        # Corresponds to the JSON property `timeMs`
        # @return [Fixnum]
        attr_accessor :time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_confidence_stats = args[:asr_confidence_stats] if args.key?(:asr_confidence_stats)
          @score_stats = args[:score_stats] if args.key?(:score_stats)
          @source_passage = args[:source_passage] if args.key?(:source_passage)
          @text = args[:text] if args.key?(:text)
          @time_ms = args[:time_ms] if args.key?(:time_ms)
        end
      end
      
      # 
      class VideoContentSearchSpanDolphinScoresSpanToken
        include Google::Apis::Core::Hashable
      
        # The ASR confidence for the token, if available.
        # Corresponds to the JSON property `asrConfidence`
        # @return [Float]
        attr_accessor :asr_confidence
      
        # Whether or not this token is the first token in a sentence.
        # Corresponds to the JSON property `isSentenceStart`
        # @return [Boolean]
        attr_accessor :is_sentence_start
        alias_method :is_sentence_start?, :is_sentence_start
      
        # A score correlated with the probability that the token is part of a span
        # candidate.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # The token text.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        # The start time of the passage with this token.
        # Corresponds to the JSON property `timeMs`
        # @return [Fixnum]
        attr_accessor :time_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @asr_confidence = args[:asr_confidence] if args.key?(:asr_confidence)
          @is_sentence_start = args[:is_sentence_start] if args.key?(:is_sentence_start)
          @score = args[:score] if args.key?(:score)
          @text = args[:text] if args.key?(:text)
          @time_ms = args[:time_ms] if args.key?(:time_ms)
        end
      end
      
      # Features for a set of Sports Key Moments (SKM) Anchors. Each instance of this
      # object should be associated with a VideoAnchorSets object. Next ID: 3
      class VideoContentSearchSportsKeyMomentsAnchorSetFeatures
        include Google::Apis::Core::Hashable
      
        # The Prefilter classification label associated with the video that contains the
        # VideoAnchorSets this object is asociated with. E.g. "basketball".
        # Corresponds to the JSON property `prefilterClassificationLabel`
        # @return [String]
        attr_accessor :prefilter_classification_label
      
        # Version of the underlying TensorFlow model.
        # Corresponds to the JSON property `tensorflowModelVersion`
        # @return [String]
        attr_accessor :tensorflow_model_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @prefilter_classification_label = args[:prefilter_classification_label] if args.key?(:prefilter_classification_label)
          @tensorflow_model_version = args[:tensorflow_model_version] if args.key?(:tensorflow_model_version)
        end
      end
      
      # 
      class VideoContentSearchTextMatchInfo
        include Google::Apis::Core::Hashable
      
        # The time gap of the matched_time_ms from the predicted timestamp of when this
        # anchor should appear in the video.
        # Corresponds to the JSON property `durationToPredictedTimeMs`
        # @return [Fixnum]
        attr_accessor :duration_to_predicted_time_ms
      
        # The float similarty score from the anchor label to matched_asr_text.
        # Corresponds to the JSON property `matchScore`
        # @return [Float]
        attr_accessor :match_score
      
        # The start token offset from the beginning of ASR where matched_asr_text starts.
        # Corresponds to the JSON property `matchedAsrStartPos`
        # @return [Fixnum]
        attr_accessor :matched_asr_start_pos
      
        # The ASR text that was a candidate match for the list anchor.
        # Corresponds to the JSON property `matchedAsrText`
        # @return [String]
        attr_accessor :matched_asr_text
      
        # The timestamp of the matched ASR in the video in milliseconds.
        # Corresponds to the JSON property `matchedAsrTimeMs`
        # @return [Fixnum]
        attr_accessor :matched_asr_time_ms
      
        # The ratio of the matched_asr_time_ms over the total duration of the video.
        # Corresponds to the JSON property `matchedAsrTimeRatio`
        # @return [Float]
        attr_accessor :matched_asr_time_ratio
      
        # The number of tokens in matched_asr_text
        # Corresponds to the JSON property `matchedAsrTokenCount`
        # @return [Fixnum]
        attr_accessor :matched_asr_token_count
      
        # The ratio of the video description item index this match corresponds to over
        # the total number of list description items for the video.
        # Corresponds to the JSON property `matchedDescriptionItemIndexRatio`
        # @return [Float]
        attr_accessor :matched_description_item_index_ratio
      
        # The video description text matched with the ASR that's used as the anchor
        # label.
        # Corresponds to the JSON property `matchedDescriptionText`
        # @return [String]
        attr_accessor :matched_description_text
      
        # The number of tokens in matched_description_text.
        # Corresponds to the JSON property `matchedDescriptionTokenCount`
        # @return [Fixnum]
        attr_accessor :matched_description_token_count
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @duration_to_predicted_time_ms = args[:duration_to_predicted_time_ms] if args.key?(:duration_to_predicted_time_ms)
          @match_score = args[:match_score] if args.key?(:match_score)
          @matched_asr_start_pos = args[:matched_asr_start_pos] if args.key?(:matched_asr_start_pos)
          @matched_asr_text = args[:matched_asr_text] if args.key?(:matched_asr_text)
          @matched_asr_time_ms = args[:matched_asr_time_ms] if args.key?(:matched_asr_time_ms)
          @matched_asr_time_ratio = args[:matched_asr_time_ratio] if args.key?(:matched_asr_time_ratio)
          @matched_asr_token_count = args[:matched_asr_token_count] if args.key?(:matched_asr_token_count)
          @matched_description_item_index_ratio = args[:matched_description_item_index_ratio] if args.key?(:matched_description_item_index_ratio)
          @matched_description_text = args[:matched_description_text] if args.key?(:matched_description_text)
          @matched_description_token_count = args[:matched_description_token_count] if args.key?(:matched_description_token_count)
        end
      end
      
      # 
      class VideoContentSearchTextSimilarityFeatures
        include Google::Apis::Core::Hashable
      
        # The hypothesis text that was used for the token overlap calculation.
        # Corresponds to the JSON property `hypothesisText`
        # @return [String]
        attr_accessor :hypothesis_text
      
        # The time in ms for the hypothesis_text.
        # Corresponds to the JSON property `hypothesisTextTime`
        # @return [Fixnum]
        attr_accessor :hypothesis_text_time
      
        # 
        # Corresponds to the JSON property `referenceText`
        # @return [String]
        attr_accessor :reference_text
      
        # Similarity scorer name.
        # Corresponds to the JSON property `scoringMethodName`
        # @return [String]
        attr_accessor :scoring_method_name
      
        # The similarity score given by the scoring method specified by the message
        # scoring_method_name.
        # Corresponds to the JSON property `similarityScore`
        # @return [Float]
        attr_accessor :similarity_score
      
        # Token by token matching stats. Exact matched token count.
        # Corresponds to the JSON property `tokenMatchCount`
        # @return [Fixnum]
        attr_accessor :token_match_count
      
        # The token_overlap_count divided by the number of tokens in the hypothesis text.
        # Corresponds to the JSON property `tokenMatchPercent`
        # @return [Float]
        attr_accessor :token_match_percent
      
        # Word by word alignment.
        # Corresponds to the JSON property `wordAlignment`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchTokenAlignment>]
        attr_accessor :word_alignment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hypothesis_text = args[:hypothesis_text] if args.key?(:hypothesis_text)
          @hypothesis_text_time = args[:hypothesis_text_time] if args.key?(:hypothesis_text_time)
          @reference_text = args[:reference_text] if args.key?(:reference_text)
          @scoring_method_name = args[:scoring_method_name] if args.key?(:scoring_method_name)
          @similarity_score = args[:similarity_score] if args.key?(:similarity_score)
          @token_match_count = args[:token_match_count] if args.key?(:token_match_count)
          @token_match_percent = args[:token_match_percent] if args.key?(:token_match_percent)
          @word_alignment = args[:word_alignment] if args.key?(:word_alignment)
        end
      end
      
      # Token by token mapping between hypothesis text and reference text.
      class VideoContentSearchTokenAlignment
        include Google::Apis::Core::Hashable
      
        # Index of the token in hypothesis text.
        # Corresponds to the JSON property `hypothesisIndex`
        # @return [Fixnum]
        attr_accessor :hypothesis_index
      
        # Token in hypothesis.
        # Corresponds to the JSON property `hypothesisToken`
        # @return [String]
        attr_accessor :hypothesis_token
      
        # Index of the word in reference.
        # Corresponds to the JSON property `referenceIndex`
        # @return [Fixnum]
        attr_accessor :reference_index
      
        # Token in label.
        # Corresponds to the JSON property `referenceToken`
        # @return [String]
        attr_accessor :reference_token
      
        # Whether it's a perfect match.
        # Corresponds to the JSON property `tokenIsMatched`
        # @return [Boolean]
        attr_accessor :token_is_matched
        alias_method :token_is_matched?, :token_is_matched
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @hypothesis_index = args[:hypothesis_index] if args.key?(:hypothesis_index)
          @hypothesis_token = args[:hypothesis_token] if args.key?(:hypothesis_token)
          @reference_index = args[:reference_index] if args.key?(:reference_index)
          @reference_token = args[:reference_token] if args.key?(:reference_token)
          @token_is_matched = args[:token_is_matched] if args.key?(:token_is_matched)
        end
      end
      
      # Token level timing information for ASR spans. This is expected to be extracted
      # from PseudoVideoData in the CDoc. Next ID: 5
      class VideoContentSearchTokenTimingInfo
        include Google::Apis::Core::Hashable
      
        # Generated from th PseudoVideoData Timestamp Confidence field, which is
        # quantized values in range 0-127. To convert to range 0-1 this field divides
        # the PseudoVideoData Timestamp Confidence field by 127.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `durationMs`
        # @return [Fixnum]
        attr_accessor :duration_ms
      
        # 
        # Corresponds to the JSON property `startMs`
        # @return [Fixnum]
        attr_accessor :start_ms
      
        # Should be a single token.
        # Corresponds to the JSON property `text`
        # @return [String]
        attr_accessor :text
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @start_ms = args[:start_ms] if args.key?(:start_ms)
          @text = args[:text] if args.key?(:text)
        end
      end
      
      # Video level info for online pipeline usage. For example: skip pattern as
      # defined in https://schema.org/SeekToAction.
      class VideoContentSearchVideoActions
        include Google::Apis::Core::Hashable
      
        # startOffset_input name as defined in https://schema.org/SeekToAction
        # Corresponds to the JSON property `skipPatternStartOffsetInput`
        # @return [String]
        attr_accessor :skip_pattern_start_offset_input
      
        # Skip to time pattern as defined in https://schema.org/SeekToAction
        # Corresponds to the JSON property `skipToTimePattern`
        # @return [String]
        attr_accessor :skip_to_time_pattern
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @skip_pattern_start_offset_input = args[:skip_pattern_start_offset_input] if args.key?(:skip_pattern_start_offset_input)
          @skip_to_time_pattern = args[:skip_to_time_pattern] if args.key?(:skip_to_time_pattern)
        end
      end
      
      # Next ID: 22
      class VideoContentSearchVideoAnchor
        include Google::Apis::Core::Hashable
      
        # The score indicating anchor confidence.
        # Corresponds to the JSON property `anchorScore`
        # @return [Float]
        attr_accessor :anchor_score
      
        # Specifies the type of the anchor.
        # Corresponds to the JSON property `anchorType`
        # @return [String]
        attr_accessor :anchor_type
      
        # When set, this is the link that should be used when clicking on a video anchor.
        # This should jump to the given time in the video.
        # Corresponds to the JSON property `destinationUrl`
        # @return [String]
        attr_accessor :destination_url
      
        # The duration of the video anchor in milliseconds.
        # Corresponds to the JSON property `duration`
        # @return [Fixnum]
        attr_accessor :duration
      
        # The score indicating the usefulness of the entity identified by 'mid'.
        # Corresponds to the JSON property `entityScore`
        # @return [Float]
        attr_accessor :entity_score
      
        # If is_filtered is true, this field illustrates the reasons.
        # Corresponds to the JSON property `filterReason`
        # @return [Array<String>]
        attr_accessor :filter_reason
      
        # If true, the anchor is filtered and not served online.
        # Corresponds to the JSON property `isFiltered`
        # @return [Boolean]
        attr_accessor :is_filtered
        alias_method :is_filtered?, :is_filtered
      
        # Convenience field that consolidates signals for whether this label is safe.
        # Corresponds to the JSON property `isSafe`
        # @return [Boolean]
        attr_accessor :is_safe
        alias_method :is_safe?, :is_safe
      
        # whether this label is bad by go/scuti
        # Corresponds to the JSON property `isScutiBad`
        # @return [Boolean]
        attr_accessor :is_scuti_bad
        alias_method :is_scuti_bad?, :is_scuti_bad
      
        # The text label of the video anchor.
        # Corresponds to the JSON property `label`
        # @return [String]
        attr_accessor :label
      
        # The score indicating label confidence.
        # Corresponds to the JSON property `labelScore`
        # @return [Float]
        attr_accessor :label_score
      
        # The mid of the video anchor.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Specifies named enitities the label has.
        # Corresponds to the JSON property `namedEntity`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchNamedEntity>]
        attr_accessor :named_entity
      
        # The precision for which the anchor should trigger. For example, if the desired
        # precision is 95%, anchors with precision_score < 0.95 should be removed.
        # Corresponds to the JSON property `precisionScore`
        # @return [Float]
        attr_accessor :precision_score
      
        # Message to contain scoring / debugging information. If you want to add
        # information which is not directly used in the final VideoAnchor data, it
        # should be put here. Next ID: 25
        # Corresponds to the JSON property `scoreInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorScoreInfo]
        attr_accessor :score_info
      
        # Startburst visual tokens or features, more details in go/starburst-mum-user-
        # guide
        # Corresponds to the JSON property `starburstFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVisualFeatures]
        attr_accessor :starburst_features
      
        # Properties of the thumbnail image to show for an anchor.
        # Corresponds to the JSON property `thumbnail`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorThumbnail]
        attr_accessor :thumbnail
      
        # The url for a frame to display for this anchor.
        # Corresponds to the JSON property `thumbnailUrl`
        # @return [String]
        attr_accessor :thumbnail_url
      
        # The time stamp of the video anchor in milliseconds.
        # Corresponds to the JSON property `time`
        # @return [Fixnum]
        attr_accessor :time
      
        # Timing info for each token in the anchor label.
        # Corresponds to the JSON property `tokenTimingInfo`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchTokenTimingInfo>]
        attr_accessor :token_timing_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_score = args[:anchor_score] if args.key?(:anchor_score)
          @anchor_type = args[:anchor_type] if args.key?(:anchor_type)
          @destination_url = args[:destination_url] if args.key?(:destination_url)
          @duration = args[:duration] if args.key?(:duration)
          @entity_score = args[:entity_score] if args.key?(:entity_score)
          @filter_reason = args[:filter_reason] if args.key?(:filter_reason)
          @is_filtered = args[:is_filtered] if args.key?(:is_filtered)
          @is_safe = args[:is_safe] if args.key?(:is_safe)
          @is_scuti_bad = args[:is_scuti_bad] if args.key?(:is_scuti_bad)
          @label = args[:label] if args.key?(:label)
          @label_score = args[:label_score] if args.key?(:label_score)
          @mid = args[:mid] if args.key?(:mid)
          @named_entity = args[:named_entity] if args.key?(:named_entity)
          @precision_score = args[:precision_score] if args.key?(:precision_score)
          @score_info = args[:score_info] if args.key?(:score_info)
          @starburst_features = args[:starburst_features] if args.key?(:starburst_features)
          @thumbnail = args[:thumbnail] if args.key?(:thumbnail)
          @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url)
          @time = args[:time] if args.key?(:time)
          @token_timing_info = args[:token_timing_info] if args.key?(:token_timing_info)
        end
      end
      
      # Aggregated rating score, used in training pipeline, etc.
      class VideoContentSearchVideoAnchorRatingScore
        include Google::Apis::Core::Hashable
      
        # Average score of bookmark usefulness.
        # Corresponds to the JSON property `averageBookmarkUsefulness`
        # @return [Float]
        attr_accessor :average_bookmark_usefulness
      
        # Average score of description quality.
        # Corresponds to the JSON property `averageDescriptionQuality`
        # @return [Float]
        attr_accessor :average_description_quality
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_bookmark_usefulness = args[:average_bookmark_usefulness] if args.key?(:average_bookmark_usefulness)
          @average_description_quality = args[:average_description_quality] if args.key?(:average_description_quality)
        end
      end
      
      # Message to contain scoring / debugging information. If you want to add
      # information which is not directly used in the final VideoAnchor data, it
      # should be put here. Next ID: 25
      class VideoContentSearchVideoAnchorScoreInfo
        include Google::Apis::Core::Hashable
      
        # Contains anchor level features that apply to all anchor types. Next id: 18.
        # Corresponds to the JSON property `anchorCommonFeatureSet`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorCommonFeatureSet]
        attr_accessor :anchor_common_feature_set
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `attachments`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :attachments
      
        # Features and debug info for individual caption entity video anchors.
        # Corresponds to the JSON property `captionEntityAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionEntityAnchorFeatures]
        attr_accessor :caption_entity_anchor_features
      
        # Features for caption span anchors for use in training.
        # Corresponds to the JSON property `captionSpanAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionSpanAnchorFeatures]
        attr_accessor :caption_span_anchor_features
      
        # Description anchor features for use in training.
        # Corresponds to the JSON property `descriptionAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchDescriptionAnchorFeatures]
        attr_accessor :description_anchor_features
      
        # A description of why the anchor was removed. This is intended for debugging
        # anchor sets which use multiple heuristics to filter anchors.
        # Corresponds to the JSON property `filterReason`
        # @return [Array<String>]
        attr_accessor :filter_reason
      
        # Whether or not the anchor will be removed in the final proto.
        # Corresponds to the JSON property `filtered`
        # @return [Boolean]
        attr_accessor :filtered
        alias_method :filtered?, :filtered
      
        # Generated predictions from generative models
        # Corresponds to the JSON property `generativeFeatures`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchGenerativePredictionFeatures>]
        attr_accessor :generative_features
      
        # Anchor-level Metadata about Instruction anchors. TODO(keyvana) Update this
        # proto.
        # Corresponds to the JSON property `instructionAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchInstructionAnchorFeatures]
        attr_accessor :instruction_anchor_features
      
        # Anchor-level metadata about the instruction anchors. Each instruction passage
        # anchor can contain multiple instruction steps and multiple description anchors
        # and thus the following fields are defined as repeated.
        # Corresponds to the JSON property `instructionTrainingDataAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchInstructionTrainingDataAnchorFeatures]
        attr_accessor :instruction_training_data_anchor_features
      
        # Detected language of label
        # Corresponds to the JSON property `labelLanguage`
        # @return [String]
        attr_accessor :label_language
      
        # 
        # Corresponds to the JSON property `labelTransformation`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorScoreInfoLabelTransformation>]
        attr_accessor :label_transformation
      
        # Anchor-level Metadata about list description anchors.
        # Corresponds to the JSON property `listAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchListAnchorFeatures]
        attr_accessor :list_anchor_features
      
        # Anchor-level metadata about the description anchors used as list items to
        # build training data for list anchors.
        # Corresponds to the JSON property `listTrainingDataAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchListTrainingDataAnchorFeatures]
        attr_accessor :list_training_data_anchor_features
      
        # Multimodal features for a single generated topic. Next ID: 8
        # Corresponds to the JSON property `multimodalTopicFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMultimodalTopicFeatures]
        attr_accessor :multimodal_topic_features
      
        # Multimodal features for a single generated topic used to build training data.
        # Corresponds to the JSON property `multimodalTopicTrainingFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchMultimodalTopicTrainingFeatures]
        attr_accessor :multimodal_topic_training_features
      
        # Keep feature values which are useful to filter titles, labels.
        # Corresponds to the JSON property `ocrAnchorFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOnScreenTextFeature]
        attr_accessor :ocr_anchor_feature
      
        # Metadata about the join of description anchors and OCR data which is used to
        # build training data.
        # Corresponds to the JSON property `ocrDescriptionTrainingDataAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOcrDescriptionTrainingDataAnchorFeatures]
        attr_accessor :ocr_description_training_data_anchor_features
      
        # Features for an individual Shopping Opinions Anchor. This file is used for
        # video anchor use case. Next Id: 34
        # Corresponds to the JSON property `opinionsAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchShoppingOpinionsAnchorFeatures]
        attr_accessor :opinions_anchor_features
      
        # Features for individual Q&A anchors. Next ID: 23
        # Corresponds to the JSON property `qnaAnchorFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchQnaAnchorFeatures]
        attr_accessor :qna_anchor_features
      
        # Aggregated rating score, used in training pipeline, etc.
        # Corresponds to the JSON property `ratingScore`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorRatingScore]
        attr_accessor :rating_score
      
        # Multi-label classification output. It contains the output for each vertical.
        # The output for some verticals can be empty, in case that vertical is not
        # supported by the classifier or if the set of verticals was restricted using
        # MultiLabelClassifierInput.verticals.
        # Corresponds to the JSON property `safeSearchClassifierOutput`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryMultiLabelClassifierOutput]
        attr_accessor :safe_search_classifier_output
      
        # ASR matching feature for any anchor types.
        # Corresponds to the JSON property `textSimilarityFeatures`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchTextSimilarityFeatures>]
        attr_accessor :text_similarity_features
      
        # Information about the thumbnail anchor.
        # Corresponds to the JSON property `thumbnailInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorThumbnailInfo]
        attr_accessor :thumbnail_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_common_feature_set = args[:anchor_common_feature_set] if args.key?(:anchor_common_feature_set)
          @attachments = args[:attachments] if args.key?(:attachments)
          @caption_entity_anchor_features = args[:caption_entity_anchor_features] if args.key?(:caption_entity_anchor_features)
          @caption_span_anchor_features = args[:caption_span_anchor_features] if args.key?(:caption_span_anchor_features)
          @description_anchor_features = args[:description_anchor_features] if args.key?(:description_anchor_features)
          @filter_reason = args[:filter_reason] if args.key?(:filter_reason)
          @filtered = args[:filtered] if args.key?(:filtered)
          @generative_features = args[:generative_features] if args.key?(:generative_features)
          @instruction_anchor_features = args[:instruction_anchor_features] if args.key?(:instruction_anchor_features)
          @instruction_training_data_anchor_features = args[:instruction_training_data_anchor_features] if args.key?(:instruction_training_data_anchor_features)
          @label_language = args[:label_language] if args.key?(:label_language)
          @label_transformation = args[:label_transformation] if args.key?(:label_transformation)
          @list_anchor_features = args[:list_anchor_features] if args.key?(:list_anchor_features)
          @list_training_data_anchor_features = args[:list_training_data_anchor_features] if args.key?(:list_training_data_anchor_features)
          @multimodal_topic_features = args[:multimodal_topic_features] if args.key?(:multimodal_topic_features)
          @multimodal_topic_training_features = args[:multimodal_topic_training_features] if args.key?(:multimodal_topic_training_features)
          @ocr_anchor_feature = args[:ocr_anchor_feature] if args.key?(:ocr_anchor_feature)
          @ocr_description_training_data_anchor_features = args[:ocr_description_training_data_anchor_features] if args.key?(:ocr_description_training_data_anchor_features)
          @opinions_anchor_features = args[:opinions_anchor_features] if args.key?(:opinions_anchor_features)
          @qna_anchor_features = args[:qna_anchor_features] if args.key?(:qna_anchor_features)
          @rating_score = args[:rating_score] if args.key?(:rating_score)
          @safe_search_classifier_output = args[:safe_search_classifier_output] if args.key?(:safe_search_classifier_output)
          @text_similarity_features = args[:text_similarity_features] if args.key?(:text_similarity_features)
          @thumbnail_info = args[:thumbnail_info] if args.key?(:thumbnail_info)
        end
      end
      
      # Used to store the label before label cleaning or other transformations. If the
      # label goes through multiple transformations, the original_label vector will
      # include the transformations in chronological order.
      class VideoContentSearchVideoAnchorScoreInfoLabelTransformation
        include Google::Apis::Core::Hashable
      
        # A label for the transformation.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # The label that was transformated from.
        # Corresponds to the JSON property `sourceLabel`
        # @return [String]
        attr_accessor :source_label
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @description = args[:description] if args.key?(:description)
          @source_label = args[:source_label] if args.key?(:source_label)
        end
      end
      
      # Aggregated set level rating score, used in training pipeline, etc.
      class VideoContentSearchVideoAnchorSetRatingScore
        include Google::Apis::Core::Hashable
      
        # Average score of set level description quality.
        # Corresponds to the JSON property `averageSetDescriptionQuality`
        # @return [Float]
        attr_accessor :average_set_description_quality
      
        # Average score of how useful the set is for navigation.
        # Corresponds to the JSON property `averageSetNavigationUsefulness`
        # @return [Float]
        attr_accessor :average_set_navigation_usefulness
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_set_description_quality = args[:average_set_description_quality] if args.key?(:average_set_description_quality)
          @average_set_navigation_usefulness = args[:average_set_navigation_usefulness] if args.key?(:average_set_navigation_usefulness)
        end
      end
      
      # One video can have multiple types of text anchors. For example, https://www.
      # youtube.com/watch?v=Rtk0I5PVOIc has both list anchors and OCR anchors.
      class VideoContentSearchVideoAnchorSets
        include Google::Apis::Core::Hashable
      
        # Video level info for online pipeline usage. For example: skip pattern as
        # defined in https://schema.org/SeekToAction.
        # Corresponds to the JSON property `videoActions`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoActions]
        attr_accessor :video_actions
      
        # 
        # Corresponds to the JSON property `videoAnchors`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchors>]
        attr_accessor :video_anchors
      
        # This message holds metadata and signals of one video. It is typically used for
        # holding debug data in tables produced by offline pipelines related to video
        # anchors. Please never populate this message into the search serving stack.
        # Next ID: 31
        # Corresponds to the JSON property `videoInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoInfo]
        attr_accessor :video_info
      
        # Video level scoring info.
        # Corresponds to the JSON property `videoScoreInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoScoreInfo]
        attr_accessor :video_score_info
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @video_actions = args[:video_actions] if args.key?(:video_actions)
          @video_anchors = args[:video_anchors] if args.key?(:video_anchors)
          @video_info = args[:video_info] if args.key?(:video_info)
          @video_score_info = args[:video_score_info] if args.key?(:video_score_info)
        end
      end
      
      # A video can have a list of text anchors, which have different anchor types.
      # Next ID: 15
      class VideoContentSearchVideoAnchors
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `anchorType`
        # @return [String]
        attr_accessor :anchor_type
      
        # The list of entity groups derived from the caption entities.
        # Corresponds to the JSON property `entityGroupInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchEntityGroupInfo]
        attr_accessor :entity_group_info
      
        # Same as above, but used for experimenting with new models.
        # Corresponds to the JSON property `experimentalPredictedQuerylessTocUsefulness`
        # @return [Float]
        attr_accessor :experimental_predicted_queryless_toc_usefulness
      
        # If is_filtered is true, this field illustrates the reasons.
        # Corresponds to the JSON property `filterReason`
        # @return [Array<String>]
        attr_accessor :filter_reason
      
        # If true, the anchor set is filtered and not served online.
        # Corresponds to the JSON property `isFiltered`
        # @return [Boolean]
        attr_accessor :is_filtered
        alias_method :is_filtered?, :is_filtered
      
        # The anchor sources being used to generate this merged anchors. This field is
        # filled only when this is a merged anchor.
        # Corresponds to the JSON property `mergedAnchorsSources`
        # @return [Array<String>]
        attr_accessor :merged_anchors_sources
      
        # The score that predicts the usefulness of this anchor set on the Huh table of
        # contents eval without considering the query.
        # Corresponds to the JSON property `predictedQuerylessTocUsefulness`
        # @return [Float]
        attr_accessor :predicted_queryless_toc_usefulness
      
        # The quality of the anchor set.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Message to contain scoring / debugging information. If you want to add
        # information which is not directly used in the final VideoAnchors data, it
        # should be put here. Next ID: 14
        # Corresponds to the JSON property `scoreInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorsScoreInfo]
        attr_accessor :score_info
      
        # Whether or not thumbnails should be displayed when serving anchors.
        # Corresponds to the JSON property `shouldServeThumbnails`
        # @return [Boolean]
        attr_accessor :should_serve_thumbnails
        alias_method :should_serve_thumbnails?, :should_serve_thumbnails
      
        # This field indicates that the thumbnail should be hidden but is forced to show.
        # Corresponds to the JSON property `thumbnailForced`
        # @return [Boolean]
        attr_accessor :thumbnail_forced
        alias_method :thumbnail_forced?, :thumbnail_forced
      
        # Information about the set of thumbnails.
        # Corresponds to the JSON property `thumbnailSetInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorsThumbnailInfo]
        attr_accessor :thumbnail_set_info
      
        # 
        # Corresponds to the JSON property `videoAnchor`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchor>]
        attr_accessor :video_anchor
      
        # Specifies whether a video has an introduction part that can be skipped. An
        # introduction is the beginning part of a video that can be safely skipped
        # without impacting user's understanding of the overall video content.
        # Corresponds to the JSON property `videoIntroduction`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoIntroduction]
        attr_accessor :video_introduction
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_type = args[:anchor_type] if args.key?(:anchor_type)
          @entity_group_info = args[:entity_group_info] if args.key?(:entity_group_info)
          @experimental_predicted_queryless_toc_usefulness = args[:experimental_predicted_queryless_toc_usefulness] if args.key?(:experimental_predicted_queryless_toc_usefulness)
          @filter_reason = args[:filter_reason] if args.key?(:filter_reason)
          @is_filtered = args[:is_filtered] if args.key?(:is_filtered)
          @merged_anchors_sources = args[:merged_anchors_sources] if args.key?(:merged_anchors_sources)
          @predicted_queryless_toc_usefulness = args[:predicted_queryless_toc_usefulness] if args.key?(:predicted_queryless_toc_usefulness)
          @score = args[:score] if args.key?(:score)
          @score_info = args[:score_info] if args.key?(:score_info)
          @should_serve_thumbnails = args[:should_serve_thumbnails] if args.key?(:should_serve_thumbnails)
          @thumbnail_forced = args[:thumbnail_forced] if args.key?(:thumbnail_forced)
          @thumbnail_set_info = args[:thumbnail_set_info] if args.key?(:thumbnail_set_info)
          @video_anchor = args[:video_anchor] if args.key?(:video_anchor)
          @video_introduction = args[:video_introduction] if args.key?(:video_introduction)
        end
      end
      
      # Message to contain scoring / debugging information. If you want to add
      # information which is not directly used in the final VideoAnchors data, it
      # should be put here. Next ID: 14
      class VideoContentSearchVideoAnchorsScoreInfo
        include Google::Apis::Core::Hashable
      
        # Contains anchor set level features that apply to all anchor types.
        # Corresponds to the JSON property `anchorsCommonFeatureSet`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchAnchorsCommonFeatureSet]
        attr_accessor :anchors_common_feature_set
      
        # Features and debug info for clusters of caption entity video anchors.
        # Corresponds to the JSON property `captionEntityAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionEntityAnchorSetFeatures]
        attr_accessor :caption_entity_anchor_set_features
      
        # 
        # Corresponds to the JSON property `captionSpanAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionSpanAnchorSetFeatures]
        attr_accessor :caption_span_anchor_set_features
      
        # A message containing set-level comment anchor features. Next ID: 3
        # Corresponds to the JSON property `commentAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCommentAnchorSetFeatures]
        attr_accessor :comment_anchor_set_features
      
        # Description anchor features for use in training.
        # Corresponds to the JSON property `descriptionAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchDescriptionAnchorSetFeatures]
        attr_accessor :description_anchor_set_features
      
        # Whether or not the anchors will be removed in the final proto.
        # Corresponds to the JSON property `filtered`
        # @return [Boolean]
        attr_accessor :filtered
        alias_method :filtered?, :filtered
      
        # Cluster-level Metadata about list anchors. Next id: 15.
        # Corresponds to the JSON property `listAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchListAnchorSetFeatures]
        attr_accessor :list_anchor_set_features
      
        # Cluster-level metadata about the description anchors used as list items to
        # build training data for list anchors.
        # Corresponds to the JSON property `listTrainingDataSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchListTrainingDataSetFeatures]
        attr_accessor :list_training_data_set_features
      
        # Features for the set of OnScreenText.
        # Corresponds to the JSON property `ocrAnchorClusterFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOnScreenTextClusterFeature]
        attr_accessor :ocr_anchor_cluster_feature
      
        # Metadata about the join of description anchors and OCR data for a set of
        # description anchors.
        # Corresponds to the JSON property `ocrDescriptionTrainingDataSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOcrDescriptionTrainingDataSetFeatures]
        attr_accessor :ocr_description_training_data_set_features
      
        # Debug info for Q&A anchors. Next ID: 15
        # Corresponds to the JSON property `qnaAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchQnaAnchorSetFeatures]
        attr_accessor :qna_anchor_set_features
      
        # Aggregated set level rating score, used in training pipeline, etc.
        # Corresponds to the JSON property `ratingScore`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoAnchorSetRatingScore]
        attr_accessor :rating_score
      
        # Features for a set of Sports Key Moments (SKM) Anchors. Each instance of this
        # object should be associated with a VideoAnchorSets object. Next ID: 3
        # Corresponds to the JSON property `sportsKeyMomentsAnchorSetFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchSportsKeyMomentsAnchorSetFeatures]
        attr_accessor :sports_key_moments_anchor_set_features
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchors_common_feature_set = args[:anchors_common_feature_set] if args.key?(:anchors_common_feature_set)
          @caption_entity_anchor_set_features = args[:caption_entity_anchor_set_features] if args.key?(:caption_entity_anchor_set_features)
          @caption_span_anchor_set_features = args[:caption_span_anchor_set_features] if args.key?(:caption_span_anchor_set_features)
          @comment_anchor_set_features = args[:comment_anchor_set_features] if args.key?(:comment_anchor_set_features)
          @description_anchor_set_features = args[:description_anchor_set_features] if args.key?(:description_anchor_set_features)
          @filtered = args[:filtered] if args.key?(:filtered)
          @list_anchor_set_features = args[:list_anchor_set_features] if args.key?(:list_anchor_set_features)
          @list_training_data_set_features = args[:list_training_data_set_features] if args.key?(:list_training_data_set_features)
          @ocr_anchor_cluster_feature = args[:ocr_anchor_cluster_feature] if args.key?(:ocr_anchor_cluster_feature)
          @ocr_description_training_data_set_features = args[:ocr_description_training_data_set_features] if args.key?(:ocr_description_training_data_set_features)
          @qna_anchor_set_features = args[:qna_anchor_set_features] if args.key?(:qna_anchor_set_features)
          @rating_score = args[:rating_score] if args.key?(:rating_score)
          @sports_key_moments_anchor_set_features = args[:sports_key_moments_anchor_set_features] if args.key?(:sports_key_moments_anchor_set_features)
        end
      end
      
      # Contains video level features that apply to all anchor types.
      class VideoContentSearchVideoCommonFeatures
        include Google::Apis::Core::Hashable
      
        # The total number of anchors in all video anchor sets.
        # Corresponds to the JSON property `anchorCount`
        # @return [Fixnum]
        attr_accessor :anchor_count
      
        # Contains transcript-level data about a video whether it comes from ASR or
        # closed captions.
        # Corresponds to the JSON property `captionInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchCaptionInfo]
        attr_accessor :caption_info
      
        # The model used for generating label_phrase_embedding.
        # Corresponds to the JSON property `labelPhraseEmbeddingModel`
        # @return [String]
        attr_accessor :label_phrase_embedding_model
      
        # 
        # Corresponds to the JSON property `unifiedScoringBertModels`
        # @return [Array<String>]
        attr_accessor :unified_scoring_bert_models
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @anchor_count = args[:anchor_count] if args.key?(:anchor_count)
          @caption_info = args[:caption_info] if args.key?(:caption_info)
          @label_phrase_embedding_model = args[:label_phrase_embedding_model] if args.key?(:label_phrase_embedding_model)
          @unified_scoring_bert_models = args[:unified_scoring_bert_models] if args.key?(:unified_scoring_bert_models)
        end
      end
      
      # Contains video level features for generated queries that are applied at the
      # video level.
      class VideoContentSearchVideoGeneratedQueryFeatures
        include Google::Apis::Core::Hashable
      
        # A description of why the video was removed. This is intended for debugging
        # generated queries that are filtered at the video level.
        # Corresponds to the JSON property `filterReason`
        # @return [Array<String>]
        attr_accessor :filter_reason
      
        # The total number of passages that were input to generating queries for this
        # video. This count might be bigger than the total number of anchors in the
        # video as some of the anchors might have been filtered by the pipeline.
        # Corresponds to the JSON property `prefilteredPassageCount`
        # @return [Fixnum]
        attr_accessor :prefiltered_passage_count
      
        # Entity annotations for one of the mids representing an anchor label or a query
        # text.
        # Corresponds to the JSON property `titleEntityAnnotations`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchEntityAnnotations]
        attr_accessor :title_entity_annotations
      
        # The total number of queries that belong to the blocklisted categories for this
        # video.
        # Corresponds to the JSON property `totalRestrictedQueries`
        # @return [Fixnum]
        attr_accessor :total_restricted_queries
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @filter_reason = args[:filter_reason] if args.key?(:filter_reason)
          @prefiltered_passage_count = args[:prefiltered_passage_count] if args.key?(:prefiltered_passage_count)
          @title_entity_annotations = args[:title_entity_annotations] if args.key?(:title_entity_annotations)
          @total_restricted_queries = args[:total_restricted_queries] if args.key?(:total_restricted_queries)
        end
      end
      
      # This message holds metadata and signals of one video. It is typically used for
      # holding debug data in tables produced by offline pipelines related to video
      # anchors. Please never populate this message into the search serving stack.
      # Next ID: 31
      class VideoContentSearchVideoInfo
        include Google::Apis::Core::Hashable
      
        # A hash of the video bytes used as a key to Amarna's video_metadata table.
        # Corresponds to the JSON property `amarnaDocid`
        # @return [String]
        attr_accessor :amarna_docid
      
        # Language information, extracted from content_based_metadata.speech_properties.
        # Corresponds to the JSON property `asrLanguage`
        # @return [String]
        attr_accessor :asr_language
      
        # NEXT TAG: 27
        # Corresponds to the JSON property `crapsData`
        # @return [Google::Apis::ContentwarehouseV1::QualityNavboostCrapsCrapsData]
        attr_accessor :craps_data
      
        # Video description.
        # Corresponds to the JSON property `description`
        # @return [String]
        attr_accessor :description
      
        # Language information, extracted from DocProperties.
        # Corresponds to the JSON property `docLanguage`
        # @return [String]
        attr_accessor :doc_language
      
        # Video duration in ms.
        # Corresponds to the JSON property `durationMs`
        # @return [Float]
        attr_accessor :duration_ms
      
        # Whether or not automatic speech recognition has been generated for this video.
        # Corresponds to the JSON property `hasAsr`
        # @return [Boolean]
        attr_accessor :has_asr
        alias_method :has_asr?, :has_asr
      
        # Whether or not the video has description anchors.
        # Corresponds to the JSON property `hasDescriptionAnchors`
        # @return [Boolean]
        attr_accessor :has_description_anchors
        alias_method :has_description_anchors?, :has_description_anchors
      
        # Convenience field that is false if any of the video's anchors have their
        # is_safe field set to false.
        # Corresponds to the JSON property `isSafe`
        # @return [Boolean]
        attr_accessor :is_safe
        alias_method :is_safe?, :is_safe
      
        # Whether or not this is watchpage.
        # Corresponds to the JSON property `isWatchpage`
        # @return [Boolean]
        attr_accessor :is_watchpage
        alias_method :is_watchpage?, :is_watchpage
      
        # Navqueries for the video.
        # Corresponds to the JSON property `navqueries`
        # @return [Array<String>]
        attr_accessor :navqueries
      
        # NSR for the video page document.
        # Corresponds to the JSON property `nsr`
        # @return [Float]
        attr_accessor :nsr
      
        # Number of views.
        # Corresponds to the JSON property `numViews`
        # @return [Fixnum]
        attr_accessor :num_views
      
        # Available tags: 14+
        # Corresponds to the JSON property `pseudoVideoData`
        # @return [Google::Apis::ContentwarehouseV1::PseudoVideoData]
        attr_accessor :pseudo_video_data
      
        # A document contains the raw text contents of the document as well as an
        # analysis. The document can be split into tokens which can contain information
        # about POS tags and dependency relations. The document can also contain
        # entities and mentions of these entities in the document. Next available id: 36
        # Corresponds to the JSON property `saftDoc`
        # @return [Google::Apis::ContentwarehouseV1::NlpSaftDocument]
        attr_accessor :saft_doc
      
        # The transcript used to generate the Saft doc.
        # Corresponds to the JSON property `saftTranscript`
        # @return [String]
        attr_accessor :saft_transcript
      
        # SalientTermSet is a collection of terms (unigrams and bigrams) with associated
        # weights that can describe something. The "salient terms".
        # Corresponds to the JSON property `salientTermSet`
        # @return [Google::Apis::ContentwarehouseV1::QualitySalientTermsSalientTermSet]
        attr_accessor :salient_term_set
      
        # The subindexid from the cdoc. Stored as an int to avoid a cyclical dependency.
        # Should be convertible to CompositeDoc.SubIndexType.
        # Corresponds to the JSON property `subindexid`
        # @return [Array<Fixnum>]
        attr_accessor :subindexid
      
        # Video title.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # Video title language Language information, set automatically by the SAFT
        # LangID.
        # Corresponds to the JSON property `titleLanguage`
        # @return [String]
        attr_accessor :title_language
      
        # Wraps other annotations that are run over auto-generated video captions.
        # Corresponds to the JSON property `transcriptAnnotations`
        # @return [Google::Apis::ContentwarehouseV1::QualityWebanswersTranscriptAnnotations]
        attr_accessor :transcript_annotations
      
        # Number of unique visits in Chrome.
        # Corresponds to the JSON property `uniqueChromeViews`
        # @return [Fixnum]
        attr_accessor :unique_chrome_views
      
        # Document url.
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # Top petacat verticals of the video produced by indexing/ml/vertical, sorted in
        # descending order by vertical confidence.
        # Corresponds to the JSON property `verticalItem`
        # @return [Array<Google::Apis::ContentwarehouseV1::IndexingMlVerticalVerticalItem>]
        attr_accessor :vertical_item
      
        # Genre of the video from the page metadata. Concatenate all with a comma
        # separator if there are multiple genres.
        # Corresponds to the JSON property `videoGenre`
        # @return [String]
        attr_accessor :video_genre
      
        # 
        # Corresponds to the JSON property `videoType`
        # @return [String]
        attr_accessor :video_type
      
        # Video url. Note that VideoInfo::url is a page url that has this video, while
        # this is a video file url.
        # Corresponds to the JSON property `videoUrl`
        # @return [String]
        attr_accessor :video_url
      
        # Represents a collection of entities returned by the WebRef service. Next
        # available tag: 14.
        # Corresponds to the JSON property `webrefEntities`
        # @return [Google::Apis::ContentwarehouseV1::RepositoryWebrefWebrefEntities]
        attr_accessor :webref_entities
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @amarna_docid = args[:amarna_docid] if args.key?(:amarna_docid)
          @asr_language = args[:asr_language] if args.key?(:asr_language)
          @craps_data = args[:craps_data] if args.key?(:craps_data)
          @description = args[:description] if args.key?(:description)
          @doc_language = args[:doc_language] if args.key?(:doc_language)
          @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
          @has_asr = args[:has_asr] if args.key?(:has_asr)
          @has_description_anchors = args[:has_description_anchors] if args.key?(:has_description_anchors)
          @is_safe = args[:is_safe] if args.key?(:is_safe)
          @is_watchpage = args[:is_watchpage] if args.key?(:is_watchpage)
          @navqueries = args[:navqueries] if args.key?(:navqueries)
          @nsr = args[:nsr] if args.key?(:nsr)
          @num_views = args[:num_views] if args.key?(:num_views)
          @pseudo_video_data = args[:pseudo_video_data] if args.key?(:pseudo_video_data)
          @saft_doc = args[:saft_doc] if args.key?(:saft_doc)
          @saft_transcript = args[:saft_transcript] if args.key?(:saft_transcript)
          @salient_term_set = args[:salient_term_set] if args.key?(:salient_term_set)
          @subindexid = args[:subindexid] if args.key?(:subindexid)
          @title = args[:title] if args.key?(:title)
          @title_language = args[:title_language] if args.key?(:title_language)
          @transcript_annotations = args[:transcript_annotations] if args.key?(:transcript_annotations)
          @unique_chrome_views = args[:unique_chrome_views] if args.key?(:unique_chrome_views)
          @url = args[:url] if args.key?(:url)
          @vertical_item = args[:vertical_item] if args.key?(:vertical_item)
          @video_genre = args[:video_genre] if args.key?(:video_genre)
          @video_type = args[:video_type] if args.key?(:video_type)
          @video_url = args[:video_url] if args.key?(:video_url)
          @webref_entities = args[:webref_entities] if args.key?(:webref_entities)
        end
      end
      
      # Specifies whether a video has an introduction part that can be skipped. An
      # introduction is the beginning part of a video that can be safely skipped
      # without impacting user's understanding of the overall video content.
      class VideoContentSearchVideoIntroduction
        include Google::Apis::Core::Hashable
      
        # If set to true, it means the video has an introduction spanning from
        # intro_start_ms to intro_end_ms.
        # Corresponds to the JSON property `hasIntro`
        # @return [Boolean]
        attr_accessor :has_intro
        alias_method :has_intro?, :has_intro
      
        # Timestamp of the end of an introduction. Will only be set if has_intro is true.
        # Indicates video may be skipped to this timestamp with minimal impact on
        # understanding the overall video contents.
        # Corresponds to the JSON property `introEndMs`
        # @return [Fixnum]
        attr_accessor :intro_end_ms
      
        # Timestamp of the beginning of an introduction. Will only be set if has_intro
        # is true. This value may be nonzero.
        # Corresponds to the JSON property `introStartMs`
        # @return [Fixnum]
        attr_accessor :intro_start_ms
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_intro = args[:has_intro] if args.key?(:has_intro)
          @intro_end_ms = args[:intro_end_ms] if args.key?(:intro_end_ms)
          @intro_start_ms = args[:intro_start_ms] if args.key?(:intro_start_ms)
        end
      end
      
      # Video-level Multimodal features for generated topics. Next ID: 2
      class VideoContentSearchVideoMultimodalTopicFeatures
        include Google::Apis::Core::Hashable
      
        # Starburst vectors. Sorted by timestamp.
        # Corresponds to the JSON property `frameStarburstData`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoContentSearchFrameStarburstData>]
        attr_accessor :frame_starburst_data
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_starburst_data = args[:frame_starburst_data] if args.key?(:frame_starburst_data)
        end
      end
      
      # Video level scoring info.
      class VideoContentSearchVideoScoreInfo
        include Google::Apis::Core::Hashable
      
        # Contains video level features that apply to all anchor types.
        # Corresponds to the JSON property `commonFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoCommonFeatures]
        attr_accessor :common_features
      
        # Features for video level info.
        # Corresponds to the JSON property `ocrVideoFeature`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchOcrVideoFeature]
        attr_accessor :ocr_video_feature
      
        # Multi-label classification output. It contains the output for each vertical.
        # The output for some verticals can be empty, in case that vertical is not
        # supported by the classifier or if the set of verticals was restricted using
        # MultiLabelClassifierInput.verticals.
        # Corresponds to the JSON property `safeSearchClassifierOutput`
        # @return [Google::Apis::ContentwarehouseV1::ClassifierPornQueryMultiLabelClassifierOutput]
        attr_accessor :safe_search_classifier_output
      
        # The version of this VideoAnchorSets in spanner.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        # Contains video level features for generated queries that are applied at the
        # video level.
        # Corresponds to the JSON property `videoGeneratedQueryFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoGeneratedQueryFeatures]
        attr_accessor :video_generated_query_features
      
        # Video-level Multimodal features for generated topics. Next ID: 2
        # Corresponds to the JSON property `videoMultimodalTopicFeatures`
        # @return [Google::Apis::ContentwarehouseV1::VideoContentSearchVideoMultimodalTopicFeatures]
        attr_accessor :video_multimodal_topic_features
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @common_features = args[:common_features] if args.key?(:common_features)
          @ocr_video_feature = args[:ocr_video_feature] if args.key?(:ocr_video_feature)
          @safe_search_classifier_output = args[:safe_search_classifier_output] if args.key?(:safe_search_classifier_output)
          @version = args[:version] if args.key?(:version)
          @video_generated_query_features = args[:video_generated_query_features] if args.key?(:video_generated_query_features)
          @video_multimodal_topic_features = args[:video_multimodal_topic_features] if args.key?(:video_multimodal_topic_features)
        end
      end
      
      # Startburst visual tokens or features, more details in go/starburst-mum-user-
      # guide
      class VideoContentSearchVisualFeatures
        include Google::Apis::Core::Hashable
      
        # Starburst features semantic or visual/
        # Corresponds to the JSON property `features`
        # @return [Array<Float>]
        attr_accessor :features
      
        # 
        # Corresponds to the JSON property `starbustVersion`
        # @return [String]
        attr_accessor :starbust_version
      
        # Starburst visual tokens
        # Corresponds to the JSON property `tokens`
        # @return [Array<Fixnum>]
        attr_accessor :tokens
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @features = args[:features] if args.key?(:features)
          @starbust_version = args[:starbust_version] if args.key?(:starbust_version)
          @tokens = args[:tokens] if args.key?(:tokens)
        end
      end
      
      # This message is used to store information about Inline Playback in the
      # VideoWebAttachment portion of the websearch index. LINT.IfChange
      class VideoCrawlVideoInlinePlaybackMetadata
        include Google::Apis::Core::Hashable
      
        # Timestamp (measured in seconds since epoch) when a video may not be used for
        # inline playback in the interest feed.
        # Corresponds to the JSON property `expirationTimestampSec`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp_sec
      
        # Publisher's Google Analytics Id to which we can report view metrics.
        # Corresponds to the JSON property `googleAnalyticsId`
        # @return [String]
        attr_accessor :google_analytics_id
      
        # All two-letter codes for countries where this video may NOT be played.
        # Corresponds to the JSON property `playbackCountryBlacklist`
        # @return [Array<String>]
        attr_accessor :playback_country_blacklist
      
        # All two-letter codes for countries where this video may be played. If empty,
        # then all countries not on the blacklist are allowed for playback.
        # Corresponds to the JSON property `playbackCountryWhitelist`
        # @return [Array<String>]
        attr_accessor :playback_country_whitelist
      
        # Set of transcodes which are available for the video.
        # Corresponds to the JSON property `transcodeItags`
        # @return [Array<Fixnum>]
        attr_accessor :transcode_itags
      
        # VAST tag for ads to be played along with this video. Currently, we only
        # support VAST tags from Doubleclick and FreeWheel.
        # Corresponds to the JSON property `vastTag`
        # @return [String]
        attr_accessor :vast_tag
      
        # Identifier video is known by in the video infrastructure. The format given
        # here is the YoutubeId format (base-64) used in Venom; for Viper/Bandaid/
        # StreamingURLService, convert to ContentIdHex.
        # Corresponds to the JSON property `videoId`
        # @return [String]
        attr_accessor :video_id
      
        # Set if the video is hosted on an external CDN, in which case it is not to be
        # transcoded and hosted at Google for the Interest Feed.
        # Corresponds to the JSON property `videoUrlOnExternalCdn`
        # @return [String]
        attr_accessor :video_url_on_external_cdn
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiration_timestamp_sec = args[:expiration_timestamp_sec] if args.key?(:expiration_timestamp_sec)
          @google_analytics_id = args[:google_analytics_id] if args.key?(:google_analytics_id)
          @playback_country_blacklist = args[:playback_country_blacklist] if args.key?(:playback_country_blacklist)
          @playback_country_whitelist = args[:playback_country_whitelist] if args.key?(:playback_country_whitelist)
          @transcode_itags = args[:transcode_itags] if args.key?(:transcode_itags)
          @vast_tag = args[:vast_tag] if args.key?(:vast_tag)
          @video_id = args[:video_id] if args.key?(:video_id)
          @video_url_on_external_cdn = args[:video_url_on_external_cdn] if args.key?(:video_url_on_external_cdn)
        end
      end
      
      # Decoder configuration for Dolby Vision encoded by any codec. Dolby Vision
      # defines a separate profile & level hierarchy regardless of the base codec. See
      # Dolby Vision profiles, levels and compatibility: https://dolby.my.salesforce.
      # com/sfc/p/#700000009YuG/a/4u000000l6G4/4R18riPaaW3gxpVx7XwyQLdEITLFjB.w.
      # Si0LoQR5j8 Dolby Vision DASH streaming: https://professional.dolby.com/
      # siteassets/content-creation/dolby-vision-for-content-creators/
      # dolbyvisioninmpegdashspecification_v2_0_public_20190107.pdf HTTP Live
      # Streaming: https://professional.dolby.com/siteassets/content-creation/dolby-
      # vision-for-content-creators/dolby-vision-streams-within-the-http-live-
      # streaming-format-v2.0-13-november-2018.pdf Dolby Vision bitstreams: https://
      # professional.dolby.com/siteassets/pdfs/
      # dolbyvisionstreamsinisobmffspecification-v2.1.2.pdf
      class VideoDoViDecoderConfiguration
        include Google::Apis::Core::Hashable
      
        # If a track contains the base layer substream.
        # Corresponds to the JSON property `blPresentFlag`
        # @return [Boolean]
        attr_accessor :bl_present_flag
        alias_method :bl_present_flag?, :bl_present_flag
      
        # Whether the stream is compatible with other sets of standard.
        # Corresponds to the JSON property `dvBlSignalCompatibilityId`
        # @return [Fixnum]
        attr_accessor :dv_bl_signal_compatibility_id
      
        # 
        # Corresponds to the JSON property `dvLevel`
        # @return [Fixnum]
        attr_accessor :dv_level
      
        # 
        # Corresponds to the JSON property `dvProfile`
        # @return [Fixnum]
        attr_accessor :dv_profile
      
        # Specifies the major version number of the Dolby Vision specification that the
        # stream complies with.
        # Corresponds to the JSON property `dvVersionMajor`
        # @return [Fixnum]
        attr_accessor :dv_version_major
      
        # Specifies the minor version number of the Dolby Vision specification that the
        # stream complies with.
        # Corresponds to the JSON property `dvVersionMinor`
        # @return [Fixnum]
        attr_accessor :dv_version_minor
      
        # If a track contains the enhancement layer substream.
        # Corresponds to the JSON property `elPresentFlag`
        # @return [Boolean]
        attr_accessor :el_present_flag
        alias_method :el_present_flag?, :el_present_flag
      
        # dvhe, dvh1, dvav, dva1: https://screenshot.googleplex.com/ipMGXFqLX9E
        # Corresponds to the JSON property `fourccTag`
        # @return [String]
        attr_accessor :fourcc_tag
      
        # If a track contains the reference picture unit substream.
        # Corresponds to the JSON property `rpuPresentFlag`
        # @return [Boolean]
        attr_accessor :rpu_present_flag
        alias_method :rpu_present_flag?, :rpu_present_flag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bl_present_flag = args[:bl_present_flag] if args.key?(:bl_present_flag)
          @dv_bl_signal_compatibility_id = args[:dv_bl_signal_compatibility_id] if args.key?(:dv_bl_signal_compatibility_id)
          @dv_level = args[:dv_level] if args.key?(:dv_level)
          @dv_profile = args[:dv_profile] if args.key?(:dv_profile)
          @dv_version_major = args[:dv_version_major] if args.key?(:dv_version_major)
          @dv_version_minor = args[:dv_version_minor] if args.key?(:dv_version_minor)
          @el_present_flag = args[:el_present_flag] if args.key?(:el_present_flag)
          @fourcc_tag = args[:fourcc_tag] if args.key?(:fourcc_tag)
          @rpu_present_flag = args[:rpu_present_flag] if args.key?(:rpu_present_flag)
        end
      end
      
      # A message holding all of the color information about a signal: -Color
      # primaries identify the meaning of red, green, and blue ( and the white point).
      # -The transfer characteristic identifies the mapping used to go between linear
      # and coded values of light. -The matrix coefficients identifies, e.g., the
      # conversion between Ycbcr to RGB (in the space of the primaries) -And the color
      # range defines the min/max of the levels used.
      class VideoFileColorInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `matrixCoefficients`
        # @return [String]
        attr_accessor :matrix_coefficients
      
        # 
        # Corresponds to the JSON property `primaries`
        # @return [String]
        attr_accessor :primaries
      
        # 
        # Corresponds to the JSON property `range`
        # @return [String]
        attr_accessor :range
      
        # 
        # Corresponds to the JSON property `transferCharacteristics`
        # @return [String]
        attr_accessor :transfer_characteristics
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @matrix_coefficients = args[:matrix_coefficients] if args.key?(:matrix_coefficients)
          @primaries = args[:primaries] if args.key?(:primaries)
          @range = args[:range] if args.key?(:range)
          @transfer_characteristics = args[:transfer_characteristics] if args.key?(:transfer_characteristics)
        end
      end
      
      # A message holding the equivalent of the content light level information in
      # HEVC or its representation in matroska/webm. This gives coarse stats on the
      # luminance levels in the content and may be used as a hint by algorithms &
      # displays to tone map.
      class VideoFileContentLightLevel
        include Google::Apis::Core::Hashable
      
        # Defines the maximum content light level (in cd/m^2) over the entire video.
        # Corresponds to the JSON property `maxContentLightLevel`
        # @return [Fixnum]
        attr_accessor :max_content_light_level
      
        # The maximum (over entire video) of the frame average light level.
        # Corresponds to the JSON property `maxFrameAverageLightLevel`
        # @return [Fixnum]
        attr_accessor :max_frame_average_light_level
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max_content_light_level = args[:max_content_light_level] if args.key?(:max_content_light_level)
          @max_frame_average_light_level = args[:max_frame_average_light_level] if args.key?(:max_frame_average_light_level)
        end
      end
      
      # Information on Frame Packing arrangement
      class VideoFileFramePackingArrangement
        include Google::Apis::Core::Hashable
      
        # Grid positions
        # Corresponds to the JSON property `gridOffset0Horizontal`
        # @return [Fixnum]
        attr_accessor :grid_offset0_horizontal
      
        # 
        # Corresponds to the JSON property `gridOffset0Vertical`
        # @return [Fixnum]
        attr_accessor :grid_offset0_vertical
      
        # 
        # Corresponds to the JSON property `gridOffset1Horizontal`
        # @return [Fixnum]
        attr_accessor :grid_offset1_horizontal
      
        # 
        # Corresponds to the JSON property `gridOffset1Vertical`
        # @return [Fixnum]
        attr_accessor :grid_offset1_vertical
      
        # Content interpretation
        # Corresponds to the JSON property `interpretation`
        # @return [String]
        attr_accessor :interpretation
      
        # Quincunx sampling flag indicating if quincunx sampling is used
        # Corresponds to the JSON property `quincunxSampling`
        # @return [Boolean]
        attr_accessor :quincunx_sampling
        alias_method :quincunx_sampling?, :quincunx_sampling
      
        # Arrangement type
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @grid_offset0_horizontal = args[:grid_offset0_horizontal] if args.key?(:grid_offset0_horizontal)
          @grid_offset0_vertical = args[:grid_offset0_vertical] if args.key?(:grid_offset0_vertical)
          @grid_offset1_horizontal = args[:grid_offset1_horizontal] if args.key?(:grid_offset1_horizontal)
          @grid_offset1_vertical = args[:grid_offset1_vertical] if args.key?(:grid_offset1_vertical)
          @interpretation = args[:interpretation] if args.key?(:interpretation)
          @quincunx_sampling = args[:quincunx_sampling] if args.key?(:quincunx_sampling)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Stats on HDR10+ (SMPTE 2094-40:2016 standard) over video frames.
      class VideoFileHdr10PlusStats
        include Google::Apis::Core::Hashable
      
        # Application version is set to max version over all frames.
        # Corresponds to the JSON property `applicationVersion`
        # @return [Fixnum]
        attr_accessor :application_version
      
        # The average of the nominal maximum display luminance of the targeted system
        # display over all frames.
        # Corresponds to the JSON property `averageTargetedSystemDisplayMaximumLuminance`
        # @return [Float]
        attr_accessor :average_targeted_system_display_maximum_luminance
      
        # This flag is set if any frame has it.
        # Corresponds to the JSON property `masteringDisplayActualPeakLuminanceFlag`
        # @return [Boolean]
        attr_accessor :mastering_display_actual_peak_luminance_flag
        alias_method :mastering_display_actual_peak_luminance_flag?, :mastering_display_actual_peak_luminance_flag
      
        # 
        # Corresponds to the JSON property `maxNumWindows`
        # @return [Fixnum]
        attr_accessor :max_num_windows
      
        # This flag is set if any frame has it.
        # Corresponds to the JSON property `targetedSystemDisplayActualPeakLuminanceFlag`
        # @return [Boolean]
        attr_accessor :targeted_system_display_actual_peak_luminance_flag
        alias_method :targeted_system_display_actual_peak_luminance_flag?, :targeted_system_display_actual_peak_luminance_flag
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @application_version = args[:application_version] if args.key?(:application_version)
          @average_targeted_system_display_maximum_luminance = args[:average_targeted_system_display_maximum_luminance] if args.key?(:average_targeted_system_display_maximum_luminance)
          @mastering_display_actual_peak_luminance_flag = args[:mastering_display_actual_peak_luminance_flag] if args.key?(:mastering_display_actual_peak_luminance_flag)
          @max_num_windows = args[:max_num_windows] if args.key?(:max_num_windows)
          @targeted_system_display_actual_peak_luminance_flag = args[:targeted_system_display_actual_peak_luminance_flag] if args.key?(:targeted_system_display_actual_peak_luminance_flag)
        end
      end
      
      # A message holding information about the mastering display color volume. This
      # metadata can be used when tone mapping an HDR signal to a display with a
      # different gamut or brightness characteristics than the mastering display. This
      # message is capable of containing SMPTE 2086 metadata.
      class VideoFileMasteringDisplayMetadata
        include Google::Apis::Core::Hashable
      
        # Representation of a color coordinate in CIE1931 color space.
        # Corresponds to the JSON property `blue`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileMasteringDisplayMetadataCie1931Coordinate]
        attr_accessor :blue
      
        # Representation of a color coordinate in CIE1931 color space.
        # Corresponds to the JSON property `green`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileMasteringDisplayMetadataCie1931Coordinate]
        attr_accessor :green
      
        # Maximum luminance of the display (in cd/m^2).
        # Corresponds to the JSON property `maxLuminance`
        # @return [Float]
        attr_accessor :max_luminance
      
        # Minimum luminance of the display (in cd/m^2).
        # Corresponds to the JSON property `minLuminance`
        # @return [Float]
        attr_accessor :min_luminance
      
        # Representation of a color coordinate in CIE1931 color space.
        # Corresponds to the JSON property `red`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileMasteringDisplayMetadataCie1931Coordinate]
        attr_accessor :red
      
        # Representation of a color coordinate in CIE1931 color space.
        # Corresponds to the JSON property `whitePoint`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileMasteringDisplayMetadataCie1931Coordinate]
        attr_accessor :white_point
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @blue = args[:blue] if args.key?(:blue)
          @green = args[:green] if args.key?(:green)
          @max_luminance = args[:max_luminance] if args.key?(:max_luminance)
          @min_luminance = args[:min_luminance] if args.key?(:min_luminance)
          @red = args[:red] if args.key?(:red)
          @white_point = args[:white_point] if args.key?(:white_point)
        end
      end
      
      # Representation of a color coordinate in CIE1931 color space.
      class VideoFileMasteringDisplayMetadataCie1931Coordinate
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `x`
        # @return [Float]
        attr_accessor :x
      
        # 
        # Corresponds to the JSON property `y`
        # @return [Float]
        attr_accessor :y
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @x = args[:x] if args.key?(:x)
          @y = args[:y] if args.key?(:y)
        end
      end
      
      # Globally allowed spherical meta data.
      class VideoFileSphericalMetadata
        include Google::Apis::Core::Hashable
      
        # Like above, but with high-pass motion filtering applied and yaw rotation
        # limited to +/- 15-degrees
        # Corresponds to the JSON property `clampedOptimalFovBounds`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataFovBounds]
        attr_accessor :clamped_optimal_fov_bounds
      
        # Specifies usage of cubemap projection.
        # Corresponds to the JSON property `cubemap`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataCubemapProjection]
        attr_accessor :cubemap
      
        # The cropping coordinates, in pixels.
        # Corresponds to the JSON property `deprecatedCroppedArea`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataCroppedArea]
        attr_accessor :deprecated_cropped_area
      
        # InitialView is from v1 spec, and is more or less equivalent to Pose from v2
        # spec. Therefore, InitialView found in xml metadata would populate the pose
        # field in this proto.
        # Corresponds to the JSON property `deprecatedInitialView`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataViewDirection]
        attr_accessor :deprecated_initial_view
      
        # Specifies usage of equirectangular projection. More specifically, these are
        # the proportion of projection cropped from each edge not covered by the video
        # frame. For uncropped frame, all values are 0. For v1 metadata, this contains
        # CroppedArea information (CroppedAreaLeftPixels, CroppedAreaTopPixels,
        # CroppedAreaImageWidthPixels, CroppedAreaImageHeightPixels)
        # Corresponds to the JSON property `equirect`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataEquirectProjection]
        attr_accessor :equirect
      
        # 
        # Corresponds to the JSON property `fullPanoHeightPixels`
        # @return [Fixnum]
        attr_accessor :full_pano_height_pixels
      
        # Dimensions of the full video frame.
        # Corresponds to the JSON property `fullPanoWidthPixels`
        # @return [Fixnum]
        attr_accessor :full_pano_width_pixels
      
        # Specifies usage of mesh projection. "content" contains the mshp atom: version/
        # flags, CRC, compression method, description of the mesh(es) (vertices,
        # coordinates corresponding to each vertex, and vertex lists to describe the
        # projection). See go/pir-spec for mshp atom data layout.
        # Corresponds to the JSON property `mesh`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataMeshProjection]
        attr_accessor :mesh
      
        # Metadata source v2(svhd)
        # Corresponds to the JSON property `metadataSource`
        # @return [String]
        attr_accessor :metadata_source
      
        # If video contains Wally-sanitized mesh and camera motion metadata (see go/
        # wally-format ), this contains the optimal FOV (smallest FOV that encompass all
        # combinations of input mesh FOV and rotations). This field will only be present
        # if full FfmpegAnalyze is performed.
        # Corresponds to the JSON property `optimalFovBounds`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataFovBounds]
        attr_accessor :optimal_fov_bounds
      
        # Specifies the compass heading, pitch & roll for the origin of the projection.
        # The origin for the "equirectangular" projection is the center of the image.
        # The origin for the other projection types is defined as the location in the
        # image that corresponds to the origin of an "equirectangular" projection.
        # Corresponds to the JSON property `pose`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataPose]
        attr_accessor :pose
      
        # Mapping type used to map the sphere to the rectangular video E.g., "
        # equirectangular", http://en.wikipedia.org/wiki/Equirectangular_projection This
        # is kept as string so that we can retain values that are unknown to us.
        # Corresponds to the JSON property `projectionType`
        # @return [String]
        attr_accessor :projection_type
      
        # The number of camera sources used to generate this video.
        # Corresponds to the JSON property `sourceCount`
        # @return [Fixnum]
        attr_accessor :source_count
      
        # Whether the video is spherical or not.
        # Corresponds to the JSON property `spherical`
        # @return [Boolean]
        attr_accessor :spherical
        alias_method :spherical?, :spherical
      
        # The stereo mode.
        # Corresponds to the JSON property `stereoMode`
        # @return [String]
        attr_accessor :stereo_mode
      
        # Whether the video has already been stitched.
        # Corresponds to the JSON property `stitched`
        # @return [Boolean]
        attr_accessor :stitched
        alias_method :stitched?, :stitched
      
        # The stitching software.
        # Corresponds to the JSON property `stitchingSoftware`
        # @return [String]
        attr_accessor :stitching_software
      
        # Epoch Timestamp of when the first frame in the video was recorded
        # Corresponds to the JSON property `timestamp`
        # @return [Fixnum]
        attr_accessor :timestamp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @clamped_optimal_fov_bounds = args[:clamped_optimal_fov_bounds] if args.key?(:clamped_optimal_fov_bounds)
          @cubemap = args[:cubemap] if args.key?(:cubemap)
          @deprecated_cropped_area = args[:deprecated_cropped_area] if args.key?(:deprecated_cropped_area)
          @deprecated_initial_view = args[:deprecated_initial_view] if args.key?(:deprecated_initial_view)
          @equirect = args[:equirect] if args.key?(:equirect)
          @full_pano_height_pixels = args[:full_pano_height_pixels] if args.key?(:full_pano_height_pixels)
          @full_pano_width_pixels = args[:full_pano_width_pixels] if args.key?(:full_pano_width_pixels)
          @mesh = args[:mesh] if args.key?(:mesh)
          @metadata_source = args[:metadata_source] if args.key?(:metadata_source)
          @optimal_fov_bounds = args[:optimal_fov_bounds] if args.key?(:optimal_fov_bounds)
          @pose = args[:pose] if args.key?(:pose)
          @projection_type = args[:projection_type] if args.key?(:projection_type)
          @source_count = args[:source_count] if args.key?(:source_count)
          @spherical = args[:spherical] if args.key?(:spherical)
          @stereo_mode = args[:stereo_mode] if args.key?(:stereo_mode)
          @stitched = args[:stitched] if args.key?(:stitched)
          @stitching_software = args[:stitching_software] if args.key?(:stitching_software)
          @timestamp = args[:timestamp] if args.key?(:timestamp)
        end
      end
      
      # The cropping coordinates, in pixels.
      class VideoFileSphericalMetadataCroppedArea
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `left`
        # @return [Fixnum]
        attr_accessor :left
      
        # 
        # Corresponds to the JSON property `top`
        # @return [Fixnum]
        attr_accessor :top
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @left = args[:left] if args.key?(:left)
          @top = args[:top] if args.key?(:top)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Specifies usage of cubemap projection.
      class VideoFileSphericalMetadataCubemapProjection
        include Google::Apis::Core::Hashable
      
        # Values 0 to 255 are reserved for current and future layouts. Value of 0
        # corresponds to a grid with 3 columns and 2 rows as follows: | right face |
        # left face | up face | | down face | front face | back face |
        # Corresponds to the JSON property `layout`
        # @return [Fixnum]
        attr_accessor :layout
      
        # Number of pixels to pad from the edge of each cube face
        # Corresponds to the JSON property `padding`
        # @return [Fixnum]
        attr_accessor :padding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @layout = args[:layout] if args.key?(:layout)
          @padding = args[:padding] if args.key?(:padding)
        end
      end
      
      # Specifies usage of equirectangular projection. More specifically, these are
      # the proportion of projection cropped from each edge not covered by the video
      # frame. For uncropped frame, all values are 0. For v1 metadata, this contains
      # CroppedArea information (CroppedAreaLeftPixels, CroppedAreaTopPixels,
      # CroppedAreaImageWidthPixels, CroppedAreaImageHeightPixels)
      class VideoFileSphericalMetadataEquirectProjection
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `projectionBoundsBottom`
        # @return [Fixnum]
        attr_accessor :projection_bounds_bottom
      
        # 
        # Corresponds to the JSON property `projectionBoundsLeft`
        # @return [Fixnum]
        attr_accessor :projection_bounds_left
      
        # 
        # Corresponds to the JSON property `projectionBoundsRight`
        # @return [Fixnum]
        attr_accessor :projection_bounds_right
      
        # 
        # Corresponds to the JSON property `projectionBoundsTop`
        # @return [Fixnum]
        attr_accessor :projection_bounds_top
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @projection_bounds_bottom = args[:projection_bounds_bottom] if args.key?(:projection_bounds_bottom)
          @projection_bounds_left = args[:projection_bounds_left] if args.key?(:projection_bounds_left)
          @projection_bounds_right = args[:projection_bounds_right] if args.key?(:projection_bounds_right)
          @projection_bounds_top = args[:projection_bounds_top] if args.key?(:projection_bounds_top)
        end
      end
      
      # 
      class VideoFileSphericalMetadataFovBounds
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `endTiltInDegrees`
        # @return [Float]
        attr_accessor :end_tilt_in_degrees
      
        # 
        # Corresponds to the JSON property `endYawInDegrees`
        # @return [Float]
        attr_accessor :end_yaw_in_degrees
      
        # 
        # Corresponds to the JSON property `startTiltInDegrees`
        # @return [Float]
        attr_accessor :start_tilt_in_degrees
      
        # 
        # Corresponds to the JSON property `startYawInDegrees`
        # @return [Float]
        attr_accessor :start_yaw_in_degrees
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_tilt_in_degrees = args[:end_tilt_in_degrees] if args.key?(:end_tilt_in_degrees)
          @end_yaw_in_degrees = args[:end_yaw_in_degrees] if args.key?(:end_yaw_in_degrees)
          @start_tilt_in_degrees = args[:start_tilt_in_degrees] if args.key?(:start_tilt_in_degrees)
          @start_yaw_in_degrees = args[:start_yaw_in_degrees] if args.key?(:start_yaw_in_degrees)
        end
      end
      
      # Specifies usage of mesh projection. "content" contains the mshp atom: version/
      # flags, CRC, compression method, description of the mesh(es) (vertices,
      # coordinates corresponding to each vertex, and vertex lists to describe the
      # projection). See go/pir-spec for mshp atom data layout.
      class VideoFileSphericalMetadataMeshProjection
        include Google::Apis::Core::Hashable
      
        # Once mesh is analyzed, this field contains the bounds of the mesh(es) In case
        # of stereo mesh, this will be the aggregate of both eye meshes
        # Corresponds to the JSON property `bounds`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadataFovBounds]
        attr_accessor :bounds
      
        # 
        # Corresponds to the JSON property `content`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :content
      
        # The mesh type field will only be populated when we have done analysis on the
        # mesh. If this field is missing, mesh analysis has not been done.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bounds = args[:bounds] if args.key?(:bounds)
          @content = args[:content] if args.key?(:content)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Specifies the compass heading, pitch & roll for the origin of the projection.
      # The origin for the "equirectangular" projection is the center of the image.
      # The origin for the other projection types is defined as the location in the
      # image that corresponds to the origin of an "equirectangular" projection.
      class VideoFileSphericalMetadataPose
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `headingDegrees`
        # @return [Float]
        attr_accessor :heading_degrees
      
        # 
        # Corresponds to the JSON property `pitchDegrees`
        # @return [Float]
        attr_accessor :pitch_degrees
      
        # 
        # Corresponds to the JSON property `rollDegrees`
        # @return [Float]
        attr_accessor :roll_degrees
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @heading_degrees = args[:heading_degrees] if args.key?(:heading_degrees)
          @pitch_degrees = args[:pitch_degrees] if args.key?(:pitch_degrees)
          @roll_degrees = args[:roll_degrees] if args.key?(:roll_degrees)
        end
      end
      
      # 
      class VideoFileSphericalMetadataViewDirection
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `headingDegrees`
        # @return [Fixnum]
        attr_accessor :heading_degrees
      
        # 
        # Corresponds to the JSON property `pitchDegrees`
        # @return [Fixnum]
        attr_accessor :pitch_degrees
      
        # 
        # Corresponds to the JSON property `rollDegrees`
        # @return [Fixnum]
        attr_accessor :roll_degrees
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @heading_degrees = args[:heading_degrees] if args.key?(:heading_degrees)
          @pitch_degrees = args[:pitch_degrees] if args.key?(:pitch_degrees)
          @roll_degrees = args[:roll_degrees] if args.key?(:roll_degrees)
        end
      end
      
      # 
      class VideoLegosLegosAnnotationsSet
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `featureSetName`
        # @return [String]
        attr_accessor :feature_set_name
      
        # A collection of annotations returned by Legos for a document.
        # Corresponds to the JSON property `legosAnnotations`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosAnnotations]
        attr_accessor :legos_annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @feature_set_name = args[:feature_set_name] if args.key?(:feature_set_name)
          @legos_annotations = args[:legos_annotations] if args.key?(:legos_annotations)
        end
      end
      
      # 
      class VideoLegosLegosAnnotationsSets
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `annotationsSet`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoLegosLegosAnnotationsSet>]
        attr_accessor :annotations_set
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotations_set = args[:annotations_set] if args.key?(:annotations_set)
        end
      end
      
      # Feel free to ignore this lint warning if only the trivia (e.g., comments) is
      # is changed. LINT.IfChange
      class VideoMediaInfo
        include Google::Apis::Core::Hashable
      
        # Each entry corresponds to one audio stream in the original media file.
        # Corresponds to the JSON property `audioStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoAudioStream>]
        attr_accessor :audio_stream
      
        # Container type of the file, e.g. FLV, H264, MP3. Uses the numeric value
        # corresponding to the ContainerId enum objects, in order to avoid the
        # dependency on vsi/videostreaminfo.proto. http://cs/symbol:ContainerId%20f:
        # google3/video/vidproc/vsi/videostreaminfo.proto
        # Corresponds to the JSON property `containerId`
        # @return [Fixnum]
        attr_accessor :container_id
      
        # Media file size in bytes.
        # Corresponds to the JSON property `fileSize`
        # @return [Fixnum]
        attr_accessor :file_size
      
        # Next ID: 19 IMPORTANT: This file is used in scattered directories, such that
        # it is risky to add values to any enumerated type. (First of all, compilation
        # breaks on switch statements without default clauses.) Run a global tap
        # presubmit: tap_presubmit -p all --train -c before submitting. Also check out
        # the blame layer of previous updates for hints on what other files to changes.
        # Corresponds to the JSON property `overview`
        # @return [Google::Apis::ContentwarehouseV1::VideoMediaOverview]
        attr_accessor :overview
      
        # Each entry corresponds to one video stream (usually just one) in the original
        # media file.
        # Corresponds to the JSON property `videoStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStream>]
        attr_accessor :video_stream
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_stream = args[:audio_stream] if args.key?(:audio_stream)
          @container_id = args[:container_id] if args.key?(:container_id)
          @file_size = args[:file_size] if args.key?(:file_size)
          @overview = args[:overview] if args.key?(:overview)
          @video_stream = args[:video_stream] if args.key?(:video_stream)
        end
      end
      
      # Next ID: 19 IMPORTANT: This file is used in scattered directories, such that
      # it is risky to add values to any enumerated type. (First of all, compilation
      # breaks on switch statements without default clauses.) Run a global tap
      # presubmit: tap_presubmit -p all --train -c before submitting. Also check out
      # the blame layer of previous updates for hints on what other files to changes.
      class VideoMediaOverview
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `aspectRatio`
        # @return [String]
        attr_accessor :aspect_ratio
      
        # 
        # Corresponds to the JSON property `audioOverview`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoMediaOverviewAudioOverview>]
        attr_accessor :audio_overview
      
        # 
        # Corresponds to the JSON property `authoringTool`
        # @return [String]
        attr_accessor :authoring_tool
      
        # 
        # Corresponds to the JSON property `colorDynamicRange`
        # @return [String]
        attr_accessor :color_dynamic_range
      
        # Creation timestamp of this media_info, in Unix timestamp since epoch.
        # Corresponds to the JSON property `creationTimeStampUsec`
        # @return [Fixnum]
        attr_accessor :creation_time_stamp_usec
      
        # 
        # Corresponds to the JSON property `dataOverview`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoMediaOverviewDataOverview>]
        attr_accessor :data_overview
      
        # 
        # Corresponds to the JSON property `frameRate`
        # @return [String]
        attr_accessor :frame_rate
      
        # Currently used by originals replacement pipeline to exclude all videos
        # containing chapter info.
        # Corresponds to the JSON property `hasChapters`
        # @return [Boolean]
        attr_accessor :has_chapters
        alias_method :has_chapters?, :has_chapters
      
        # Video clip info description with no PII.
        # Corresponds to the JSON property `mediaClipInfoOverview`
        # @return [Google::Apis::ContentwarehouseV1::VideoMediaOverviewMediaClipInfoOverview]
        attr_accessor :media_clip_info_overview
      
        # 
        # Corresponds to the JSON property `orientation`
        # @return [String]
        attr_accessor :orientation
      
        # 
        # Corresponds to the JSON property `origin`
        # @return [String]
        attr_accessor :origin
      
        # 
        # Corresponds to the JSON property `projection`
        # @return [String]
        attr_accessor :projection
      
        # 
        # Corresponds to the JSON property `resolution`
        # @return [String]
        attr_accessor :resolution
      
        # 
        # Corresponds to the JSON property `spatialAudioMode`
        # @return [String]
        attr_accessor :spatial_audio_mode
      
        # 
        # Corresponds to the JSON property `stereoMode`
        # @return [String]
        attr_accessor :stereo_mode
      
        # 
        # Corresponds to the JSON property `timedtextOverview`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoMediaOverviewTimedTextOverview>]
        attr_accessor :timedtext_overview
      
        # 
        # Corresponds to the JSON property `videoOverview`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoMediaOverviewVideoOverview>]
        attr_accessor :video_overview
      
        # This only applies when: projection = PROJECTION_PARTIALLY_SPHERICAL
        # Corresponds to the JSON property `wallyMeshType`
        # @return [String]
        attr_accessor :wally_mesh_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
          @audio_overview = args[:audio_overview] if args.key?(:audio_overview)
          @authoring_tool = args[:authoring_tool] if args.key?(:authoring_tool)
          @color_dynamic_range = args[:color_dynamic_range] if args.key?(:color_dynamic_range)
          @creation_time_stamp_usec = args[:creation_time_stamp_usec] if args.key?(:creation_time_stamp_usec)
          @data_overview = args[:data_overview] if args.key?(:data_overview)
          @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
          @has_chapters = args[:has_chapters] if args.key?(:has_chapters)
          @media_clip_info_overview = args[:media_clip_info_overview] if args.key?(:media_clip_info_overview)
          @orientation = args[:orientation] if args.key?(:orientation)
          @origin = args[:origin] if args.key?(:origin)
          @projection = args[:projection] if args.key?(:projection)
          @resolution = args[:resolution] if args.key?(:resolution)
          @spatial_audio_mode = args[:spatial_audio_mode] if args.key?(:spatial_audio_mode)
          @stereo_mode = args[:stereo_mode] if args.key?(:stereo_mode)
          @timedtext_overview = args[:timedtext_overview] if args.key?(:timedtext_overview)
          @video_overview = args[:video_overview] if args.key?(:video_overview)
          @wally_mesh_type = args[:wally_mesh_type] if args.key?(:wally_mesh_type)
        end
      end
      
      # Audio stream description with no PII.
      class VideoMediaOverviewAudioOverview
        include Google::Apis::Core::Hashable
      
        # Number of audio channels.
        # Corresponds to the JSON property `channels`
        # @return [Fixnum]
        attr_accessor :channels
      
        # Content type of the audio track extracted from VSI. This is only populated
        # with valid "acont" xtag values at the moment, i.e., if VSI reports an invalid
        # string, we ignore it. Supported acont xtag values can be found in google3/
        # video/storage/common/xtag_validation.cc. Examples: "original", "dubbed", "
        # descriptive", "commentary", etc.
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # Language of the audio track extracted from VSI. Populated if it's deemed a
        # valid code by ISO639-2b, ISO639-2t or III library.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # 
        # Corresponds to the JSON property `loudness1770Lkfs`
        # @return [Float]
        attr_accessor :loudness1770_lkfs
      
        # Approximate audio length, has the same caveats as its video equivalent.
        # Corresponds to the JSON property `roundedUpOriginalDurationSec`
        # @return [Fixnum]
        attr_accessor :rounded_up_original_duration_sec
      
        # 
        # Corresponds to the JSON property `spatialAudioMode`
        # @return [String]
        attr_accessor :spatial_audio_mode
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @channels = args[:channels] if args.key?(:channels)
          @content_type = args[:content_type] if args.key?(:content_type)
          @language = args[:language] if args.key?(:language)
          @loudness1770_lkfs = args[:loudness1770_lkfs] if args.key?(:loudness1770_lkfs)
          @rounded_up_original_duration_sec = args[:rounded_up_original_duration_sec] if args.key?(:rounded_up_original_duration_sec)
          @spatial_audio_mode = args[:spatial_audio_mode] if args.key?(:spatial_audio_mode)
        end
      end
      
      # Data stream description with no PII. Currently used by originals replacement
      # pipeline to exclude all clips that have data streams. Fields in proto are used
      # to exclude clips with certain types of data streams.
      class VideoMediaOverviewDataOverview
        include Google::Apis::Core::Hashable
      
        # Whether the data stream has camera motion metadata (dynamic) or not (static).
        # Some Wally/VR180 videos do.
        # Corresponds to the JSON property `hasCameraMotionMetadata`
        # @return [Boolean]
        attr_accessor :has_camera_motion_metadata
        alias_method :has_camera_motion_metadata?, :has_camera_motion_metadata
      
        # If true, source contains metadata for OZO spatial audio support. See b/
        # 62393568 for more information about the OZO spatial audio format. Note that
        # SpatialAudioMode is independent of this format.
        # Corresponds to the JSON property `hasOzoAudio`
        # @return [Boolean]
        attr_accessor :has_ozo_audio
        alias_method :has_ozo_audio?, :has_ozo_audio
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_camera_motion_metadata = args[:has_camera_motion_metadata] if args.key?(:has_camera_motion_metadata)
          @has_ozo_audio = args[:has_ozo_audio] if args.key?(:has_ozo_audio)
        end
      end
      
      # Video clip info description with no PII.
      class VideoMediaOverviewMediaClipInfoOverview
        include Google::Apis::Core::Hashable
      
        # Corresponds to vsi.video_clip_info().has_geolocation()
        # Corresponds to the JSON property `hasGeolocation`
        # @return [Boolean]
        attr_accessor :has_geolocation
        alias_method :has_geolocation?, :has_geolocation
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @has_geolocation = args[:has_geolocation] if args.key?(:has_geolocation)
        end
      end
      
      # Timed text stream description with no PII. Currently used by originals
      # replacement pipeline to exclude all clips that have timed text streams. Add
      # fields to proto if we want to only exclude clips with certain types of timed
      # text streams in the future.
      class VideoMediaOverviewTimedTextOverview
        include Google::Apis::Core::Hashable
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
        end
      end
      
      # Video stream description with no PII.
      class VideoMediaOverviewVideoOverview
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `aspectRatio`
        # @return [String]
        attr_accessor :aspect_ratio
      
        # Prefer average_fps to match the logic used in transcoder for format profile
        # frame rate checks. First added for Photos, see b/165839654.
        # Corresponds to the JSON property `averageFps`
        # @return [Float]
        attr_accessor :average_fps
      
        # 
        # Corresponds to the JSON property `codecId`
        # @return [Fixnum]
        attr_accessor :codec_id
      
        # 
        # Corresponds to the JSON property `colorDynamicRange`
        # @return [String]
        attr_accessor :color_dynamic_range
      
        # 
        # Corresponds to the JSON property `fps`
        # @return [Float]
        attr_accessor :fps
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `resolution`
        # @return [String]
        attr_accessor :resolution
      
        # Approximate video length. Data is rounded up to the next second, to avoid
        # being PII. (Long ago, YTFE set a precedent of rounding up durations, rather
        # than rounding to the closest second.) This value is derived from metadata in
        # the source video, and often differs from the actual duration of any given
        # transcode. In videos without valid timestamps, this value is not calculable,
        # and is reported as zero. Prefer the value from MediaInfo::VideoStream over
        # this value, which was added to resolve b/202864365.
        # Corresponds to the JSON property `roundedUpOriginalDurationSec`
        # @return [Fixnum]
        attr_accessor :rounded_up_original_duration_sec
      
        # 
        # Corresponds to the JSON property `videoHasClosedCaptions`
        # @return [Boolean]
        attr_accessor :video_has_closed_captions
        alias_method :video_has_closed_captions?, :video_has_closed_captions
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
          @average_fps = args[:average_fps] if args.key?(:average_fps)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @color_dynamic_range = args[:color_dynamic_range] if args.key?(:color_dynamic_range)
          @fps = args[:fps] if args.key?(:fps)
          @height = args[:height] if args.key?(:height)
          @resolution = args[:resolution] if args.key?(:resolution)
          @rounded_up_original_duration_sec = args[:rounded_up_original_duration_sec] if args.key?(:rounded_up_original_duration_sec)
          @video_has_closed_captions = args[:video_has_closed_captions] if args.key?(:video_has_closed_captions)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class VideoPerDocData
        include Google::Apis::Core::Hashable
      
        # Core signals for video content corpus which will be fetched for every query.
        # If a signal is required only for a subset of search queries then it should be
        # added as a separate field in the schema.
        # Corresponds to the JSON property `coreSignals`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexVideoCoreSignals]
        attr_accessor :core_signals
      
        # Data about multiple video frames associated with the video.
        # Corresponds to the JSON property `frames`
        # @return [Google::Apis::ContentwarehouseV1::MediaIndexVideoFrames]
        attr_accessor :frames
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @core_signals = args[:core_signals] if args.key?(:core_signals)
          @frames = args[:frames] if args.key?(:frames)
        end
      end
      
      # 
      class VideoPipelineViperThumbnailerColumnData
        include Google::Apis::Core::Hashable
      
        # The blobRef where the representative frame is stored. This is repeated in
        # order to support multiple thumbnails in the future.
        # Corresponds to the JSON property `frameBlobRefs`
        # @return [Array<Google::Apis::ContentwarehouseV1::BlobstoreBlobRef>]
        attr_accessor :frame_blob_refs
      
        # List of individual video frames, each saved as an image file
        # Corresponds to the JSON property `frameFileList`
        # @return [Google::Apis::ContentwarehouseV1::VideoThumbnailsFrameFileList]
        attr_accessor :frame_file_list
      
        # Frame type generated (VR/360/3D/default).
        # Corresponds to the JSON property `frameTypeGenerated`
        # @return [String]
        attr_accessor :frame_type_generated
      
        # True if the thumbnails are generated from drishti_thumbnailer.
        # Corresponds to the JSON property `generatedFromDrishtiThumbnailer`
        # @return [Boolean]
        attr_accessor :generated_from_drishti_thumbnailer
        alias_method :generated_from_drishti_thumbnailer?, :generated_from_drishti_thumbnailer
      
        # 
        # Corresponds to the JSON property `highResPreviewThumbnailGenerated`
        # @return [Boolean]
        attr_accessor :high_res_preview_thumbnail_generated
        alias_method :high_res_preview_thumbnail_generated?, :high_res_preview_thumbnail_generated
      
        # hq720.jpg is a 1280x720 pixel image generated only when the input video
        # resolution is 1280x720 or higher.
        # Corresponds to the JSON property `hq720Generated`
        # @return [Boolean]
        attr_accessor :hq720_generated
        alias_method :hq720_generated?, :hq720_generated
      
        # The flags below indicate whether certain optional thumbnail images were
        # generated. hqdefault.jpg is a 480x360 pixel high quality image which should
        # normally be always generated.
        # Corresponds to the JSON property `hqdefaultGenerated`
        # @return [Boolean]
        attr_accessor :hqdefault_generated
        alias_method :hqdefault_generated?, :hqdefault_generated
      
        # True if a set of backup HVC thumbnails is generated.
        # Corresponds to the JSON property `hvcBackupGenerated`
        # @return [Boolean]
        attr_accessor :hvc_backup_generated
        alias_method :hvc_backup_generated?, :hvc_backup_generated
      
        # True if the thumbnails are generated with background crop and scrim.
        # Corresponds to the JSON property `improvedVerticalGenerated`
        # @return [Boolean]
        attr_accessor :improved_vertical_generated
        alias_method :improved_vertical_generated?, :improved_vertical_generated
      
        # maxresdefault.jpg is an image of the same resolution as the input video. It is
        # generated only when the input video is significantly higher-resolution than
        # 640x480.
        # Corresponds to the JSON property `maxresdefaultGenerated`
        # @return [Boolean]
        attr_accessor :maxresdefault_generated
        alias_method :maxresdefault_generated?, :maxresdefault_generated
      
        # Height of the generated maxresdefault thumbnail.
        # Corresponds to the JSON property `maxresdefaultHeight`
        # @return [Fixnum]
        attr_accessor :maxresdefault_height
      
        # Width of the generated maxresdefault thumbnail.
        # Corresponds to the JSON property `maxresdefaultWidth`
        # @return [Fixnum]
        attr_accessor :maxresdefault_width
      
        # True if moving thumbnails are generated.
        # Corresponds to the JSON property `movingThumbnailGenerated`
        # @return [Boolean]
        attr_accessor :moving_thumbnail_generated
        alias_method :moving_thumbnail_generated?, :moving_thumbnail_generated
      
        # True if private thumbnails were generated and stored in the thumbnail database.
        # Corresponds to the JSON property `privateThumbnailsGenerated`
        # @return [Boolean]
        attr_accessor :private_thumbnails_generated
        alias_method :private_thumbnails_generated?, :private_thumbnails_generated
      
        # True if public thumbnails were generated and stored in the thumbnail database.
        # Corresponds to the JSON property `publicThumbnailsGenerated`
        # @return [Boolean]
        attr_accessor :public_thumbnails_generated
        alias_method :public_thumbnails_generated?, :public_thumbnails_generated
      
        # Analysis result of running the rerun thumbnailer
        # Corresponds to the JSON property `rerunStatus`
        # @return [String]
        attr_accessor :rerun_status
      
        # sddefault.jpg is a 640x480 pixel image generated only when the input video
        # resolution is 640x480 or higher.
        # Corresponds to the JSON property `sddefaultGenerated`
        # @return [Boolean]
        attr_accessor :sddefault_generated
        alias_method :sddefault_generated?, :sddefault_generated
      
        # This flag indicates if storyboard mosaic images were generated and stored in
        # the thumbnail database.
        # Corresponds to the JSON property `storyboardGenerated`
        # @return [Boolean]
        attr_accessor :storyboard_generated
        alias_method :storyboard_generated?, :storyboard_generated
      
        # Number of levels of storyboard generated (0 if policy default).
        # Corresponds to the JSON property `storyboardNumLevels`
        # @return [Fixnum]
        attr_accessor :storyboard_num_levels
      
        # Policy number that governed the storyboard generation. If zero, no policy was
        # used and the storyboard format is not fully specified by the parameters
        # contained in this message.
        # Corresponds to the JSON property `storyboardPolicy`
        # @return [Fixnum]
        attr_accessor :storyboard_policy
      
        # Version of the storyboard.
        # Corresponds to the JSON property `storyboardVersion`
        # @return [Fixnum]
        attr_accessor :storyboard_version
      
        # Video duration of the video.
        # Corresponds to the JSON property `storyboardVideoDurationMs`
        # @return [Fixnum]
        attr_accessor :storyboard_video_duration_ms
      
        # Height of the video that was storyboarded.
        # Corresponds to the JSON property `storyboardVideoHeight`
        # @return [Fixnum]
        attr_accessor :storyboard_video_height
      
        # Width of the video that was storyboarded.
        # Corresponds to the JSON property `storyboardVideoWidth`
        # @return [Fixnum]
        attr_accessor :storyboard_video_width
      
        # This flag indicates if images in WebP format were created and stored in the
        # thumbnail database.
        # Corresponds to the JSON property `webpGenerated`
        # @return [Boolean]
        attr_accessor :webp_generated
        alias_method :webp_generated?, :webp_generated
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_blob_refs = args[:frame_blob_refs] if args.key?(:frame_blob_refs)
          @frame_file_list = args[:frame_file_list] if args.key?(:frame_file_list)
          @frame_type_generated = args[:frame_type_generated] if args.key?(:frame_type_generated)
          @generated_from_drishti_thumbnailer = args[:generated_from_drishti_thumbnailer] if args.key?(:generated_from_drishti_thumbnailer)
          @high_res_preview_thumbnail_generated = args[:high_res_preview_thumbnail_generated] if args.key?(:high_res_preview_thumbnail_generated)
          @hq720_generated = args[:hq720_generated] if args.key?(:hq720_generated)
          @hqdefault_generated = args[:hqdefault_generated] if args.key?(:hqdefault_generated)
          @hvc_backup_generated = args[:hvc_backup_generated] if args.key?(:hvc_backup_generated)
          @improved_vertical_generated = args[:improved_vertical_generated] if args.key?(:improved_vertical_generated)
          @maxresdefault_generated = args[:maxresdefault_generated] if args.key?(:maxresdefault_generated)
          @maxresdefault_height = args[:maxresdefault_height] if args.key?(:maxresdefault_height)
          @maxresdefault_width = args[:maxresdefault_width] if args.key?(:maxresdefault_width)
          @moving_thumbnail_generated = args[:moving_thumbnail_generated] if args.key?(:moving_thumbnail_generated)
          @private_thumbnails_generated = args[:private_thumbnails_generated] if args.key?(:private_thumbnails_generated)
          @public_thumbnails_generated = args[:public_thumbnails_generated] if args.key?(:public_thumbnails_generated)
          @rerun_status = args[:rerun_status] if args.key?(:rerun_status)
          @sddefault_generated = args[:sddefault_generated] if args.key?(:sddefault_generated)
          @storyboard_generated = args[:storyboard_generated] if args.key?(:storyboard_generated)
          @storyboard_num_levels = args[:storyboard_num_levels] if args.key?(:storyboard_num_levels)
          @storyboard_policy = args[:storyboard_policy] if args.key?(:storyboard_policy)
          @storyboard_version = args[:storyboard_version] if args.key?(:storyboard_version)
          @storyboard_video_duration_ms = args[:storyboard_video_duration_ms] if args.key?(:storyboard_video_duration_ms)
          @storyboard_video_height = args[:storyboard_video_height] if args.key?(:storyboard_video_height)
          @storyboard_video_width = args[:storyboard_video_width] if args.key?(:storyboard_video_width)
          @webp_generated = args[:webp_generated] if args.key?(:webp_generated)
        end
      end
      
      # 
      class VideoPipelineViperVsiColumnData
        include Google::Apis::Core::Hashable
      
        # Note that when a VSI is from a user video, the information reflects the info
        # in that source. Fields like lengths, fps, etc. are not guaranteed to be the
        # same as those of transcodes. If the relevant info in source is too broken, the
        # corresponding fields (e.g., lengths) could be unset or with the default value,
        # meaning VSI cannot compute them from the given info. Next id: 82
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfo]
        attr_accessor :info
      
        # Total time taken in seconds to read the input
        # Corresponds to the JSON property `inputReadTime`
        # @return [Float]
        attr_accessor :input_read_time
      
        # Was the VSI computed on a partial file ?
        # Corresponds to the JSON property `partialFile`
        # @return [Boolean]
        attr_accessor :partial_file
        alias_method :partial_file?, :partial_file
      
        # Total time (of all attempts) taken in seconds to compute VSI
        # Corresponds to the JSON property `totalVsiTime`
        # @return [Float]
        attr_accessor :total_vsi_time
      
        # 
        # Corresponds to the JSON property `vsiStats`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoPipelineViperVsiColumnDataVsiStats>]
        attr_accessor :vsi_stats
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @info = args[:info] if args.key?(:info)
          @input_read_time = args[:input_read_time] if args.key?(:input_read_time)
          @partial_file = args[:partial_file] if args.key?(:partial_file)
          @total_vsi_time = args[:total_vsi_time] if args.key?(:total_vsi_time)
          @vsi_stats = args[:vsi_stats] if args.key?(:vsi_stats)
        end
      end
      
      # The stats of each output vsi.
      class VideoPipelineViperVsiColumnDataVsiStats
        include Google::Apis::Core::Hashable
      
        # True if the output vsi is a partial vsi.
        # Corresponds to the JSON property `partialVsi`
        # @return [Boolean]
        attr_accessor :partial_vsi
        alias_method :partial_vsi?, :partial_vsi
      
        # The time (in secondes) from vsi_engine init to vsi written to output buffer.
        # Corresponds to the JSON property `vsiTime`
        # @return [Float]
        attr_accessor :vsi_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @partial_vsi = args[:partial_vsi] if args.key?(:partial_vsi)
          @vsi_time = args[:vsi_time] if args.key?(:vsi_time)
        end
      end
      
      # 
      class VideoRational32
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `denominator`
        # @return [Fixnum]
        attr_accessor :denominator
      
        # 
        # Corresponds to the JSON property `numerator`
        # @return [Fixnum]
        attr_accessor :numerator
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @denominator = args[:denominator] if args.key?(:denominator)
          @numerator = args[:numerator] if args.key?(:numerator)
        end
      end
      
      # This SEI message only takes the payload type and the sum of the payload sizes
      # for all SEI messages of this type. More informations, such as timestamp,
      # payload, may be added in the future.
      class VideoSeiMessage
        include Google::Apis::Core::Hashable
      
        # message count of each payloadtype
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # If the video stream has multiple SEI messages with the same payload type, this
        # is the sum of all these payloads' sizes.
        # Corresponds to the JSON property `cumulativeSize`
        # @return [Fixnum]
        attr_accessor :cumulative_size
      
        # use int type in case there are payload types that are not included in the
        # SEIPayloadType enum below. The enum can be used for lookup
        # Corresponds to the JSON property `payloadtype`
        # @return [Fixnum]
        attr_accessor :payloadtype
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @cumulative_size = args[:cumulative_size] if args.key?(:cumulative_size)
          @payloadtype = args[:payloadtype] if args.key?(:payloadtype)
        end
      end
      
      # Measurement of loudness. Next tag = 3
      class VideoStorageLoudnessData
        include Google::Apis::Core::Hashable
      
        # Loudness measured using ITU-R BS. 1770
        # Corresponds to the JSON property `itu1770LoudnessDb`
        # @return [Float]
        attr_accessor :itu1770_loudness_db
      
        # Perceived loudness of audio measured using replaygain.
        # Corresponds to the JSON property `perceptualLoudnessDb`
        # @return [Float]
        attr_accessor :perceptual_loudness_db
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @itu1770_loudness_db = args[:itu1770_loudness_db] if args.key?(:itu1770_loudness_db)
          @perceptual_loudness_db = args[:perceptual_loudness_db] if args.key?(:perceptual_loudness_db)
        end
      end
      
      # Individual video frame saved in an image file.
      class VideoThumbnailsFrameFile
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `filename`
        # @return [String]
        attr_accessor :filename
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `msOffset`
        # @return [Fixnum]
        attr_accessor :ms_offset
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @filename = args[:filename] if args.key?(:filename)
          @height = args[:height] if args.key?(:height)
          @ms_offset = args[:ms_offset] if args.key?(:ms_offset)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # List of individual video frames, each saved as an image file
      class VideoThumbnailsFrameFileList
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `frameFiles`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoThumbnailsFrameFile>]
        attr_accessor :frame_files
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @frame_files = args[:frame_files] if args.key?(:frame_files)
        end
      end
      
      # LINT.IfChange Score calculated from a thumbnail. NextID: 15
      class VideoThumbnailsThumbnailScore
        include Google::Apis::Core::Hashable
      
        # Checksum of the thumbnail bytes used to identify which image the score belongs
        # to. Only filled when thumbnail version is 0.
        # Corresponds to the JSON property `checksum`
        # @return [Fixnum]
        attr_accessor :checksum
      
        # Color sampling score encoded as uint32. Encode/Decode using youtube::color::
        # RgbToUint / UIntToRgb. Field is only relevant for TYPE_COLOR_SAMPLING.
        # Corresponds to the JSON property `colorSampling`
        # @return [Fixnum]
        attr_accessor :color_sampling
      
        # Thumbnail dense features.
        # Corresponds to the JSON property `denseFeatures`
        # @return [Array<Float>]
        attr_accessor :dense_features
      
        # FeatureExtra extension for dense features.
        # Corresponds to the JSON property `denseGeneralExtraFeatures`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiFeatureExtra]
        attr_accessor :dense_general_extra_features
      
        # If true, score is manually assigned.
        # Corresponds to the JSON property `isAssigned`
        # @return [Boolean]
        attr_accessor :is_assigned
        alias_method :is_assigned?, :is_assigned
      
        # If true, score will be instantly indexed by YouTube search indexer.
        # Corresponds to the JSON property `isInstant`
        # @return [Boolean]
        attr_accessor :is_instant
        alias_method :is_instant?, :is_instant
      
        # 
        # Corresponds to the JSON property `modelVersion`
        # @return [String]
        attr_accessor :model_version
      
        # 
        # Corresponds to the JSON property `overwriteReason`
        # @return [String]
        attr_accessor :overwrite_reason
      
        # Thumbnail quantized dense features, available in TYPE_STARBURST_COMPRESSED
        # Corresponds to the JSON property `quantizedFeatures`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :quantized_features
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Thumbnail sparse features, available in TYPE_STARBURST
        # Corresponds to the JSON property `sparseFeatures`
        # @return [Google::Apis::ContentwarehouseV1::DrishtiSparseFeatureData]
        attr_accessor :sparse_features
      
        # 
        # Corresponds to the JSON property `thumbnailSet`
        # @return [String]
        attr_accessor :thumbnail_set
      
        # Version number of the thumbnail. Should be consistent with the version number
        # in the ytimg_content column family.
        # Corresponds to the JSON property `thumbnailVersion`
        # @return [Fixnum]
        attr_accessor :thumbnail_version
      
        # 
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @checksum = args[:checksum] if args.key?(:checksum)
          @color_sampling = args[:color_sampling] if args.key?(:color_sampling)
          @dense_features = args[:dense_features] if args.key?(:dense_features)
          @dense_general_extra_features = args[:dense_general_extra_features] if args.key?(:dense_general_extra_features)
          @is_assigned = args[:is_assigned] if args.key?(:is_assigned)
          @is_instant = args[:is_instant] if args.key?(:is_instant)
          @model_version = args[:model_version] if args.key?(:model_version)
          @overwrite_reason = args[:overwrite_reason] if args.key?(:overwrite_reason)
          @quantized_features = args[:quantized_features] if args.key?(:quantized_features)
          @score = args[:score] if args.key?(:score)
          @sparse_features = args[:sparse_features] if args.key?(:sparse_features)
          @thumbnail_set = args[:thumbnail_set] if args.key?(:thumbnail_set)
          @thumbnail_version = args[:thumbnail_version] if args.key?(:thumbnail_version)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # 
      class VideoTimedtextS4AliResults
        include Google::Apis::Core::Hashable
      
        # The complete list of language scores, sorted from high score to low.
        # Corresponds to the JSON property `langResults`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoTimedtextS4LangScore>]
        attr_accessor :lang_results
      
        # What kind of speech (if any) was detected.
        # Corresponds to the JSON property `speechClass`
        # @return [String]
        attr_accessor :speech_class
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lang_results = args[:lang_results] if args.key?(:lang_results)
          @speech_class = args[:speech_class] if args.key?(:speech_class)
        end
      end
      
      # 
      class VideoTimedtextS4LangScore
        include Google::Apis::Core::Hashable
      
        # A score between 0.0 and 1.0; the relative probability that this is the
        # language of the video. This should not be interpreted as an absolute
        # probability. For instance, scores may be calculated for all languages even for
        # videos for which no speech was detected.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # The language code for one of the languages supported by automatic language
        # identification.
        # Corresponds to the JSON property `langCode`
        # @return [String]
        attr_accessor :lang_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @lang_code = args[:lang_code] if args.key?(:lang_code)
        end
      end
      
      # This message contains user data registered itu-t t.35 data
      class VideoUserDataRegisteredItuTt35
        include Google::Apis::Core::Hashable
      
        # Counts itu-t t.35 message with the same country code and provider code
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # 
        # Corresponds to the JSON property `countryCode`
        # @return [Fixnum]
        attr_accessor :country_code
      
        # 
        # Corresponds to the JSON property `providerCode`
        # @return [Fixnum]
        attr_accessor :provider_code
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @country_code = args[:country_code] if args.key?(:country_code)
          @provider_code = args[:provider_code] if args.key?(:provider_code)
        end
      end
      
      # This message contains unregistered user data identified by a UUID
      class VideoUserDataUnregistered
        include Google::Apis::Core::Hashable
      
        # Counts user data with the same uuid and payload If payload size is larger than
        # limit, the payload will be 'Payload size is larger than limit: ' + limit size
        # Count will be for user data with same uuid and payload exceeds limit in this
        # case
        # Corresponds to the JSON property `count`
        # @return [Fixnum]
        attr_accessor :count
      
        # Payload may not be filled in Payload may contain user data
        # Corresponds to the JSON property `payload`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :payload
      
        # 
        # Corresponds to the JSON property `uuid`
        # @return [String]
        attr_accessor :uuid
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @count = args[:count] if args.key?(:count)
          @payload = args[:payload] if args.key?(:payload)
          @uuid = args[:uuid] if args.key?(:uuid)
        end
      end
      
      # VideoClipInfo : meta information extracted from video file Next id: 26
      class VideoVideoClipInfo
        include Google::Apis::Core::Hashable
      
        # Lists the artist of the original subject of the file.
        # Corresponds to the JSON property `artist`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :artist
      
        # Audio vendor ID
        # Corresponds to the JSON property `audioVendorId`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :audio_vendor_id
      
        # Different containers use different video clip info. The following fields
        # include info from popular formats: AVI, MOV, and WMV.
        # Corresponds to the JSON property `author`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :author
      
        # 
        # Corresponds to the JSON property `comment`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :comment
      
        # Lists the name of the person or organization that commissioned the subject of
        # the file.
        # Corresponds to the JSON property `commissioned`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :commissioned
      
        # Records the copyright information for the file.
        # Corresponds to the JSON property `copyright`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :copyright
      
        # 
        # Corresponds to the JSON property `digitizationTime`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :digitization_time
      
        # 
        # Corresponds to the JSON property `director`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :director
      
        # The engineer who worked on the file.
        # Corresponds to the JSON property `engineer`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :engineer
      
        # Generic geo-location information. This is error-prone due to the fact that is
        # uses signed integer fields, which are not supported by proto1 API and are cast
        # to unsigned integers. Consider using the metadata_util function directly,
        # which fills out a version 2 API proto.
        # Corresponds to the JSON property `geolocation`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoGeoLocation]
        attr_accessor :geolocation
      
        # 
        # Corresponds to the JSON property `info`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :info
      
        # Provides a list of keywords that refer to the file or subject of the file.
        # Corresponds to the JSON property `keywords`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :keywords
      
        # The camera make such as Apple, Samsung etc.
        # Corresponds to the JSON property `make`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :make
      
        # Describes the original subject of the file.
        # Corresponds to the JSON property `medium`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :medium
      
        # Container level metadata
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoClipInfo>]
        attr_accessor :metadata
      
        # The camera model such as iPhone7 or Pixel, etc.
        # Corresponds to the JSON property `model`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :model
      
        # 
        # Corresponds to the JSON property `performer`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :performer
      
        # 
        # Corresponds to the JSON property `producer`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :producer
      
        # 
        # Corresponds to the JSON property `requirements`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :requirements
      
        # Identifies the name of the software packages used to create the file.
        # Corresponds to the JSON property `software`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :software
      
        # Identifies the name of the person or organization who supplied the original
        # subject of the file.
        # Corresponds to the JSON property `sourceProvider`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :source_provider
      
        # Describes the contents of the file.
        # Corresponds to the JSON property `subject`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :subject
      
        # Identifies the technician who digitized the subject file.
        # Corresponds to the JSON property `technician`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :technician
      
        # 
        # Corresponds to the JSON property `title`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :title
      
        # Video vendor ID
        # Corresponds to the JSON property `videoVendorId`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :video_vendor_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @artist = args[:artist] if args.key?(:artist)
          @audio_vendor_id = args[:audio_vendor_id] if args.key?(:audio_vendor_id)
          @author = args[:author] if args.key?(:author)
          @comment = args[:comment] if args.key?(:comment)
          @commissioned = args[:commissioned] if args.key?(:commissioned)
          @copyright = args[:copyright] if args.key?(:copyright)
          @digitization_time = args[:digitization_time] if args.key?(:digitization_time)
          @director = args[:director] if args.key?(:director)
          @engineer = args[:engineer] if args.key?(:engineer)
          @geolocation = args[:geolocation] if args.key?(:geolocation)
          @info = args[:info] if args.key?(:info)
          @keywords = args[:keywords] if args.key?(:keywords)
          @make = args[:make] if args.key?(:make)
          @medium = args[:medium] if args.key?(:medium)
          @metadata = args[:metadata] if args.key?(:metadata)
          @model = args[:model] if args.key?(:model)
          @performer = args[:performer] if args.key?(:performer)
          @producer = args[:producer] if args.key?(:producer)
          @requirements = args[:requirements] if args.key?(:requirements)
          @software = args[:software] if args.key?(:software)
          @source_provider = args[:source_provider] if args.key?(:source_provider)
          @subject = args[:subject] if args.key?(:subject)
          @technician = args[:technician] if args.key?(:technician)
          @title = args[:title] if args.key?(:title)
          @video_vendor_id = args[:video_vendor_id] if args.key?(:video_vendor_id)
        end
      end
      
      # Generic geo-location information. This is error-prone due to the fact that is
      # uses signed integer fields, which are not supported by proto1 API and are cast
      # to unsigned integers. Consider using the metadata_util function directly,
      # which fills out a version 2 API proto.
      class VideoVideoGeoLocation
        include Google::Apis::Core::Hashable
      
        # Altitude is in meters and multiplied by 100 (i.e., in centimeters). Up till 10
        # km this fits in 3 bytes.
        # Corresponds to the JSON property `altitudeE2`
        # @return [Fixnum]
        attr_accessor :altitude_e2
      
        # Latitude and longitude are in degrees and multiplied by 10^7. This gives the
        # worst precision of about 1 cm at the equator.
        # Corresponds to the JSON property `latitudeE7`
        # @return [Fixnum]
        attr_accessor :latitude_e7
      
        # 
        # Corresponds to the JSON property `longitudeE7`
        # @return [Fixnum]
        attr_accessor :longitude_e7
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @altitude_e2 = args[:altitude_e2] if args.key?(:altitude_e2)
          @latitude_e7 = args[:latitude_e7] if args.key?(:latitude_e7)
          @longitude_e7 = args[:longitude_e7] if args.key?(:longitude_e7)
        end
      end
      
      # 
      class VideoVideoStream
        include Google::Apis::Core::Hashable
      
        # Video bitrate in bits/s.
        # Corresponds to the JSON property `bitrate`
        # @return [Fixnum]
        attr_accessor :bitrate
      
        # Video codec ID. Uses the numeric value corresponding to the CodecId enum
        # object, in order to avoid the dependency on vsi/videostreaminfo.proto. http://
        # cs/symbol:CodecId%20f:google3/video/vidproc/vsi/videostreaminfo.proto
        # Corresponds to the JSON property `codecId`
        # @return [Fixnum]
        attr_accessor :codec_id
      
        # Video frame per second, obtained by parsing video header information. The
        # value can be inaccurate for some types of codecs. See comments at http://cs/
        # symbol:video_fps%20f:google3/video/vidproc/vsi/videostreaminfo.proto
        # Corresponds to the JSON property `fps`
        # @return [Float]
        attr_accessor :fps
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Video length, in seconds. This value is derived from metadata in the source
        # video, and often differs from the actual duration of any given transcode. In
        # videos without valid timestamps, this value is not calculable, and is reported
        # as zero.
        # Corresponds to the JSON property `lengthSec`
        # @return [Float]
        attr_accessor :length_sec
      
        # Index of the stream in the file, 0-based.
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        # video width and height.
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @bitrate = args[:bitrate] if args.key?(:bitrate)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @fps = args[:fps] if args.key?(:fps)
          @height = args[:height] if args.key?(:height)
          @length_sec = args[:length_sec] if args.key?(:length_sec)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # Note that when a VSI is from a user video, the information reflects the info
      # in that source. Fields like lengths, fps, etc. are not guaranteed to be the
      # same as those of transcodes. If the relevant info in source is too broken, the
      # corresponding fields (e.g., lengths) could be unset or with the default value,
      # meaning VSI cannot compute them from the given info. Next id: 82
      class VideoVideoStreamInfo
        include Google::Apis::Core::Hashable
      
        # audio bitrate in bits/s
        # Corresponds to the JSON property `audioBitrate`
        # @return [Float]
        attr_accessor :audio_bitrate
      
        # audio channels
        # Corresponds to the JSON property `audioChannels`
        # @return [Fixnum]
        attr_accessor :audio_channels
      
        # Primary audio codec information Fields 15-20, 41-42, 48, 52-53 for audio will
        # be obsolete soon. Please start using the new repeated audio_stream and
        # video_stream. For now, audio_stream(0) will match these fields. Primary audio
        # codec information starts:
        # Corresponds to the JSON property `audioCodecId`
        # @return [String]
        attr_accessor :audio_codec_id
      
        # 
        # Corresponds to the JSON property `audioEndTimestamp`
        # @return [Fixnum]
        attr_accessor :audio_end_timestamp
      
        # audio frame size
        # Corresponds to the JSON property `audioFrameSize`
        # @return [Fixnum]
        attr_accessor :audio_frame_size
      
        # audio length in seconds Note that when the VSI is from users videos, it is not
        # guaranteed to be the same as transcode lengths and it could be 0 when the full
        # VSI cannot compute the length from the source header and timestamps (for
        # example when header and timestamps are too broken).
        # Corresponds to the JSON property `audioLength`
        # @return [Float]
        attr_accessor :audio_length
      
        # Number of audio frames. Ffmpeg does not report the number of frames accurately.
        # video::TranscodedVideoFileInformation calls Google's analyzer to get
        # information of both audio and video frame numbers.
        # Corresponds to the JSON property `audioNumberOfFrames`
        # @return [Fixnum]
        attr_accessor :audio_number_of_frames
      
        # audio sample rate
        # Corresponds to the JSON property `audioSampleRate`
        # @return [Fixnum]
        attr_accessor :audio_sample_rate
      
        # Number of meaningful bits per decoded audio sample. This is an implicit
        # conceptual meaning. This is *NOT* the same as ffmpeg's internal sample format
        # that is used when actually decoding with ffmpeg.
        # Corresponds to the JSON property `audioSampleSize`
        # @return [Fixnum]
        attr_accessor :audio_sample_size
      
        # 
        # Corresponds to the JSON property `audioStartTimestamp`
        # @return [Fixnum]
        attr_accessor :audio_start_timestamp
      
        # 
        # Corresponds to the JSON property `audioStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoAudioStream>]
        attr_accessor :audio_stream
      
        # 
        # Corresponds to the JSON property `audioStreamCodecTag`
        # @return [Fixnum]
        attr_accessor :audio_stream_codec_tag
      
        # Audio-Video interleaving distance between packets (in bytes)
        # Corresponds to the JSON property `avDistance`
        # @return [Fixnum]
        attr_accessor :av_distance
      
        # Audio and video length in seconds. It's the max of the audio and video length.
        # Note that when the VSI is from users videos, it is not guaranteed to be the
        # same as transcode lengths and it could be 0 when the full VSI cannot compute
        # the length from the source header and timestamps (for example when header and
        # timestamps are too broken).
        # Corresponds to the JSON property `avLength`
        # @return [Float]
        attr_accessor :av_length
      
        # Average video fps from analyzing entire file.
        # Corresponds to the JSON property `averageVideoFps`
        # @return [Float]
        attr_accessor :average_video_fps
      
        # Build label of the VSI mpm.
        # Corresponds to the JSON property `buildLabel`
        # @return [String]
        attr_accessor :build_label
      
        # Container Id.
        # Corresponds to the JSON property `containerId`
        # @return [String]
        attr_accessor :container_id
      
        # Name of the container format guessed by ffmpeg.
        # Corresponds to the JSON property `containerType`
        # @return [String]
        attr_accessor :container_type
      
        # If the video contains chapters info.
        # Corresponds to the JSON property `containsChapters`
        # @return [Boolean]
        attr_accessor :contains_chapters
        alias_method :contains_chapters?, :contains_chapters
      
        # 
        # Corresponds to the JSON property `dataStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoDataStream>]
        attr_accessor :data_stream
      
        # 
        # Corresponds to the JSON property `displayHeight`
        # @return [Fixnum]
        attr_accessor :display_height
      
        # final display video width and height if explicitly set in the video otherwise
        # this can be calculated from source width/height and video_pixel_aspect_ratio
        # Corresponds to the JSON property `displayWidth`
        # @return [Fixnum]
        attr_accessor :display_width
      
        # Input file header fingerprint
        # Corresponds to the JSON property `fileHeaderFingerprint`
        # @return [Fixnum]
        attr_accessor :file_header_fingerprint
      
        # The file type string returned by libmagic, a third party library. It might
        # accidentally include some user content. Some normal file_magic examples: --
        # RIFF (little-endian) data, AVI, 1016 x 696, 30.00 fps, video: XviD, audio: (
        # stereo, 48000 Hz) -- MPEG sequence, v2, program multiplex -- ISO Media, MPEG
        # v4 system, iTunes AVC-LC -- Microsoft Windows Movie Maker project file
        # Corresponds to the JSON property `fileMagic`
        # @return [String]
        attr_accessor :file_magic
      
        # Input file modification time
        # Corresponds to the JSON property `fileModifiedTime`
        # @return [Fixnum]
        attr_accessor :file_modified_time
      
        # Input file name. DEPRECATED; don't expect the file name to be correct.
        # Corresponds to the JSON property `fileName`
        # @return [String]
        attr_accessor :file_name
      
        # Input file size in bytes
        # Corresponds to the JSON property `fileSize`
        # @return [Fixnum]
        attr_accessor :file_size
      
        # High-level file type guessed by looking at the file headers and libmagic.
        # Corresponds to the JSON property `fileType`
        # @return [Fixnum]
        attr_accessor :file_type
      
        # 
        # Corresponds to the JSON property `imageStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoVideoStream>]
        attr_accessor :image_stream
      
        # True if the video is likely to be an ASF file.
        # Corresponds to the JSON property `isAsf`
        # @return [Boolean]
        attr_accessor :is_asf
        alias_method :is_asf?, :is_asf
      
        # True if the video is actually an image file (JPEG, PNG, GIF, etc) and not a
        # video file.
        # Corresponds to the JSON property `isImageFile`
        # @return [Boolean]
        attr_accessor :is_image_file
        alias_method :is_image_file?, :is_image_file
      
        # Check if a video size insane or not. It is set if the input file is an MOV
        # file.
        # Corresponds to the JSON property `isVideoInsaneSize`
        # @return [Boolean]
        attr_accessor :is_video_insane_size
        alias_method :is_video_insane_size?, :is_video_insane_size
      
        # 
        # Corresponds to the JSON property `level`
        # @return [Fixnum]
        attr_accessor :level
      
        # 
        # Corresponds to the JSON property `metadata`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoMetadata]
        attr_accessor :metadata
      
        # Total number of audio streams in the file
        # Corresponds to the JSON property `numAudioStreams`
        # @return [Fixnum]
        attr_accessor :num_audio_streams
      
        # Total number of data streams in the file
        # Corresponds to the JSON property `numDataStreams`
        # @return [Fixnum]
        attr_accessor :num_data_streams
      
        # Total number of image streams in the file
        # Corresponds to the JSON property `numImageStreams`
        # @return [Fixnum]
        attr_accessor :num_image_streams
      
        # Total number of timedtext streams in the file
        # Corresponds to the JSON property `numTimedtextStreams`
        # @return [Fixnum]
        attr_accessor :num_timedtext_streams
      
        # Total number of video streams in the file
        # Corresponds to the JSON property `numVideoStreams`
        # @return [Fixnum]
        attr_accessor :num_video_streams
      
        # If this field is not set, then only base video file information has been
        # generated (and ffmpeg parsing hasn't yet been done). If this is set to 'false',
        # then ffmpeg failed to parse the file - otherwise it will set to 'true'
        # Corresponds to the JSON property `parsedByFfmpeg`
        # @return [Boolean]
        attr_accessor :parsed_by_ffmpeg
        alias_method :parsed_by_ffmpeg?, :parsed_by_ffmpeg
      
        # By default we assume that the entire file was given computing the VSI - if
        # that is not true this flag should be set to true.
        # Corresponds to the JSON property `partialFile`
        # @return [Boolean]
        attr_accessor :partial_file
        alias_method :partial_file?, :partial_file
      
        # Pixel format for the video stream.
        # Corresponds to the JSON property `pixFmt`
        # @return [String]
        attr_accessor :pix_fmt
      
        # video profile
        # Corresponds to the JSON property `profile`
        # @return [String]
        attr_accessor :profile
      
        # 
        # Corresponds to the JSON property `timedtextStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoTimedTextStream>]
        attr_accessor :timedtext_stream
      
        # video bitrate in bits/s
        # Corresponds to the JSON property `videoBitrate`
        # @return [Float]
        attr_accessor :video_bitrate
      
        # VideoClipInfo : meta information extracted from video file Next id: 26
        # Corresponds to the JSON property `videoClipInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoClipInfo]
        attr_accessor :video_clip_info
      
        # Primary video codec information Fields 1-2, 4-10, 28, 37, 44, 49, 51, 54-55,
        # 57-62, 69 will be obsolete soon. Please start using the new repeated
        # video_stream. For now, video_stream(0) will match these fields. Note however
        # that some of the fields in VideoStream are not populated correctly yet in
        # videostreaminfo.cc, but that will be handled gradually.
        # Corresponds to the JSON property `videoCodecId`
        # @return [String]
        attr_accessor :video_codec_id
      
        # 
        # Corresponds to the JSON property `videoEndTimestamp`
        # @return [Fixnum]
        attr_accessor :video_end_timestamp
      
        # video frame per second, obtained by parsing video header information. It could
        # be inaccurate for some types of codecs, notably, WMV, ASF, and FLV. It will be
        # inaccurate for videos that does not have constant frame rate since it is the
        # smallest framerate that can accurately represent all timestamps (see ffmpeg
        # doc for AVStream.r_frame_rate). Also frame rate can be parsed from headers and
        # can be wrong if it is not available there since ffmpeg uses a heuristic for
        # determining it.
        # Corresponds to the JSON property `videoFps`
        # @return [Float]
        attr_accessor :video_fps
      
        # video frame size
        # Corresponds to the JSON property `videoFrameSize`
        # @return [Fixnum]
        attr_accessor :video_frame_size
      
        # video has b frames
        # Corresponds to the JSON property `videoHasBFrames`
        # @return [Boolean]
        attr_accessor :video_has_b_frames
        alias_method :video_has_b_frames?, :video_has_b_frames
      
        # video (MOV) has fragments
        # Corresponds to the JSON property `videoHasFragments`
        # @return [Boolean]
        attr_accessor :video_has_fragments
        alias_method :video_has_fragments?, :video_has_fragments
      
        # video (MOV) has moov atom before mdat atom allowing streaming transcoding
        # Corresponds to the JSON property `videoHasLeadingMoovAtom`
        # @return [Boolean]
        attr_accessor :video_has_leading_moov_atom
        alias_method :video_has_leading_moov_atom?, :video_has_leading_moov_atom
      
        # video has non-monotonic DTS (potential problem)
        # Corresponds to the JSON property `videoHasNonMonotonicDts`
        # @return [Boolean]
        attr_accessor :video_has_non_monotonic_dts
        alias_method :video_has_non_monotonic_dts?, :video_has_non_monotonic_dts
      
        # video has non-monotonic PTS.
        # Corresponds to the JSON property `videoHasNonMonotonicPts`
        # @return [Boolean]
        attr_accessor :video_has_non_monotonic_pts
        alias_method :video_has_non_monotonic_pts?, :video_has_non_monotonic_pts
      
        # video (MOV) has a possibly av desync issue due to edit lists not starting at 0
        # Corresponds to the JSON property `videoHasNonZeroStartEditList`
        # @return [Boolean]
        attr_accessor :video_has_non_zero_start_edit_list
        alias_method :video_has_non_zero_start_edit_list?, :video_has_non_zero_start_edit_list
      
        # video has possible open GOP
        # Corresponds to the JSON property `videoHasPossibleOpenGop`
        # @return [Boolean]
        attr_accessor :video_has_possible_open_gop
        alias_method :video_has_possible_open_gop?, :video_has_possible_open_gop
      
        # video has frames with different aspect ratios.
        # Corresponds to the JSON property `videoHasVariableAspectRatio`
        # @return [Boolean]
        attr_accessor :video_has_variable_aspect_ratio
        alias_method :video_has_variable_aspect_ratio?, :video_has_variable_aspect_ratio
      
        # 
        # Corresponds to the JSON property `videoHeight`
        # @return [Fixnum]
        attr_accessor :video_height
      
        # Information on interlaced video.
        # Corresponds to the JSON property `videoInterlace`
        # @return [String]
        attr_accessor :video_interlace
      
        # video length in seconds Note that when the VSI is from users videos, it is not
        # guaranteed to be the same as transcode lengths and it could be 0 when the full
        # VSI cannot compute the length from the source header and timestamps (for
        # example when header and timestamps are too broken).
        # Corresponds to the JSON property `videoLength`
        # @return [Float]
        attr_accessor :video_length
      
        # Number of Video frames Warning: running video::FfmpegVideoFileInformation()
        # won't set this info Ffmpeg tool does not report the number of frames
        # accurately. We can't rely on fps and video length. So we will set this after
        # we processed every frame using the filter framework
        # Corresponds to the JSON property `videoNumberOfFrames`
        # @return [Fixnum]
        attr_accessor :video_number_of_frames
      
        # Invisible frame count Keep a count of frames that are not displayed should the
        # full frame count be needed for the video stream. The only codec currently
        # reporting this value is VP8 with alternate reference frames enabled
        # Corresponds to the JSON property `videoNumberOfInvisibleFrames`
        # @return [Fixnum]
        attr_accessor :video_number_of_invisible_frames
      
        # video pixel aspect ratio
        # Corresponds to the JSON property `videoPixelAspectRatio`
        # @return [Float]
        attr_accessor :video_pixel_aspect_ratio
      
        # Is the video rotated ?
        # Corresponds to the JSON property `videoRotation`
        # @return [String]
        attr_accessor :video_rotation
      
        # Start/end timestamps of audio/video in ms.
        # Corresponds to the JSON property `videoStartTimestamp`
        # @return [Fixnum]
        attr_accessor :video_start_timestamp
      
        # 
        # Corresponds to the JSON property `videoStream`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoVideoStream>]
        attr_accessor :video_stream
      
        # 
        # Corresponds to the JSON property `videoStreamCodecTag`
        # @return [Fixnum]
        attr_accessor :video_stream_codec_tag
      
        # source video width and height
        # Corresponds to the JSON property `videoWidth`
        # @return [Fixnum]
        attr_accessor :video_width
      
        # Version number of the videostreaminfo application that generated this protobuf.
        # Corresponds to the JSON property `videostreaminfoVersion`
        # @return [Fixnum]
        attr_accessor :videostreaminfo_version
      
        # Luma PSNR of the transcoded file.
        # Corresponds to the JSON property `yPsnr`
        # @return [Float]
        attr_accessor :y_psnr
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @audio_bitrate = args[:audio_bitrate] if args.key?(:audio_bitrate)
          @audio_channels = args[:audio_channels] if args.key?(:audio_channels)
          @audio_codec_id = args[:audio_codec_id] if args.key?(:audio_codec_id)
          @audio_end_timestamp = args[:audio_end_timestamp] if args.key?(:audio_end_timestamp)
          @audio_frame_size = args[:audio_frame_size] if args.key?(:audio_frame_size)
          @audio_length = args[:audio_length] if args.key?(:audio_length)
          @audio_number_of_frames = args[:audio_number_of_frames] if args.key?(:audio_number_of_frames)
          @audio_sample_rate = args[:audio_sample_rate] if args.key?(:audio_sample_rate)
          @audio_sample_size = args[:audio_sample_size] if args.key?(:audio_sample_size)
          @audio_start_timestamp = args[:audio_start_timestamp] if args.key?(:audio_start_timestamp)
          @audio_stream = args[:audio_stream] if args.key?(:audio_stream)
          @audio_stream_codec_tag = args[:audio_stream_codec_tag] if args.key?(:audio_stream_codec_tag)
          @av_distance = args[:av_distance] if args.key?(:av_distance)
          @av_length = args[:av_length] if args.key?(:av_length)
          @average_video_fps = args[:average_video_fps] if args.key?(:average_video_fps)
          @build_label = args[:build_label] if args.key?(:build_label)
          @container_id = args[:container_id] if args.key?(:container_id)
          @container_type = args[:container_type] if args.key?(:container_type)
          @contains_chapters = args[:contains_chapters] if args.key?(:contains_chapters)
          @data_stream = args[:data_stream] if args.key?(:data_stream)
          @display_height = args[:display_height] if args.key?(:display_height)
          @display_width = args[:display_width] if args.key?(:display_width)
          @file_header_fingerprint = args[:file_header_fingerprint] if args.key?(:file_header_fingerprint)
          @file_magic = args[:file_magic] if args.key?(:file_magic)
          @file_modified_time = args[:file_modified_time] if args.key?(:file_modified_time)
          @file_name = args[:file_name] if args.key?(:file_name)
          @file_size = args[:file_size] if args.key?(:file_size)
          @file_type = args[:file_type] if args.key?(:file_type)
          @image_stream = args[:image_stream] if args.key?(:image_stream)
          @is_asf = args[:is_asf] if args.key?(:is_asf)
          @is_image_file = args[:is_image_file] if args.key?(:is_image_file)
          @is_video_insane_size = args[:is_video_insane_size] if args.key?(:is_video_insane_size)
          @level = args[:level] if args.key?(:level)
          @metadata = args[:metadata] if args.key?(:metadata)
          @num_audio_streams = args[:num_audio_streams] if args.key?(:num_audio_streams)
          @num_data_streams = args[:num_data_streams] if args.key?(:num_data_streams)
          @num_image_streams = args[:num_image_streams] if args.key?(:num_image_streams)
          @num_timedtext_streams = args[:num_timedtext_streams] if args.key?(:num_timedtext_streams)
          @num_video_streams = args[:num_video_streams] if args.key?(:num_video_streams)
          @parsed_by_ffmpeg = args[:parsed_by_ffmpeg] if args.key?(:parsed_by_ffmpeg)
          @partial_file = args[:partial_file] if args.key?(:partial_file)
          @pix_fmt = args[:pix_fmt] if args.key?(:pix_fmt)
          @profile = args[:profile] if args.key?(:profile)
          @timedtext_stream = args[:timedtext_stream] if args.key?(:timedtext_stream)
          @video_bitrate = args[:video_bitrate] if args.key?(:video_bitrate)
          @video_clip_info = args[:video_clip_info] if args.key?(:video_clip_info)
          @video_codec_id = args[:video_codec_id] if args.key?(:video_codec_id)
          @video_end_timestamp = args[:video_end_timestamp] if args.key?(:video_end_timestamp)
          @video_fps = args[:video_fps] if args.key?(:video_fps)
          @video_frame_size = args[:video_frame_size] if args.key?(:video_frame_size)
          @video_has_b_frames = args[:video_has_b_frames] if args.key?(:video_has_b_frames)
          @video_has_fragments = args[:video_has_fragments] if args.key?(:video_has_fragments)
          @video_has_leading_moov_atom = args[:video_has_leading_moov_atom] if args.key?(:video_has_leading_moov_atom)
          @video_has_non_monotonic_dts = args[:video_has_non_monotonic_dts] if args.key?(:video_has_non_monotonic_dts)
          @video_has_non_monotonic_pts = args[:video_has_non_monotonic_pts] if args.key?(:video_has_non_monotonic_pts)
          @video_has_non_zero_start_edit_list = args[:video_has_non_zero_start_edit_list] if args.key?(:video_has_non_zero_start_edit_list)
          @video_has_possible_open_gop = args[:video_has_possible_open_gop] if args.key?(:video_has_possible_open_gop)
          @video_has_variable_aspect_ratio = args[:video_has_variable_aspect_ratio] if args.key?(:video_has_variable_aspect_ratio)
          @video_height = args[:video_height] if args.key?(:video_height)
          @video_interlace = args[:video_interlace] if args.key?(:video_interlace)
          @video_length = args[:video_length] if args.key?(:video_length)
          @video_number_of_frames = args[:video_number_of_frames] if args.key?(:video_number_of_frames)
          @video_number_of_invisible_frames = args[:video_number_of_invisible_frames] if args.key?(:video_number_of_invisible_frames)
          @video_pixel_aspect_ratio = args[:video_pixel_aspect_ratio] if args.key?(:video_pixel_aspect_ratio)
          @video_rotation = args[:video_rotation] if args.key?(:video_rotation)
          @video_start_timestamp = args[:video_start_timestamp] if args.key?(:video_start_timestamp)
          @video_stream = args[:video_stream] if args.key?(:video_stream)
          @video_stream_codec_tag = args[:video_stream_codec_tag] if args.key?(:video_stream_codec_tag)
          @video_width = args[:video_width] if args.key?(:video_width)
          @videostreaminfo_version = args[:videostreaminfo_version] if args.key?(:videostreaminfo_version)
          @y_psnr = args[:y_psnr] if args.key?(:y_psnr)
        end
      end
      
      # Next id: 25
      class VideoVideoStreamInfoAudioStream
        include Google::Apis::Core::Hashable
      
        # Optional ambisonics metadata.
        # Corresponds to the JSON property `ambisonics`
        # @return [Google::Apis::ContentwarehouseV1::VideoAmbisonicsAmbisonicsMetadata]
        attr_accessor :ambisonics
      
        # audio bitrate in bits/s
        # Corresponds to the JSON property `bitrate`
        # @return [Fixnum]
        attr_accessor :bitrate
      
        # 
        # Corresponds to the JSON property `channelPosition`
        # @return [Array<String>]
        attr_accessor :channel_position
      
        # number of audio channels
        # Corresponds to the JSON property `channels`
        # @return [Fixnum]
        attr_accessor :channels
      
        # some container allows for a clock discontinuity. In this case, the
        # end_timestamp may not be the correct DTS of the stream.
        # Corresponds to the JSON property `clockDiscontinuityUs`
        # @return [Fixnum]
        attr_accessor :clock_discontinuity_us
      
        # 
        # Corresponds to the JSON property `codecFourcc`
        # @return [String]
        attr_accessor :codec_fourcc
      
        # Primary audio codec information
        # Corresponds to the JSON property `codecId`
        # @return [String]
        attr_accessor :codec_id
      
        # RFC6381 Codec string.
        # Corresponds to the JSON property `codecString`
        # @return [String]
        attr_accessor :codec_string
      
        # Specifies the content_type of the audio stream as given in the metadata.
        # Corresponds to the JSON property `contentType`
        # @return [String]
        attr_accessor :content_type
      
        # The bytes offset of the end of the first decodable packet.
        # Corresponds to the JSON property `decodeOffset`
        # @return [Fixnum]
        attr_accessor :decode_offset
      
        # 
        # Corresponds to the JSON property `endTimestamp`
        # @return [Fixnum]
        attr_accessor :end_timestamp
      
        # audio frame size
        # Corresponds to the JSON property `frameSize`
        # @return [Fixnum]
        attr_accessor :frame_size
      
        # Specifies the language of the audio stream as given in the metadata.
        # Corresponds to the JSON property `language`
        # @return [String]
        attr_accessor :language
      
        # audio length in seconds Note that when the VSI is from users videos, it is not
        # guaranteed to be the same as transcode lengths and it could be 0 when the full
        # VSI cannot compute the length from the source header and timestamps (for
        # example when header and timestamps are too broken).
        # Corresponds to the JSON property `length`
        # @return [Float]
        attr_accessor :length
      
        # Metadata for audio elementary stream;
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoClipInfo>]
        attr_accessor :metadata
      
        # Number of audio frames.
        # Corresponds to the JSON property `numberOfFrames`
        # @return [Fixnum]
        attr_accessor :number_of_frames
      
        # 
        # Corresponds to the JSON property `profile`
        # @return [String]
        attr_accessor :profile
      
        # audio sample rate
        # Corresponds to the JSON property `sampleRate`
        # @return [Fixnum]
        attr_accessor :sample_rate
      
        # Number of meaningful bits per decoded audio sample. This is an implicit
        # conceptual meaning. This is *NOT* the same as ffmpeg's internal sample format
        # that is used when actually decoding with ffmpeg.
        # Corresponds to the JSON property `sampleSize`
        # @return [Fixnum]
        attr_accessor :sample_size
      
        # Start/end timestamps of audio in ms.
        # Corresponds to the JSON property `startTimestamp`
        # @return [Fixnum]
        attr_accessor :start_timestamp
      
        # 
        # Corresponds to the JSON property `streamCodecTag`
        # @return [Fixnum]
        attr_accessor :stream_codec_tag
      
        # Index of the stream in the file. it is 0 based.
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ambisonics = args[:ambisonics] if args.key?(:ambisonics)
          @bitrate = args[:bitrate] if args.key?(:bitrate)
          @channel_position = args[:channel_position] if args.key?(:channel_position)
          @channels = args[:channels] if args.key?(:channels)
          @clock_discontinuity_us = args[:clock_discontinuity_us] if args.key?(:clock_discontinuity_us)
          @codec_fourcc = args[:codec_fourcc] if args.key?(:codec_fourcc)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @codec_string = args[:codec_string] if args.key?(:codec_string)
          @content_type = args[:content_type] if args.key?(:content_type)
          @decode_offset = args[:decode_offset] if args.key?(:decode_offset)
          @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp)
          @frame_size = args[:frame_size] if args.key?(:frame_size)
          @language = args[:language] if args.key?(:language)
          @length = args[:length] if args.key?(:length)
          @metadata = args[:metadata] if args.key?(:metadata)
          @number_of_frames = args[:number_of_frames] if args.key?(:number_of_frames)
          @profile = args[:profile] if args.key?(:profile)
          @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
          @sample_size = args[:sample_size] if args.key?(:sample_size)
          @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
          @stream_codec_tag = args[:stream_codec_tag] if args.key?(:stream_codec_tag)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
        end
      end
      
      # Data streams refer to additional data separate from audio and video streams
      # For example: camera motion metadata (see http://go/wally-format) Available
      # tags: 4+
      class VideoVideoStreamInfoDataStream
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `codecFourcc`
        # @return [String]
        attr_accessor :codec_fourcc
      
        # Codec information
        # Corresponds to the JSON property `codecId`
        # @return [String]
        attr_accessor :codec_id
      
        # 
        # Corresponds to the JSON property `streamCodecTag`
        # @return [Fixnum]
        attr_accessor :stream_codec_tag
      
        # Index of the stream in the file
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @codec_fourcc = args[:codec_fourcc] if args.key?(:codec_fourcc)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @stream_codec_tag = args[:stream_codec_tag] if args.key?(:stream_codec_tag)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
        end
      end
      
      # 
      class VideoVideoStreamInfoMetadata
        include Google::Apis::Core::Hashable
      
        # An attached 3D look up table
        # Corresponds to the JSON property `luts`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoMetadataLutAttachments]
        attr_accessor :luts
      
        # Information on Frame Packing arrangement
        # Corresponds to the JSON property `videoFpa`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileFramePackingArrangement]
        attr_accessor :video_fpa
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @luts = args[:luts] if args.key?(:luts)
          @video_fpa = args[:video_fpa] if args.key?(:video_fpa)
        end
      end
      
      # An attached 3D look up table
      class VideoVideoStreamInfoMetadataLutAttachments
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `lut`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoMetadataLutAttachmentsLut3D>]
        attr_accessor :lut
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @lut = args[:lut] if args.key?(:lut)
        end
      end
      
      # Description and encoding of a 3d lut.
      class VideoVideoStreamInfoMetadataLutAttachmentsLut3D
        include Google::Apis::Core::Hashable
      
        # Lut data, sanitized and encoded in google's binary coded form of 3D look-up
        # tables.
        # Corresponds to the JSON property `data`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :data
      
        # Original file name of the lut (present in the original file)
        # Corresponds to the JSON property `fileName`
        # @return [String]
        attr_accessor :file_name
      
        # The size (in each dimension) of the lut. For a 3D cube of size NxNxN, this
        # will be N. If the value is -1, then the file was determined to be invalid.
        # This is useful for logging files where the input could not be parsed, and is
        # useful for to indicate info of the 3D lut without having to decode/inspect the
        # binary data.
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @data = args[:data] if args.key?(:data)
          @file_name = args[:file_name] if args.key?(:file_name)
          @size = args[:size] if args.key?(:size)
        end
      end
      
      # Timed text streams refer to the streams that are separated from audio and
      # video streams. Closed caption streams embedded in video streams (e.g. MPEG-2 -
      # Line 21) do not belong here.
      class VideoVideoStreamInfoTimedTextStream
        include Google::Apis::Core::Hashable
      
        # Codec information.
        # Corresponds to the JSON property `codecId`
        # @return [String]
        attr_accessor :codec_id
      
        # Metadata for the stream.
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoClipInfo>]
        attr_accessor :metadata
      
        # 
        # Corresponds to the JSON property `streamCodecTag`
        # @return [Fixnum]
        attr_accessor :stream_codec_tag
      
        # Index of the stream in the file. it is 0 based.
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @metadata = args[:metadata] if args.key?(:metadata)
          @stream_codec_tag = args[:stream_codec_tag] if args.key?(:stream_codec_tag)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
        end
      end
      
      # TODO(yanghu) add 25/50/75 percentiles of FPS to have a 5 number summary. Next
      # id: 48
      class VideoVideoStreamInfoVideoStream
        include Google::Apis::Core::Hashable
      
        # This represents the canonical frame rate of the video. This is named
        # average_fps for historical reasons, and may not actually be the arithmetic
        # mean. For variable frame rate videos, the algorithm may change again in future.
        # Currently, full vsi set it with arithmetic mean, and partial vsi set it with
        # median.
        # Corresponds to the JSON property `averageFps`
        # @return [Float]
        attr_accessor :average_fps
      
        # video bitrate in bits/s
        # Corresponds to the JSON property `bitrate`
        # @return [Fixnum]
        attr_accessor :bitrate
      
        # A message holding all of the color information about a signal: -Color
        # primaries identify the meaning of red, green, and blue ( and the white point).
        # -The transfer characteristic identifies the mapping used to go between linear
        # and coded values of light. -The matrix coefficients identifies, e.g., the
        # conversion between Ycbcr to RGB (in the space of the primaries) -And the color
        # range defines the min/max of the levels used.
        # Corresponds to the JSON property `bitstreamColorInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileColorInfo]
        attr_accessor :bitstream_color_info
      
        # 
        # Corresponds to the JSON property `cleanAperture`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoVideoStreamCleanAperture]
        attr_accessor :clean_aperture
      
        # some container allows for a clock discontinuity. In this case, the
        # end_timestamp may not be the correct DTS of the stream.
        # Corresponds to the JSON property `clockDiscontinuityUs`
        # @return [Fixnum]
        attr_accessor :clock_discontinuity_us
      
        # 
        # Corresponds to the JSON property `closedCaptions`
        # @return [Google::Apis::ContentwarehouseV1::VideoClosedCaptions]
        attr_accessor :closed_captions
      
        # closed_gop_size refers to chunkable boundaries for each specified codec and
        # may actually contain one or more GOPs, e.g. for H.264, closed_gop_size will
        # denote the distance (frame count) between two IDR frames.
        # Corresponds to the JSON property `closedGopSize`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoVideoStreamStatistics]
        attr_accessor :closed_gop_size
      
        # 
        # Corresponds to the JSON property `codecFourcc`
        # @return [String]
        attr_accessor :codec_fourcc
      
        # Primary video codec information
        # Corresponds to the JSON property `codecId`
        # @return [String]
        attr_accessor :codec_id
      
        # RFC6381 Codec string.
        # Corresponds to the JSON property `codecString`
        # @return [String]
        attr_accessor :codec_string
      
        # A message holding all of the color information about a signal: -Color
        # primaries identify the meaning of red, green, and blue ( and the white point).
        # -The transfer characteristic identifies the mapping used to go between linear
        # and coded values of light. -The matrix coefficients identifies, e.g., the
        # conversion between Ycbcr to RGB (in the space of the primaries) -And the color
        # range defines the min/max of the levels used.
        # Corresponds to the JSON property `colorInfo`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileColorInfo]
        attr_accessor :color_info
      
        # A message holding the equivalent of the content light level information in
        # HEVC or its representation in matroska/webm. This gives coarse stats on the
        # luminance levels in the content and may be used as a hint by algorithms &
        # displays to tone map.
        # Corresponds to the JSON property `contentLightLevel`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileContentLightLevel]
        attr_accessor :content_light_level
      
        # The bytes offset of the end of the first decodable packet.
        # Corresponds to the JSON property `decodeOffset`
        # @return [Fixnum]
        attr_accessor :decode_offset
      
        # 
        # Corresponds to the JSON property `displayHeight`
        # @return [Fixnum]
        attr_accessor :display_height
      
        # final display video width and height if explicitly set in the video otherwise
        # this can be calculated from source width/height and video_pixel_aspect_ratio
        # Corresponds to the JSON property `displayWidth`
        # @return [Fixnum]
        attr_accessor :display_width
      
        # Decoder configuration for Dolby Vision encoded by any codec. Dolby Vision
        # defines a separate profile & level hierarchy regardless of the base codec. See
        # Dolby Vision profiles, levels and compatibility: https://dolby.my.salesforce.
        # com/sfc/p/#700000009YuG/a/4u000000l6G4/4R18riPaaW3gxpVx7XwyQLdEITLFjB.w.
        # Si0LoQR5j8 Dolby Vision DASH streaming: https://professional.dolby.com/
        # siteassets/content-creation/dolby-vision-for-content-creators/
        # dolbyvisioninmpegdashspecification_v2_0_public_20190107.pdf HTTP Live
        # Streaming: https://professional.dolby.com/siteassets/content-creation/dolby-
        # vision-for-content-creators/dolby-vision-streams-within-the-http-live-
        # streaming-format-v2.0-13-november-2018.pdf Dolby Vision bitstreams: https://
        # professional.dolby.com/siteassets/pdfs/
        # dolbyvisionstreamsinisobmffspecification-v2.1.2.pdf
        # Corresponds to the JSON property `doviConfiguration`
        # @return [Google::Apis::ContentwarehouseV1::VideoDoViDecoderConfiguration]
        attr_accessor :dovi_configuration
      
        # 
        # Corresponds to the JSON property `endTimestamp`
        # @return [Fixnum]
        attr_accessor :end_timestamp
      
        # Should the video be mirrored horizontally / vertically? When rotation and flip
        # both are present for a video, it is assumed that the flip is applied first,
        # and then the rotation.
        # Corresponds to the JSON property `flip`
        # @return [String]
        attr_accessor :flip
      
        # video frame per second, obtained by parsing video header information. It could
        # be inaccurate for some types of codecs, notably, WMV, ASF, and FLV. It will be
        # inaccurate for videos that does not have constant frame rate since it is the
        # smallest framerate that can accurately represent all timestamps (see ffmpeg
        # doc for AVStream.r_frame_rate). Also frame rate can be parsed from headers and
        # can be wrong if it is not available there since ffmpeg uses a heuristic for
        # determining it.
        # Corresponds to the JSON property `fps`
        # @return [Float]
        attr_accessor :fps
      
        # video frame size
        # Corresponds to the JSON property `frameSize`
        # @return [Fixnum]
        attr_accessor :frame_size
      
        # Statistics about gop sizes of the video.
        # Corresponds to the JSON property `gopSize`
        # @return [Google::Apis::ContentwarehouseV1::VideoVideoStreamInfoVideoStreamStatistics]
        attr_accessor :gop_size
      
        # video has b frames
        # Corresponds to the JSON property `hasBFrames`
        # @return [Boolean]
        attr_accessor :has_b_frames
        alias_method :has_b_frames?, :has_b_frames
      
        # Stats on HDR10+ (SMPTE 2094-40:2016 standard) over video frames.
        # Corresponds to the JSON property `hdr10PlusStats`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileHdr10PlusStats]
        attr_accessor :hdr10_plus_stats
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # Information on interlaced video.
        # Corresponds to the JSON property `interlace`
        # @return [String]
        attr_accessor :interlace
      
        # Check if a video size insane or not. It is set if the input file is an MOV
        # file.
        # Corresponds to the JSON property `isInsaneSize`
        # @return [Boolean]
        attr_accessor :is_insane_size
        alias_method :is_insane_size?, :is_insane_size
      
        # User data registered Itu-T T.35 SEI message
        # Corresponds to the JSON property `ituTT35`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoUserDataRegisteredItuTt35>]
        attr_accessor :itu_tt35
      
        # video length in seconds Note that when the VSI is from users videos, it is not
        # guaranteed to be the same as transcode lengths and it could be 0 when the full
        # VSI cannot compute the length from the source header and timestamps (for
        # example when header and timestamps are too broken).
        # Corresponds to the JSON property `length`
        # @return [Float]
        attr_accessor :length
      
        # 
        # Corresponds to the JSON property `level`
        # @return [Fixnum]
        attr_accessor :level
      
        # A message holding information about the mastering display color volume. This
        # metadata can be used when tone mapping an HDR signal to a display with a
        # different gamut or brightness characteristics than the mastering display. This
        # message is capable of containing SMPTE 2086 metadata.
        # Corresponds to the JSON property `masteringDisplayMetadata`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileMasteringDisplayMetadata]
        attr_accessor :mastering_display_metadata
      
        # Maximum instantaneous frame rate seen from analyzing the entire stream.
        # Corresponds to the JSON property `maxFps`
        # @return [Float]
        attr_accessor :max_fps
      
        # Metadata for video elementary stream;
        # Corresponds to the JSON property `metadata`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoClipInfo>]
        attr_accessor :metadata
      
        # Minimum instantaneous frame rate seen from analyzing the entire stream.
        # Corresponds to the JSON property `minFps`
        # @return [Float]
        attr_accessor :min_fps
      
        # Number of video frames.
        # Corresponds to the JSON property `numberOfFrames`
        # @return [Fixnum]
        attr_accessor :number_of_frames
      
        # Invisible frame count Keep a count of frames that are not displayed should the
        # full frame count be needed for the video stream. The only codec currently
        # reporting this value is VP8 with alternate reference frames enabled
        # Corresponds to the JSON property `numberOfInvisibleFrames`
        # @return [Fixnum]
        attr_accessor :number_of_invisible_frames
      
        # Pixel format for the video stream.
        # Corresponds to the JSON property `pixFmt`
        # @return [String]
        attr_accessor :pix_fmt
      
        # video pixel aspect ratio
        # Corresponds to the JSON property `pixelAspectRatio`
        # @return [Float]
        attr_accessor :pixel_aspect_ratio
      
        # 
        # Corresponds to the JSON property `profile`
        # @return [String]
        attr_accessor :profile
      
        # The nominal frame rate ('fps' field) represented as a fraction.
        # Corresponds to the JSON property `rationalFps`
        # @return [Google::Apis::ContentwarehouseV1::VideoRational32]
        attr_accessor :rational_fps
      
        # Is the video rotated ?
        # Corresponds to the JSON property `rotation`
        # @return [String]
        attr_accessor :rotation
      
        # video SEI payload types and total payload size of a type this is only for H.
        # 264 and H.265
        # Corresponds to the JSON property `seiMessage`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoSeiMessage>]
        attr_accessor :sei_message
      
        # Globally allowed spherical meta data.
        # Corresponds to the JSON property `spherical`
        # @return [Google::Apis::ContentwarehouseV1::VideoFileSphericalMetadata]
        attr_accessor :spherical
      
        # Start/end timestamps of audio/video in ms.
        # Corresponds to the JSON property `startTimestamp`
        # @return [Fixnum]
        attr_accessor :start_timestamp
      
        # 
        # Corresponds to the JSON property `streamCodecTag`
        # @return [Fixnum]
        attr_accessor :stream_codec_tag
      
        # Index of the stream in the file. it is 0 based.
        # Corresponds to the JSON property `streamIndex`
        # @return [Fixnum]
        attr_accessor :stream_index
      
        # User data unregistered SEI message
        # Corresponds to the JSON property `userDataUnregistered`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoUserDataUnregistered>]
        attr_accessor :user_data_unregistered
      
        # source video width and height
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @average_fps = args[:average_fps] if args.key?(:average_fps)
          @bitrate = args[:bitrate] if args.key?(:bitrate)
          @bitstream_color_info = args[:bitstream_color_info] if args.key?(:bitstream_color_info)
          @clean_aperture = args[:clean_aperture] if args.key?(:clean_aperture)
          @clock_discontinuity_us = args[:clock_discontinuity_us] if args.key?(:clock_discontinuity_us)
          @closed_captions = args[:closed_captions] if args.key?(:closed_captions)
          @closed_gop_size = args[:closed_gop_size] if args.key?(:closed_gop_size)
          @codec_fourcc = args[:codec_fourcc] if args.key?(:codec_fourcc)
          @codec_id = args[:codec_id] if args.key?(:codec_id)
          @codec_string = args[:codec_string] if args.key?(:codec_string)
          @color_info = args[:color_info] if args.key?(:color_info)
          @content_light_level = args[:content_light_level] if args.key?(:content_light_level)
          @decode_offset = args[:decode_offset] if args.key?(:decode_offset)
          @display_height = args[:display_height] if args.key?(:display_height)
          @display_width = args[:display_width] if args.key?(:display_width)
          @dovi_configuration = args[:dovi_configuration] if args.key?(:dovi_configuration)
          @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp)
          @flip = args[:flip] if args.key?(:flip)
          @fps = args[:fps] if args.key?(:fps)
          @frame_size = args[:frame_size] if args.key?(:frame_size)
          @gop_size = args[:gop_size] if args.key?(:gop_size)
          @has_b_frames = args[:has_b_frames] if args.key?(:has_b_frames)
          @hdr10_plus_stats = args[:hdr10_plus_stats] if args.key?(:hdr10_plus_stats)
          @height = args[:height] if args.key?(:height)
          @interlace = args[:interlace] if args.key?(:interlace)
          @is_insane_size = args[:is_insane_size] if args.key?(:is_insane_size)
          @itu_tt35 = args[:itu_tt35] if args.key?(:itu_tt35)
          @length = args[:length] if args.key?(:length)
          @level = args[:level] if args.key?(:level)
          @mastering_display_metadata = args[:mastering_display_metadata] if args.key?(:mastering_display_metadata)
          @max_fps = args[:max_fps] if args.key?(:max_fps)
          @metadata = args[:metadata] if args.key?(:metadata)
          @min_fps = args[:min_fps] if args.key?(:min_fps)
          @number_of_frames = args[:number_of_frames] if args.key?(:number_of_frames)
          @number_of_invisible_frames = args[:number_of_invisible_frames] if args.key?(:number_of_invisible_frames)
          @pix_fmt = args[:pix_fmt] if args.key?(:pix_fmt)
          @pixel_aspect_ratio = args[:pixel_aspect_ratio] if args.key?(:pixel_aspect_ratio)
          @profile = args[:profile] if args.key?(:profile)
          @rational_fps = args[:rational_fps] if args.key?(:rational_fps)
          @rotation = args[:rotation] if args.key?(:rotation)
          @sei_message = args[:sei_message] if args.key?(:sei_message)
          @spherical = args[:spherical] if args.key?(:spherical)
          @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
          @stream_codec_tag = args[:stream_codec_tag] if args.key?(:stream_codec_tag)
          @stream_index = args[:stream_index] if args.key?(:stream_index)
          @user_data_unregistered = args[:user_data_unregistered] if args.key?(:user_data_unregistered)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class VideoVideoStreamInfoVideoStreamCleanAperture
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `horizontalOffset`
        # @return [Fixnum]
        attr_accessor :horizontal_offset
      
        # 
        # Corresponds to the JSON property `verticalOffset`
        # @return [Fixnum]
        attr_accessor :vertical_offset
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @height = args[:height] if args.key?(:height)
          @horizontal_offset = args[:horizontal_offset] if args.key?(:horizontal_offset)
          @vertical_offset = args[:vertical_offset] if args.key?(:vertical_offset)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # 
      class VideoVideoStreamInfoVideoStreamStatistics
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `max`
        # @return [Fixnum]
        attr_accessor :max
      
        # 
        # Corresponds to the JSON property `mean`
        # @return [Float]
        attr_accessor :mean
      
        # 
        # Corresponds to the JSON property `min`
        # @return [Fixnum]
        attr_accessor :min
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @max = args[:max] if args.key?(:max)
          @mean = args[:mean] if args.key?(:mean)
          @min = args[:min] if args.key?(:min)
        end
      end
      
      # 
      class VideoYoutubeCommentsClassificationProtoSmartSuggestion
        include Google::Apis::Core::Hashable
      
        # Diversification threshold used in prediction. Additional responses which are
        # closer than the threshold to the already selected responses will be skipped.
        # Corresponds to the JSON property `diversificationThreshold`
        # @return [Float]
        attr_accessor :diversification_threshold
      
        # Bias weight used in prediction.
        # Corresponds to the JSON property `likelihoodBiasWeight`
        # @return [Float]
        attr_accessor :likelihood_bias_weight
      
        # Content of the reply snippet (could include emoji as well as text).
        # Corresponds to the JSON property `replyContent`
        # @return [String]
        attr_accessor :reply_content
      
        # Model score for the predicted reply snippet.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @diversification_threshold = args[:diversification_threshold] if args.key?(:diversification_threshold)
          @likelihood_bias_weight = args[:likelihood_bias_weight] if args.key?(:likelihood_bias_weight)
          @reply_content = args[:reply_content] if args.key?(:reply_content)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Smart reply suggestions for comment.
      class VideoYoutubeCommentsClassificationProtoYouTubeCommentSmartReply
        include Google::Apis::Core::Hashable
      
        # The order of the reply snippets in the list determines how they should be
        # displayed in the UI and the client is not supposed to re-order the list using
        # the scores.
        # Corresponds to the JSON property `smartSuggestions`
        # @return [Array<Google::Apis::ContentwarehouseV1::VideoYoutubeCommentsClassificationProtoSmartSuggestion>]
        attr_accessor :smart_suggestions
      
        # Identifier (language_code, channel_id, etc) for the suggestion list from which
        # the top k suggestions are selected.
        # Corresponds to the JSON property `suggestionListIdentifier`
        # @return [String]
        attr_accessor :suggestion_list_identifier
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @smart_suggestions = args[:smart_suggestions] if args.key?(:smart_suggestions)
          @suggestion_list_identifier = args[:suggestion_list_identifier] if args.key?(:suggestion_list_identifier)
        end
      end
      
      # Used for stanza KV pair. Next tag: 7.
      class VideoYoutubeCommentsRankingCtrMetrics
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `downvotes`
        # @return [Fixnum]
        attr_accessor :downvotes
      
        # 
        # Corresponds to the JSON property `impressions`
        # @return [Fixnum]
        attr_accessor :impressions
      
        # 
        # Corresponds to the JSON property `measureWindow`
        # @return [String]
        attr_accessor :measure_window
      
        # 
        # Corresponds to the JSON property `teaserClicks`
        # @return [Fixnum]
        attr_accessor :teaser_clicks
      
        # 
        # Corresponds to the JSON property `teaserImpressions`
        # @return [Fixnum]
        attr_accessor :teaser_impressions
      
        # 
        # Corresponds to the JSON property `upvotes`
        # @return [Fixnum]
        attr_accessor :upvotes
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @downvotes = args[:downvotes] if args.key?(:downvotes)
          @impressions = args[:impressions] if args.key?(:impressions)
          @measure_window = args[:measure_window] if args.key?(:measure_window)
          @teaser_clicks = args[:teaser_clicks] if args.key?(:teaser_clicks)
          @teaser_impressions = args[:teaser_impressions] if args.key?(:teaser_impressions)
          @upvotes = args[:upvotes] if args.key?(:upvotes)
        end
      end
      
      # Some per-doc info is returned for all www DocInfo requests. Next id: 92
      class WwwDocInfo
        include Google::Apis::Core::Hashable
      
        # Additional stats output by SafeSearch. See classifier/porn/public/porn-
        # attachments.h.
        # Corresponds to the JSON property `additionalSafesearchStats`
        # @return [Array<Fixnum>]
        attr_accessor :additional_safesearch_stats
      
        # Sometimes called secureid
        # Corresponds to the JSON property `authMethod`
        # @return [Fixnum]
        attr_accessor :auth_method
      
        # Bad meta flag
        # Corresponds to the JSON property `badMetadescription`
        # @return [Boolean]
        attr_accessor :bad_metadescription
        alias_method :bad_metadescription?, :bad_metadescription
      
        # Size of document
        # Corresponds to the JSON property `bodySize`
        # @return [Fixnum]
        attr_accessor :body_size
      
        # 
        # Corresponds to the JSON property `bodyTitleLanguages`
        # @return [Array<String>]
        attr_accessor :body_title_languages
      
        # 
        # Corresponds to the JSON property `boilerplateMetadescription`
        # @return [Boolean]
        attr_accessor :boilerplate_metadescription
        alias_method :boilerplate_metadescription?, :boilerplate_metadescription
      
        # Detected color in the image in RGB565 format in the lower 16 bits.
        # Corresponds to the JSON property `colorDetectionResult`
        # @return [Fixnum]
        attr_accessor :color_detection_result
      
        # If not present, then the type
        # Corresponds to the JSON property `contentType`
        # @return [Fixnum]
        attr_accessor :content_type
      
        # Url of coupled doc (e.g. image)
        # Corresponds to the JSON property `coupledUrl`
        # @return [String]
        attr_accessor :coupled_url
      
        # 
        # Corresponds to the JSON property `coupledUrlEncoding`
        # @return [Fixnum]
        attr_accessor :coupled_url_encoding
      
        # Last time this doc crawled
        # Corresponds to the JSON property `crawlTime`
        # @return [Fixnum]
        attr_accessor :crawl_time
      
        # Thumbnail cropping information.
        # Corresponds to the JSON property `cropData`
        # @return [Fixnum]
        attr_accessor :crop_data
      
        # 
        # Corresponds to the JSON property `dataVersion`
        # @return [String]
        attr_accessor :data_version
      
        # Fields generated by the docserver, but whose meaning is unclear. Sometimes
        # last crawl time
        # Corresponds to the JSON property `docVersionId`
        # @return [Fixnum]
        attr_accessor :doc_version_id
      
        # 
        # Corresponds to the JSON property `encoding`
        # @return [Fixnum]
        attr_accessor :encoding
      
        # fails_safe_search is never filled in production.
        # Corresponds to the JSON property `failsSafeSearch`
        # @return [Fixnum]
        attr_accessor :fails_safe_search
      
        # If converted to TEXT or HTML
        # Corresponds to the JSON property `fileTypeId`
        # @return [Fixnum]
        attr_accessor :file_type_id
      
        # Indicate if the meta description in a different language than its page.
        # Corresponds to the JSON property `foreignMetadescription`
        # @return [Boolean]
        attr_accessor :foreign_metadescription
        alias_method :foreign_metadescription?, :foreign_metadescription
      
        # 
        # Corresponds to the JSON property `fuzzyMetadescription`
        # @return [Boolean]
        attr_accessor :fuzzy_metadescription
        alias_method :fuzzy_metadescription?, :fuzzy_metadescription
      
        # Addition to support google label per-search-result annotation.
        # Corresponds to the JSON property `googleLabelData`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :google_label_data
      
        # If true, the original document has a bad SSL certificate.
        # Corresponds to the JSON property `hasBadSslCertificate`
        # @return [Boolean]
        attr_accessor :has_bad_ssl_certificate
        alias_method :has_bad_ssl_certificate?, :has_bad_ssl_certificate
      
        # image height
        # Corresponds to the JSON property `imageHeight`
        # @return [Fixnum]
        attr_accessor :image_height
      
        # The image license info for licensable images(go/Licensable-Images-PRD) This
        # proto in design doc: go/licensable-images-edd
        # Corresponds to the JSON property `imageLicenseInfo`
        # @return [Google::Apis::ContentwarehouseV1::ImageSearchImageLicenseInfo]
        attr_accessor :image_license_info
      
        # 
        # Corresponds to the JSON property `imagePublisher`
        # @return [String]
        attr_accessor :image_publisher
      
        # size in bytes;
        # Corresponds to the JSON property `imageSize`
        # @return [Fixnum]
        attr_accessor :image_size
      
        # image width
        # Corresponds to the JSON property `imageWidth`
        # @return [Fixnum]
        attr_accessor :image_width
      
        # The timestamp (the time since the Epoch, in microseconds) when the docjoin is
        # exported from indexing. This is mainly exported and used by Youtube Search.
        # See MustangBasicInfo.indexing_ts for more details.
        # Corresponds to the JSON property `indexingTs`
        # @return [Fixnum]
        attr_accessor :indexing_ts
      
        # If ipaddr is set, ip should be ignored (it should not be set). Ipaddr should
        # be either 4- or 16-byte string for IPv4 or IPv6 addresses. If ipaddr is not
        # set, ip is set to the IPv4 address for the host.
        # Corresponds to the JSON property `ip`
        # @return [Fixnum]
        attr_accessor :ip
      
        # 
        # Corresponds to the JSON property `ipaddr`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :ipaddr
      
        # Is this image animated?
        # Corresponds to the JSON property `isAnimated`
        # @return [Boolean]
        attr_accessor :is_animated
        alias_method :is_animated?, :is_animated
      
        # Hosted Images related fields.
        # Corresponds to the JSON property `isHostedImage`
        # @return [Boolean]
        attr_accessor :is_hosted_image
        alias_method :is_hosted_image?, :is_hosted_image
      
        # Doc porn classification.
        # Corresponds to the JSON property `isPorn`
        # @return [Boolean]
        attr_accessor :is_porn
        alias_method :is_porn?, :is_porn
      
        # Is disallowed for crawling according to host's robots.txt.
        # Corresponds to the JSON property `isRoboted`
        # @return [Boolean]
        attr_accessor :is_roboted
        alias_method :is_roboted?, :is_roboted
      
        # Consider the page classification is_porn as an alternative for is_site_porn,
        # and talk to safesearch@google.com for additional information if needed.
        # Corresponds to the JSON property `isSitePorn`
        # @return [Boolean]
        attr_accessor :is_site_porn
        alias_method :is_site_porn?, :is_site_porn
      
        # Doc softporn classification.
        # Corresponds to the JSON property `isSoftporn`
        # @return [Boolean]
        attr_accessor :is_softporn
        alias_method :is_softporn?, :is_softporn
      
        # go/iii-td b/130371355
        # Corresponds to the JSON property `language`
        # @return [Fixnum]
        attr_accessor :language
      
        # This returns the most probable language for the document. The complete set of
        # languages is in the GenericSearchResponse. (If some future use requires all
        # languages from the doc request, note that fetching that will require decoding
        # the entire per-doc data attachment, which is a performance hit) Use docinfo-
        # util.h to set & read language fields. Language tag as defined by http://www.
        # unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/html/bcp47 If
        # not present, then use language.
        # Corresponds to the JSON property `languageTag`
        # @return [String]
        attr_accessor :language_tag
      
        # Unused by gws
        # Corresponds to the JSON property `lastModTime`
        # @return [Fixnum]
        attr_accessor :last_mod_time
      
        # Indicates the web-master opt-in state of this image. This project is still in
        # MVP stage, please contact us licensed-media-team@ before use.
        # Corresponds to the JSON property `licensedWebImagesOptInState`
        # @return [String]
        attr_accessor :licensed_web_images_opt_in_state
      
        # 
        # Corresponds to the JSON property `lowQualityMetadescription`
        # @return [Boolean]
        attr_accessor :low_quality_metadescription
        alias_method :low_quality_metadescription?, :low_quality_metadescription
      
        # If meta description/body title were detected to be in a different language
        # from the document language (the 'language' field above) in
        # RosettaLanguageAnnotator, the detected languages are populated here. Note: as
        # of ariane/154728, no more than one language is populated for each field.
        # Corresponds to the JSON property `metaDescriptionLanguages`
        # @return [Array<String>]
        attr_accessor :meta_description_languages
      
        # Nearby text of the image on landing page. Used to construct Scroll to Image
        # urls.
        # Corresponds to the JSON property `nearbyText`
        # @return [String]
        attr_accessor :nearby_text
      
        # If not 0, we should not show the image in overlay mode in image snippets.
        # Corresponds to the JSON property `noimageframeoverlayreason`
        # @return [Fixnum]
        attr_accessor :noimageframeoverlayreason
      
        # 
        # Corresponds to the JSON property `partialBoilerplateMetadescription`
        # @return [Boolean]
        attr_accessor :partial_boilerplate_metadescription
        alias_method :partial_boilerplate_metadescription?, :partial_boilerplate_metadescription
      
        # 'porn_stats' is used in porn demotion and filtering. See classifier/porn/
        # public/porn-attachments.h.
        # Corresponds to the JSON property `pornStats`
        # @return [Fixnum]
        attr_accessor :porn_stats
      
        # Quality score (also known as QScore, see go/qscore-faq).
        # Corresponds to the JSON property `qualityWithoutAdjustment`
        # @return [Float]
        attr_accessor :quality_without_adjustment
      
        # Url of referring doc
        # Corresponds to the JSON property `referrerUrl`
        # @return [String]
        attr_accessor :referrer_url
      
        # 
        # Corresponds to the JSON property `relatedimages`
        # @return [Array<Google::Apis::ContentwarehouseV1::WwwDocInfoRelatedImages>]
        attr_accessor :relatedimages
      
        # True if the meta-description is duplicated on many other pages and this page
        # is the rootpage of such pages which have the same meta-description.
        # Corresponds to the JSON property `rootpageDuplicateMetadescription`
        # @return [Boolean]
        attr_accessor :rootpage_duplicate_metadescription
        alias_method :rootpage_duplicate_metadescription?, :rootpage_duplicate_metadescription
      
        # Has noarchive meta robots flag
        # Corresponds to the JSON property `seenNoarchive`
        # @return [Boolean]
        attr_accessor :seen_noarchive
        alias_method :seen_noarchive?, :seen_noarchive
      
        # Has noindex meta robots flag
        # Corresponds to the JSON property `seenNoindex`
        # @return [Boolean]
        attr_accessor :seen_noindex
        alias_method :seen_noindex?, :seen_noindex
      
        # NOTE(kinoue): ODP/GWD snippet is unlaunched as of June 2017. This is no longer
        # used.
        # Corresponds to the JSON property `seenNoodp`
        # @return [Boolean]
        attr_accessor :seen_noodp
        alias_method :seen_noodp?, :seen_noodp
      
        # Has nopreview meta robots flag
        # Corresponds to the JSON property `seenNopreview`
        # @return [Boolean]
        attr_accessor :seen_nopreview
        alias_method :seen_nopreview?, :seen_nopreview
      
        # Has nosnippet meta robots flag
        # Corresponds to the JSON property `seenNosnippet`
        # @return [Boolean]
        attr_accessor :seen_nosnippet
        alias_method :seen_nosnippet?, :seen_nosnippet
      
        # Has notranslate meta robots flag
        # Corresponds to the JSON property `seenNotranslate`
        # @return [Boolean]
        attr_accessor :seen_notranslate
        alias_method :seen_notranslate?, :seen_notranslate
      
        # This proto is a lightweight version of ShoppingAnnotation in docjoin
        # attachment. We're doing a deep copy of protos defined in ShoppingAnnotation so
        # that we can control individual fields that will sit in Muppet. Data here will
        # be used for scoring organic shopping web results and previews. Many shopping
        # related signals, e.g., product review score, are also served from this
        # attachment. Next ID: 20
        # Corresponds to the JSON property `shoppingAttachment`
        # @return [Google::Apis::ContentwarehouseV1::QualityShoppingShoppingAttachment]
        attr_accessor :shopping_attachment
      
        # Shopping offer info from Inventory & Policy Service.
        # Corresponds to the JSON property `shoppingOffers`
        # @return [Array<Google::Apis::ContentwarehouseV1::ImageMustangShoppingOffer>]
        attr_accessor :shopping_offers
      
        # Subindex id of the document should be one of the values defined by enum
        # CompositeDoc::SubIndexType. Used for superroot/gws logging if a shard has
        # documents from multiple indices.
        # Corresponds to the JSON property `subindex`
        # @return [Fixnum]
        attr_accessor :subindex
      
        # thumbnail height
        # Corresponds to the JSON property `thumbHeight`
        # @return [Fixnum]
        attr_accessor :thumb_height
      
        # Additions for image search.
        # Corresponds to the JSON property `thumbWidth`
        # @return [Fixnum]
        attr_accessor :thumb_width
      
        # 
        # Corresponds to the JSON property `thumbnail`
        # @return [Array<Google::Apis::ContentwarehouseV1::WwwDocInfoThumbnail>]
        attr_accessor :thumbnail
      
        # Landing page title.
        # Corresponds to the JSON property `title`
        # @return [String]
        attr_accessor :title
      
        # 
        # Corresponds to the JSON property `unionBuildTime`
        # @return [Fixnum]
        attr_accessor :union_build_time
      
        # Url
        # Corresponds to the JSON property `url`
        # @return [String]
        attr_accessor :url
      
        # empty => same as url
        # Corresponds to the JSON property `urlAfterRedirects`
        # @return [String]
        attr_accessor :url_after_redirects
      
        # See webutil/urlencoding
        # Corresponds to the JSON property `urlEncoding`
        # @return [Fixnum]
        attr_accessor :url_encoding
      
        # If an image request, was the coupled image visible on the page?
        # Corresponds to the JSON property `visibleImage`
        # @return [Boolean]
        attr_accessor :visible_image
        alias_method :visible_image?, :visible_image
      
        # Is this doc visual RTL? See enum VisualType in visualtype.h. Default is
        # NOT_VISUAL_DOCUMENT.
        # Corresponds to the JSON property `visualType`
        # @return [Fixnum]
        attr_accessor :visual_type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_safesearch_stats = args[:additional_safesearch_stats] if args.key?(:additional_safesearch_stats)
          @auth_method = args[:auth_method] if args.key?(:auth_method)
          @bad_metadescription = args[:bad_metadescription] if args.key?(:bad_metadescription)
          @body_size = args[:body_size] if args.key?(:body_size)
          @body_title_languages = args[:body_title_languages] if args.key?(:body_title_languages)
          @boilerplate_metadescription = args[:boilerplate_metadescription] if args.key?(:boilerplate_metadescription)
          @color_detection_result = args[:color_detection_result] if args.key?(:color_detection_result)
          @content_type = args[:content_type] if args.key?(:content_type)
          @coupled_url = args[:coupled_url] if args.key?(:coupled_url)
          @coupled_url_encoding = args[:coupled_url_encoding] if args.key?(:coupled_url_encoding)
          @crawl_time = args[:crawl_time] if args.key?(:crawl_time)
          @crop_data = args[:crop_data] if args.key?(:crop_data)
          @data_version = args[:data_version] if args.key?(:data_version)
          @doc_version_id = args[:doc_version_id] if args.key?(:doc_version_id)
          @encoding = args[:encoding] if args.key?(:encoding)
          @fails_safe_search = args[:fails_safe_search] if args.key?(:fails_safe_search)
          @file_type_id = args[:file_type_id] if args.key?(:file_type_id)
          @foreign_metadescription = args[:foreign_metadescription] if args.key?(:foreign_metadescription)
          @fuzzy_metadescription = args[:fuzzy_metadescription] if args.key?(:fuzzy_metadescription)
          @google_label_data = args[:google_label_data] if args.key?(:google_label_data)
          @has_bad_ssl_certificate = args[:has_bad_ssl_certificate] if args.key?(:has_bad_ssl_certificate)
          @image_height = args[:image_height] if args.key?(:image_height)
          @image_license_info = args[:image_license_info] if args.key?(:image_license_info)
          @image_publisher = args[:image_publisher] if args.key?(:image_publisher)
          @image_size = args[:image_size] if args.key?(:image_size)
          @image_width = args[:image_width] if args.key?(:image_width)
          @indexing_ts = args[:indexing_ts] if args.key?(:indexing_ts)
          @ip = args[:ip] if args.key?(:ip)
          @ipaddr = args[:ipaddr] if args.key?(:ipaddr)
          @is_animated = args[:is_animated] if args.key?(:is_animated)
          @is_hosted_image = args[:is_hosted_image] if args.key?(:is_hosted_image)
          @is_porn = args[:is_porn] if args.key?(:is_porn)
          @is_roboted = args[:is_roboted] if args.key?(:is_roboted)
          @is_site_porn = args[:is_site_porn] if args.key?(:is_site_porn)
          @is_softporn = args[:is_softporn] if args.key?(:is_softporn)
          @language = args[:language] if args.key?(:language)
          @language_tag = args[:language_tag] if args.key?(:language_tag)
          @last_mod_time = args[:last_mod_time] if args.key?(:last_mod_time)
          @licensed_web_images_opt_in_state = args[:licensed_web_images_opt_in_state] if args.key?(:licensed_web_images_opt_in_state)
          @low_quality_metadescription = args[:low_quality_metadescription] if args.key?(:low_quality_metadescription)
          @meta_description_languages = args[:meta_description_languages] if args.key?(:meta_description_languages)
          @nearby_text = args[:nearby_text] if args.key?(:nearby_text)
          @noimageframeoverlayreason = args[:noimageframeoverlayreason] if args.key?(:noimageframeoverlayreason)
          @partial_boilerplate_metadescription = args[:partial_boilerplate_metadescription] if args.key?(:partial_boilerplate_metadescription)
          @porn_stats = args[:porn_stats] if args.key?(:porn_stats)
          @quality_without_adjustment = args[:quality_without_adjustment] if args.key?(:quality_without_adjustment)
          @referrer_url = args[:referrer_url] if args.key?(:referrer_url)
          @relatedimages = args[:relatedimages] if args.key?(:relatedimages)
          @rootpage_duplicate_metadescription = args[:rootpage_duplicate_metadescription] if args.key?(:rootpage_duplicate_metadescription)
          @seen_noarchive = args[:seen_noarchive] if args.key?(:seen_noarchive)
          @seen_noindex = args[:seen_noindex] if args.key?(:seen_noindex)
          @seen_noodp = args[:seen_noodp] if args.key?(:seen_noodp)
          @seen_nopreview = args[:seen_nopreview] if args.key?(:seen_nopreview)
          @seen_nosnippet = args[:seen_nosnippet] if args.key?(:seen_nosnippet)
          @seen_notranslate = args[:seen_notranslate] if args.key?(:seen_notranslate)
          @shopping_attachment = args[:shopping_attachment] if args.key?(:shopping_attachment)
          @shopping_offers = args[:shopping_offers] if args.key?(:shopping_offers)
          @subindex = args[:subindex] if args.key?(:subindex)
          @thumb_height = args[:thumb_height] if args.key?(:thumb_height)
          @thumb_width = args[:thumb_width] if args.key?(:thumb_width)
          @thumbnail = args[:thumbnail] if args.key?(:thumbnail)
          @title = args[:title] if args.key?(:title)
          @union_build_time = args[:union_build_time] if args.key?(:union_build_time)
          @url = args[:url] if args.key?(:url)
          @url_after_redirects = args[:url_after_redirects] if args.key?(:url_after_redirects)
          @url_encoding = args[:url_encoding] if args.key?(:url_encoding)
          @visible_image = args[:visible_image] if args.key?(:visible_image)
          @visual_type = args[:visual_type] if args.key?(:visual_type)
        end
      end
      
      # Return related images.
      class WwwDocInfoRelatedImages
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `imageDocid`
        # @return [Fixnum]
        attr_accessor :image_docid
      
        # 
        # Corresponds to the JSON property `thumbHeight`
        # @return [Fixnum]
        attr_accessor :thumb_height
      
        # 
        # Corresponds to the JSON property `thumbType`
        # @return [String]
        attr_accessor :thumb_type
      
        # 
        # Corresponds to the JSON property `thumbWidth`
        # @return [Fixnum]
        attr_accessor :thumb_width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @image_docid = args[:image_docid] if args.key?(:image_docid)
          @thumb_height = args[:thumb_height] if args.key?(:thumb_height)
          @thumb_type = args[:thumb_type] if args.key?(:thumb_type)
          @thumb_width = args[:thumb_width] if args.key?(:thumb_width)
        end
      end
      
      # 
      class WwwDocInfoThumbnail
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `expirationTimestampMicros`
        # @return [Fixnum]
        attr_accessor :expiration_timestamp_micros
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # The type here corresponds to image_base::ThumbnailType defined in image/base/
        # thumbnail-type.proto.
        # Corresponds to the JSON property `type`
        # @return [Fixnum]
        attr_accessor :type
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @expiration_timestamp_micros = args[:expiration_timestamp_micros] if args.key?(:expiration_timestamp_micros)
          @height = args[:height] if args.key?(:height)
          @type = args[:type] if args.key?(:type)
          @width = args[:width] if args.key?(:width)
        end
      end
      
      # We can return the content attribute for some or all meta tags.
      class WwwMetaTag
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `content`
        # @return [String]
        attr_accessor :content
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @content = args[:content] if args.key?(:content)
          @name = args[:name] if args.key?(:name)
        end
      end
      
      # The following message contains info of sub image docs, it is populated in
      # query_state and consumed in web image boost twiddler: (go/
      # WebImageBoostTwiddler).
      class WwwResultInfoSubImageDocInfo
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `additionalSafesearchSignals`
        # @return [Array<Fixnum>]
        attr_accessor :additional_safesearch_signals
      
        # The best thumbnail type is either 300K or 50K.
        # Corresponds to the JSON property `bestThumbnailType`
        # @return [String]
        attr_accessor :best_thumbnail_type
      
        # 
        # Corresponds to the JSON property `crops`
        # @return [Fixnum]
        attr_accessor :crops
      
        # Deepcrop thumbnail cropping hints.
        # Corresponds to the JSON property `deepCropBytes`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :deep_crop_bytes
      
        # 
        # Corresponds to the JSON property `docid`
        # @return [Fixnum]
        attr_accessor :docid
      
        # 
        # Corresponds to the JSON property `documentTrust`
        # @return [Float]
        attr_accessor :document_trust
      
        # EQ* is a unified signal to capture the emotional quality (e.g. inspiration,
        # lifestyle, context, etc.) of an image. For more information, please refer to
        # go/image-inspiration-ranking-framework.
        # Corresponds to the JSON property `eqStar`
        # @return [Float]
        attr_accessor :eq_star
      
        # Estimated Image Relevance ranging between 0.0 (Off-Topic) to 1.0 (Very Useful).
        # Corresponds to the JSON property `estRelevance`
        # @return [Float]
        attr_accessor :est_relevance
      
        # The subset of FlowProto that we want to go into production AND be stored in
        # ContentSignals.
        # Corresponds to the JSON property `flowOutput`
        # @return [Google::Apis::ContentwarehouseV1::ImageContentFlowProtoProd]
        attr_accessor :flow_output
      
        # 
        # Corresponds to the JSON property `height`
        # @return [Fixnum]
        attr_accessor :height
      
        # 
        # Corresponds to the JSON property `height50k`
        # @return [Fixnum]
        attr_accessor :height50k
      
        # DeepTags human model score. go/VisualShoppingImageAttributes
        # Corresponds to the JSON property `humanModelScore`
        # @return [Float]
        attr_accessor :human_model_score
      
        # 
        # Corresponds to the JSON property `imageUrl`
        # @return [String]
        attr_accessor :image_url
      
        # 
        # Corresponds to the JSON property `pamirNormalizedScore`
        # @return [Float]
        attr_accessor :pamir_normalized_score
      
        # Encoded Safe Search annotations of the image. See image/safesearch/overall/
        # public/image_porn_attachments.h for decoding functions.
        # Corresponds to the JSON property `pornSignals`
        # @return [Fixnum]
        attr_accessor :porn_signals
      
        # Result is not on the Images Universal blacklist. For more comprehensive
        # filtering of IU images, including this bit, see superroot/impls/images/quality/
        # safesearch/iu_inappropriate_filter_lib.h
        # Corresponds to the JSON property `safeForUniversal`
        # @return [Boolean]
        attr_accessor :safe_for_universal
        alias_method :safe_for_universal?, :safe_for_universal
      
        # Salient score, indicating how important an image is to the page it's on. Check
        # go/salient-images-design-doc for details.
        # Corresponds to the JSON property `salience`
        # @return [Float]
        attr_accessor :salience
      
        # 4-bytes: (low order on the left) RRRRRRRR GGGGGGGG BBBBBBBB SS where R: 8-bits
        # encoding color 'r' G: 8-bits encoding color 'g' B: 8-bits encoding color 'b' S:
        # 2-bits encoding the color source - 00 = from color detection result - 01 =
        # from cairo This field has the salient color information.
        # Corresponds to the JSON property `salientColorInfo`
        # @return [Fixnum]
        attr_accessor :salient_color_info
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # TQ* is a signal to capture the technical quality (e.g. exposure, sharpness,
        # composition, etc.) of an image. For more information, please refer to go/
        # tqstar.
        # Corresponds to the JSON property `tqStar`
        # @return [Float]
        attr_accessor :tq_star
      
        # 
        # Corresponds to the JSON property `tradFrac`
        # @return [Float]
        attr_accessor :trad_frac
      
        # 
        # Corresponds to the JSON property `width`
        # @return [Fixnum]
        attr_accessor :width
      
        # Width and height of the AREA_50K thumbnail for this image.
        # Corresponds to the JSON property `width50k`
        # @return [Fixnum]
        attr_accessor :width50k
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @additional_safesearch_signals = args[:additional_safesearch_signals] if args.key?(:additional_safesearch_signals)
          @best_thumbnail_type = args[:best_thumbnail_type] if args.key?(:best_thumbnail_type)
          @crops = args[:crops] if args.key?(:crops)
          @deep_crop_bytes = args[:deep_crop_bytes] if args.key?(:deep_crop_bytes)
          @docid = args[:docid] if args.key?(:docid)
          @document_trust = args[:document_trust] if args.key?(:document_trust)
          @eq_star = args[:eq_star] if args.key?(:eq_star)
          @est_relevance = args[:est_relevance] if args.key?(:est_relevance)
          @flow_output = args[:flow_output] if args.key?(:flow_output)
          @height = args[:height] if args.key?(:height)
          @height50k = args[:height50k] if args.key?(:height50k)
          @human_model_score = args[:human_model_score] if args.key?(:human_model_score)
          @image_url = args[:image_url] if args.key?(:image_url)
          @pamir_normalized_score = args[:pamir_normalized_score] if args.key?(:pamir_normalized_score)
          @porn_signals = args[:porn_signals] if args.key?(:porn_signals)
          @safe_for_universal = args[:safe_for_universal] if args.key?(:safe_for_universal)
          @salience = args[:salience] if args.key?(:salience)
          @salient_color_info = args[:salient_color_info] if args.key?(:salient_color_info)
          @score = args[:score] if args.key?(:score)
          @tq_star = args[:tq_star] if args.key?(:tq_star)
          @trad_frac = args[:trad_frac] if args.key?(:trad_frac)
          @width = args[:width] if args.key?(:width)
          @width50k = args[:width50k] if args.key?(:width50k)
        end
      end
      
      # Per-document response for a www DocInfo request. Next field position: 55
      class WwwSnippetResponse
        include Google::Apis::Core::Hashable
      
        # A list of answers that had at least one hit in the document. Answers are
        # identified by their index into the QRewriteQueryParams_AnswerSnippetInfo array
        # (see //query/proto/query-params.proto).
        # Corresponds to the JSON property `answerDocMatches`
        # @return [Array<Fixnum>]
        attr_accessor :answer_doc_matches
      
        # Tidbits chosen from the document body. Consists of repeated [begin, end) half-
        # open ranges in token offsets from the beginning of the document.
        # Corresponds to the JSON property `chosenBodyTidbits`
        # @return [Array<Fixnum>]
        attr_accessor :chosen_body_tidbits
      
        # Some per-doc info is returned for all www DocInfo requests. Next id: 92
        # Corresponds to the JSON property `docInfo`
        # @return [Google::Apis::ContentwarehouseV1::WwwDocInfo]
        attr_accessor :doc_info
      
        # Set of per-document markup restrictions based on go/eucd-indexing-design. Used
        # for EUCD and global preview compliance. Next ID: 17
        # Corresponds to the JSON property `docPreviewRestrictions`
        # @return [Google::Apis::ContentwarehouseV1::QualityDniDocPreviewRestrictions]
        attr_accessor :doc_preview_restrictions
      
        # Set of per-document markup restrictions based on go/eucd-indexing-design. Used
        # for EUCD and global preview compliance. Next ID: 17
        # Corresponds to the JSON property `docPreviewRestrictionsForAmp`
        # @return [Google::Apis::ContentwarehouseV1::QualityDniDocPreviewRestrictions]
        attr_accessor :doc_preview_restrictions_for_amp
      
        # Bitfield of snippet events and the various events. See SnippetEvents in ./
        # snippets/defines.h for details on the contents.
        # Corresponds to the JSON property `events`
        # @return [Fixnum]
        attr_accessor :events
      
        # the extra info response from ascorer used to build snippets in GWS experiments
        # Corresponds to the JSON property `extraInfo`
        # @return [Google::Apis::ContentwarehouseV1::ExtraSnippetInfoResponse]
        attr_accessor :extra_info
      
        # A bitvector of the tidbits in the snippet that are appropriate for the Quick
        # Scroll (Findy) Chrome extension. Typically these contain "extra body matches",
        # i.e., important query items not in the title.
        # Corresponds to the JSON property `findyTidbits`
        # @return [Fixnum]
        attr_accessor :findy_tidbits
      
        # Additional available data (message type ids)
        # Corresponds to the JSON property `hasMessageType`
        # @return [Array<Fixnum>]
        attr_accessor :has_message_type
      
        # This is proto2's version of MessageSet.
        # Corresponds to the JSON property `info`
        # @return [Google::Apis::ContentwarehouseV1::Proto2BridgeMessageSet]
        attr_accessor :info
      
        # True if the document represents a login page.
        # Corresponds to the JSON property `isLoginPage`
        # @return [Boolean]
        attr_accessor :is_login_page
        alias_method :is_login_page?, :is_login_page
      
        # Assume this is true unless we discover that the result doesn't match the the
        # query, in which case this result is invalid despite having returned docinfo.
        # Corresponds to the JSON property `isValidResult`
        # @return [Boolean]
        attr_accessor :is_valid_result
        alias_method :is_valid_result?, :is_valid_result
      
        # Document keywords
        # Corresponds to the JSON property `keyword`
        # @return [Array<String>]
        attr_accessor :keyword
      
        # Data to generate the list snippets UI.
        # Corresponds to the JSON property `listSnippet`
        # @return [Google::Apis::ContentwarehouseV1::ListSnippetResponse]
        attr_accessor :list_snippet
      
        # List summary phrase for list pages.
        # Corresponds to the JSON property `listSummary`
        # @return [String]
        attr_accessor :list_summary
      
        # An experimental long snippet. The protocol allows any permutation of headers
        # and plain text paragraphs, but typical responses are just paragraphs or
        # alternating headers and paragraphs.
        # Corresponds to the JSON property `longStructuredSnippet`
        # @return [Google::Apis::ContentwarehouseV1::LongStructuredSnippet]
        attr_accessor :long_structured_snippet
      
        # Bitmap representing matches to leaf query terms within document (body section
        # and url). It gets populated if query_matches_info = true.
        # Corresponds to the JSON property `matchesBitmapEncoded`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :matches_bitmap_encoded
      
        # 
        # Corresponds to the JSON property `matchesBitmapSize`
        # @return [Fixnum]
        attr_accessor :matches_bitmap_size
      
        # Meta tags
        # Corresponds to the JSON property `metaTags`
        # @return [Array<Google::Apis::ContentwarehouseV1::WwwMetaTag>]
        attr_accessor :meta_tags
      
        # Similar to num_tokens_skipped_by_in_doc_restrictions_in_scoring, but this
        # number is for tokens skipped during printing, since printer owns its own token
        # info manager which populates tokens.
        # Corresponds to the JSON property `numTokensSkippedByInDocRestrictionsInPrinting`
        # @return [Fixnum]
        attr_accessor :num_tokens_skipped_by_in_doc_restrictions_in_printing
      
        # Number of tokens that is skipped because of in doc restrictions during scoring.
        # This is an estimate, as the list of tokens is cached in TokenInfoManager. We
        # should only monitor the cases where this number is too big or non-zero.
        # Corresponds to the JSON property `numTokensSkippedByInDocRestrictionsInScoring`
        # @return [Fixnum]
        attr_accessor :num_tokens_skipped_by_in_doc_restrictions_in_scoring
      
        # 
        # Corresponds to the JSON property `numberOfPages`
        # @return [Fixnum]
        attr_accessor :number_of_pages
      
        # LocalWWWInfo
        # Corresponds to the JSON property `obsoleteLocalinfo`
        # @return [String]
        attr_accessor :obsolete_localinfo
      
        # ManyboxData
        # Corresponds to the JSON property `obsoleteManybox`
        # @return [String]
        attr_accessor :obsolete_manybox
      
        # These fields were previously optional messages, but CL 2388905 moved them into
        # the MessageSet. However, at this time, old Mustang binaries are still deployed
        # in production and probably will be around for awhile. So, servers which need
        # to talk to old binaries and need to use these fields need to check both the
        # obsolete versions and the MessageSet version. Sitemap
        # Corresponds to the JSON property `obsoleteSitemap`
        # @return [String]
        attr_accessor :obsolete_sitemap
      
        # Was odp used in the snippets? DEPRECATED - this is no longer populated as of
        # June 2017.
        # Corresponds to the JSON property `odp`
        # @return [Boolean]
        attr_accessor :odp
        alias_method :odp?, :odp
      
        # DEPRECATED If requested, the orion entities
        # Corresponds to the JSON property `orionEntities`
        # @return [Google::Apis::ContentwarehouseV1::OrionDocEntitiesProto]
        attr_accessor :orion_entities
      
        # Abbreviated bibliographic data from Google Scholar.
        # Corresponds to the JSON property `scienceInfo`
        # @return [Google::Apis::ContentwarehouseV1::ScienceIndexSignal]
        attr_accessor :science_info
      
        # 
        # Corresponds to the JSON property `sectionHeadingAnchorName`
        # @return [String]
        attr_accessor :section_heading_anchor_name
      
        # If requested, the snippet generator may take note of query items present in an
        # entry in an on-page table-of-contents (i.e. a series of on-page links to named
        # anchors.) If so, these two fields contain the formatted and highlighted entry
        # and the name of the on-page anchor it links to, respectively. This may be used
        # by GWS to show a direct link to that named anchor on the page.
        # Corresponds to the JSON property `sectionHeadingText`
        # @return [String]
        attr_accessor :section_heading_text
      
        # Did a negative query term match the meta description?
        # Corresponds to the JSON property `seenNotTerm`
        # @return [Boolean]
        attr_accessor :seen_not_term
        alias_method :seen_not_term?, :seen_not_term
      
        # DEPRECATED Sentiment snippets
        # Corresponds to the JSON property `sentimentSnippets`
        # @return [Array<Google::Apis::ContentwarehouseV1::RepositoryAnnotationsMustangSentimentSnippetAnnotations>]
        attr_accessor :sentiment_snippets
      
        # The display name of the document's domain used as the first part of VisUrl, e.
        # g, "Google > play > store" is the VisUrl of "https://play.google.com/store/".
        # Wherein, "Google" is site_display_name of the domain "google.com". See go/site-
        # display-name for more details.
        # Corresponds to the JSON property `siteDisplayName`
        # @return [String]
        attr_accessor :site_display_name
      
        # Byline date for time sensitive snippets. Most of the time it originates from
        # quality_timebased::SyntacticDate and it is floored to PT midnight.
        # Corresponds to the JSON property `snippetBylineDate`
        # @return [Fixnum]
        attr_accessor :snippet_byline_date
      
        # Extra snippet info used for snippet scoring / modification in superroot. Next
        # ID: 11
        # Corresponds to the JSON property `snippetExtraInfo`
        # @return [Google::Apis::ContentwarehouseV1::SnippetExtraInfo]
        attr_accessor :snippet_extra_info
      
        # List of bitmaps representing matches to leaf query terms within each of the
        # highlighted snippet text fragments. Consecutive bitmaps correspond to
        # consecutive text fragments. It gets populated iff
        # return_query_snippet_highlight_matches = true. Example: document body section:
        # "This cafe has pet friendly patio." squery: (a (o dog :o pet :syn:general)
        # friendly :o (o restaurant :o cafe :syn:general)) Let's assume the returned
        # snippet text contains the whole document body section where two fragments get
        # highlighted as follows: "This *cafe* has *pet friendly* patio." Then, the
        # returned snippet_highlight_matches_bitmap[] list will have two bitmaps: bitmap[
        # 0] = <"cafe" -> leaf term with index 4> = `encoded: DenseEncode("00001"), size:
        # 5` bitmap[1] = <"pet" and "friendly" -> leaf terms with indexes 1 and 2> = `
        # encoded: DenseEncode("011"), size: 3`
        # Corresponds to the JSON property `snippetHighlightMatchesBitmap`
        # @return [Array<Google::Apis::ContentwarehouseV1::WwwSnippetResponseBitmapPb>]
        attr_accessor :snippet_highlight_matches_bitmap
      
        # If requested the page number on which the snippet begins. (Only for documents
        # such as PDFs where page numbers are well-defined.)
        # Corresponds to the JSON property `snippetPageNumber`
        # @return [Fixnum]
        attr_accessor :snippet_page_number
      
        # Character counts of snippet prefix, if any. E.g. section heading, list summary,
        # byline date.
        # Corresponds to the JSON property `snippetPrefixCharCount`
        # @return [Fixnum]
        attr_accessor :snippet_prefix_char_count
      
        # How tokens are rendered in generating snippet.
        # Corresponds to the JSON property `snippetRenderedToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::MustangSnippetsRenderedToken>]
        attr_accessor :snippet_rendered_token
      
        # A hash for duplicate detection. Two results with the same content can return
        # different snippets if, for example, one has an ODP entry and the other does
        # not. Gws can use this value reliably to filter duplicates. It is a hash of
        # body only tidbits.
        # Corresponds to the JSON property `snippethash`
        # @return [Fixnum]
        attr_accessor :snippethash
      
        # This is a protocol buffer to export into flatfiles in ranklab. All fields are
        # converted into flatfiles with some specific prefix and a field name like '
        # snippet_features_snippet_data_source_type'.
        # Corresponds to the JSON property `snippetsRanklabFeatures`
        # @return [Google::Apis::ContentwarehouseV1::MustangReposWwwSnippetsSnippetsRanklabFeatures]
        attr_accessor :snippets_ranklab_features
      
        # This field is never set.
        # Corresponds to the JSON property `squeryFingerprint`
        # @return [Fixnum]
        attr_accessor :squery_fingerprint
      
        # True if the title length is already adjusted for the browser width. If it is
        # true, GWS needs not truncate the title.
        # Corresponds to the JSON property `titleLengthAdjustedForBrowserWidth`
        # @return [Boolean]
        attr_accessor :title_length_adjusted_for_browser_width
        alias_method :title_length_adjusted_for_browser_width?, :title_length_adjusted_for_browser_width
      
        # How tokens are rendered in generating title. Note: In rendering a title, the
        # page title part and the site/host/domain title part can be flipped after
        # initial rendering. The flip, if happend, may not be reflected in this field.
        # That is, this field may contain the tokens in the original, pre-flip, order.
        # Corresponds to the JSON property `titleRenderedToken`
        # @return [Array<Google::Apis::ContentwarehouseV1::MustangSnippetsRenderedToken>]
        attr_accessor :title_rendered_token
      
        # Data related to title sizing calculations in Muppet.
        # Corresponds to the JSON property `titleSizeParams`
        # @return [Google::Apis::ContentwarehouseV1::TitleSizeParams]
        attr_accessor :title_size_params
      
        # Only for desktop web search. Please refer to Title.
        # keep_original_title_and_populate_truncated_one for more details.
        # Corresponds to the JSON property `truncatedTitle`
        # @return [String]
        attr_accessor :truncated_title
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @answer_doc_matches = args[:answer_doc_matches] if args.key?(:answer_doc_matches)
          @chosen_body_tidbits = args[:chosen_body_tidbits] if args.key?(:chosen_body_tidbits)
          @doc_info = args[:doc_info] if args.key?(:doc_info)
          @doc_preview_restrictions = args[:doc_preview_restrictions] if args.key?(:doc_preview_restrictions)
          @doc_preview_restrictions_for_amp = args[:doc_preview_restrictions_for_amp] if args.key?(:doc_preview_restrictions_for_amp)
          @events = args[:events] if args.key?(:events)
          @extra_info = args[:extra_info] if args.key?(:extra_info)
          @findy_tidbits = args[:findy_tidbits] if args.key?(:findy_tidbits)
          @has_message_type = args[:has_message_type] if args.key?(:has_message_type)
          @info = args[:info] if args.key?(:info)
          @is_login_page = args[:is_login_page] if args.key?(:is_login_page)
          @is_valid_result = args[:is_valid_result] if args.key?(:is_valid_result)
          @keyword = args[:keyword] if args.key?(:keyword)
          @list_snippet = args[:list_snippet] if args.key?(:list_snippet)
          @list_summary = args[:list_summary] if args.key?(:list_summary)
          @long_structured_snippet = args[:long_structured_snippet] if args.key?(:long_structured_snippet)
          @matches_bitmap_encoded = args[:matches_bitmap_encoded] if args.key?(:matches_bitmap_encoded)
          @matches_bitmap_size = args[:matches_bitmap_size] if args.key?(:matches_bitmap_size)
          @meta_tags = args[:meta_tags] if args.key?(:meta_tags)
          @num_tokens_skipped_by_in_doc_restrictions_in_printing = args[:num_tokens_skipped_by_in_doc_restrictions_in_printing] if args.key?(:num_tokens_skipped_by_in_doc_restrictions_in_printing)
          @num_tokens_skipped_by_in_doc_restrictions_in_scoring = args[:num_tokens_skipped_by_in_doc_restrictions_in_scoring] if args.key?(:num_tokens_skipped_by_in_doc_restrictions_in_scoring)
          @number_of_pages = args[:number_of_pages] if args.key?(:number_of_pages)
          @obsolete_localinfo = args[:obsolete_localinfo] if args.key?(:obsolete_localinfo)
          @obsolete_manybox = args[:obsolete_manybox] if args.key?(:obsolete_manybox)
          @obsolete_sitemap = args[:obsolete_sitemap] if args.key?(:obsolete_sitemap)
          @odp = args[:odp] if args.key?(:odp)
          @orion_entities = args[:orion_entities] if args.key?(:orion_entities)
          @science_info = args[:science_info] if args.key?(:science_info)
          @section_heading_anchor_name = args[:section_heading_anchor_name] if args.key?(:section_heading_anchor_name)
          @section_heading_text = args[:section_heading_text] if args.key?(:section_heading_text)
          @seen_not_term = args[:seen_not_term] if args.key?(:seen_not_term)
          @sentiment_snippets = args[:sentiment_snippets] if args.key?(:sentiment_snippets)
          @site_display_name = args[:site_display_name] if args.key?(:site_display_name)
          @snippet_byline_date = args[:snippet_byline_date] if args.key?(:snippet_byline_date)
          @snippet_extra_info = args[:snippet_extra_info] if args.key?(:snippet_extra_info)
          @snippet_highlight_matches_bitmap = args[:snippet_highlight_matches_bitmap] if args.key?(:snippet_highlight_matches_bitmap)
          @snippet_page_number = args[:snippet_page_number] if args.key?(:snippet_page_number)
          @snippet_prefix_char_count = args[:snippet_prefix_char_count] if args.key?(:snippet_prefix_char_count)
          @snippet_rendered_token = args[:snippet_rendered_token] if args.key?(:snippet_rendered_token)
          @snippethash = args[:snippethash] if args.key?(:snippethash)
          @snippets_ranklab_features = args[:snippets_ranklab_features] if args.key?(:snippets_ranklab_features)
          @squery_fingerprint = args[:squery_fingerprint] if args.key?(:squery_fingerprint)
          @title_length_adjusted_for_browser_width = args[:title_length_adjusted_for_browser_width] if args.key?(:title_length_adjusted_for_browser_width)
          @title_rendered_token = args[:title_rendered_token] if args.key?(:title_rendered_token)
          @title_size_params = args[:title_size_params] if args.key?(:title_size_params)
          @truncated_title = args[:truncated_title] if args.key?(:truncated_title)
        end
      end
      
      # Encoded bitmap.
      class WwwSnippetResponseBitmapPb
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `encoded`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :encoded
      
        # 
        # Corresponds to the JSON property `size`
        # @return [Fixnum]
        attr_accessor :size
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @encoded = args[:encoded] if args.key?(:encoded)
          @size = args[:size] if args.key?(:size)
        end
      end
      
      # 
      class WatchpageLanguageWatchPageLanguageResult
        include Google::Apis::Core::Hashable
      
        # The language predicted by the WatchPage Language model.
        # Corresponds to the JSON property `watchpageLanguage`
        # @return [String]
        attr_accessor :watchpage_language
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @watchpage_language = args[:watchpage_language] if args.key?(:watchpage_language)
        end
      end
      
      # Page boosting using Live Results data. Attaching this proto to a document
      # indicates that a Live Result feed exists for that document, and that this feed
      # has sufficient reliability to warrant potential boosting of the document rank.
      # Next ID: 3
      class WeboftrustLiveResultDocBoostData
        include Google::Apis::Core::Hashable
      
        # Identifies the degree to which the existence of this LiveResult should boost a
        # query's score (when the query is performed within the hot_times range). This
        # field is always in the range [0,1]. A missing field, a value of 0, or a value
        # outside the legal range indicates that no boosting is performed. A value of 1
        # indicates that the maximum level of boosting will be applied. This field will
        # be updated from time to time based on CTR and other signals.
        # Corresponds to the JSON property `boostLevel`
        # @return [Float]
        attr_accessor :boost_level
      
        # Time range (start time and end time). Used to indicate the times in which a
        # LiveResult is considered "hot" and thus a potential for boosting. Specified as
        # Unix time (seconds since midnight, January 1, 1970). Time zone is same as that
        # for query_start_time (i.e., GMT). Next ID: 3
        # Corresponds to the JSON property `hotTimes`
        # @return [Google::Apis::ContentwarehouseV1::WeboftrustTimeRange]
        attr_accessor :hot_times
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @boost_level = args[:boost_level] if args.key?(:boost_level)
          @hot_times = args[:hot_times] if args.key?(:hot_times)
        end
      end
      
      # Per-provider attachment of a LiveResult. Used to identify pages for which
      # result-based triggering of Live Results should appear. Theoretically there can
      # be more than one attachment per web document, so we keep them as a repeated
      # field of the LiveResultsDocAttachment. Next ID: 4
      class WeboftrustLiveResultProviderDocAttachment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `providerId`
        # @return [Fixnum]
        attr_accessor :provider_id
      
        # Tag that specifies the use-case within provider's data. It appears as a string
        # in Alexandria signal and in the DocJoins. During the indexing stage this field
        # will be converted to a 64-bit fingerprint to save space. See the "tag_fp"
        # field, below.
        # Corresponds to the JSON property `tag`
        # @return [String]
        attr_accessor :tag
      
        # A fingerprint of the "tag" field, automatically calculated during the indexing
        # stage. Will be used as a key for fetching the data.
        # Corresponds to the JSON property `tagFp`
        # @return [Fixnum]
        attr_accessor :tag_fp
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @provider_id = args[:provider_id] if args.key?(:provider_id)
          @tag = args[:tag] if args.key?(:tag)
          @tag_fp = args[:tag_fp] if args.key?(:tag_fp)
        end
      end
      
      # Message to which we attach to web documents in order to decide which
      # LiveResult to trigger. Next ID: 3
      class WeboftrustLiveResultsDocAttachments
        include Google::Apis::Core::Hashable
      
        # Information about potential rank boosting for the document by virtue of its
        # Live Result feed.
        # Corresponds to the JSON property `docBoost`
        # @return [Array<Google::Apis::ContentwarehouseV1::WeboftrustLiveResultDocBoostData>]
        attr_accessor :doc_boost
      
        # Identifies a Live Result which is to be attached to the document.
        # Corresponds to the JSON property `providerAttachment`
        # @return [Array<Google::Apis::ContentwarehouseV1::WeboftrustLiveResultProviderDocAttachment>]
        attr_accessor :provider_attachment
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @doc_boost = args[:doc_boost] if args.key?(:doc_boost)
          @provider_attachment = args[:provider_attachment] if args.key?(:provider_attachment)
        end
      end
      
      # Time range (start time and end time). Used to indicate the times in which a
      # LiveResult is considered "hot" and thus a potential for boosting. Specified as
      # Unix time (seconds since midnight, January 1, 1970). Time zone is same as that
      # for query_start_time (i.e., GMT). Next ID: 3
      class WeboftrustTimeRange
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `endUnixTime`
        # @return [Fixnum]
        attr_accessor :end_unix_time
      
        # Start and end times should always appear. Marked as optional to avoid breaking
        # code.
        # Corresponds to the JSON property `startUnixTime`
        # @return [Fixnum]
        attr_accessor :start_unix_time
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_unix_time = args[:end_unix_time] if args.key?(:end_unix_time)
          @start_unix_time = args[:start_unix_time] if args.key?(:start_unix_time)
        end
      end
      
      # IMPORTANT: It is unsafe to accept this message from an untrusted source, since
      # it's trivial for an attacker to forge serialized messages that don't fulfill
      # the type's safety contract -- for example, it could contain attacker
      # controlled script. A system which receives a SafeHtmlProto implicitly trusts
      # the producer of the SafeHtmlProto. So, it's generally safe to return this
      # message in RPC responses, but generally unsafe to accept it in RPC requests.
      class WebutilHtmlTypesSafeHtmlProto
        include Google::Apis::Core::Hashable
      
        # IMPORTANT: Never set or read this field, even from tests, it is private. See
        # documentation at the top of .proto file for programming language packages with
        # which to create or read this message.
        # Corresponds to the JSON property `privateDoNotAccessOrElseSafeHtmlWrappedValue`
        # @return [String]
        attr_accessor :private_do_not_access_or_else_safe_html_wrapped_value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @private_do_not_access_or_else_safe_html_wrapped_value = args[:private_do_not_access_or_else_safe_html_wrapped_value] if args.key?(:private_do_not_access_or_else_safe_html_wrapped_value)
        end
      end
      
      # 
      class WirelessTranscoderFetchFetchMetadata
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `name`
        # @return [String]
        attr_accessor :name
      
        # 
        # Corresponds to the JSON property `value`
        # NOTE: Values are automatically base64 encoded/decoded in the client library.
        # @return [String]
        attr_accessor :value
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @name = args[:name] if args.key?(:name)
          @value = args[:value] if args.key?(:value)
        end
      end
      
      # To tag which fetcher satisfied this fetch request with optional detail.
      class WirelessTranscoderFetchFetchSourceInfo
        include Google::Apis::Core::Hashable
      
        # Provides fetcher-specific detail about how source satisfied the request.
        # Corresponds to the JSON property `detail`
        # @return [String]
        attr_accessor :detail
      
        # The fetcher that ultimately satisfied this fetch request.
        # Corresponds to the JSON property `source`
        # @return [String]
        attr_accessor :source
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @detail = args[:detail] if args.key?(:detail)
          @source = args[:source] if args.key?(:source)
        end
      end
      
      # Contains information about comment that is posted through a Super VOD purchase.
      # Next ID: 6
      class YoutubeBackstageSuperVodCommentInfo
        include Google::Apis::Core::Hashable
      
        # Currency code the user uses to purchase this Super VOD item.
        # Corresponds to the JSON property `currencyCode`
        # @return [String]
        attr_accessor :currency_code
      
        # The ID of the Super VOD entitlement. It uniquely identifies a Super VOD
        # purchase.
        # Corresponds to the JSON property `entitlementId`
        # @return [String]
        attr_accessor :entitlement_id
      
        # Price of Super VOD item the user purchases in micros.
        # Corresponds to the JSON property `priceInMicros`
        # @return [Fixnum]
        attr_accessor :price_in_micros
      
        # The Super VOD item the user purchases, it represents price tier.
        # Corresponds to the JSON property `superVodItemId`
        # @return [String]
        attr_accessor :super_vod_item_id
      
        # Which version of experiment this Super VOD comment is posted in.
        # Corresponds to the JSON property `version`
        # @return [String]
        attr_accessor :version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @currency_code = args[:currency_code] if args.key?(:currency_code)
          @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
          @price_in_micros = args[:price_in_micros] if args.key?(:price_in_micros)
          @super_vod_item_id = args[:super_vod_item_id] if args.key?(:super_vod_item_id)
          @version = args[:version] if args.key?(:version)
        end
      end
      
      # Intended to be simpler to work with than the ExportedStanza it's derived from
      # See documentation: https://g3doc.corp.google.com/company/teams/youtube/
      # community_intelligence/eng_resources/data_sources.md#ministanza Next available:
      # 74
      class YoutubeCommentsClusteringMiniStanza
        include Google::Apis::Core::Hashable
      
        # TnS Ansible scores map. Keyed by various model names.
        # Corresponds to the JSON property `ansibleScores`
        # @return [Hash<String,Float>]
        attr_accessor :ansible_scores
      
        # Automod scores map. Keyed by various model names.
        # Corresponds to the JSON property `automodScores`
        # @return [Hash<String,Float>]
        attr_accessor :automod_scores
      
        # Blarney Stone classification scores: go/blarneystone Next available ID: 6
        # Corresponds to the JSON property `blarneyStoneScore`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDistillerBlarneyStoneScores]
        attr_accessor :blarney_stone_score
      
        # The channel this channel discussion comment belongs to. Note that this will
        # match channel_id for such comments.
        # Corresponds to the JSON property `channelDiscussionId`
        # @return [String]
        attr_accessor :channel_discussion_id
      
        # The channel of the video this comment belongs to.
        # Corresponds to the JSON property `channelId`
        # @return [String]
        attr_accessor :channel_id
      
        # Channel profile quality scores map. Keyed by various model names.
        # Corresponds to the JSON property `channelProfileQualityScores`
        # @return [Hash<String,Float>]
        attr_accessor :channel_profile_quality_scores
      
        # Char entropy of the comment.
        # Corresponds to the JSON property `charEntropy`
        # @return [Float]
        attr_accessor :char_entropy
      
        # Comment classification mapping all secondary keys to values. E.g. `"joke_v1":0.
        # 8, "joke_v2":0.7, "question_v1":0.3`.
        # Corresponds to the JSON property `commentClassification`
        # @return [Hash<String,Float>]
        attr_accessor :comment_classification
      
        # List of pre-defined classification score buckets to which the comment belongs.
        # E.g. satisfaction_v1_percentile_80.
        # Corresponds to the JSON property `commentClassificationBuckets`
        # @return [Array<String>]
        attr_accessor :comment_classification_buckets
      
        # Comment classification for ranking mapping all secondary keys to values. E.g. `
        # "joke_v1":0.8, "joke_v2":0.7, "question_v1":0.3`.
        # Corresponds to the JSON property `commentClassificationRanking`
        # @return [Hash<String,Float>]
        attr_accessor :comment_classification_ranking
      
        # Whether the comment is on a video, post, or other product.
        # Corresponds to the JSON property `commentType`
        # @return [String]
        attr_accessor :comment_type
      
        # The text content of the comment.
        # Corresponds to the JSON property `content`
        # @return [String]
        attr_accessor :content
      
        # The stanza content last update timestamp, as observed by the server. Note that
        # for many comments older than Nov. 2014 this is unset in the original stanza.
        # MiniStanza tries to be consistent with the original so for such comments it
        # remains unset in MiniStanza. If you use this field you should check
        # has_content_update_timestamp().
        # Corresponds to the JSON property `contentUpdateTimestamp`
        # @return [String]
        attr_accessor :content_update_timestamp
      
        # Whether or not this comment is eligible for comment classifier coverage
        # sampling (in Kapla). Refer to go/coverage-monitoring-for-kapla-comment-
        # classifiers for more information.
        # Corresponds to the JSON property `coverageSamplingEligible`
        # @return [Boolean]
        attr_accessor :coverage_sampling_eligible
        alias_method :coverage_sampling_eligible?, :coverage_sampling_eligible
      
        # The creation device. Derived from shares:yt_creation_device
        # Corresponds to the JSON property `creationDevice`
        # @return [String]
        attr_accessor :creation_device
      
        # The time when the comment is created.
        # Corresponds to the JSON property `creationTimeInSeconds`
        # @return [Fixnum]
        attr_accessor :creation_time_in_seconds
      
        # The language code with extra script details. This is derived from
        # detailed_language_code if it's populated, otherwise the same as language_code.
        # E.g. mr-Latn
        # Corresponds to the JSON property `detailedLanguageCode`
        # @return [String]
        attr_accessor :detailed_language_code
      
        # Stores the number of different kind of user engagement actions. Abuse Report
        # is also consider an engagement. Currently we only have abuse report
        # engagements but in future we might add other types of engagements as well.
        # Corresponds to the JSON property `distillerEngagements`
        # @return [Google::Apis::ContentwarehouseV1::AppsPeopleActivityStreamqualityDistillerEngagements]
        attr_accessor :distiller_engagements
      
        # The qualified comment teaser filters that this comment is eligible for. Refer
        # to go/comment-teaser-design for more information.
        # Corresponds to the JSON property `eligibleQualifiedTeaserFilters`
        # @return [Array<String>]
        attr_accessor :eligible_qualified_teaser_filters
      
        # Used for stanza KV pair. Next tag: 7.
        # Corresponds to the JSON property `empiricalCtrs`
        # @return [Google::Apis::ContentwarehouseV1::VideoYoutubeCommentsRankingCtrMetrics]
        attr_accessor :empirical_ctrs
      
        # Fountain Discovery Score, which represents the reputation of the author.
        # Corresponds to the JSON property `fds`
        # @return [Float]
        attr_accessor :fds
      
        # Indicator for whether there is creator heart on this comment.
        # Corresponds to the JSON property `hasCreatorHeart`
        # @return [Boolean]
        attr_accessor :has_creator_heart
        alias_method :has_creator_heart?, :has_creator_heart
      
        # If the comment has a creator reply.
        # Corresponds to the JSON property `hasCreatorReply`
        # @return [Boolean]
        attr_accessor :has_creator_reply
        alias_method :has_creator_reply?, :has_creator_reply
      
        # If the author is a channel member (sponsor).
        # Corresponds to the JSON property `isAuthorSponsor`
        # @return [Boolean]
        attr_accessor :is_author_sponsor
        alias_method :is_author_sponsor?, :is_author_sponsor
      
        # Whether a comment is from deleted shares. See stanza_restrictions for more
        # specific information and is_publicly_visible for comments which are allowed to
        # be seen by everyone.
        # Corresponds to the JSON property `isDeleted`
        # @return [Boolean]
        attr_accessor :is_deleted
        alias_method :is_deleted?, :is_deleted
      
        # Whether the comment is pinned. This is derived from the DestinationStreamDump.
        # Corresponds to the JSON property `isPinned`
        # @return [Boolean]
        attr_accessor :is_pinned
        alias_method :is_pinned?, :is_pinned
      
        # If the post is publicly visible.
        # Corresponds to the JSON property `isPubliclyVisible`
        # @return [Boolean]
        attr_accessor :is_publicly_visible
        alias_method :is_publicly_visible?, :is_publicly_visible
      
        # Whether the comment is a reply.
        # Corresponds to the JSON property `isReply`
        # @return [Boolean]
        attr_accessor :is_reply
        alias_method :is_reply?, :is_reply
      
        # If the comment author is publicly subscribed to the channel.
        # Corresponds to the JSON property `isSubscriber`
        # @return [Boolean]
        attr_accessor :is_subscriber
        alias_method :is_subscriber?, :is_subscriber
      
        # Unicode CLDR language code of the segments, as implemented by //depot/google3/
        # java/com/google/i18n/identifiers/LanguageCode.java This is derived from
        # user_content and should be considered the canonical language code of the
        # comment.
        # Corresponds to the JSON property `languageCode`
        # @return [String]
        attr_accessor :language_code
      
        # The time when last reply is created.
        # Corresponds to the JSON property `lastReplyTimestampUsec`
        # @return [Fixnum]
        attr_accessor :last_reply_timestamp_usec
      
        # Low quality decisions. Keyed by decision types corresponding to secondary keys.
        # Corresponds to the JSON property `lowQualityDecisions`
        # @return [Hash<String,Boolean>]
        attr_accessor :low_quality_decisions
      
        # Timed comments for the "mentioned" secondary key.
        # Corresponds to the JSON property `mentionedTimestampCommentSecond`
        # @return [Fixnum]
        attr_accessor :mentioned_timestamp_comment_second
      
        # Misinfo scores map. Keyed by various model names.
        # Corresponds to the JSON property `misinfoScores`
        # @return [Hash<String,Float>]
        attr_accessor :misinfo_scores
      
        # Number of dislikes the comment has.
        # Corresponds to the JSON property `numDislikes`
        # @return [Fixnum]
        attr_accessor :num_dislikes
      
        # Number of likes the comment has.
        # Corresponds to the JSON property `numLikes`
        # @return [Fixnum]
        attr_accessor :num_likes
      
        # Number of different repliers the comment has.
        # Corresponds to the JSON property `numRepliers`
        # @return [Fixnum]
        attr_accessor :num_repliers
      
        # Number of non-abusive replies the comment has.
        # Corresponds to the JSON property `numReplies`
        # @return [Fixnum]
        attr_accessor :num_replies
      
        # Bucketed number of subscribers held by comment author.
        # Corresponds to the JSON property `numSubscribersBucket`
        # @return [Fixnum]
        attr_accessor :num_subscribers_bucket
      
        # Offline engagement scores map. Keyed by various model names.
        # Corresponds to the JSON property `offlineEngagementScores`
        # @return [Hash<String,Float>]
        attr_accessor :offline_engagement_scores
      
        # The parent stanza's stanza_id, empty for top-level posts (non-replies). Prefer
        # is_reply field for checking if a comment is a reply since that is unaffected
        # by surrogatization. For replies to replies, this is the root stanza_id (not
        # guaranteed AFAIK).
        # Corresponds to the JSON property `parentId`
        # @return [String]
        attr_accessor :parent_id
      
        # The post this comment belongs to.
        # Corresponds to the JSON property `postId`
        # @return [String]
        attr_accessor :post_id
      
        # The language code stored in the KV pair ranking:post_language. This should
        # usually be the same as language_code but is not guaranteed to be identical.
        # The KV pair is needed because ranking can't consume user_content.
        # Corresponds to the JSON property `rankingPostLanguage`
        # @return [String]
        attr_accessor :ranking_post_language
      
        # Segments (go/social-segments) represent structured social content, e.g. the
        # contents of a G+ stream post or chat message. A single post or message may
        # consist of a sequence of segments, each representing a type of content, e.g.
        # plain text, hash tag, mention, etc. Segments correspond approximately to units
        # of content delimited by HTML tags, so that a piece of bolded text would be a
        # distinct Segment, a link would be a distinct Segment, and so forth. A single
        # Segment may have multiple such qualifiers; e.g. it may be a bold link; in this
        # case, information about all such qualifiers will be encoded in the Segment
        # proto.
        # Corresponds to the JSON property `segments`
        # @return [Google::Apis::ContentwarehouseV1::SocialCommonSegments]
        attr_accessor :segments
      
        # Sensitivity scores map for smart reply sensitivity scores. Keyed by model
        # names. See (g3doc/company/teams/expander/research/conversation/sensitive.md)
        # for more information on sensitivity scores.
        # Corresponds to the JSON property `sensitivityScores`
        # @return [Hash<String,Float>]
        attr_accessor :sensitivity_scores
      
        # Sentiment information extracted from the annotated content by Goldmine. This
        # mirrors nlp_sentiment.SentimentAnnotation. Next tag: 5.
        # Corresponds to the JSON property `sentiment`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeCommentsSentimentSentiment]
        attr_accessor :sentiment
      
        # Smart replies for this comment. Keyed by model names.
        # Corresponds to the JSON property `smartReplies`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::VideoYoutubeCommentsClassificationProtoYouTubeCommentSmartReply>]
        attr_accessor :smart_replies
      
        # Refers to the stanza this data is derived from.
        # Corresponds to the JSON property `stanzaId`
        # @return [String]
        attr_accessor :stanza_id
      
        # Contains various restriction information about a stanza.
        # Corresponds to the JSON property `stanzaRestrictions`
        # @return [Array<Google::Apis::ContentwarehouseV1::SocialStanzaStanzaRestriction>]
        attr_accessor :stanza_restrictions
      
        # A Principal represents something to which permissions are assigned, often but
        # not always a user or group of some kind. It is most appropriate for use in
        # ACLs and authorization checks. Callers should prefer to use the wrapper
        # classes in google3/security/credentials/public/principal.h google3/java/com/
        # google/security/credentials/Principal.java google3/security/credentials/go/
        # principal.go unless direct proto access is essential. If you update this
        # protocol buffer, please update the wrapper classes as well.
        # Corresponds to the JSON property `subject`
        # @return [Google::Apis::ContentwarehouseV1::SecurityCredentialsPrincipalProto]
        attr_accessor :subject
      
        # Whether the comment is authored by the creator.
        # Corresponds to the JSON property `subjectIsVideoOwner`
        # @return [Boolean]
        attr_accessor :subject_is_video_owner
        alias_method :subject_is_video_owner?, :subject_is_video_owner
      
        # The timestamp (in seconds) when the author subscribed to the channel.
        # Corresponds to the JSON property `subscriptionTimestamp`
        # @return [Fixnum]
        attr_accessor :subscription_timestamp
      
        # Contains information about comment that is posted through a Super VOD purchase.
        # Next ID: 6
        # Corresponds to the JSON property `superThanksInfo`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeBackstageSuperVodCommentInfo]
        attr_accessor :super_thanks_info
      
        # Comment text embedding.
        # Corresponds to the JSON property `textEmbedding`
        # @return [Hash<String,Google::Apis::ContentwarehouseV1::YoutubeCommentsRankingYouTubeCommentTextEmbedding>]
        attr_accessor :text_embedding
      
        # Text length of the comment.
        # Corresponds to the JSON property `textLength`
        # @return [Fixnum]
        attr_accessor :text_length
      
        # Text quality scores for a single comment.
        # Corresponds to the JSON property `textQualityScores`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeCommentsRankingYouTubeCommentTextQualityAnnotation]
        attr_accessor :text_quality_scores
      
        # The video this comment belongs to.
        # Corresponds to the JSON property `videoId`
        # @return [String]
        attr_accessor :video_id
      
        # Unique video timestamps in seconds sorted by timestamp. This is derived from
        # text Segments, not from a KV. These may exceed the length of the video since
        # that isn't checked at segmentation time. The segmentation rules have changed
        # over time e.g. in the past "10:00 PM" was treated as a timestamp.
        # Corresponds to the JSON property `videoTimestamps`
        # @return [Array<Fixnum>]
        attr_accessor :video_timestamps
      
        # Word entropy of the comment.
        # Corresponds to the JSON property `wordEntropy`
        # @return [Float]
        attr_accessor :word_entropy
      
        # Existing quality corpus scores.
        # Corresponds to the JSON property `ytCommentQualityScore`
        # @return [Float]
        attr_accessor :yt_comment_quality_score
      
        # 
        # Corresponds to the JSON property `ytCommentQualityScore2`
        # @return [Float]
        attr_accessor :yt_comment_quality_score2
      
        # 
        # Corresponds to the JSON property `ytCommentQualityScore3`
        # @return [Float]
        attr_accessor :yt_comment_quality_score3
      
        # For replies to replies, this contains the parent reply's id. The parent_id
        # field is actually the root stanza_id (not guaranteed AFAIK).
        # Corresponds to the JSON property `ytReplyToItemId`
        # @return [String]
        attr_accessor :yt_reply_to_item_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @ansible_scores = args[:ansible_scores] if args.key?(:ansible_scores)
          @automod_scores = args[:automod_scores] if args.key?(:automod_scores)
          @blarney_stone_score = args[:blarney_stone_score] if args.key?(:blarney_stone_score)
          @channel_discussion_id = args[:channel_discussion_id] if args.key?(:channel_discussion_id)
          @channel_id = args[:channel_id] if args.key?(:channel_id)
          @channel_profile_quality_scores = args[:channel_profile_quality_scores] if args.key?(:channel_profile_quality_scores)
          @char_entropy = args[:char_entropy] if args.key?(:char_entropy)
          @comment_classification = args[:comment_classification] if args.key?(:comment_classification)
          @comment_classification_buckets = args[:comment_classification_buckets] if args.key?(:comment_classification_buckets)
          @comment_classification_ranking = args[:comment_classification_ranking] if args.key?(:comment_classification_ranking)
          @comment_type = args[:comment_type] if args.key?(:comment_type)
          @content = args[:content] if args.key?(:content)
          @content_update_timestamp = args[:content_update_timestamp] if args.key?(:content_update_timestamp)
          @coverage_sampling_eligible = args[:coverage_sampling_eligible] if args.key?(:coverage_sampling_eligible)
          @creation_device = args[:creation_device] if args.key?(:creation_device)
          @creation_time_in_seconds = args[:creation_time_in_seconds] if args.key?(:creation_time_in_seconds)
          @detailed_language_code = args[:detailed_language_code] if args.key?(:detailed_language_code)
          @distiller_engagements = args[:distiller_engagements] if args.key?(:distiller_engagements)
          @eligible_qualified_teaser_filters = args[:eligible_qualified_teaser_filters] if args.key?(:eligible_qualified_teaser_filters)
          @empirical_ctrs = args[:empirical_ctrs] if args.key?(:empirical_ctrs)
          @fds = args[:fds] if args.key?(:fds)
          @has_creator_heart = args[:has_creator_heart] if args.key?(:has_creator_heart)
          @has_creator_reply = args[:has_creator_reply] if args.key?(:has_creator_reply)
          @is_author_sponsor = args[:is_author_sponsor] if args.key?(:is_author_sponsor)
          @is_deleted = args[:is_deleted] if args.key?(:is_deleted)
          @is_pinned = args[:is_pinned] if args.key?(:is_pinned)
          @is_publicly_visible = args[:is_publicly_visible] if args.key?(:is_publicly_visible)
          @is_reply = args[:is_reply] if args.key?(:is_reply)
          @is_subscriber = args[:is_subscriber] if args.key?(:is_subscriber)
          @language_code = args[:language_code] if args.key?(:language_code)
          @last_reply_timestamp_usec = args[:last_reply_timestamp_usec] if args.key?(:last_reply_timestamp_usec)
          @low_quality_decisions = args[:low_quality_decisions] if args.key?(:low_quality_decisions)
          @mentioned_timestamp_comment_second = args[:mentioned_timestamp_comment_second] if args.key?(:mentioned_timestamp_comment_second)
          @misinfo_scores = args[:misinfo_scores] if args.key?(:misinfo_scores)
          @num_dislikes = args[:num_dislikes] if args.key?(:num_dislikes)
          @num_likes = args[:num_likes] if args.key?(:num_likes)
          @num_repliers = args[:num_repliers] if args.key?(:num_repliers)
          @num_replies = args[:num_replies] if args.key?(:num_replies)
          @num_subscribers_bucket = args[:num_subscribers_bucket] if args.key?(:num_subscribers_bucket)
          @offline_engagement_scores = args[:offline_engagement_scores] if args.key?(:offline_engagement_scores)
          @parent_id = args[:parent_id] if args.key?(:parent_id)
          @post_id = args[:post_id] if args.key?(:post_id)
          @ranking_post_language = args[:ranking_post_language] if args.key?(:ranking_post_language)
          @segments = args[:segments] if args.key?(:segments)
          @sensitivity_scores = args[:sensitivity_scores] if args.key?(:sensitivity_scores)
          @sentiment = args[:sentiment] if args.key?(:sentiment)
          @smart_replies = args[:smart_replies] if args.key?(:smart_replies)
          @stanza_id = args[:stanza_id] if args.key?(:stanza_id)
          @stanza_restrictions = args[:stanza_restrictions] if args.key?(:stanza_restrictions)
          @subject = args[:subject] if args.key?(:subject)
          @subject_is_video_owner = args[:subject_is_video_owner] if args.key?(:subject_is_video_owner)
          @subscription_timestamp = args[:subscription_timestamp] if args.key?(:subscription_timestamp)
          @super_thanks_info = args[:super_thanks_info] if args.key?(:super_thanks_info)
          @text_embedding = args[:text_embedding] if args.key?(:text_embedding)
          @text_length = args[:text_length] if args.key?(:text_length)
          @text_quality_scores = args[:text_quality_scores] if args.key?(:text_quality_scores)
          @video_id = args[:video_id] if args.key?(:video_id)
          @video_timestamps = args[:video_timestamps] if args.key?(:video_timestamps)
          @word_entropy = args[:word_entropy] if args.key?(:word_entropy)
          @yt_comment_quality_score = args[:yt_comment_quality_score] if args.key?(:yt_comment_quality_score)
          @yt_comment_quality_score2 = args[:yt_comment_quality_score2] if args.key?(:yt_comment_quality_score2)
          @yt_comment_quality_score3 = args[:yt_comment_quality_score3] if args.key?(:yt_comment_quality_score3)
          @yt_reply_to_item_id = args[:yt_reply_to_item_id] if args.key?(:yt_reply_to_item_id)
        end
      end
      
      # Comment text embedding.
      class YoutubeCommentsRankingYouTubeCommentTextEmbedding
        include Google::Apis::Core::Hashable
      
        # Comment text embedding.
        # Corresponds to the JSON property `textEmbedding`
        # @return [Array<Float>]
        attr_accessor :text_embedding
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @text_embedding = args[:text_embedding] if args.key?(:text_embedding)
        end
      end
      
      # Text quality scores for a single comment.
      class YoutubeCommentsRankingYouTubeCommentTextQualityAnnotation
        include Google::Apis::Core::Hashable
      
        # Score produced by the user flag prediction model.
        # Corresponds to the JSON property `flagPredictionScore`
        # @return [Float]
        attr_accessor :flag_prediction_score
      
        # Version identifier of the flag prediction model.
        # Corresponds to the JSON property `flagPredictionVersion`
        # @return [String]
        attr_accessor :flag_prediction_version
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @flag_prediction_score = args[:flag_prediction_score] if args.key?(:flag_prediction_score)
          @flag_prediction_version = args[:flag_prediction_version] if args.key?(:flag_prediction_version)
        end
      end
      
      # Sentiment information extracted from the annotated content by Goldmine. This
      # mirrors nlp_sentiment.SentimentAnnotation. Next tag: 5.
      class YoutubeCommentsSentimentSentiment
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `entitySentiment`
        # @return [Array<Google::Apis::ContentwarehouseV1::YoutubeCommentsSentimentSentimentEntitySentimentAnnotation>]
        attr_accessor :entity_sentiment
      
        # Total magnitude of the sentiment. A positive number representing the total
        # intensity of sentiment regardless of positive vs negative polarity.
        # Corresponds to the JSON property `magnitude`
        # @return [Float]
        attr_accessor :magnitude
      
        # Polarity of the sentiment. Value is between -1.0 and 1.0 inclusive, with
        # larger numbers representing more positive sentiment and negative numbers
        # representing negative sentiment.
        # Corresponds to the JSON property `polarity`
        # @return [Float]
        attr_accessor :polarity
      
        # The average score over sentences. This combines the polarity and magnitude
        # signals into one value. Bounded between -1.0 and 1.0.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_sentiment = args[:entity_sentiment] if args.key?(:entity_sentiment)
          @magnitude = args[:magnitude] if args.key?(:magnitude)
          @polarity = args[:polarity] if args.key?(:polarity)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # An entity level sentiment annotation containing the sentiment values
      # aggregated over all mentions of an entity. Next tag: 7.
      class YoutubeCommentsSentimentSentimentEntitySentimentAnnotation
        include Google::Apis::Core::Hashable
      
        # The representative entity name. This can be blank for cases when there is no
        # explicit name like "I" or "it". The mentions' tokens can be used to get more
        # details about each entity.
        # Corresponds to the JSON property `entityName`
        # @return [String]
        attr_accessor :entity_name
      
        # Total magnitude of the sentiment.
        # Corresponds to the JSON property `magnitude`
        # @return [Float]
        attr_accessor :magnitude
      
        # 
        # Corresponds to the JSON property `mentionSentiment`
        # @return [Array<Google::Apis::ContentwarehouseV1::YoutubeCommentsSentimentSentimentEntitySentimentAnnotationMentionSentimentAnnotation>]
        attr_accessor :mention_sentiment
      
        # MID for this entity, if available.
        # Corresponds to the JSON property `mid`
        # @return [String]
        attr_accessor :mid
      
        # Polarity of the sentiment. See above for detail.
        # Corresponds to the JSON property `polarity`
        # @return [Float]
        attr_accessor :polarity
      
        # The per entity score between -1.0 and 1.0. Combines the signal from polarity
        # and magnitude values.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity_name = args[:entity_name] if args.key?(:entity_name)
          @magnitude = args[:magnitude] if args.key?(:magnitude)
          @mention_sentiment = args[:mention_sentiment] if args.key?(:mention_sentiment)
          @mid = args[:mid] if args.key?(:mid)
          @polarity = args[:polarity] if args.key?(:polarity)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # A mention level sentiment annotation containing the sentiment values for a
      # single entity mention. // Next tag: 6.
      class YoutubeCommentsSentimentSentimentEntitySentimentAnnotationMentionSentimentAnnotation
        include Google::Apis::Core::Hashable
      
        # Token end index in corresponding SAFT document (inclusive).
        # Corresponds to the JSON property `endToken`
        # @return [Fixnum]
        attr_accessor :end_token
      
        # Total magnitude of the sentiment.
        # Corresponds to the JSON property `magnitude`
        # @return [Float]
        attr_accessor :magnitude
      
        # Polarity of the sentiment. See above for detail.
        # Corresponds to the JSON property `polarity`
        # @return [Float]
        attr_accessor :polarity
      
        # The per mention score between -1.0 and 1.0. Combines the signal from polarity
        # and magnitude values.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        # Token start index in corresponding SAFT document.
        # Corresponds to the JSON property `startToken`
        # @return [Fixnum]
        attr_accessor :start_token
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @end_token = args[:end_token] if args.key?(:end_token)
          @magnitude = args[:magnitude] if args.key?(:magnitude)
          @polarity = args[:polarity] if args.key?(:polarity)
          @score = args[:score] if args.key?(:score)
          @start_token = args[:start_token] if args.key?(:start_token)
        end
      end
      
      # The annotation of a document by a given entity, for a given type of
      # relationship. The annotation should be valid for the complete annotated
      # document, not simply a part of the document such as a video segment.
      class YoutubeDiscoveryLegosLegosAnnotation
        include Google::Apis::Core::Hashable
      
        # The identification of a Knowledge Graph (KG) entity in Legos.
        # Corresponds to the JSON property `entity`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosEntity]
        attr_accessor :entity
      
        # Description of a format Legos annotation. http://go/legos/formats.md
        # Corresponds to the JSON property `format`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosFormatRelationship]
        attr_accessor :format
      
        # Description of a semantic Legos annotation. http://go/legos/project.md#
        # semantic-intent-annotations
        # Corresponds to the JSON property `semantic`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosSemanticRelationship]
        attr_accessor :semantic
      
        # Description of a taxonomic Legos annotation. http://go/legos/project.md#
        # taxonomy-annotations
        # Corresponds to the JSON property `taxonomic`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosTaxonomicRelationship]
        attr_accessor :taxonomic
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @entity = args[:entity] if args.key?(:entity)
          @format = args[:format] if args.key?(:format)
          @semantic = args[:semantic] if args.key?(:semantic)
          @taxonomic = args[:taxonomic] if args.key?(:taxonomic)
        end
      end
      
      # A collection of annotations returned by Legos for a document.
      class YoutubeDiscoveryLegosLegosAnnotations
        include Google::Apis::Core::Hashable
      
        # The annotations for this document. For a given (entity, relationship type)
        # pair, there will be at most one annotation. The list has no particular order.
        # Corresponds to the JSON property `annotations`
        # @return [Array<Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosAnnotation>]
        attr_accessor :annotations
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @annotations = args[:annotations] if args.key?(:annotations)
        end
      end
      
      # The identification of a Knowledge Graph (KG) entity in Legos.
      class YoutubeDiscoveryLegosLegosEntity
        include Google::Apis::Core::Hashable
      
        # DO NOT USE THIS FIELD. The entity name here can be random garbage and when it'
        # s actually a name it will be in a random language (most of the time English
        # but not always). This field is going away soon. For a replacement you should
        # probably use the following RPC: cs/symbol:Ytpedia.GetNames please read go/ytks-
        # calling details on how to call it and don't hesitate to write to us for help
        # with this (or in any case before starting to send real traffic to us) at: g/yt-
        # knowledge-service
        # Corresponds to the JSON property `debugName`
        # @return [String]
        attr_accessor :debug_name
      
        # The ID of the Knowledge Graph entity. Note: this is the primary ID at
        # generation time. See https://sites.google.com/a/google.com/knowledge-graph/
        # data/primary_ids
        # Corresponds to the JSON property `kgId`
        # @return [String]
        attr_accessor :kg_id
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @debug_name = args[:debug_name] if args.key?(:debug_name)
          @kg_id = args[:kg_id] if args.key?(:kg_id)
        end
      end
      
      # Description of a format Legos annotation. http://go/legos/formats.md
      class YoutubeDiscoveryLegosLegosFormatRelationship
        include Google::Apis::Core::Hashable
      
        # Format classification confidence score, in the 0-1 range. A score of XX% means
        # that we expect at least XX% of the documents annotated with this format to be
        # correctly annotated; i.e. thresholding at XX% yields a precision of at least
        # XX%.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
        end
      end
      
      # Description of a semantic Legos annotation. http://go/legos/project.md#
      # semantic-intent-annotations
      class YoutubeDiscoveryLegosLegosSemanticRelationship
        include Google::Apis::Core::Hashable
      
        # Confidence score. Thresholding at the confidence score at 0.XX yields
        # annotations of precision of at least XX%. Only filled in the intent definition
        # Legos. Please use IsSemanticAnnotationAtConfidenceThreshold() from video/
        # youtube/discovery/legos/annotations/public/legos_annotations_util.h to obtain
        # only intent definition Legos. For more information on the migration please
        # look at go/legos-intent-migration.
        # Corresponds to the JSON property `confidence`
        # @return [Float]
        attr_accessor :confidence
      
        # 
        # Corresponds to the JSON property `contexts`
        # @return [Array<Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosSemanticRelationshipContext>]
        attr_accessor :contexts
      
        # DEPRECATED. Please use confidence instead. Will be set to the same value as
        # confidence in early January 2019. See go/legos-intent-migration for more
        # information.
        # Corresponds to the JSON property `topicalityScore`
        # @return [Float]
        attr_accessor :topicality_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @confidence = args[:confidence] if args.key?(:confidence)
          @contexts = args[:contexts] if args.key?(:contexts)
          @topicality_score = args[:topicality_score] if args.key?(:topicality_score)
        end
      end
      
      # Extra context about how the entity relates to the document. Typically vertical-
      # specific.
      class YoutubeDiscoveryLegosLegosSemanticRelationshipContext
        include Google::Apis::Core::Hashable
      
        # The identification of a Knowledge Graph (KG) entity in Legos.
        # Corresponds to the JSON property `subject`
        # @return [Google::Apis::ContentwarehouseV1::YoutubeDiscoveryLegosLegosEntity]
        attr_accessor :subject
      
        # The type of semantic relationship between the document and the entity. This
        # allows one to retrieve vertical-specific fine-grained information about the
        # document.
        # Corresponds to the JSON property `type`
        # @return [String]
        attr_accessor :type
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @subject = args[:subject] if args.key?(:subject)
          @type = args[:type] if args.key?(:type)
        end
      end
      
      # Description of a taxonomic Legos annotation. http://go/legos/project.md#
      # taxonomy-annotations
      class YoutubeDiscoveryLegosLegosTaxonomicRelationship
        include Google::Apis::Core::Hashable
      
        # Set to true if the taxonomy annotation is redundant amongst the set of other
        # taxonomy annotations for the same document, i.e. if there is at least one
        # other taxonomy annotation that is a child node of this one.
        # Corresponds to the JSON property `isRedundant`
        # @return [Boolean]
        attr_accessor :is_redundant
        alias_method :is_redundant?, :is_redundant
      
        # A score, in the 0-1 range, used to rank taxonomy annotations.
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @is_redundant = args[:is_redundant] if args.key?(:is_redundant)
          @score = args[:score] if args.key?(:score)
        end
      end
      
      # Blarney Stone classification scores: go/blarneystone Next available ID: 6
      class YoutubeDistillerBlarneyStoneScores
        include Google::Apis::Core::Hashable
      
        # 
        # Corresponds to the JSON property `familySafeV1Score`
        # @return [Float]
        attr_accessor :family_safe_v1_score
      
        # 
        # Corresponds to the JSON property `mildHateHarassV1Score`
        # @return [Float]
        attr_accessor :mild_hate_harass_v1_score
      
        # 
        # Corresponds to the JSON property `mildHateHarassV2Score`
        # @return [Float]
        attr_accessor :mild_hate_harass_v2_score
      
        # The scores corresponds to each of the abe_models in /cns/yk-d/home/
        # blarneystone/model0/config-2015-11-20.pbtxt
        # Corresponds to the JSON property `modelScores`
        # @return [Array<Google::Apis::ContentwarehouseV1::YoutubeDistillerModelScore>]
        attr_accessor :model_scores
      
        # 
        # Corresponds to the JSON property `severeHateHarassV1Score`
        # @return [Float]
        attr_accessor :severe_hate_harass_v1_score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @family_safe_v1_score = args[:family_safe_v1_score] if args.key?(:family_safe_v1_score)
          @mild_hate_harass_v1_score = args[:mild_hate_harass_v1_score] if args.key?(:mild_hate_harass_v1_score)
          @mild_hate_harass_v2_score = args[:mild_hate_harass_v2_score] if args.key?(:mild_hate_harass_v2_score)
          @model_scores = args[:model_scores] if args.key?(:model_scores)
          @severe_hate_harass_v1_score = args[:severe_hate_harass_v1_score] if args.key?(:severe_hate_harass_v1_score)
        end
      end
      
      # Next available ID: 4
      class YoutubeDistillerModelScore
        include Google::Apis::Core::Hashable
      
        # The classifier trained with tensor flow.
        # Corresponds to the JSON property `classifier`
        # @return [String]
        attr_accessor :classifier
      
        # The model trained with dist belief [going to be deprecated].
        # Corresponds to the JSON property `model`
        # @return [String]
        attr_accessor :model
      
        # 
        # Corresponds to the JSON property `score`
        # @return [Float]
        attr_accessor :score
      
        def initialize(**args)
           update!(**args)
        end
      
        # Update properties of this object
        def update!(**args)
          @classifier = args[:classifier] if args.key?(:classifier)
          @model = args[:model] if args.key?(:model)
          @score = args[:score] if args.key?(:score)
        end
      end
    end
  end
end
